/******************************************************************************

         Copyright (c) 2020 Intel Corporation

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

*******************************************************************************/

#ifndef _DSL_MGMT_UBUS_INTERFACE_H_
#define _DSL_MGMT_UBUS_INTERFACE_H_

#include <libubox/blobmsg.h>

/* Get supported objects names.

   \param pObjectsNames     Pointer to array of strings [O],
   \param pUbusObject       Pointer to number of objects [O].

   \return  0 on success,
            -1 on any error including not supported Ubus framework.
*/
int DSL_ST_UbusObjectsGet(
   char ***pObjectsNames,
   unsigned int *pObjectsNamesNum
);

/* Get object supported methods names
   and number of object instances.

   \param pObjectName         Name of object [I],
   \param pObjectMethods      Pointer to array of strings [O],
   \param pObjectMethodsNum   Pointer to number of methods [O],
   \param pObjectNum          Pointer to number of instances of object [O].

   \return  0 on success,
            -1 on any error including not supported Ubus framework.
*/
int DSL_ST_UbusObjectsDetailsGet(
   const char *pObjectName,
   char ***pObjectMethods,
   unsigned int *pObjectMethodsNum,
   unsigned int *pObjectNum
);

/* Get DSL Status matching specific Ubus instance,
   e.g. dsl.line.0 info

   \param pObjectName         Name of object [I],
   \param pMethodName         Name of method [I],
   \param nObjectNum          Number of object instance [I],
   \param nChannelLineNum     Number of line (only for channel object) [I],
   \param pData               Pointer to UBUS data [O],
   \param bSubscriptionMode   Indication of working mode [I].

   \return  0 on success,
            -1 on any error including not supported Ubus framework.
*/
int DSL_ST_UbusDataGet(
   const char *pObjectName,
   const char *pMethodName,
   const unsigned int nObjectNum,
   const unsigned int nChannelLineNum,
   struct blob_buf *pData,
   const bool bSubscriptionMode
);

#endif /* _DSL_MGMT_UBUS_INTERFACE_H_ */
