/******************************************************************************

         Copyright (c) 2020 Intel Corporation

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

*******************************************************************************/

#ifndef _DSL_MGMT_MANAGER_H_
#define _DSL_MGMT_MANAGER_H_

#ifdef HAVE_CONFIG_H
#include "dsl_cpe_config.h"
#endif

#include <stdio.h>      /* fprintf */

#if defined(INCLUDE_DSL_STATUS_UBUS_SUPPORT) && (INCLUDE_DSL_STATUS_UBUS_SUPPORT == 1)
#define DSL_MNGR_UBUS_SUPPORT 1
#else
#define DSL_MNGR_UBUS_SUPPORT 0
#endif /* defined(INCLUDE_DSL_UBUS_SUPPORT) && (INCLUDE_DSL_UBUS_SUPPORT == 0) */

#if defined(DSL_MNGR_UBUS_SUPPORT) && (DSL_MNGR_UBUS_SUPPORT == 1)
#include <stdarg.h>     /* va_list */
#include <libubox/uloop.h>
#include <libubox/blobmsg.h>
#include <libubus.h>
#endif /* defined(DSL_MNGR_UBUS_SUPPORT) && (DSL_MNGR_UBUS_SUPPORT == 1) */

#define DSL_MNGR_PREFIX "DSL_MNGR: "
#define DSL_MNGR_CRLF "\n"

#if defined(DSL_MNGR_UBUS_SUPPORT) && (DSL_MNGR_UBUS_SUPPORT == 1)

/**********************************************/
/* typedefs                                   */
/**********************************************/

typedef enum {
   DSL_MNGR_CHANNEL_METHOD_ARG_LINE,
   __DSL_MNGR_CHANNEL_METHOD_ARG_MAX,
} DSL_MNGR_ChannelMethodPolicy_t;

typedef enum {
   DSL_MNGR_LOG_LEVEL_FIRST = 0,
   DSL_MNGR_LOG_LEVEL_DEBUG = 0,
   DSL_MNGR_LOG_LEVEL_INFO,
   DSL_MNGR_LOG_LEVEL_WARNING,
   DSL_MNGR_LOG_LEVEL_ERROR,
   DSL_MNGR_LOG_LEVEL_LAST
} DSL_MNGR_LogLevel_t;

/**********************************************/
/* external declarations                      */
/**********************************************/

extern struct blobmsg_policy
   DSL_MNGR_ChannelMethodPolicy[__DSL_MNGR_CHANNEL_METHOD_ARG_MAX];

extern DSL_MNGR_LogLevel_t nLogLevel;

/**********************************************/
/* global function declarations               */
/**********************************************/

void DSL_MNGR_LogError(
   const char* msg,
   ...
);

void DSL_MNGR_LogWarning(
   const char* msg,
   ...
);

void DSL_MNGR_LogInfo(
   const char* msg,
   ...
);

void DSL_MNGR_LogDebug(
   const char* msg,
   ...
);

/**********************************************/
/* global function definitions                */
/**********************************************/

/**
   Prints message to stdout according to log level.

   \param level			Log level on which message will be printed, [I]
   \param msg			Message to be printed, [I]
   \param args			list of arguments to be printed. [I]

   \return  none
*/
inline void DSL_MNGR_Log(
   const DSL_MNGR_LogLevel_t level,
   const char* msg,
   va_list args)
{
   if (level >= nLogLevel)
   {
      vfprintf(stdout, msg, args);
   }
}

#endif /* defined(DSL_MNGR_UBUS_SUPPORT) && (DSL_MNGR_UBUS_SUPPORT == 1) */

#endif /* _DSL_MGMT_MANAGER_H_ */
