/******************************************************************************

         Copyright (c) 2019 - 2020 Intel Corporation

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

*******************************************************************************/

#ifndef _DSL_MGMT_STATUS_PARSER_H
#define _DSL_MGMT_STATUS_PARSER_H

#if defined(DSL_VRX_DEVICE_VRX518) || defined(DSL_GFAST_DEVICE_VRX618)

#if defined(DSL_VRX_DEVICE_VRX518)
/* VRX518 */
#include "dsl_cpe_control.h"
#elif defined(DSL_GFAST_DEVICE_VRX618)
/* VRX618 */
#include "lib_dsl_api.h"
#endif /* VRX518/VRX618 */

#if defined(INCLUDE_DSL_STATUS_PARSER) && (INCLUDE_DSL_STATUS_PARSER == 1)

#if defined(DSL_VRX_DEVICE_VRX518)
/* VRX518 */
#define DSL_ST_Context_t DSL_CPE_Control_Context_t
#elif defined(DSL_GFAST_DEVICE_VRX618)
/* VRX618 */
#define DSL_ST_Context_t DSL_Context_t
#endif /* VRX518/VRX618 */

/**
   Definitions for all specified Status File nodes
   (these definitions will be used for different
   type parameters' updates)
*/
typedef enum
{
   DSL_ROOT = 0,
   /* common section */
   DSL_LINE_ENTRIES,/*1*/
   DSL_CHANNEL_ENTRIES,/*2*/
   DSL_BND_GROUP_ENTRIES,/*3*/
   DSL_API_VERSION,/*4*/
   DSL_DRV_VERSION,/*5*/
   DSL_HW_VERSION,/*6*/
   DSL_CHIPSET_TYPE,/*7*/
   /* <dsl.status> section */
   DSL_STATUS,/*8*/
   DSL_STATUS_LINE,/*9*/
      /* <dsl.status.line.[id]> section */
      DSL_STATUS_LINE_ID,
      DSL_STATUS_LINE_STATUS,
      DSL_STATUS_LINE_UPSTREAM,
      DSL_STATUS_LINE_FW_VERSION,
      DSL_STATUS_LINE_LINK_STATUS,
      DSL_STATUS_LINE_STD_SUPPORTED,
      DSL_STATUS_LINE_XTSE,
      DSL_STATUS_LINE_STD_USED,
      DSL_STATUS_LINE_XTSE_USED,
      DSL_STATUS_LINE_ENCODING,
      DSL_STATUS_LINE_ALLOWED_PROFILES,
      DSL_STATUS_LINE_CURRENT_PROFILE,
      DSL_STATUS_LINE_PWR_MGMT_STATE,
      DSL_STATUS_LINE_SUCC_FAIL_CAUSE,
      DSL_STATUS_LINE_LAST_STATE_TRANSM,
      DSL_STATUS_LINE_LAST_STATE_TRANSM_US,
      DSL_STATUS_LINE_LAST_STATE_TRANSM_DS,
      DSL_STATUS_LINE_US0_MASK,
      DSL_STATUS_LINE_TRELLIS,
      DSL_STATUS_LINE_TRELLIS_US,
      DSL_STATUS_LINE_TRELLIS_DS,
      DSL_STATUS_LINE_ACT_SNR_MODE,
      DSL_STATUS_LINE_ACT_SNR_MODE_US,
      DSL_STATUS_LINE_ACT_SNR_MODE_DS,
      DSL_STATUS_LINE_LINE_NR,
      DSL_STATUS_LINE_MAX_BIT_RATE,
      DSL_STATUS_LINE_MAX_BIT_RATE_US,
      DSL_STATUS_LINE_MAX_BIT_RATE_DS,
      DSL_STATUS_LINE_NOISE_MARGIN,
      DSL_STATUS_LINE_NOISE_MARGIN_US,
      DSL_STATUS_LINE_NOISE_MARGIN_DS,
      DSL_STATUS_LINE_SNR_MPB,
      DSL_STATUS_LINE_SNR_MPB_US,
      DSL_STATUS_LINE_SNR_MPB_DS,
      DSL_STATUS_LINE_POWER,
      DSL_STATUS_LINE_POWER_US,
      DSL_STATUS_LINE_POWER_DS,
      DSL_STATUS_LINE_XTUR_VENDOR,
      DSL_STATUS_LINE_XTUR_COUNTRY,
      DSL_STATUS_LINE_XTUR_ANSI_STD,
      DSL_STATUS_LINE_XTUR_ANSI_REV,
      DSL_STATUS_LINE_XTUC_VENDOR,
      DSL_STATUS_LINE_XTUC_COUNTRY,
      DSL_STATUS_LINE_XTUC_ANSI_STD,
      DSL_STATUS_LINE_XTUC_ANSI_REV,
#if defined(DSL_VRX_DEVICE_VRX518)
      DSL_STATUS_LINE_UPBOKLER,
#endif /* defined(DSL_VRX_DEVICE_VRX518) */
      DSL_STATUS_LINE_UPBOKLER_PB,
      DSL_STATUS_LINE_RXTHRSH_DS,
      DSL_STATUS_LINE_ACT_RA_MODE,
      DSL_STATUS_LINE_ACT_RA_MODE_US,
      DSL_STATUS_LINE_ACT_RA_MODE_DS,
      DSL_STATUS_LINE_SNR_MROC,
      DSL_STATUS_LINE_SNR_MROC_US,
      DSL_STATUS_LINE_SNR_MROC_DS,
      DSL_STATUS_LINE_ATTENUATION,
      DSL_STATUS_LINE_ATTENUATION_US,
      DSL_STATUS_LINE_ATTENUATION_DS,
#if defined(DSL_VRX_DEVICE_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION)
      DSL_STATUS_LINE_MFD_BASIC_DATA,
      DSL_STATUS_LINE_MFD_BASIC_DATA_FILTER_DETECTION,
      DSL_STATUS_LINE_MFD_BASIC_DATA_METRIC3,
#endif /* defined(DSL_VRX_DEVICE_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION) */
      DSL_STATUS_LINE_CHANNEL,
         /* <dsl.status.line.[id].channel.[id]> section */
         DSL_STATUS_LINE_CHANNEL_ID,
         DSL_STATUS_LINE_CHANNEL_STATUS,
         DSL_STATUS_LINE_CHANNEL_LINKENC_SUPP,
         DSL_STATUS_LINE_CHANNEL_LINKENC_USED,
         DSL_STATUS_LINE_CHANNEL_LPATH,
         DSL_STATUS_LINE_CHANNEL_INTLVDEPTH,
         DSL_STATUS_LINE_CHANNEL_INTLVBLOCK,
         DSL_STATUS_LINE_CHANNEL_ACT_INTERL_DELAY,
         DSL_STATUS_LINE_CHANNEL_ACTINP,
         DSL_STATUS_LINE_CHANNEL_INPREPORT,
         DSL_STATUS_LINE_CHANNEL_NFEC,
         DSL_STATUS_LINE_CHANNEL_RFEC,
         DSL_STATUS_LINE_CHANNEL_LSYMB,
         DSL_STATUS_LINE_CHANNEL_DATARATE,
         DSL_STATUS_LINE_CHANNEL_DATARATE_US,
         DSL_STATUS_LINE_CHANNEL_DATARATE_DS,
         DSL_STATUS_LINE_CHANNEL_ACTNDR,
         DSL_STATUS_LINE_CHANNEL_ACTNDR_US,
         DSL_STATUS_LINE_CHANNEL_ACTNDR_DS,
         DSL_STATUS_LINE_CHANNEL_ACTINPREIN,
         DSL_STATUS_LINE_CHANNEL_ACTINPREIN_US,
         DSL_STATUS_LINE_CHANNEL_ACTINPREIN_DS,
#if defined(DSL_VRX_DEVICE_VRX518)
   DSL_STATUS_BND_GROUP,
      /* <dsl.status.bonding_group.[id]> section */
      DSL_STATUS_BND_GROUP_ID,
      DSL_STATUS_BND_GROUP_BOND_SCHEMES_SUPPORTED,
      DSL_STATUS_BND_GROUP_BOND_SCHEME,
      DSL_STATUS_BND_GROUP_DATARATE,
      DSL_STATUS_BND_GROUP_DATARATE_US,
      DSL_STATUS_BND_GROUP_DATARATE_DS,
#endif /* defined(DSL_VRX_DEVICE_VRX518) */
#if defined(DSL_GFAST_DEVICE_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
   /* <dsl.status.fast> section */
   DSL_STATUS_FAST,
   DSL_STATUS_FAST_LINE,
      /* <dsl.status.fast.line.[id]> section */
      DSL_STATUS_FAST_LINE_ID,
      DSL_STATUS_FAST_LINE_ALLOWED_PROFILES,
      DSL_STATUS_FAST_LINE_CURRENT_PROFILE,
      DSL_STATUS_FAST_LINE_SNRMRMC,
      DSL_STATUS_FAST_LINE_SNRMRMC_US,
      DSL_STATUS_FAST_LINE_SNRMRMC_DS,
      DSL_STATUS_FAST_LINE_BITSRMCPS,
      DSL_STATUS_FAST_LINE_BITSRMCPS_US,
      DSL_STATUS_FAST_LINE_BITSRMCPS_DS,
      DSL_STATUS_FAST_LINE_MINEFTR,
#endif /* defined(DSL_GFAST_DEVICE_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */
   /* <dsl.stats> section */
   DSL_STATS,
   DSL_STATS_LINE,
      /* <dsl.stats.line.[id]> section */
      DSL_STATS_LINE_ID,
      DSL_STATS_LINE_TOTAL_START,
      DSL_STATS_LINE_SHOWTIME_START,
      DSL_STATS_LINE_LAST_SHOWTIME_START,
      DSL_STATS_LINE_CURRENT_DAY_START,
      DSL_STATS_LINE_QUARTER_HOUR_START,
      DSL_STATS_LINE_TOTAL,
      DSL_STATS_LINE_TOTAL_ERR_SECS,
      DSL_STATS_LINE_TOTAL_SEV_ERR_SECS,
      DSL_STATS_LINE_SHOWTIME,
      DSL_STATS_LINE_SHOWTIME_ERR_SECS,
      DSL_STATS_LINE_SHOWTIME_SEV_ERR_SECS,
      DSL_STATS_LINE_LAST_SHOWTIME,
      DSL_STATS_LINE_LAST_SHOWTIME_ERR_SECS,
      DSL_STATS_LINE_LAST_SHOWTIME_SEV_ERR_SECS,
      DSL_STATS_LINE_CURRENT_DAY,
      DSL_STATS_LINE_CURRENT_DAY_ERR_SECS,
      DSL_STATS_LINE_CURRENT_DAY_SEV_ERR_SECS,
      DSL_STATS_LINE_QUARTER_HOUR,
      DSL_STATS_LINE_QUARTER_HOUR_ERR_SECS,
      DSL_STATS_LINE_QUARTER_HOUR_SEV_ERR_SECS,
      DSL_STATS_LINE_CHANNEL,
         /* <dsl.stats.line.[id].channel.[id]> section */
         DSL_STATS_LINE_CHANNEL_ID,
         DSL_STATS_LINE_CHANNEL_TOTAL_START,
         DSL_STATS_LINE_CHANNEL_SHOWTIME_START,
         DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_START,
         DSL_STATS_LINE_CHANNEL_CURRENT_DAY_START,
         DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_START,
         DSL_STATS_LINE_CHANNEL_TOTAL,
         DSL_STATS_LINE_CHANNEL_TOTAL_XTUR_FEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_TOTAL_XTUR_CRC_ERRORS,
         DSL_STATS_LINE_CHANNEL_TOTAL_XTUC_FEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_TOTAL_XTUC_CRC_ERRORS,
         DSL_STATS_LINE_CHANNEL_TOTAL_XTUR_HEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_TOTAL_XTUC_HEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_SHOWTIME,
         DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUR_FEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUR_CRC_ERRORS,
         DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUC_FEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUC_CRC_ERRORS,
         DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUR_HEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUC_HEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME,
         DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUR_FEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUR_CRC_ERRORS,
         DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUC_FEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUC_CRC_ERRORS,
         DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUR_HEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUC_HEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_CURRENT_DAY,
         DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUR_FEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUR_CRC_ERRORS,
         DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUC_FEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUC_CRC_ERRORS,
         DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUR_HEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUC_HEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_QUARTER_HOUR,
         DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUR_FEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUR_CRC_ERRORS,
         DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUC_FEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUC_CRC_ERRORS,
         DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUR_HEC_ERRORS,
         DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUC_HEC_ERRORS,
#if defined(DSL_GFAST_DEVICE_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
   DSL_STATS_FAST,
   DSL_STATS_FAST_LINE,
      /* <dsl.stats.fast.line.[id]> section */
      DSL_STATS_FAST_LINE_ID,
      DSL_STATS_FAST_LINE_TOTAL,
      DSL_STATS_FAST_LINE_TOTAL_SUCCESS_BSW,
      DSL_STATS_FAST_LINE_TOTAL_SUCCESS_SRA,
      DSL_STATS_FAST_LINE_TOTAL_SUCCESS_FRA,
      DSL_STATS_FAST_LINE_TOTAL_SUCCESS_RPA,
      DSL_STATS_FAST_LINE_TOTAL_SUCCESS_TIGA,
      DSL_STATS_FAST_LINE_SHOWTIME,
      DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_BSW,
      DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_SRA,
      DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_FRA,
      DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_RPA,
      DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_TIGA,
      DSL_STATS_FAST_LINE_LAST_SHOWTIME,
      DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_BSW,
      DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_SRA,
      DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_FRA,
      DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_RPA,
      DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_TIGA,
#endif /* defined(DSL_GFAST_DEVICE_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */
   DSL_CONFIGURATION,
      DSL_CONFIGURATION_STATUS
} DSL_ST_StatusNodeIdx_t;

typedef enum
{
   DSL_ST_STATUS,
   DSL_ST_STATISTICS,
   DSL_ST_CONFIGURATION
} DSL_ST_StatusSectionIdx_t;

/**
   This function creates the initial Status File
   and updates the init parameters values

   \param pContext   - Pointer to dsl library context structure, [I]

   \return
   Return values are defined within the DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
DSL_Error_t DSL_ST_DslStatusInitialize(
   DSL_ST_Context_t *pContext);

/**
   This function updates Status File parameters
   triggered by events

   \param pContext   - Pointer to dsl library context structure, [I]

   \return
   Return values are defined within the DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
DSL_Error_t DSL_ST_DslStatusEvtUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   DSL_uint16_t nLine,
   DSL_uint8_t nChannel);

/**
   This function updates Status File parameters
   triggered by the polling timer

   \param pContext   - Pointer to dsl library context structure, [I]

   \return
   Return values are defined within the DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
DSL_Error_t DSL_ST_DslStatusPollUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusSectionIdx_t ePollSectionIdx);

/**
   This function frees Status File related
   dynamically allocated resources
*/
DSL_void_t DSL_ST_DslStatusResourcesFree(
   DSL_void_t);

#endif /* defined(INCLUDE_DSL_STATUS_PARSER) && (INCLUDE_DSL_STATUS_PARSER == 1) */
#endif /* defined(DSL_VRX_DEVICE_VRX518) || defined(DSL_GFAST_DEVICE_VRX618) */

#endif /* _DSL_MGMT_STATUS_PARSER_H */
