/******************************************************************************

         Copyright (c) 2020 Intel Corporation

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

*******************************************************************************/

#ifndef _DSL_MGMT_STATUS_UBUS_H
#define _DSL_MGMT_STATUS_UBUS_H

#if defined(DSL_VRX_DEVICE_VRX518)

#include "dsl_mgmt_status_definitions.h"

#if defined(INCLUDE_DSL_STATUS_UBUS_SUPPORT) && (INCLUDE_DSL_STATUS_UBUS_SUPPORT == 1)

/**
   Create and initialize internal data.

   \return  0 on success,
            -1 on any error.
*/
DSL_Error_t DSL_ST_UbusInit();

/**
   Updates status parameter in Ubus Module's internal data structure.

   \param eNodeIdx      status node index [I]
   \param nLine         line number [I]
   \param nChannel      channel number [I]
   \param eParamType    redundant? [I]
   \param uValue        new value [I]

   \return  0 on success,
            -1 on any error.
*/
DSL_Error_t DSL_ST_UbusUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nLine,
   const DSL_uint8_t nChannel,
   const DSL_ST_StatusNodeType_t eParamType,
   const DSL_ST_ParamValue_t *uValue
);

/**
   Finalize update process.
   Prepare data to be provided for DSL Manager.

   \return  0 on success,
            -1 on any error.
*/
DSL_Error_t DSL_ST_UbusSync(DSL_void_t);

/**
   Free acquired resources.

   \return  0 on success,
            -1 on any error.
*/
DSL_Error_t DSL_ST_UbusDeinit(DSL_void_t);

#endif /* defined(INCLUDE_DSL_STATUS_UBUS_SUPPORT) && (INCLUDE_DSL_STATUS_UBUS_SUPPORT == 1) */
#endif /* defined(DSL_VRX_DEVICE_VRX518) */

#endif /* _DSL_MGMT_STATUS_UBUS_H */
