/******************************************************************************

         Copyright (c) 2019 - 2020 Intel Corporation

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

*******************************************************************************/
#if defined(DSL_VRX_DEVICE_VRX518) || defined(DSL_GFAST_DEVICE_VRX618)

#if defined(DSL_VRX_DEVICE_VRX518)
/* VRX518 */
#include "dsl_cpe_control.h"
#elif defined(DSL_GFAST_DEVICE_VRX618)
/* VRX618 */
#include "lib_dsl_api.h"
#endif /* VRX518/VRX618 */

#if defined(INCLUDE_DSL_STATUS_PARSER) && (INCLUDE_DSL_STATUS_PARSER == 1)

#define DSL_ST_DEBUG_MODE 0

#include "dsl_mgmt_status_parser.h"
#include "dsl_mgmt_status_definitions.h"
#include "dsl_mgmt_status_json.h"
#if defined(DSL_ST_PLATFORM_VRX518)
#include "dsl_mgmt_status_ubus.h"
#include "drv_dsl_cpe_api_ioctl.h"
#include "drv_dsl_cpe_api.h"
#include "dsl_cpe_bnd_vrx.h"
#elif defined(DSL_ST_PLATFORM_VRX618)
#if (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
#include "lib_dsl_api_fast.h"
#endif /* (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */
#else
#error DSL Status Parser - platform not supported!
#endif

/* TODO: unify printing for VRX518 and VRX618 */
#if defined(DSL_ST_PLATFORM_VRX518)
#undef DSL_CCA_DBG_BLOCK
#define DSL_CCA_DBG_BLOCK DSL_CCA_DBG_APP
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

/*
   Status param definition
*/
typedef struct DSL_ST_StatusParam_t
{
   const DSL_ST_StatusNode_t *pStatusNode;
   DSL_uint16_t nLine;
   DSL_uint8_t nChannel;
   DSL_uint8_t nBndGroup;
   struct DSL_ST_StatusParam_t* pNext;
} DSL_ST_StatusParamsList_t;
static DSL_uint32_t nParamsNum = 0;

/*
   Handle for the main list of all actual status params according to the
   actual number of devices, channels, bonding groups etc. configured in
   the system, to be used as a basis for all status update operations.
   To be created on the basis of statusNodesArray[] (that is a template only)
*/
static DSL_ST_StatusParamsList_t *pAllStatusParams = DSL_NULL;

/*
   Call flags definitions
*/
typedef enum {
   DSL_ST_FLAG_LINE_STATE_GET,
   DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_CONFIG_GET,
   DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_STATUS_GET,
   DSL_ST_FLAG_BAND_PLAN_SUPPORT_GET,
   DSL_ST_FLAG_BAND_PLAN_STATUS_GET,
   DSL_ST_FLAG_G997_POWER_MANAGEMENT_STATUS_GET,
   DSL_ST_FLAG_G997_LINE_INIT_STATUS_GET,
   DSL_ST_FLAG_G997_LAST_STATE_TRANSMITTED_GET,
   DSL_ST_FLAG_LINE_FEATURE_STATUS_GET,
   DSL_ST_FLAG_G997_LINE_STATUS_GET,
   DSL_ST_FLAG_G997_LINE_STATUS_PER_BAND_GET,
   DSL_ST_FLAG_G997_LINE_INVENTORY_GET,
   DSL_ST_FLAG_G997_US_POWER_BACK_OFF_STATUS_GET,
   DSL_ST_FLAG_G997_RATE_ADAPTATION_STATUS_GET,
   DSL_ST_FLAG_G997_CHANNEL_STATUS_GET,
#if defined(DSL_ST_PLATFORM_VRX518)
   DSL_ST_FLAG_SYSTEM_INTERFACE_CONFIG_GET,
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
   DSL_ST_FLAG_SYSTEM_INTERFACE_STATUS_GET,
   DSL_ST_FLAG_G997_FRAMING_PARAMETER_STATUS_GET,
   DSL_ST_FLAG_PM_CHANNEL_COUNTERS_TOTAL_GET,
   DSL_ST_FLAG_PM_CHANNEL_COUNTERS_SHOWTIME_GET,
   DSL_ST_FLAG_PM_LINE_INIT_COUNTERS_1DAY_GET,
   DSL_ST_FLAG_PM_CHANNEL_COUNTERS_15MIN_GET,
   DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_TOTAL_GET,
   DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_SHOWTIME_GET,
   DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_1DAY_GET,
   DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_15MIN_GET,
   DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_TOTAL_GET,
   DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_SHOWTIME_GET,
   DSL_ST_FLAG_PM_CHANNEL_COUNTERS_1DAY_GET,
   DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_1DAY_GET,
   DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_15MIN_GET,
#if defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION)
   DSL_ST_FLAG_FILTER_DETECTION_BASIC_DATA_GET,
#endif /* defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION) */
#if defined(DSL_ST_PLATFORM_VRX518)
   DSL_ST_FLAG_BND_CONFIG_GET,
   DSL_ST_FLAG_BND_STATUS_GET,
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
#if defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
   DSL_ST_FLAG_FAST_PROFILE_CONFIG_GET,
   DSL_ST_FLAG_FAST_PROFILE_STATUS_GET,
   DSL_ST_FLAG_FAST_LINE_STATUS_GET,
   DSL_ST_FLAG_FAST_RMC_BIT_ALLOCATION_TABLE_GET,
   DSL_ST_FLAG_FAST_RETRANS_COUNTERS_TOTAL_GET,
   DSL_ST_FLAG_FAST_OLR_STATISTICS_TOTAL_GET,
   DSL_ST_FLAG_FAST_OLR_COUNTERS_SHOWTIME_GET
#endif /* defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */
} DSL_ST_CallFlag_t;

/*
   Call flag struct declaration
   (needed to avoid redundand API functions calls
   for grouped parameters)
*/
typedef struct {
   const DSL_ST_CallFlag_t eCallFlag;
   DSL_boolean_t bIsSet;
} DSL_ST_CallFlagSwitch_t;

/*
   Call flags definitions (separate flag for each call
   that provides information for more then one parameter),
   initially set to FALSE
*/
static DSL_ST_CallFlagSwitch_t callFlags[] =
{
   { DSL_ST_FLAG_LINE_STATE_GET, DSL_FALSE },
   { DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_CONFIG_GET, DSL_FALSE },
   { DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_STATUS_GET, DSL_FALSE },
   { DSL_ST_FLAG_BAND_PLAN_SUPPORT_GET, DSL_FALSE },
   { DSL_ST_FLAG_BAND_PLAN_STATUS_GET, DSL_FALSE },
   { DSL_ST_FLAG_G997_POWER_MANAGEMENT_STATUS_GET, DSL_FALSE },
   { DSL_ST_FLAG_G997_LINE_INIT_STATUS_GET, DSL_FALSE },
   { DSL_ST_FLAG_G997_LAST_STATE_TRANSMITTED_GET, DSL_FALSE },
   { DSL_ST_FLAG_LINE_FEATURE_STATUS_GET, DSL_FALSE },
   { DSL_ST_FLAG_G997_LINE_STATUS_GET, DSL_FALSE },
   { DSL_ST_FLAG_G997_LINE_STATUS_PER_BAND_GET, DSL_FALSE },
   { DSL_ST_FLAG_G997_LINE_INVENTORY_GET , DSL_FALSE },
   { DSL_ST_FLAG_G997_US_POWER_BACK_OFF_STATUS_GET, DSL_FALSE },
   { DSL_ST_FLAG_G997_RATE_ADAPTATION_STATUS_GET, DSL_FALSE },
   { DSL_ST_FLAG_G997_CHANNEL_STATUS_GET, DSL_FALSE },
#if defined(DSL_ST_PLATFORM_VRX518)
   { DSL_ST_FLAG_SYSTEM_INTERFACE_CONFIG_GET, DSL_FALSE },
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
   { DSL_ST_FLAG_SYSTEM_INTERFACE_STATUS_GET, DSL_FALSE },
   { DSL_ST_FLAG_G997_FRAMING_PARAMETER_STATUS_GET, DSL_FALSE },
   { DSL_ST_FLAG_PM_CHANNEL_COUNTERS_TOTAL_GET, DSL_FALSE },
   { DSL_ST_FLAG_PM_CHANNEL_COUNTERS_SHOWTIME_GET, DSL_FALSE },
   { DSL_ST_FLAG_PM_LINE_INIT_COUNTERS_1DAY_GET, DSL_FALSE },
   { DSL_ST_FLAG_PM_CHANNEL_COUNTERS_15MIN_GET, DSL_FALSE },
   { DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_TOTAL_GET, DSL_FALSE },
   { DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_SHOWTIME_GET, DSL_FALSE },
   { DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_1DAY_GET, DSL_FALSE },
   { DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_15MIN_GET, DSL_FALSE },
   { DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_TOTAL_GET, DSL_FALSE },
   { DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_SHOWTIME_GET, DSL_FALSE },
   { DSL_ST_FLAG_PM_CHANNEL_COUNTERS_1DAY_GET, DSL_FALSE },
   { DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_1DAY_GET, DSL_FALSE },
   { DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_15MIN_GET, DSL_FALSE },
#if defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION)
   { DSL_ST_FLAG_FILTER_DETECTION_BASIC_DATA_GET, DSL_FALSE },
#endif /* defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION) */
#if defined(DSL_ST_PLATFORM_VRX518)
   { DSL_ST_FLAG_BND_CONFIG_GET, DSL_FALSE },
   { DSL_ST_FLAG_BND_STATUS_GET, DSL_FALSE },
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
#if defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
   { DSL_ST_FLAG_FAST_PROFILE_CONFIG_GET, DSL_FALSE },
   { DSL_ST_FLAG_FAST_PROFILE_STATUS_GET, DSL_FALSE },
   { DSL_ST_FLAG_FAST_LINE_STATUS_GET, DSL_FALSE },
   { DSL_ST_FLAG_FAST_RMC_BIT_ALLOCATION_TABLE_GET, DSL_FALSE },
   { DSL_ST_FLAG_FAST_RETRANS_COUNTERS_TOTAL_GET, DSL_FALSE },
   { DSL_ST_FLAG_FAST_OLR_STATISTICS_TOTAL_GET, DSL_FALSE },
   { DSL_ST_FLAG_FAST_OLR_COUNTERS_SHOWTIME_GET, DSL_FALSE }
#endif /* defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */
};
static const DSL_uint32_t nFlagsNum =
   sizeof(callFlags) / sizeof(callFlags[0]);

/*
   Unified local definitions for platform
   specific types, constants and functions
*/
#if defined(DSL_ST_PLATFORM_VRX518)
/* types */
#define DSL_ST_Profile_t DSL_ProfileType_t
#define DSL_ST_LineState_t DSL_LineState_t
#define DSL_ST_G997_XTUSystemEnabling_t DSL_G997_XTUSystemEnabling_t
#define DSL_ST_BandPlanSupport_t DSL_BandPlanSupport_t
#define DSL_ST_BandPlanStatus_t DSL_BandPlanStatus_t
#define DSL_ST_PowerManagement_t DSL_G997_PowerManagement_t
#define DSL_ST_PowerManagementStatus_t DSL_G997_PowerManagementStatus_t
#define DSL_ST_G997_LineInitStatus_t DSL_G997_LineInitStatus_t
#define DSL_ST_LastStateTransmitted_t DSL_G997_LastStateTransmitted_t
#define DSL_ST_LineFeature_t DSL_LineFeature_t
#define DSL_ST_G997_LineStatus_t DSL_G997_LineStatus_t
#define DSL_ST_G997_LineStatusPerBand_t DSL_G997_LineStatusPerBand_t
#define DSL_ST_G997_LineInventory_t DSL_G997_LineInventory_t
#define DSL_ST_G997_UsPowerBackOffStatus_t DSL_G997_UsPowerBackOffStatus_t
#define DSL_ST_G997_RateAdaptationStatus_t DSL_G997_RateAdaptationStatus_t
#define DSL_ST_G997_ChannelStatus_t DSL_G997_ChannelStatus_t
#define DSL_ST_G997_FramingParameterStatus_t DSL_G997_FramingParameterStatus_t
#define DSL_ST_PM_ChannelCountersTotal_t DSL_PM_ChannelCountersTotal_t
#define DSL_ST_PM_ChannelCounters_t DSL_PM_ChannelCounters_t
#define DSL_ST_PM_LineInitCounters_t DSL_PM_LineInitCounters_t
#define DSL_ST_PM_LineSecCountersTotal_t DSL_PM_LineSecCountersTotal_t
#define DSL_ST_PM_LineSecCounters_t DSL_PM_LineSecCounters_t
#define DSL_ST_PM_DataPathCountersTotal_t DSL_PM_DataPathCountersTotal_t
#define DSL_ST_PM_DataPathCounters_t DSL_PM_DataPathCounters_t

#elif defined(DSL_ST_PLATFORM_VRX618)
/* types */
#define DSL_ST_Profile_t DSL_Profile_t
#define DSL_ST_LineState_t DSL_LineStateData_t
#define DSL_ST_G997_XTUSystemEnabling_t DSL_G997_XTUSystemEnablingData_t
#define DSL_ST_BandPlanSupport_t DSL_BandPlanSupportData_t
#define DSL_ST_BandPlanStatus_t DSL_BandPlanStatusData_t
#define DSL_ST_PowerManagement_t DSL_G997_PowerManagementState_t
#define DSL_ST_PowerManagementStatus_t DSL_G997_PowerManagementState_t
#define DSL_ST_G997_LineInitStatus_t DSL_G997_LineInitFailureStatus_t
#define DSL_ST_LastStateTransmitted_t DSL_uint32_t
#define DSL_ST_LineFeature_t DSL_LineFeatureData_t
#define DSL_ST_G997_LineStatus_t DSL_G997_LineStatusData_t
#define DSL_ST_G997_LineStatusPerBand_t DSL_G997_LineStatusPerBandData_t
#define DSL_ST_G997_LineInventory_t DSL_G997_LineInventoryData_t
#define DSL_ST_G997_UsPowerBackOffStatus_t DSL_G997_UsPowerBackOffStatusData_t
#define DSL_ST_G997_RateAdaptationStatus_t DSL_G997_RateAdaptationStatusData_t
#define DSL_ST_G997_ChannelStatus_t DSL_G997_ChannelStatusData_t
#define DSL_ST_G997_FramingParameterStatus_t DSL_G997_FramingParameterStatusData_t
#define DSL_ST_PM_ChannelCountersTotal_t DSL_PM_ChannelCountersData_t
#define DSL_ST_PM_ChannelCounters_t DSL_PM_ChannelCountersData_t
#define DSL_ST_PM_LineInitCounters_t DSL_PM_LineInitCountersData_t
#define DSL_ST_PM_LineSecCountersTotal_t DSL_PM_LineSecCountersData_t
#define DSL_ST_PM_LineSecCounters_t DSL_PM_LineSecCountersData_t
#define DSL_ST_PM_DataPathCountersTotal_t DSL_PM_DataPathCountersData_t
#define DSL_ST_PM_DataPathCounters_t DSL_PM_DataPathCountersData_t
#else
#error DSL Status Parser - platform not supported!
#endif

/*
   Additional definitions for internal use
   in the individual params' update functions
*/

/* line status values */
typedef enum
{
    DSL_ST_LINE_NOT_INITIALIZED,
    DSL_ST_LINE_DOWN,
    DSL_ST_LINE_READY,
    DSL_ST_LINE_HANDSHAKE,
    DSL_ST_LINE_TRAINING,
    DSL_ST_LINE_UP,
    DSL_ST_LINE_ERROR,
    DSL_ST_LINE_LDM_ACTIVE,
    DSL_ST_LINE_LDM_COMPLETE
} DSL_ST_LineStatus_t;

/* link status values */
typedef enum
{
   DSL_ST_LINK_ESTABLISHING,
   DSL_ST_LINK_INITIALIZING,
   DSL_ST_LINK_DISABLED,
   DSL_ST_LINK_UP,
   DSL_ST_LINK_ERROR
} DSL_ST_LinkStatus_t;

/* size of link encapsulation status string */
#define DSL_ST_MAX_LINK_ENC_STRING_SIZE 40*sizeof(DSL_char_t)

/* Standards struct declaration for standard parameters */
typedef struct {
   DSL_uint8_t nOctet;
   DSL_uint8_t nBit;
   DSL_char_t *sName;
} DSL_ST_Standarts_t;

/* Available standards definition */
static const DSL_ST_Standarts_t standartsTable[] = {
   { 0, XTSE_1_01_A_T1_413, ",T1.413" },
   { 0, XTSE_1_02_C_TS_101388, ",ETSI_101_388" },
   { 0, XTSE_1_03_A_1_NO | XTSE_1_04_A_1_O, ",G.992.1_Annex_A" },
   { 0, XTSE_1_05_B_1_NO | XTSE_1_06_B_1_O, ",G.992.1_Annex_B" },
   { 0, XTSE_1_07_C_1_NO | XTSE_1_08_C_1_O, ",G.992.1_Annex_C" },

   { 1, XTSE_2_01_A_2_NO, ",G.992.2_Annex_A" },
   { 1, XTSE_2_02_B_2_O, ",G.992.2_Annex_B" },
   { 1, XTSE_2_03_C_2_NO | XTSE_2_04_C_2_O, ",G.992.2_Annex_C" },

   { 2, XTSE_3_03_A_3_NO | XTSE_3_04_A_3_O, ",G.992.3_Annex_A" },
   { 2, XTSE_3_05_B_3_NO | XTSE_3_06_B_3_O, ",G.992.3_Annex_B" },

   { 3, XTSE_4_01_A_4_NO | XTSE_4_02_A_4_O, ",G.992.4_Annex_A" },
   { 3, XTSE_4_05_I_3_NO | XTSE_4_06_I_3_O, ",G.992.3_Annex_I" },
   { 3, XTSE_4_07_J_3_NO | XTSE_4_08_J_3_O, ",G.992.3_Annex_J" },

   { 4, XTSE_5_01_I_4_NO | XTSE_5_02_I_4_O, ",G.992.4_Annex_I" },
   { 4, XTSE_5_03_L_3_NO | XTSE_5_04_L_3_NO, ",G.992.3_Annex_L" },
   { 4, XTSE_5_05_L_3_O | XTSE_5_06_L_3_O, ",G.992.3_Annex_L" },
   { 4, XTSE_5_07_M_3_NO | XTSE_5_08_M_3_O, ",G.992.3_Annex_M" },

   { 5, XTSE_6_01_A_5_NO | XTSE_6_02_A_5_O, ",G.992.5_Annex_A" },
   { 5, XTSE_6_03_B_5_NO | XTSE_6_04_B_5_O, ",G.992.5_Annex_B" },
   { 5, XTSE_6_07_I_5_NO | XTSE_6_08_I_5_O, ",G.992.5_Annex_I" },

   { 6, XTSE_7_01_J_5_NO | XTSE_7_02_J_5_O, ",G.992.5_Annex_J" },
   { 6, XTSE_7_03_M_5_NO | XTSE_7_04_M_5_O, ",G.992.5_Annex_M" },

   { 7, XTSE_8_01_A, ",G.993.2_Annex_A" },
   { 7, XTSE_8_02_B, ",G.993.2_Annex_B" },
   { 7, XTSE_8_03_C, ",G.993.2_Annex_C" },

#if defined(DSL_ST_PLATFORM_VRX618)
   { 8, XTSE_9_01_A_5, ",G.993.5_Annex_A" },
   { 8, XTSE_9_02_B_5, ",G.993.5_Annex_B" },
   { 8, XTSE_9_03_C_5, ",G.993.5_Annex_C" },
   { 8, XTSE_9_04_A_5F, ",G.993.5-friendly-G.993.2_Annex_A" },
   { 8, XTSE_9_05_B_5F, ",G.993.5-friendly-G.993.2_Annex_B" },
   { 8, XTSE_9_06_C_5F, ",G.993.5-friendly-G.993.2_Annex_C" },
   { 8, XTSE_9_08_FST, ",G.Fast" }
#endif /* defined(DSL_ST_PLATFORM_VRX618) */
};
static const DSL_uint32_t nStandardsNum =
   sizeof(standartsTable) / sizeof(standartsTable[0]);

/* Supported profiles definitions */
static const DSL_char_t *profilesTable[] = {
   ",8a",
   ",8b",
   ",8c",
   ",8d",
   ",12a",
   ",12b",
   ",17a",
   ",30a",
#if defined(DSL_ST_PLATFORM_VRX618)
   ",17b",
#endif /* defined(DSL_ST_PLATFORM_VRX618) */
   ",35b"
};

#if defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
/* Supported Fast profiles definitions */
static DSL_char_t *fastProfilesTable[] = {
   ",106a", ",106b", ",106c", ",212a", ",212c" };
static const DSL_uint32_t nFastProfileTableLen =
   sizeof(fastProfilesTable) / sizeof(fastProfilesTable[0]);
#endif /* defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */

#if defined(DSL_ST_PLATFORM_VRX518)
/* Supported bonding schemes */
typedef enum {
   DSL_ST_BND_SCHEME_ATM = 0,
   DSL_ST_BND_SCHEME_PTM
} DSL_ST_BndSchemeType;

typedef struct {
   DSL_ST_BndSchemeType eType;
   DSL_char_t *sName;
} DSL_ST_BndScheme;

static DSL_ST_BndScheme bndSchemeTable[] = {
   { DSL_ST_BND_SCHEME_ATM, ",ATM" },
   { DSL_ST_BND_SCHEME_PTM, ",Ethernet" }
};

static const DSL_uint32_t nBndSchemesNum =
   sizeof(bndSchemeTable) / sizeof(bndSchemeTable[0]);
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

/* Definitions for vendor and country id */
#define DSL_ST_MAX_LEN_VENDOR_ID 4
#define DSL_ST_MAX_LEN_COUNTRY_ID 2

/* Max string length to be written to an output array */
#if defined(MAX_JSON_ARR_STR_LEN)
#define MAX_ARR_STR_LEN MAX_JSON_ARR_STR_LEN
#else
#define MAX_ARR_STR_LEN 512
#endif /* defined(MAX_JSON_ARR_STR_LEN) */

/* Max hex string length to be written to an output array */
#if defined(MAX_JSON_HEX_STR_LEN)
#define MAX_HEX_STR_LEN MAX_JSON_HEX_STR_LEN
#else
#define MAX_HEX_STR_LEN 5
#endif /* defined(MAX_JSON_HEX_STR_LEN) */

/* Definitions for PM counters */
#define DSL_ST_PM_HISTORY_INTERVALS_NUM 2

/*
   Struct to keep all dynamic resources.
   The names of the parameters MUST contain the names
   of the call flags (see DSL_ST_CallFlag_t above) -
   they will be handled via macros.
*/
typedef struct
{
   struct {
      DSL_ST_LineState_t
         *pD_DSL_ST_FLAG_LINE_STATE_GET;
      DSL_ST_G997_XTUSystemEnabling_t
         *pD_DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_CONFIG_GET;
      DSL_ST_G997_XTUSystemEnabling_t
         *pD_DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_STATUS_GET;
      DSL_ST_BandPlanSupport_t
         *pD_DSL_ST_FLAG_BAND_PLAN_SUPPORT_GET;
      DSL_ST_BandPlanStatus_t
         *pD_DSL_ST_FLAG_BAND_PLAN_STATUS_GET;
      DSL_ST_PowerManagementStatus_t
         *pD_DSL_ST_FLAG_G997_POWER_MANAGEMENT_STATUS_GET;
      DSL_ST_G997_LineInitStatus_t
         *pD_DSL_ST_FLAG_G997_LINE_INIT_STATUS_GET;
      DSL_ST_LastStateTransmitted_t
         *pD_DSL_ST_FLAG_G997_LAST_STATE_TRANSMITTED_GET;
      DSL_ST_LineFeature_t
         *pD_DSL_ST_FLAG_LINE_FEATURE_STATUS_GET;
      DSL_ST_G997_LineStatus_t
         *pD_DSL_ST_FLAG_G997_LINE_STATUS_GET;
      DSL_ST_G997_LineStatusPerBand_t
         *pD_DSL_ST_FLAG_G997_LINE_STATUS_PER_BAND_GET;
      DSL_ST_G997_LineInventory_t
         *pD_DSL_ST_FLAG_G997_LINE_INVENTORY_GET;
      DSL_ST_G997_UsPowerBackOffStatus_t
         *pD_DSL_ST_FLAG_G997_US_POWER_BACK_OFF_STATUS_GET;
      DSL_ST_G997_RateAdaptationStatus_t
         *pD_DSL_ST_FLAG_G997_RATE_ADAPTATION_STATUS_GET;
      DSL_ST_G997_ChannelStatus_t
         *pD_DSL_ST_FLAG_G997_CHANNEL_STATUS_GET;
#if defined(DSL_ST_PLATFORM_VRX518)
      DSL_SystemInterfaceConfig_t
         *pD_DSL_ST_FLAG_SYSTEM_INTERFACE_CONFIG_GET;
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
      DSL_ST_G997_XTUSystemEnabling_t
         *pD_DSL_ST_FLAG_SYSTEM_INTERFACE_STATUS_GET;
      DSL_ST_G997_FramingParameterStatus_t
         *pD_DSL_ST_FLAG_G997_FRAMING_PARAMETER_STATUS_GET;
      DSL_ST_PM_ChannelCountersTotal_t
         *pD_DSL_ST_FLAG_PM_CHANNEL_COUNTERS_TOTAL_GET;
      DSL_ST_PM_ChannelCounters_t
         *pD_DSL_ST_FLAG_PM_CHANNEL_COUNTERS_SHOWTIME_GET;
      DSL_ST_PM_LineInitCounters_t
         *pD_DSL_ST_FLAG_PM_LINE_INIT_COUNTERS_1DAY_GET;
      DSL_ST_PM_ChannelCounters_t
         *pD_DSL_ST_FLAG_PM_CHANNEL_COUNTERS_15MIN_GET;
      DSL_ST_PM_LineSecCountersTotal_t
         *pD_DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_TOTAL_GET;
      DSL_ST_PM_LineSecCounters_t
         *pD_DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_SHOWTIME_GET;
      DSL_ST_PM_LineSecCounters_t
         *pD_DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_1DAY_GET;
      DSL_ST_PM_LineSecCounters_t
         *pD_DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_15MIN_GET;
      DSL_ST_PM_DataPathCountersTotal_t
         *pD_DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_TOTAL_GET;
      DSL_ST_PM_DataPathCounters_t
         *pD_DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_SHOWTIME_GET;
      DSL_ST_PM_ChannelCounters_t
         *pD_DSL_ST_FLAG_PM_CHANNEL_COUNTERS_1DAY_GET;
      DSL_ST_PM_DataPathCounters_t
         *pD_DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_1DAY_GET;
      DSL_ST_PM_DataPathCounters_t
         *pD_DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_15MIN_GET;
#if defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION)
      DSL_FilterDetectionBasic_t
         *pD_DSL_ST_FLAG_FILTER_DETECTION_BASIC_DATA_GET;
#endif /* defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION) */
#if defined(DSL_ST_PLATFORM_VRX518)
      DSL_BND_Config_t
         *pD_DSL_ST_FLAG_BND_CONFIG_GET;
      DSL_BND_StatusGet_t
         *pD_DSL_ST_FLAG_BND_STATUS_GET;
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
#if defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
      DSL_FastProfileConfigData_t
         *pD_DSL_ST_FLAG_FAST_PROFILE_CONFIG_GET;
      DSL_FastProfileStatusData_t
         *pD_DSL_ST_FLAG_FAST_PROFILE_STATUS_GET;
      DSL_FastLineStatusData_t
         *pD_DSL_ST_FLAG_FAST_LINE_STATUS_GET;
      DSL_FastBatRmcTable
         *pD_DSL_ST_FLAG_FAST_RMC_BIT_ALLOCATION_TABLE_GET;
      DSL_PM_RetransmissionCountersData_t
         *pD_DSL_ST_FLAG_FAST_RETRANS_COUNTERS_TOTAL_GET;
      DSL_FastOlrStatisticsTotalData_t
         *pD_DSL_ST_FLAG_FAST_OLR_STATISTICS_TOTAL_GET;
      DSL_PM_FastOlrCountersData_t
         *pD_DSL_ST_FLAG_FAST_OLR_COUNTERS_SHOWTIME_GET;
#endif /* defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */
   } sData;
   struct {
      DSL_Error_t
         *pE_DSL_ST_FLAG_LINE_STATE_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_CONFIG_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_STATUS_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_BAND_PLAN_SUPPORT_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_BAND_PLAN_STATUS_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_G997_POWER_MANAGEMENT_STATUS_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_G997_LINE_INIT_STATUS_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_G997_LAST_STATE_TRANSMITTED_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_LINE_FEATURE_STATUS_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_G997_LINE_STATUS_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_G997_LINE_STATUS_PER_BAND_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_G997_LINE_INVENTORY_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_G997_US_POWER_BACK_OFF_STATUS_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_G997_RATE_ADAPTATION_STATUS_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_G997_CHANNEL_STATUS_GET;
#if defined(DSL_ST_PLATFORM_VRX518)
      DSL_Error_t
         *pE_DSL_ST_FLAG_SYSTEM_INTERFACE_CONFIG_GET;
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
      DSL_Error_t
         *pE_DSL_ST_FLAG_SYSTEM_INTERFACE_STATUS_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_G997_FRAMING_PARAMETER_STATUS_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_PM_CHANNEL_COUNTERS_TOTAL_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_PM_CHANNEL_COUNTERS_SHOWTIME_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_PM_LINE_INIT_COUNTERS_1DAY_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_PM_CHANNEL_COUNTERS_15MIN_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_TOTAL_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_SHOWTIME_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_1DAY_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_15MIN_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_TOTAL_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_SHOWTIME_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_PM_CHANNEL_COUNTERS_1DAY_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_1DAY_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_15MIN_GET;
#if defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION)
      DSL_Error_t
         *pE_DSL_ST_FLAG_FILTER_DETECTION_BASIC_DATA_GET;
#endif /* defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION) */
#if defined(DSL_ST_PLATFORM_VRX518)
      DSL_Error_t
         *pE_DSL_ST_FLAG_BND_CONFIG_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_BND_STATUS_GET;
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
#if defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
      DSL_Error_t
         *pE_DSL_ST_FLAG_FAST_PROFILE_CONFIG_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_FAST_PROFILE_STATUS_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_FAST_LINE_STATUS_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_FAST_RMC_BIT_ALLOCATION_TABLE_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_FAST_RETRANS_COUNTERS_TOTAL_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_FAST_OLR_STATISTICS_TOTAL_GET;
      DSL_Error_t
         *pE_DSL_ST_FLAG_FAST_OLR_COUNTERS_SHOWTIME_GET;
#endif /* defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */
   } sError;
} DSL_ST_DynamicResources_t;

static DSL_ST_DynamicResources_t* pDynamicResources = { DSL_NULL };

#define DSL_ST_DYNAMIC_DATA_ARRAY1_GET(pData, type, flag, size) \
   do { \
      if (pData == DSL_NULL && pDynamicResources != DSL_NULL) \
      { \
         type **ppTmpData = &pDynamicResources->sData.pD_##flag; \
         if (*ppTmpData == DSL_NULL) \
         { \
            DSL_uint32_t nSize = (size) * sizeof(type); \
            *ppTmpData = (type*)DSL_ST_Malloc(nSize); \
            if (*ppTmpData != DSL_NULL) \
            { \
               memset(*ppTmpData, 0, nSize); \
               DSL_ST_DEBUG_MEMINFO_ADD(nSize); \
            } \
         } \
         pData = *ppTmpData; \
      } \
   } while(0)

#define DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(pError, flag, size) \
   do { \
      if (pError == DSL_NULL && pDynamicResources != DSL_NULL) \
      { \
         DSL_Error_t **ppTmpError = &pDynamicResources->sError.pE_##flag; \
         if (*ppTmpError == DSL_NULL) \
         { \
            DSL_uint32_t nSize = (size) * sizeof(DSL_Error_t); \
            *ppTmpError = (DSL_Error_t*)DSL_ST_Malloc(nSize); \
            if (*ppTmpError != DSL_NULL) \
            { \
               memset(*ppTmpError, 0, nSize); \
               DSL_ST_DEBUG_MEMINFO_ADD(nSize); \
            } \
         } \
         pError = *ppTmpError; \
      } \
   } while(0)

#define DSL_ST_DYNAMIC_DATA_ARRAY2_GET(pData, type, flag, size1, size2) \
   do { \
      if (pData == DSL_NULL && pDynamicResources != DSL_NULL) \
      { \
         type** ppTmpData = &pDynamicResources->sData.pD_##flag; \
         if (*ppTmpData == DSL_NULL) \
         { \
            DSL_uint32_t nSize = (size1) * (size2) * sizeof(type); \
            *ppTmpData = (type*)DSL_ST_Malloc(nSize); \
            if (*ppTmpData != DSL_NULL) \
            { \
               memset(*ppTmpData, 0, nSize); \
               DSL_ST_DEBUG_MEMINFO_ADD(nSize); \
            } \
         } \
         pData = *ppTmpData; \
         nArrayY = size2; \
      } \
   } while(0)

#define DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(pError, flag, size1, size2) \
   do { \
      if (pError == DSL_NULL && pDynamicResources != DSL_NULL) \
      { \
         DSL_Error_t **ppTmpError = &pDynamicResources->sError.pE_##flag; \
         if (*ppTmpError == DSL_NULL) \
         { \
            DSL_uint32_t nSize = (size1) * (size2) * sizeof(DSL_Error_t); \
            *ppTmpError = (DSL_Error_t*)DSL_ST_Malloc(nSize); \
            if (*ppTmpError != DSL_NULL) \
            { \
               memset(*ppTmpError, 0, nSize); \
               DSL_ST_DEBUG_MEMINFO_ADD(nSize); \
            } \
         } \
         pError = *ppTmpError; \
         nArrayY = size2; \
      } \
   } while(0)

/* Macro to get a value from indicated place in a memory allocated
   as 1-dimensional array like it was a 2-dimensional array of sizes
   [nArrayY][nArrayX], according to the formula
   X[index1][index2] = X + (nArrayY * index1) + index2,
   example (array 2x2):
   2D index | 1D index
   0 0      | 0
   0 1      | 1
   1 0      | 2
   1 1      | 3 */
#define DSL_ST_ARRAY2_INDEX_VAL(pSrcArray, index1, index2) \
      *(pSrcArray + (nArrayY * index1) + index2)

/* Macro to get a pointer to indicated place in a memory allocated
   as 1-dimensional array like it was a 2-dimensional array of sizes
   [nArrayY][nArrayX], according to the formula
   X[index1][index2] = X + (nArrayY * index1) + index2,
   example (array 2x2):
   2D index | 1D index
   0 0      | 0
   0 1      | 1
   1 0      | 2
   1 1      | 3 */
#define DSL_ST_ARRAY2_INDEX_PTR(pSrcArray, index1, index2) \
      (pSrcArray + (nArrayY * index1) + index2)

#define DSL_ST_DYNAMIC_DATA_ARRAY3_GET(pData, type, flag, size1, size2, size3) \
   do { \
      if (pData == DSL_NULL && pDynamicResources != DSL_NULL) \
      { \
         type **ppTmpData = &pDynamicResources->sData.pD_##flag; \
         if (*ppTmpData == DSL_NULL) \
         { \
            DSL_uint32_t nSize = (size1) * (size2) * (size3) * sizeof(type); \
            *ppTmpData = (type*)DSL_ST_Malloc(nSize); \
            if (*ppTmpData != DSL_NULL) \
            { \
               memset(*ppTmpData, 0, nSize); \
               DSL_ST_DEBUG_MEMINFO_ADD(nSize); \
            } \
         } \
         pData = *ppTmpData; \
         nArrayY = size2; \
         nArrayZ = size3; \
      } \
   } while(0)

#define DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(pError, flag, size1, size2, size3) \
   do { \
      if (pError == DSL_NULL && pDynamicResources != DSL_NULL) \
      { \
         DSL_Error_t **ppTmpError = &pDynamicResources->sError.pE_##flag; \
         if (*ppTmpError == DSL_NULL) \
         { \
            DSL_uint32_t nSize = \
               (size1) * (size2) * (size3) * sizeof(DSL_Error_t); \
            *ppTmpError = (DSL_Error_t*)DSL_ST_Malloc(nSize); \
            if (*ppTmpError != DSL_NULL) \
            { \
               memset(*ppTmpError, 0, nSize); \
               DSL_ST_DEBUG_MEMINFO_ADD(nSize); \
            } \
         } \
         pError = *ppTmpError; \
         nArrayY = size2; \
         nArrayZ = size3; \
      } \
   } while(0)

/* Macro to get value from indicated place in a memory allocated
   as 1-dimensional array like it was a 3-dimensional array of sizes
   [nArrayZ][nArrayY][nArrayX], according to the formula
   X[index1][index2][index3] = X + ((nArrayZ * nArrayY) * index1) +
   (nArrayY * index2) + index3,
   example (array 2x2x2):
   3D index | 1D index
   0 0 0    | 0
   0 0 1    | 1
   0 1 0    | 2
   0 1 1    | 3
   1 0 0    | 4
   1 0 1    | 5
   1 1 0    | 6
   1 1 1    | 7 */
#define DSL_ST_ARRAY3_INDEX_VAL(pSrcArray, index1, index2, index3) \
      *(pSrcArray + ((nArrayZ * nArrayY) * index1) + \
      (nArrayY * index2) + index3)

/* Macro to get pointer to indicated place in a memory allocated
   as 1-dimensional array like it was a 3-dimensional array of sizes
   [nArrayZ][nArrayY][nArrayX], according to the formula
   X[index1][index2][index3] = X + ((nArrayZ * nArrayY) * index1) +
   (nArrayY * index2) + index3,
   example (array 2x2x2):
   3D index | 1D index
   0 0 0    | 0
   0 0 1    | 1
   0 1 0    | 2
   0 1 1    | 3
   1 0 0    | 4
   1 0 1    | 5
   1 1 0    | 6
   1 1 1    | 7 */
#define DSL_ST_ARRAY3_INDEX_PTR(pSrcArray, index1, index2, index3) \
      (pSrcArray + ((nArrayZ * nArrayY) * index1) + \
      (nArrayY * index2) + index3)

#define DSL_ST_DYNAMIC_DATA_ARRAY4_GET(pData, type, flag, size1, size2, size3, size4) \
   do { \
      if (pData == DSL_NULL && pDynamicResources != DSL_NULL) \
      { \
         type **ppTmpData = &pDynamicResources->sData.pD_##flag; \
         if (*ppTmpData == DSL_NULL) \
         { \
            DSL_uint32_t nSize = (size1) * (size2) * \
               (size3) * (size4) * sizeof(type); \
            *ppTmpData = (type*)DSL_ST_Malloc(nSize); \
            if (*ppTmpData != DSL_NULL) \
            { \
               memset(*ppTmpData, 0, nSize); \
               DSL_ST_DEBUG_MEMINFO_ADD(nSize); \
            } \
         } \
         pData = *ppTmpData; \
         nArrayY = size2; \
         nArrayZ = size3; \
         nArrayW = size4; \
      } \
   } while(0)

#define DSL_ST_DYNAMIC_ERROR_ARRAY4_GET(pError, flag, size1, size2, size3, size4) \
   do { \
      if (pError == DSL_NULL && pDynamicResources != DSL_NULL) \
      { \
         DSL_Error_t **ppTmpError = &pDynamicResources->sError.pE_##flag; \
         if (*ppTmpError == DSL_NULL) \
         { \
            DSL_uint32_t nSize = \
               (size1) * (size2) * (size3) * (size4) * sizeof(DSL_Error_t); \
            *ppTmpError = (DSL_Error_t*)DSL_ST_Malloc(nSize); \
            if (*ppTmpError != DSL_NULL) \
            { \
               memset(*ppTmpError, 0, nSize); \
               DSL_ST_DEBUG_MEMINFO_ADD(nSize); \
            } \
         } \
         pError = *ppTmpError; \
         nArrayY = size2; \
         nArrayZ = size3; \
         nArrayW = size4; \
      } \
   } while(0)

/* Macro to get value from indicated place in a memory allocated
   as 1-dimensional array like it was a 4-dimensional array of sizes
   [nArrayW][nArrayZ][nArrayY][nArrayX], according to the formula
   X[index1][index2][index3][index4] = X + ((nArrayW * nArrayZ * nArrayY) *
   index1) + ((nArrayZ * nArrayY) * index2) + (nArrayY * index3) + index4,
   example (array 2x2x2x2):
   4D index   | 1D index (8*index1 + 4*index2 + 2*index3 + index4)
      0 0 0 0    | 0
      0 0 0 1    | 1
      0 0 1 0    | 2
      0 0 1 1    | 3
      0 1 0 0    | 4
      0 1 0 1    | 5
      0 1 1 0    | 6
      0 1 1 1    | 7
      1 0 0 0    | 8
      1 0 0 1    | 9
      1 0 1 0    | 10
      1 0 1 1    | 11
      1 1 0 0    | 12
      1 1 0 1    | 13
      1 1 1 0    | 14
      1 1 1 1    | 15 */
#define DSL_ST_ARRAY4_INDEX_VAL(pSrcArray, index1, index2, index3, index4) \
      *(pSrcArray + ((nArrayW * nArrayZ * nArrayY) * index1) + \
      ((nArrayZ * nArrayY) * index2) + \
      (nArrayY * index3) + index4)

/* Macro to get pointer to indicated place in a memory allocated
   as 1-dimensional array like it was a 4-dimensional array of sizes
   [nArrayW][nArrayZ][nArrayY][nArrayX], according to the formula
   X[index1][index2][index3][index4] = X + ((nArrayW * nArrayZ * nArrayY) *
   index1) + ((nArrayZ * nArrayY) * index2) + (nArrayY * index3) + index4,
   example (array 2x2x2x2):
      4D index   | 1D index (8*index1 + 4*index2 + 2*index3 + index4)
      0 0 0 0    | 0
      0 0 0 1    | 1
      0 0 1 0    | 2
      0 0 1 1    | 3
      0 1 0 0    | 4
      0 1 0 1    | 5
      0 1 1 0    | 6
      0 1 1 1    | 7
      1 0 0 0    | 8
      1 0 0 1    | 9
      1 0 1 0    | 10
      1 0 1 1    | 11
      1 1 0 0    | 12
      1 1 0 1    | 13
      1 1 1 0    | 14
      1 1 1 1    | 15 */
#define DSL_ST_ARRAY4_INDEX_PTR(pSrcArray, index1, index2, index3, index4) \
      (pSrcArray + ((nArrayW * nArrayZ * nArrayY) * index1) + \
      ((nArrayZ * nArrayY) * index2) + \
      (nArrayY * index3) + index4)

/*
   Macro to free dynamically allocated resources in pDynamicResources
*/
#define DSL_ST_DYN_RES_FREE(flag) \
   do { \
      /* free Data resource */ \
      if (pDynamicResources->sData.pD_##flag != DSL_NULL) \
      { \
         DSL_ST_Free(pDynamicResources->sData.pD_##flag); \
         pDynamicResources->sData.pD_##flag = DSL_NULL; \
      } \
      /* free Error resource */ \
      if (pDynamicResources->sError.pE_##flag != DSL_NULL) \
      { \
         DSL_ST_Free(pDynamicResources->sError.pE_##flag); \
         pDynamicResources->sError.pE_##flag = DSL_NULL; \
      } \
   } while(0)

/**********************************************/
/* start local function declarations          */
/**********************************************/

static DSL_void_t DSL_ST_ParamsListCreate();

static DSL_void_t DSL_ST_StatusOutputInitialize();

static DSL_Error_t DSL_ST_StatusOutputUpdate();

static DSL_Error_t DSL_ST_InitParamsUpdate(
   DSL_ST_Context_t *pContext
);

static DSL_Error_t DSL_ST_EvtParamsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   DSL_uint16_t nLine,
   DSL_uint8_t nChannel
);

static DSL_Error_t DSL_ST_PollParamsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusSectionIdx_t eSectionIdx
);

static DSL_void_t DSL_ST_DynamicResourcesFree(
   DSL_void_t);

static DSL_Error_t DSL_ST_StatusParamsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nLine,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_LineNrOfEntriesUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ChannelNrOfEntriesUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_BndGroupNrOfEntriesUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ApiVersionUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_MeiVersionUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_HwVersionUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ChipsetTypeUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_LineStatusUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_UpstreamUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_FwVersionUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_LinkStatusUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_StdSupportedUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_XtseConfigUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_StdUsedUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_XtseStatusUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_LineEncodingUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_AllowedProfilesUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_CurrentProfileUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_PowerMgmtStateUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_SuccFailCauseUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_LastStateTransmUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel,
   const DSL_AccessDir_t nDirection);

static DSL_void_t DSL_ST_Us0MaskUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_LineFeatureUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_LineNrUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_MaxBitRateUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_NoiseMarginUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_PowerUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_AttenuationUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_SnrMpbUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel,
   const DSL_AccessDir_t nDirection);

static DSL_void_t DSL_ST_XturVendorUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_XturCountryUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_XtucVendorUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_XtucCountryUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_XturAnsiStdUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_XturAnsiRevUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_XtucAnsiStdUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_XtucAnsiRevUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

#if defined(DSL_ST_PLATFORM_VRX518)
static DSL_void_t DSL_ST_UpboklerUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel);
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

static DSL_void_t DSL_ST_UpboklerPbUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_RxthrshDsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_ActRaModeUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel,
   const DSL_AccessDir_t nDirection);

static DSL_void_t DSL_ST_SnrMrocUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_ChannelActStatusUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_ChannelStatusUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_ChannelLinkEncapSupportedUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_ChannelLinkEncapUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_ChannelFramingUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

#if defined(DSL_ST_PLATFORM_VRX618)
static DSL_void_t DSL_ST_ChannelActINPReportUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

#if defined(DSL_ST_PLATFORM_VRX518)
static DSL_void_t DSL_ST_BndSchemesSupportedUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_BndSchemeUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);

static DSL_void_t DSL_ST_BndDatarateUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel);
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
/* VRX618 only */
static DSL_void_t DSL_ST_FastAllowedProfilesUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

/* VRX618 only */
static DSL_void_t DSL_ST_FastCurrentProfileUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

/* VRX618 only */
static DSL_void_t DSL_ST_FastSnrmrmcUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

/* VRX618 only */
static DSL_void_t DSL_ST_FastBitsrmcpsUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

/* VRX618 only */
static DSL_void_t DSL_ST_FastMineftrUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);
#endif /* defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */

static DSL_void_t DSL_ST_TotalStartUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ShowtimeStartUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_LastShowtimeStartUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_CurrDayStartUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_QuarterHourStartUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_TotalErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_TotalSevErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ShowtimeErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ShowtimeSevErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_LastShowtimeErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_LastShowtimeSevErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_CurrDayErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_CurrDaySevErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_QuarterHourErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_QuarterHourSevErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ChannelCountersTotalUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ChannelDataPathCountersTotalUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ChannelCountersShowtimeUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ChannelDataPathCountersShowtimeUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ChannelCounters1DayUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ChannelDataPathCounters1DayUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ChannelCounters15MinUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

static DSL_void_t DSL_ST_ChannelDataPathCounters15MinUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

#if defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION)
static DSL_void_t DSL_ST_MfdBasicDataStatusUpdate(
   DSL_ST_Context_t* pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);
#endif /* defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION) */

#if defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
/* VRX618 */
static DSL_void_t DSL_ST_FastTotalSuccessBswUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

/* VRX618 */
static DSL_void_t DSL_ST_FastTotalSuccessSraUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

/* VRX618 */
static DSL_void_t DSL_ST_FastTotalSuccessFraUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

/* VRX618 */
static DSL_void_t DSL_ST_FastTotalSuccessRpaUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

/* VRX618 */
static DSL_void_t DSL_ST_FastTotalSuccessTigaUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

/* VRX618 */
static DSL_void_t DSL_ST_FastShowtimeSuccessBswUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

/* VRX618 */
static DSL_void_t DSL_ST_FastShowtimeSuccessSraUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

/* VRX618 */
static DSL_void_t DSL_ST_FastShowtimeSuccessFraUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

/* VRX618 */
static DSL_void_t DSL_ST_FastShowtimeSuccessRpaUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);

/* VRX618 */
static DSL_void_t DSL_ST_FastShowtimeSuccessTigaUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);
#endif /* defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */

#if defined(DSL_ST_PLATFORM_VRX518)
#if defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1)
static DSL_void_t DSL_ST_ConfigurationStatusUpdate(
   DSL_CPE_Control_Context_t* pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel
);
#endif /* defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1) */
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

/**********************************************/
/* start global function definitions          */
/**********************************************/

/*
   For a detailed description of the function, please refer to the
   description in the header file 'drv_cpe_status_parser.h'
*/
DSL_Error_t DSL_ST_DslStatusInitialize(
   DSL_ST_Context_t *pContext)
{
   DSL_Error_t nErrorCode = DSL_SUCCESS;

#if defined(DSL_ST_PLATFORM_VRX518)
   /* TODO: unify printing for VRX518 and VRX618 */
   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_ST_DslStatusInitialize" DSL_CPE_CRLF));
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

   /* here global, final list of parameters pAllStatusParams is
      created, according to the actual number of lines, channels
      etc. (to be used by all update functions from now on) */
   DSL_ST_ParamsListCreate();

   /* Here the framework-specific output is initialized */
   DSL_ST_StatusOutputInitialize();

   nErrorCode = DSL_ST_InitParamsUpdate(pContext);

   if (nErrorCode == DSL_SUCCESS)
   {
      nErrorCode = DSL_ST_StatusOutputUpdate();
   }

#if defined(DSL_ST_PLATFORM_VRX518)
   /* TODO: unify printing for VRX518 and VRX618 */
   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_ST_DslStatusInitialize, retCode=%d"
      DSL_CPE_CRLF, nErrorCode));
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

   return nErrorCode;
}

/*
   For a detailed description of the function, please refer to the
   description in the header file 'drv_cpe_status_parser.h'
*/
DSL_Error_t DSL_ST_DslStatusEvtUpdate(
   DSL_ST_Context_t* pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   DSL_uint16_t nLine,
   DSL_uint8_t nChannel)
{
   DSL_Error_t nErrorCode = DSL_SUCCESS;

#if defined(DSL_ST_PLATFORM_VRX518)
   /* TODO: unify printing for VRX518 and VRX618 */
   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_ST_DslStatusEvtUpdate, node=%d"
      DSL_CPE_CRLF, (DSL_int_t)eNodeIdx));
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

   nErrorCode = DSL_ST_EvtParamsUpdate(
      pContext, eNodeIdx, nLine, nChannel);

   if (nErrorCode == DSL_SUCCESS)
   {
      nErrorCode = DSL_ST_StatusOutputUpdate();
   }

#if defined(DSL_ST_PLATFORM_VRX518)
   /* TODO: unify printing for VRX518 and VRX618 */
   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_ST_DslStatusEvtUpdate, retCode=%d"
      DSL_CPE_CRLF, nErrorCode));
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

   return nErrorCode;
}

/*
   For a detailed description of the function, please refer to the
   description in the header file 'drv_cpe_status_parser.h'
*/
DSL_Error_t DSL_ST_DslStatusPollUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusSectionIdx_t ePollSectionIdx)
{
   DSL_Error_t nErrorCode = DSL_SUCCESS;

#if defined(DSL_ST_PLATFORM_VRX518)
   /* TODO: unify printing for VRX518 and VRX618 */
   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_ST_DslStatusPollUpdate, section=%d"
      DSL_CPE_CRLF, (DSL_int_t)ePollSectionIdx));
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

   nErrorCode = DSL_ST_PollParamsUpdate(
      pContext, ePollSectionIdx);

   if (nErrorCode == DSL_SUCCESS)
   {
      nErrorCode = DSL_ST_StatusOutputUpdate();
   }

#if defined(DSL_ST_PLATFORM_VRX518)
   /* TODO: unify printing for VRX518 and VRX618 */
   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_ST_DslStatusPollUpdate, retCode=%d"
      DSL_CPE_CRLF, nErrorCode));
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

   return nErrorCode;
}

/*
   For a detailed description of the function, please refer to the
   description in the header file 'drv_cpe_status_parser.h'
*/
DSL_void_t DSL_ST_DslStatusResourcesFree(
   DSL_void_t)
{
#if defined(DSL_ST_PLATFORM_VRX518)
   /* TODO: unify printing for VRX518 and VRX618 */
   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_ST_DslStatusResourcesFree"
      DSL_CPE_CRLF));
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

   DSL_ST_DynamicResourcesFree();

#if defined(INCLUDE_DSL_STATUS_UBUS_SUPPORT) && (INCLUDE_DSL_STATUS_UBUS_SUPPORT == 1)
   (DSL_void_t)DSL_ST_UbusDeinit();
#endif /* defined(INCLUDE_DSL_STATUS_UBUS_SUPPORT) && (INCLUDE_DSL_STATUS_UBUS_SUPPORT == 1) */

#if defined(DSL_ST_PLATFORM_VRX518)
   /* TODO: unify printing for VRX518 and VRX618 */
   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_ST_DslStatusResourcesFree"
      DSL_CPE_CRLF));
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
}

/*********************************************/
/* start local function definitions          */
/*********************************************/

/*
   This function returns ioctl flag
*/
static DSL_Error_t DSL_ST_CallFlagGet(
   DSL_ST_CallFlag_t eCallFlag,
   const DSL_ST_CallFlagSwitch_t **ppIoctlFlag)
{
   DSL_Error_t nErrorCode = DSL_ERROR;

   for (DSL_uint8_t i = 0; i < nFlagsNum; ++i)
   {
      if (callFlags[i].eCallFlag == eCallFlag)
      {
         *ppIoctlFlag = &callFlags[i];

         /* flag found */
         nErrorCode = DSL_SUCCESS;
      }
   }

   return nErrorCode;
}

/*
   This function toggles ioctl flag to TRUE
*/
static DSL_void_t DSL_ST_CallFlagSet(
   DSL_ST_CallFlag_t eCallFlag)
{
   DSL_ST_CallFlagSwitch_t *pIoctlFlag = DSL_NULL;

   if (DSL_ST_CallFlagGet(eCallFlag,
      (const DSL_ST_CallFlagSwitch_t**)&pIoctlFlag) == DSL_SUCCESS)
   {
      pIoctlFlag->bIsSet = DSL_TRUE;
   }
   else
   {
#if defined(DSL_ST_PLATFORM_VRX518)
      /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - Status Parser, DSL_ST_CallFlagSet: flag not found!"
         DSL_CPE_CRLF));
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
   }
}

/*
   This function returns current "is set" value of related ioctl flag
*/
static DSL_boolean_t DSL_ST_IsCallFlagSet(DSL_ST_CallFlag_t eCallFlag)
{
   DSL_boolean_t bIsSet = DSL_FALSE;
   const DSL_ST_CallFlagSwitch_t *pIoctlFlag = DSL_NULL;

   if (DSL_ST_CallFlagGet(eCallFlag, &pIoctlFlag) == DSL_SUCCESS)
   {
      bIsSet = pIoctlFlag->bIsSet;
   }
   else
   {
#if defined(DSL_ST_PLATFORM_VRX518)
      /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - Status Parser, DSL_ST_IsCallFlagSet: flag not found!"
         DSL_CPE_CRLF));
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
   }

   return bIsSet;
}

/*
   This function toggles all ioctl flags back to FALSE
*/
static DSL_void_t DSL_ST_CallFlagsReset()
{
   for (DSL_uint8_t i = 0; i < nFlagsNum; ++i)
   {
      callFlags[i].bIsSet = DSL_FALSE;
   }
}

/*
   This function adds item to the global pAllStatusParams list
*/
static DSL_void_t DSL_ST_ParamsListItemAdd(
   const DSL_ST_StatusNode_t* pNode,
   const DSL_uint16_t nLine,
   const DSL_uint8_t nChannel,
   const DSL_uint8_t nBndGroup
)
{
   DSL_ST_StatusParamsList_t *pStatusParam =
      (DSL_ST_StatusParamsList_t*)
      DSL_ST_Malloc(sizeof(DSL_ST_StatusParamsList_t));

   if (pStatusParam != DSL_NULL)
   {
      /* create new status parameter */
      pStatusParam->pStatusNode = pNode;
      pStatusParam->nLine = nLine;
      pStatusParam->nChannel = nChannel;
      pStatusParam->nBndGroup = nBndGroup;
      pStatusParam->pNext = DSL_NULL;

      /* update pAllStatusParams list with the new parameter */
      if (pAllStatusParams == DSL_NULL)
      {
         pAllStatusParams = pStatusParam;
      }
      else
      {
         DSL_ST_StatusParamsList_t* pHead = pAllStatusParams;
         while (pHead->pNext != DSL_NULL)
         {
            pHead = pHead->pNext;
         }

         pHead->pNext = pStatusParam;
      }

      /* update global variable keeping number of parameters */
      nParamsNum++;
   }
}

/*
   This function creates list of all actual status parameters
   with line, channel and bonding group number information, on
   the basis of "nodes" defined in the statusNodesArray array
   and number of lines, channels and bonding groups currently
   configured
*/
static DSL_void_t DSL_ST_ParamsListCreate()
{
   DSL_uint16_t nLine = 0;
   DSL_uint8_t nChannel = 0, nBndGroup = 0;

   /* iterate through all nodes in the statusNodesArray array
      and create appropriate status parameters */
   for (DSL_uint32_t nNode = 0; nNode < nNodesNum; ++nNode)
   {
      if (statusNodesArray[nNode].eSubsection == DSL_ST_SUBSECTION_COMMON)
      {
#if defined(DSL_ST_PLATFORM_VRX518)
         if (statusNodesArray[nNode].eNodeIdx == DSL_STATUS_BND_GROUP &&
            !INCLUDE_DSL_BONDING)
         {
            /* skip this node in single link mode */
            continue;
         }
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
         DSL_ST_ParamsListItemAdd(
            &statusNodesArray[nNode], nLine, nChannel, nBndGroup);
      }
#if defined(DSL_ST_PLATFORM_VRX518)
      else if (statusNodesArray[nNode].eSubsection == DSL_ST_SUBSECTION_BND_GROUP &&
         INCLUDE_DSL_BONDING)
      {
         /* for CPE nBndGroup is always 0 */
         DSL_ST_ParamsListItemAdd(
            &statusNodesArray[nNode], nLine, nChannel, nBndGroup);
      }
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
      else if (statusNodesArray[nNode].eSubsection == DSL_ST_SUBSECTION_LINE
         || statusNodesArray[nNode].eSubsection == DSL_ST_SUBSECTION_CHANNEL)
      {
         for (nLine = 0; nLine < DSL_ST_DSL_ENTITIES; ++nLine)
         {
            if (statusNodesArray[nNode].eSubsection == DSL_ST_SUBSECTION_LINE)
            {
               DSL_ST_ParamsListItemAdd(
                  &statusNodesArray[nNode], nLine, nChannel, nBndGroup);
            }
            else if (statusNodesArray[nNode].eSubsection == DSL_ST_SUBSECTION_CHANNEL)
            {
               for (nChannel = 0;
                  nChannel < DSL_ST_CHANNELS_PER_LINE; ++nChannel)
               {
                  DSL_ST_ParamsListItemAdd(
                     &statusNodesArray[nNode], nLine, nChannel, nBndGroup);
               }
               /* reset nChannel value for line-only (no channel) params,
                  in order to not to store incorrect (non-zero) channel
                  value in them */
               nChannel = 0;
            }
         }
         /* reset nLine value for common (no line and no channel) params,
            in order to not to store incorrect (non-zero) line value in them */
         nLine = 0;
      }
   }
}

/**
   This function initializes all supported status outputs
   (it is intended to call all initialize functions for all supported
   frameworks in order to prepare status outputs in framework-specific
   formats)
*/
static DSL_void_t DSL_ST_StatusOutputInitialize()
{
#if defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1)
   /* Initialize the JSON status file */
   DSL_ST_JsonStatusInitialize();
#endif /* defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1) */

#if defined(INCLUDE_DSL_STATUS_UBUS_SUPPORT) && (INCLUDE_DSL_STATUS_UBUS_SUPPORT == 1)
   (DSL_void_t)DSL_ST_UbusInit();
#endif /* defined(INCLUDE_DSL_STATUS_UBUS_SUPPORT) && (INCLUDE_DSL_STATUS_UBUS_SUPPORT == 1) */
}

/**
   This function triggers final steps of a single status update in all
   supported frameworks (for JSON it means writing data to a file)
*/
static DSL_Error_t DSL_ST_StatusOutputUpdate()
{
   DSL_Error_t nErrorCode = DSL_SUCCESS;
   DSL_Error_t nRetVal = DSL_SUCCESS;

#if defined(INCLUDE_DSL_STATUS_UBUS_SUPPORT) && (INCLUDE_DSL_STATUS_UBUS_SUPPORT == 1)
   nRetVal = DSL_ST_UbusSync();
   if (nRetVal != DSL_SUCCESS)
   {
      nErrorCode = nRetVal;
   }
#endif /* defined(INCLUDE_DSL_STATUS_UBUS_SUPPORT) && (INCLUDE_DSL_STATUS_UBUS_SUPPORT == 1) */

#if defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1)
   /* Update JSON status file */
   nRetVal = DSL_ST_JsonStatusUpdate();
   if (nRetVal != DSL_SUCCESS)
   {
      nErrorCode = nRetVal;
   }
#endif /* defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1) */

   DSL_ST_DEBUG_MEMINFO_PRINT;

   return nErrorCode;
}

/**
   This function triggers init type params update
*/
static DSL_Error_t DSL_ST_InitParamsUpdate(
   DSL_ST_Context_t *pContext)
{
   DSL_Error_t nRet = DSL_SUCCESS, nErrorCode = DSL_SUCCESS;
   DSL_ST_StatusParamsList_t *pStatusParamsListItem = pAllStatusParams;

   while (pStatusParamsListItem != DSL_NULL)
   {
      if (pStatusParamsListItem->pStatusNode->eUpdateType ==
            DSL_UPDATE_TYPE_INIT)
      {
         nRet = DSL_ST_StatusParamsUpdate(
            pContext, pStatusParamsListItem->pStatusNode->eNodeIdx,
            pStatusParamsListItem->nLine, pStatusParamsListItem->nChannel);

         /* keep error code in case of any
            failure and continue */
         if (nRet != DSL_SUCCESS)
         {
            nErrorCode = nRet;
         }

      }

      /* go to the next param in the list */
      pStatusParamsListItem = pStatusParamsListItem->pNext;
   }

   /* reset all call flags to FALSE */
   DSL_ST_CallFlagsReset();

   return nErrorCode;
}

/**
   This Afunction triggers given evt type param update
*/
static DSL_Error_t DSL_ST_EvtParamsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   DSL_uint16_t nLine,
   DSL_uint8_t nChannel)
{
   DSL_Error_t nErrorCode = DSL_SUCCESS;

   nErrorCode = DSL_ST_StatusParamsUpdate(pContext, eNodeIdx, nLine, nChannel);

   /* reset all call flags to FALSE */
   DSL_ST_CallFlagsReset();

   return nErrorCode;
}

/*
   This function maps provided section to the internal section definition
*/
static DSL_void_t DSL_ST_InternalSectionGet(
   const DSL_ST_StatusSectionIdx_t eInputSection,
   DSL_ST_StatusNodeSection_t *eOutputSection)
{
   /* Map selected section to the internal section definition */
   switch (eInputSection)
   {
      case DSL_ST_STATUS:
         *eOutputSection = DSL_ST_SECTION_STATUS;
         break;
      case DSL_ST_STATISTICS:
         *eOutputSection = DSL_ST_SECTION_STATS;
         break;
      case DSL_ST_CONFIGURATION:
         *eOutputSection = DSL_ST_SECTION_CONFIG;
         break;
      default:
         *eOutputSection = DSL_ST_SECTION_UNKNOWN;
         break;
   }
}

/**
   This function triggers polling type params update
*/
static DSL_Error_t DSL_ST_PollParamsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusSectionIdx_t eSectionIdx)
{
   DSL_Error_t nRet = DSL_SUCCESS, nErrorCode = DSL_SUCCESS;
   DSL_ST_StatusParamsList_t *pStatusParamsListItem = pAllStatusParams;
   DSL_ST_StatusNodeSection_t eSelectedSection = DSL_ST_SECTION_UNKNOWN;

   DSL_ST_InternalSectionGet(eSectionIdx, &eSelectedSection);
   if (eSelectedSection == DSL_ST_SECTION_UNKNOWN)
   {
#if defined(DSL_ST_PLATFORM_VRX518)
      /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_ST_PollParamsUpdate: section undefined! (idx=%d)!"
         DSL_CPE_CRLF, eSectionIdx));
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
      return DSL_ERROR;
   }

   /* update all poll type parameters witing given section */
   while (pStatusParamsListItem != DSL_NULL)
   {
      if (pStatusParamsListItem->pStatusNode->eSection == eSelectedSection &&
          pStatusParamsListItem->pStatusNode->eUpdateType == DSL_UPDATE_TYPE_POLL)
      {
         /* update all lines' params in the section */
         for (DSL_uint16_t nLine = 0;
            nLine < DSL_ST_DSL_ENTITIES; ++nLine)
         {
            /* update all channels per line params in the section */
            for (DSL_uint8_t nChannel = 0;
               nChannel < DSL_ST_CHANNELS_PER_LINE; ++nChannel)
            {
               nRet = DSL_ST_StatusParamsUpdate(
                  pContext, pStatusParamsListItem->pStatusNode->eNodeIdx,
                  nLine, nChannel);

               /* keep error code in case of any
                  failure and continue */
               if (nRet != DSL_SUCCESS)
               {
                  nErrorCode = nRet;
               }
            }
         }
      }

      /* go to the next param in the list */
      pStatusParamsListItem = pStatusParamsListItem->pNext;
   }

   /* reset all call flags to FALSE */
   DSL_ST_CallFlagsReset();

   return nErrorCode;
}

static DSL_void_t DSL_ST_DynamicResourcesFree(
   DSL_void_t)
{
   if (pDynamicResources != DSL_NULL)
   {
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_LINE_STATE_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_CONFIG_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_STATUS_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_BAND_PLAN_SUPPORT_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_BAND_PLAN_STATUS_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_G997_POWER_MANAGEMENT_STATUS_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_G997_LINE_INIT_STATUS_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_G997_LAST_STATE_TRANSMITTED_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_LINE_FEATURE_STATUS_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_G997_LINE_STATUS_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_G997_LINE_STATUS_PER_BAND_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_G997_LINE_INVENTORY_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_G997_US_POWER_BACK_OFF_STATUS_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_G997_RATE_ADAPTATION_STATUS_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_G997_CHANNEL_STATUS_GET);
#if defined(DSL_ST_PLATFORM_VRX518)
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_SYSTEM_INTERFACE_CONFIG_GET);
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_SYSTEM_INTERFACE_STATUS_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_G997_FRAMING_PARAMETER_STATUS_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_TOTAL_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_SHOWTIME_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_PM_LINE_INIT_COUNTERS_1DAY_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_15MIN_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_TOTAL_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_SHOWTIME_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_1DAY_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_15MIN_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_TOTAL_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_SHOWTIME_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_1DAY_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_1DAY_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_15MIN_GET);
#if defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION)
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_FILTER_DETECTION_BASIC_DATA_GET);
#endif /* defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION) */
#if defined(DSL_ST_PLATFORM_VRX518)
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_BND_CONFIG_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_BND_STATUS_GET);
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
#if defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_FAST_PROFILE_CONFIG_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_FAST_PROFILE_STATUS_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_FAST_LINE_STATUS_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_FAST_RMC_BIT_ALLOCATION_TABLE_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_FAST_RETRANS_COUNTERS_TOTAL_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_FAST_OLR_STATISTICS_TOTAL_GET);
      DSL_ST_DYN_RES_FREE(DSL_ST_FLAG_FAST_OLR_COUNTERS_SHOWTIME_GET);
#endif /* defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */

      /* free the dynamic resources' handle */
      DSL_ST_Free(pDynamicResources);
      pDynamicResources = DSL_NULL;
   }

   /* free the status params list's handle */
   if (pAllStatusParams != DSL_NULL)
   {
      DSL_ST_Free(pAllStatusParams);
      pAllStatusParams = DSL_NULL;
   }
}

/**
   This function triggers given param update for any update type
*/
static DSL_Error_t DSL_ST_StatusParamsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nLine,
   const DSL_uint8_t nChannel)
{
   DSL_Error_t nErrorCode = DSL_SUCCESS;

   /* initialize dynamic resources - will be used
      in the "params update" functions */
   if (pDynamicResources == DSL_NULL)
   {
      pDynamicResources =
         (DSL_ST_DynamicResources_t*)DSL_ST_Malloc(
            sizeof(DSL_ST_DynamicResources_t));
      if (pDynamicResources == DSL_NULL)
      {
#if defined(DSL_ST_PLATFORM_VRX518)
         /* TODO: unify printing for VRX518 and VRX618 */
         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - DSL_ST_StatusParamsUpdate: dynamic resources"
            "allocation failure!" DSL_CPE_CRLF));
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
         return DSL_ERROR;
      }
      memset(pDynamicResources, 0, sizeof(DSL_ST_DynamicResources_t));
   }

   switch (eNodeIdx)
   {
   case DSL_LINE_ENTRIES:
      DSL_ST_LineNrOfEntriesUpdate(eNodeIdx, nLine, nChannel);
      break;
   case DSL_CHANNEL_ENTRIES:
      DSL_ST_ChannelNrOfEntriesUpdate(eNodeIdx, nLine, nChannel);
      break;
   case DSL_BND_GROUP_ENTRIES:
      DSL_ST_BndGroupNrOfEntriesUpdate(eNodeIdx, nLine, nChannel);
      break;
   case DSL_API_VERSION:
      DSL_ST_ApiVersionUpdate(pContext, eNodeIdx, nLine, nChannel);
      break;
   case DSL_DRV_VERSION:
      DSL_ST_MeiVersionUpdate(pContext, eNodeIdx, nLine, nChannel);
      break;
   case DSL_HW_VERSION:
      DSL_ST_HwVersionUpdate(pContext, eNodeIdx, nLine, nChannel);
      break;
   case DSL_CHIPSET_TYPE:
      DSL_ST_ChipsetTypeUpdate(pContext, eNodeIdx, nLine, nChannel);
      break;
   /***********************************/
   /* <dsl.status.line.[id]> section: */
   /***********************************/
      case DSL_STATUS_LINE_STATUS:
         DSL_ST_LineStatusUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_UPSTREAM:
         DSL_ST_UpstreamUpdate(eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_FW_VERSION:
         DSL_ST_FwVersionUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_LINK_STATUS:
         DSL_ST_LinkStatusUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_STD_SUPPORTED:
         DSL_ST_StdSupportedUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_XTSE:
         DSL_ST_XtseConfigUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_STD_USED:
         DSL_ST_StdUsedUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_XTSE_USED:
         DSL_ST_XtseStatusUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_ENCODING:
         DSL_ST_LineEncodingUpdate(eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_ALLOWED_PROFILES:
         DSL_ST_AllowedProfilesUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_CURRENT_PROFILE:
         DSL_ST_CurrentProfileUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_PWR_MGMT_STATE:
         DSL_ST_PowerMgmtStateUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_SUCC_FAIL_CAUSE:
         DSL_ST_SuccFailCauseUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_LAST_STATE_TRANSM_US:
         DSL_ST_LastStateTransmUpdate(
            pContext, eNodeIdx, nLine, nChannel, DSL_UPSTREAM);
         break;
      case DSL_STATUS_LINE_LAST_STATE_TRANSM_DS:
         DSL_ST_LastStateTransmUpdate(
            pContext, eNodeIdx, nLine, nChannel, DSL_DOWNSTREAM);
         break;
      case DSL_STATUS_LINE_US0_MASK:
         DSL_ST_Us0MaskUpdate(eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_TRELLIS_US:
      case DSL_STATUS_LINE_TRELLIS_DS:
      case DSL_STATUS_LINE_ACT_SNR_MODE_US:
      case DSL_STATUS_LINE_ACT_SNR_MODE_DS:
         DSL_ST_LineFeatureUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_LINE_NR:
         DSL_ST_LineNrUpdate(eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_MAX_BIT_RATE_US:
         DSL_ST_MaxBitRateUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_MAX_BIT_RATE_DS:
         DSL_ST_MaxBitRateUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_NOISE_MARGIN_US:
         DSL_ST_NoiseMarginUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_NOISE_MARGIN_DS:
         DSL_ST_NoiseMarginUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_SNR_MPB_US:
         DSL_ST_SnrMpbUpdate(
            pContext, eNodeIdx, nLine, nChannel, DSL_UPSTREAM);
         break;
      case DSL_STATUS_LINE_SNR_MPB_DS:
         DSL_ST_SnrMpbUpdate(
            pContext, eNodeIdx, nLine, nChannel, DSL_DOWNSTREAM);
         break;
      case DSL_STATUS_LINE_POWER_US:
         DSL_ST_PowerUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_POWER_DS:
         DSL_ST_PowerUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_XTUR_VENDOR:
         DSL_ST_XturVendorUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_XTUR_COUNTRY:
         DSL_ST_XturCountryUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_XTUR_ANSI_STD:
         DSL_ST_XturAnsiStdUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_XTUR_ANSI_REV:
         DSL_ST_XturAnsiRevUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_XTUC_VENDOR:
         DSL_ST_XtucVendorUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_XTUC_COUNTRY:
         DSL_ST_XtucCountryUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_XTUC_ANSI_STD:
         DSL_ST_XtucAnsiStdUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_XTUC_ANSI_REV:
         DSL_ST_XtucAnsiRevUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
#if defined(DSL_ST_PLATFORM_VRX518)
      case DSL_STATUS_LINE_UPBOKLER:
         DSL_ST_UpboklerUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
      case DSL_STATUS_LINE_UPBOKLER_PB:
         DSL_ST_UpboklerPbUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_RXTHRSH_DS:
         DSL_ST_RxthrshDsUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_ACT_RA_MODE_US:
         DSL_ST_ActRaModeUpdate(
            pContext, eNodeIdx, nLine, nChannel, DSL_UPSTREAM);
         break;
      case DSL_STATUS_LINE_ACT_RA_MODE_DS:
         DSL_ST_ActRaModeUpdate(
            pContext, eNodeIdx, nLine, nChannel, DSL_DOWNSTREAM);
         break;
      case DSL_STATUS_LINE_SNR_MROC_US:
         DSL_ST_SnrMrocUpdate(eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_SNR_MROC_DS:
         DSL_ST_SnrMrocUpdate(eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_ATTENUATION_US:
         DSL_ST_AttenuationUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_LINE_ATTENUATION_DS:
         DSL_ST_AttenuationUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
#if defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION)
      case DSL_STATUS_LINE_MFD_BASIC_DATA_FILTER_DETECTION:
      case DSL_STATUS_LINE_MFD_BASIC_DATA_METRIC3:
         DSL_ST_MfdBasicDataStatusUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
#endif /* defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION) */
      /************************************************/
      /* <dsl.status.line.[id].channel.[id]> section: */
      /************************************************/
         case DSL_STATUS_LINE_CHANNEL_STATUS:
            DSL_ST_ChannelStatusUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATUS_LINE_CHANNEL_LINKENC_SUPP:
            DSL_ST_ChannelLinkEncapSupportedUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATUS_LINE_CHANNEL_LINKENC_USED:
            DSL_ST_ChannelLinkEncapUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;

         case DSL_STATUS_LINE_CHANNEL_LPATH:
         case DSL_STATUS_LINE_CHANNEL_INTLVDEPTH:
         case DSL_STATUS_LINE_CHANNEL_INTLVBLOCK:
            DSL_ST_ChannelFramingUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATUS_LINE_CHANNEL_ACT_INTERL_DELAY:
         case DSL_STATUS_LINE_CHANNEL_ACTINP:
            DSL_ST_ChannelActStatusUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATUS_LINE_CHANNEL_INPREPORT:
#if defined(DSL_ST_PLATFORM_VRX618)
            DSL_ST_ChannelActINPReportUpdate(
               pContext, eNodeIdx, nLine, nChannel);
#elif defined(DSL_ST_PLATFORM_VRX518)
            DSL_ST_ChannelActStatusUpdate(
               pContext, eNodeIdx, nLine, nChannel);
#endif
            break;
         case DSL_STATUS_LINE_CHANNEL_NFEC:
         case DSL_STATUS_LINE_CHANNEL_RFEC:
         case DSL_STATUS_LINE_CHANNEL_LSYMB:
            DSL_ST_ChannelFramingUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATUS_LINE_CHANNEL_DATARATE_US:
         case DSL_STATUS_LINE_CHANNEL_DATARATE_DS:
            DSL_ST_ChannelActStatusUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATUS_LINE_CHANNEL_ACTNDR_US:
         case DSL_STATUS_LINE_CHANNEL_ACTINPREIN_US:
         case DSL_STATUS_LINE_CHANNEL_ACTNDR_DS:
         case DSL_STATUS_LINE_CHANNEL_ACTINPREIN_DS:
            DSL_ST_ChannelActStatusUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
#if defined(DSL_ST_PLATFORM_VRX518)
      /********************************************/
      /* <dsl.status.bonding_group.[id]> section: */
      /********************************************/
      case DSL_STATUS_BND_GROUP_BOND_SCHEMES_SUPPORTED:
         DSL_ST_BndSchemesSupportedUpdate(pContext, eNodeIdx,
            nLine, nChannel);
         break;
      case DSL_STATUS_BND_GROUP_BOND_SCHEME:
         DSL_ST_BndSchemeUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_BND_GROUP_DATARATE_US:
      case DSL_STATUS_BND_GROUP_DATARATE_DS:
         DSL_ST_BndDatarateUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
#if defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
   /****************************************/
   /* <dsl.status.fast.line.[id]> section: */
   /****************************************/
      case DSL_STATUS_FAST_LINE_ALLOWED_PROFILES:
         DSL_ST_FastAllowedProfilesUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_FAST_LINE_CURRENT_PROFILE:
         DSL_ST_FastCurrentProfileUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_FAST_LINE_SNRMRMC_US:
      case DSL_STATUS_FAST_LINE_SNRMRMC_DS:
         DSL_ST_FastSnrmrmcUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_FAST_LINE_BITSRMCPS_US:
      case DSL_STATUS_FAST_LINE_BITSRMCPS_DS:
         DSL_ST_FastBitsrmcpsUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATUS_FAST_LINE_MINEFTR:
         DSL_ST_FastMineftrUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
#endif /* defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */
   /**********************************/
   /* <dsl.stats.line.[id]> section: */
   /**********************************/
      case DSL_STATS_LINE_TOTAL_START:
         DSL_ST_TotalStartUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_SHOWTIME_START:
         DSL_ST_ShowtimeStartUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_LAST_SHOWTIME_START:
         DSL_ST_LastShowtimeStartUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_CURRENT_DAY_START:
         DSL_ST_CurrDayStartUpdate(pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_QUARTER_HOUR_START:
         DSL_ST_QuarterHourStartUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_TOTAL_ERR_SECS:
         DSL_ST_TotalErrSecsUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_TOTAL_SEV_ERR_SECS:
         DSL_ST_TotalSevErrSecsUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_SHOWTIME_ERR_SECS:
         DSL_ST_ShowtimeErrSecsUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_SHOWTIME_SEV_ERR_SECS:
         DSL_ST_ShowtimeSevErrSecsUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_LAST_SHOWTIME_ERR_SECS:
         DSL_ST_LastShowtimeErrSecsUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_LAST_SHOWTIME_SEV_ERR_SECS:
         DSL_ST_LastShowtimeSevErrSecsUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_CURRENT_DAY_ERR_SECS:
         DSL_ST_CurrDayErrSecsUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_CURRENT_DAY_SEV_ERR_SECS:
         DSL_ST_CurrDaySevErrSecsUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_QUARTER_HOUR_ERR_SECS:
         DSL_ST_QuarterHourErrSecsUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_LINE_QUARTER_HOUR_SEV_ERR_SECS:
         DSL_ST_QuarterHourSevErrSecsUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      /***********************************************/
      /* <dsl.stats.line.[id].channel.[id]> section: */
      /***********************************************/
         case DSL_STATS_LINE_CHANNEL_TOTAL_START:
         case DSL_STATS_LINE_CHANNEL_TOTAL_XTUR_FEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_TOTAL_XTUR_CRC_ERRORS:
            DSL_ST_ChannelCountersTotalUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATS_LINE_CHANNEL_TOTAL_XTUC_FEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_TOTAL_XTUC_CRC_ERRORS:
            DSL_ST_ChannelCountersTotalUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATS_LINE_CHANNEL_TOTAL_XTUR_HEC_ERRORS:
            DSL_ST_ChannelDataPathCountersTotalUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATS_LINE_CHANNEL_TOTAL_XTUC_HEC_ERRORS:
            DSL_ST_ChannelDataPathCountersTotalUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATS_LINE_CHANNEL_SHOWTIME_START:
         case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUR_FEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUR_CRC_ERRORS:
            DSL_ST_ChannelCountersShowtimeUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUC_FEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUC_CRC_ERRORS:
            DSL_ST_ChannelCountersShowtimeUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_START:
         case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUR_FEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUR_CRC_ERRORS:
            DSL_ST_ChannelCountersShowtimeUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUC_FEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUC_CRC_ERRORS:
            DSL_ST_ChannelCountersShowtimeUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUR_HEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUC_HEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUR_HEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUC_HEC_ERRORS:
            DSL_ST_ChannelDataPathCountersShowtimeUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_START:
         case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUR_FEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUR_CRC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUC_FEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUC_CRC_ERRORS:
            DSL_ST_ChannelCounters1DayUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUR_HEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUC_HEC_ERRORS:
            DSL_ST_ChannelDataPathCounters1DayUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_START:
         case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUR_FEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUR_CRC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUC_FEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUC_CRC_ERRORS:
            DSL_ST_ChannelCounters15MinUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
         case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUR_HEC_ERRORS:
         case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUC_HEC_ERRORS:
            DSL_ST_ChannelDataPathCounters15MinUpdate(
               pContext, eNodeIdx, nLine, nChannel);
            break;
#if defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
   /***************************************/
   /* <dsl.stats.fast.line.[id]> section: */
   /***************************************/
      case DSL_STATS_FAST_LINE_TOTAL_SUCCESS_BSW:
         DSL_ST_FastTotalSuccessBswUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_FAST_LINE_TOTAL_SUCCESS_SRA:
         DSL_ST_FastTotalSuccessSraUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_FAST_LINE_TOTAL_SUCCESS_FRA:
         DSL_ST_FastTotalSuccessFraUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_FAST_LINE_TOTAL_SUCCESS_RPA:
         DSL_ST_FastTotalSuccessRpaUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_FAST_LINE_TOTAL_SUCCESS_TIGA:
         DSL_ST_FastTotalSuccessTigaUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_BSW:
      case DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_BSW:
         DSL_ST_FastShowtimeSuccessBswUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_SRA:
      case DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_SRA:
         DSL_ST_FastShowtimeSuccessSraUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_FRA:
      case DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_FRA:
         DSL_ST_FastShowtimeSuccessFraUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_RPA:
      case DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_RPA:
         DSL_ST_FastShowtimeSuccessRpaUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
      case DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_TIGA:
      case DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_TIGA:
         DSL_ST_FastShowtimeSuccessTigaUpdate(
            pContext, eNodeIdx, nLine, nChannel);
         break;
#endif /* defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */
#if defined(DSL_ST_PLATFORM_VRX518)
#if defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1)
   /********************************/
   /* <dsl.configuration> section: */
   /********************************/
   case DSL_CONFIGURATION_STATUS:
      DSL_ST_ConfigurationStatusUpdate(
         pContext, eNodeIdx, nLine, nChannel);
      break;
#endif /* defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1) */
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
   default:
#if defined(DSL_ST_PLATFORM_VRX518)
      /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - Status Parser (DSL_ST_StatusParamsUpdate): "
         "unknown node! (eNodeIdx=%d, nLine=%d, nChannel=%d)"
         DSL_CPE_CRLF, eNodeIdx, nLine, nChannel));
      nErrorCode = DSL_ERROR;
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
      break;
   }

   return nErrorCode;
}

/*
   This function is meant to trigger single status parameter
   update for all supported frameworks.
*/
static DSL_void_t DSL_ST_StatusParamUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nLine,
   const DSL_uint8_t nChannel,
   const DSL_ST_StatusNodeType_t eParamType,
   const DSL_ST_ParamValue_t *uValue
)
{
#if defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1)
   /* trigger single param update in the JSON module */
   DSL_ST_JsonStatusParamUpdate(eNodeIdx, nLine, nChannel, eParamType, uValue);
#endif /* defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1) */

#if defined(INCLUDE_DSL_STATUS_UBUS_SUPPORT) && (INCLUDE_DSL_STATUS_UBUS_SUPPORT == 1)
   DSL_ST_UbusUpdate(eNodeIdx, nLine, nChannel, eParamType, uValue);
#endif /* defined(INCLUDE_DSL_STATUS_UBUS_SUPPORT) && (INCLUDE_DSL_STATUS_UBUS_SUPPORT == 1) */
}

/* --- Common section --- */

static DSL_void_t DSL_ST_LineNrOfEntriesUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

   /* update integer param */
   uValue.nValue = DSL_ST_DSL_ENTITIES;
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_INT, &uValue);
}

static DSL_void_t DSL_ST_ChannelNrOfEntriesUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

   /* update integer param */
   uValue.nValue = DSL_ST_CHANNELS_PER_LINE;
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_INT, &uValue);
}

static DSL_void_t DSL_ST_BndGroupNrOfEntriesUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

   /* update integer param */
   uValue.nValue = DSL_ST_BND_GROUP_ENTRIES;
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_INT, &uValue);
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all version information needed
   for common "version" parameters in the status tree
   and keeps it in a static structure in order to not to
   send IOCTL requests each time
*/
static const DSL_char_t* DSL_ST_VersionInfoGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx)
{
   DSL_Error_t nRet = DSL_SUCCESS;
   static DSL_VersionInformation_t sVersionInfo = { 0 };
   const char *sVersion = DSL_NULL;
   const DSL_int_t nDevice = 0;

   /* send IOCTL only if struct is zeroed (first execution)
   or some parameters are not yet set (some information
   can be available with delay, e.g. hw version is available
   later, after FW DL) */
   if ((eNodeIdx == DSL_API_VERSION && (
         DSL_ST_strnlen_s(
            sVersionInfo.data.DSL_DriverVersionApi,
            MAX_INFO_STRING_LEN) == 0 ||
         strcmp(sVersionInfo.data.DSL_DriverVersionApi, "n/a") == 0)) ||
      (eNodeIdx == DSL_DRV_VERSION && (
         DSL_ST_strnlen_s(
            sVersionInfo.data.DSL_DriverVersionMeiBsp,
            MAX_INFO_STRING_LEN) == 0 ||
         strcmp(sVersionInfo.data.DSL_DriverVersionMeiBsp, "n/a") == 0)) ||
      (eNodeIdx == DSL_HW_VERSION && (
         DSL_ST_strnlen_s(
            sVersionInfo.data.DSL_ChipSetHWVersion,
            MAX_INFO_STRING_LEN) == 0 ||
         strcmp(sVersionInfo.data.DSL_ChipSetHWVersion, "n/a") == 0)) ||
      (eNodeIdx == DSL_CHIPSET_TYPE && (
            DSL_ST_strnlen_s(
               sVersionInfo.data.DSL_ChipSetType,
               MAX_INFO_STRING_LEN) == 0 ||
            strcmp(sVersionInfo.data.DSL_ChipSetType, "n/a") == 0))
      )
   {
      nRet = DSL_CPE_Ioctl(pContext->fd[nDevice],
         DSL_FIO_VERSION_INFORMATION_GET, (int)&sVersionInfo);

      if (nRet < DSL_SUCCESS ||
         sVersionInfo.accessCtl.nReturn < DSL_SUCCESS)
      {
         /* TODO: unify printing for VRX518 and VRX618 */
         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - StatusParser, DSL_ST_VersionInfoGet: "
            "DSL_FIO_VERSION_INFORMATION_GET ioctl failed "
            "(device<%d>, nRet = %d, accessCtrl = %d)!" DSL_CPE_CRLF,
            nDevice, nRet, sVersionInfo.accessCtl.nReturn));
      }
   }

   switch (eNodeIdx)
   {
   case DSL_API_VERSION:
      sVersion = sVersionInfo.data.DSL_DriverVersionApi;
      break;
   case DSL_DRV_VERSION:
      sVersion = sVersionInfo.data.DSL_DriverVersionMeiBsp;
      break;
   case DSL_HW_VERSION:
      sVersion = sVersionInfo.data.DSL_ChipSetHWVersion;
      break;
   case DSL_CHIPSET_TYPE:
      sVersion = sVersionInfo.data.DSL_ChipSetType;
      break;
   case DSL_STATUS_LINE_FW_VERSION:
      if (pContext->pWhatStrings != DSL_NULL &&
         pContext->pWhatStrings->bCreated == DSL_TRUE)
      {
         sVersion = pContext->pWhatStrings->sData;
      }
      break;
   default:
      /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_ST_VersionInfoGet: "
         "unknown node!"
         DSL_CPE_CRLF));
      break;
   }

   return sVersion;
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all version information needed
   for common "version" parameters in the status tree
*/
static const DSL_char_t* DSL_ST_VersionInfoGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx)
{
   DSL_Error_t nRet = DSL_SUCCESS;
   static DSL_VersionInformationData_t sVersionInfo = { 0 };
   const char *sVersion = DSL_NULL;

   /* send IOCTL only if struct is zeroed (first execution)
   or some parameters are not yet set (some information
   can be available with delay, e.g. hw version is available
   later, after FW DL) */
   if ((eNodeIdx == DSL_API_VERSION && (
         DSL_ST_strnlen_s(
            sVersionInfo.DSL_APILibraryVersion, MAX_INFO_STRING_LEN) == 0 ||
         strcmp(sVersionInfo.DSL_APILibraryVersion, "n/a") == 0)) ||
      (eNodeIdx == DSL_DRV_VERSION && (
         DSL_ST_strnlen_s(
            sVersionInfo.DSL_DriverVersion, MAX_INFO_STRING_LEN) == 0 ||
         strcmp(sVersionInfo.DSL_DriverVersion, "n/a") == 0)) ||
      (eNodeIdx == DSL_HW_VERSION && (
         DSL_ST_strnlen_s(
            sVersionInfo.DSL_ChipSetHWVersion, MAX_INFO_STRING_LEN) == 0 ||
         strcmp(sVersionInfo.DSL_ChipSetHWVersion, "n/a") == 0)) ||
      (eNodeIdx == DSL_CHIPSET_TYPE && (
         DSL_ST_strnlen_s(
            sVersionInfo.DSL_ChipSetType, MAX_INFO_STRING_LEN) == 0 ||
         strcmp(sVersionInfo.DSL_ChipSetType, "n/a") == 0)) ||
      /* FW version can change in the runtime */
      (eNodeIdx == DSL_STATUS_LINE_FW_VERSION))
   {
      nRet = DSL_VersionInformationGet(pContext, &sVersionInfo);

      if (nRet < DSL_SUCCESS)
      {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - StatusParser, DSL_ST_VersionInfoGet: "
            "DSL_FIO_VERSION_INFORMATION_GET ioctl failed "
            "(device<%d>, nRet = %d, accessCtrl = %d)!" DSL_CPE_CRLF,
            nDevice, nRet, sVersionInfo.accessCtl.nReturn));
#endif /* if 0 */
      }
   }

   switch (eNodeIdx)
   {
   case DSL_API_VERSION:
      sVersion = sVersionInfo.DSL_APILibraryVersion;
      break;
   case DSL_DRV_VERSION:
      sVersion = sVersionInfo.DSL_DriverVersion;
      break;
   case DSL_HW_VERSION:
      sVersion = sVersionInfo.DSL_ChipSetHWVersion;
      break;
   case DSL_CHIPSET_TYPE:
      sVersion = sVersionInfo.DSL_ChipSetType;
      break;
   case DSL_STATUS_LINE_FW_VERSION:
      sVersion = sVersionInfo.DSL_ChipSetFWVersion;
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_ST_VersionInfoGet: "
         "unknown node!"
         DSL_CPE_CRLF));
#endif /* if 0 */
      break;
   }

   return sVersion;
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_ApiVersionUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   uValue.sValue = DSL_ST_VersionInfoGet__vrx518(pContext, DSL_API_VERSION);
#elif defined(DSL_ST_PLATFORM_VRX618)
   uValue.sValue = DSL_ST_VersionInfoGet__vrx618(pContext, DSL_API_VERSION);
#endif /* VRX518/VRX618 */

   /* update string param */
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_STRING, &uValue);
}

static DSL_void_t DSL_ST_MeiVersionUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   uValue.sValue = DSL_ST_VersionInfoGet__vrx518(pContext, DSL_DRV_VERSION);
#elif defined(DSL_ST_PLATFORM_VRX618)
   uValue.sValue = DSL_ST_VersionInfoGet__vrx618(pContext, DSL_DRV_VERSION);
#endif /* VRX518/VRX618 */

   /* update string param */
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_STRING, &uValue);
}

static DSL_void_t DSL_ST_HwVersionUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   uValue.sValue = DSL_ST_VersionInfoGet__vrx518(pContext, DSL_HW_VERSION);
#elif defined(DSL_ST_PLATFORM_VRX618)
   uValue.sValue = DSL_ST_VersionInfoGet__vrx618(pContext, DSL_HW_VERSION);
#endif /* VRX518/VRX618 */

   /* update string param */
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_STRING, &uValue);
}

static DSL_void_t DSL_ST_ChipsetTypeUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   uValue.sValue = DSL_ST_VersionInfoGet__vrx518(pContext, DSL_CHIPSET_TYPE);
#elif defined(DSL_ST_PLATFORM_VRX618)
   uValue.sValue = DSL_ST_VersionInfoGet__vrx618(pContext, DSL_CHIPSET_TYPE);
#endif /* VRX518/VRX618 */

   /* update string param */
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_STRING, &uValue);
}

/* --- Line section --- */

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_LINE_STATE_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_LineStateGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_ST_LineStatus_t *pLineState,
   DSL_ST_LinkStatus_t *pLinkState)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_LineState_t *pLineData = DSL_NULL;
#define STATUS_SET_IF_REQUESTED(ptr, value) \
   if (ptr != DSL_NULL) \
   { \
      *ptr = value; \
   } \
   do{}while(0)
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_LINE_STATE_GET, DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pLineData, DSL_LineState_t,
      DSL_ST_FLAG_LINE_STATE_GET, DSL_ST_DSL_ENTITIES);

   if ((pLineState == DSL_NULL && pLinkState == DSL_NULL) ||
         nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pLineData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_LINE_STATE_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_LINE_STATE_GET, (int)&pLineData[nDev]);

         if (nRet < DSL_SUCCESS ||
            pLineData[nDev].accessCtl.nReturn != DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_LINE_STATE_GET ioctl failed "
               "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, pLineData[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }

         DSL_ST_CallFlagSet(DSL_ST_FLAG_LINE_STATE_GET);
      }
   }

   switch (pLineData[nDevice].data.nLineState)
   {
   case DSL_LINESTATE_NOT_INITIALIZED:
   case DSL_LINESTATE_NOT_UPDATED:
   case DSL_LINESTATE_DISABLED:
   case DSL_LINESTATE_IDLE_REQUEST:
      STATUS_SET_IF_REQUESTED(pLinkState, DSL_ST_LINK_INITIALIZING);
      break;
   case DSL_LINESTATE_IDLE:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_DOWN);
      STATUS_SET_IF_REQUESTED(pLinkState, DSL_ST_LINK_DISABLED);
      break;
   case DSL_LINESTATE_EXCEPTION:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_ERROR);
      STATUS_SET_IF_REQUESTED(pLinkState, DSL_ST_LINK_ERROR);
      break;
   case DSL_LINESTATE_SILENT:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_READY);
      break;
   case DSL_LINESTATE_HANDSHAKE:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_HANDSHAKE);
      break;
   case DSL_LINESTATE_FULL_INIT:
   case DSL_LINESTATE_SHOWTIME_NO_SYNC:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_TRAINING);
      break;
   case DSL_LINESTATE_SHOWTIME_TC_SYNC:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_UP);
      STATUS_SET_IF_REQUESTED(pLinkState, DSL_ST_LINK_UP);
      break;
   case DSL_LINESTATE_LOOPDIAGNOSTIC_ACTIVE:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_LDM_ACTIVE);
      break;
   case DSL_LINESTATE_LOOPDIAGNOSTIC_COMPLETE:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_LDM_COMPLETE);
      break;
   default:
      break;
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_LineStateGet API function
*/
static DSL_Error_t DSL_ST_LineStateGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_ST_LineStatus_t *pLineState,
   DSL_ST_LinkStatus_t *pLinkState)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_LineStateData_t *pLineData = DSL_NULL;
#define STATUS_SET_IF_REQUESTED(ptr, value) \
   if (ptr != DSL_NULL) \
   { \
      *ptr = value; \
   } \
   do{}while(0)
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_LINE_STATE_GET, DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pLineData, DSL_LineStateData_t,
      DSL_ST_FLAG_LINE_STATE_GET, DSL_ST_DSL_ENTITIES);

   if ((pLineState == DSL_NULL && pLinkState == DSL_NULL) ||
      nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pLineData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_LINE_STATE_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         /* get current line state */
         nRet = DSL_LineStateGet(pContext, nDev, &pLineData[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_LINE_STATE_GET ioctl failed "
               "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, pLineData[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_LINE_STATE_GET);
   }

   /* map line state to internal type */
   switch (pLineData[nDevice].nLineState)
   {
   case DSL_LINESTATUS_NOT_INITIALIZED:
   case DSL_LINESTATUS_IDLE_REQUEST:
      STATUS_SET_IF_REQUESTED(pLinkState, DSL_ST_LINK_INITIALIZING);
      break;
   case DSL_LINESTATUS_IDLE:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_DOWN);
      STATUS_SET_IF_REQUESTED(pLinkState, DSL_ST_LINK_DISABLED);
      break;
   case DSL_LINESTATUS_SILENT:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_READY);
      break;
   case DSL_LINESTATUS_HANDSHAKE:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_HANDSHAKE);
      break;
   case DSL_LINESTATUS_FULL_INIT:
   case DSL_LINESTATE_SHORT_INIT_ENTRY:
   case DSL_LINESTATUS_DISCOVERY:
   case DSL_LINESTATUS_TRAINING:
   case DSL_LINESTATUS_ANALYSIS:
   case DSL_LINESTATUS_EXCHANGE:
   case DSL_LINESTATUS_SHOWTIME_NO_SYNC:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_TRAINING);
      break;
   case DSL_LINESTATUS_SHOWTIME_TC_SYNC:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_UP);
      STATUS_SET_IF_REQUESTED(pLinkState, DSL_ST_LINK_UP);
      break;
   case DSL_LINESTATUS_EXCEPTION:
      STATUS_SET_IF_REQUESTED(pLineState, DSL_ST_LINE_ERROR);
      STATUS_SET_IF_REQUESTED(pLinkState, DSL_ST_LINK_ERROR);
      break;
   default:
      break;
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_LineStatusUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_LineStatus_t eLineState = DSL_ST_LINE_NOT_INITIALIZED;
   DSL_char_t sLineStatus[32] = "";
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineStateGet__vrx518(
      pContext, nDevice, &eLineState, DSL_NULL) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineStateGet__vrx618(
         pContext, nDevice, &eLineState, DSL_NULL) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      switch (eLineState)
      {
      case DSL_ST_LINE_DOWN:
      case DSL_ST_LINE_ERROR:
         DSL_ST_strncpy_s(sLineStatus, sizeof(sLineStatus),
            "DOWN", sizeof("DOWN"));
         break;
      case DSL_ST_LINE_READY:
         DSL_ST_strncpy_s(sLineStatus, sizeof(sLineStatus),
            "READY", sizeof("READY"));
         break;
      case DSL_ST_LINE_HANDSHAKE:
         DSL_ST_strncpy_s(sLineStatus, sizeof(sLineStatus),
            "HANDSHAKE", sizeof("HANDSHAKE"));
         break;
      case DSL_ST_LINE_TRAINING:
         DSL_ST_strncpy_s(sLineStatus, sizeof(sLineStatus),
            "TRAINING", sizeof("TRAINING"));
         break;
      case DSL_ST_LINE_UP:
         DSL_ST_strncpy_s(sLineStatus, sizeof(sLineStatus),
            "UP", sizeof("UP"));
         break;
      case DSL_ST_LINE_LDM_ACTIVE:
         DSL_ST_strncpy_s(sLineStatus, sizeof(sLineStatus),
            "LDM_ACTIVE", sizeof("LDM_ACTIVE"));
         break;
      case DSL_ST_LINE_LDM_COMPLETE:
         DSL_ST_strncpy_s(sLineStatus, sizeof(sLineStatus),
            "LDM_COMPLETE", sizeof("LDM_COMPLETE"));
         break;
      default:
         break;
      }

      /* update string param */
      uValue.sValue = sLineStatus;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

static DSL_void_t DSL_ST_UpstreamUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

   /* update boolean param */
   uValue.bValue = DSL_TRUE; /* always true */
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_BOOL, &uValue);
}

static DSL_void_t DSL_ST_FwVersionUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   uValue.sValue = DSL_ST_VersionInfoGet__vrx518(pContext, eNodeIdx);
#elif defined(DSL_ST_PLATFORM_VRX618)
   uValue.sValue = DSL_ST_VersionInfoGet__vrx618(pContext, eNodeIdx);
#endif /* VRX518/VRX618 */

   /* update string param */
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_STRING, &uValue);
}

static DSL_void_t DSL_ST_LinkStatusUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_LinkStatus_t eLinkState = DSL_ST_LINK_ESTABLISHING;
   DSL_char_t sLinkStatus[32] = "";
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineStateGet__vrx518(
      pContext, nDevice, DSL_NULL, &eLinkState) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineStateGet__vrx618(
      pContext, nDevice, DSL_NULL, &eLinkState) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      switch (eLinkState)
      {
      case DSL_ST_LINK_ESTABLISHING:
         DSL_ST_strncpy_s(sLinkStatus, sizeof(sLinkStatus),
            "EstablishingLink", sizeof("EstablishingLink"));
         break;
      case DSL_ST_LINK_INITIALIZING:
         DSL_ST_strncpy_s(sLinkStatus, sizeof(sLinkStatus),
            "Initializing", sizeof("Initializing"));
         break;
      case DSL_ST_LINK_DISABLED:
         DSL_ST_strncpy_s(sLinkStatus, sizeof(sLinkStatus),
            "Disabled", sizeof("Disabled"));
         break;
      case DSL_ST_LINK_UP:
         DSL_ST_strncpy_s(sLinkStatus, sizeof(sLinkStatus),
            "Up", sizeof("Up"));
         break;
      case DSL_ST_LINK_ERROR:
         DSL_ST_strncpy_s(sLinkStatus, sizeof(sLinkStatus),
            "Error", sizeof("Error"));
         break;
      default:
         break;
      }

      /* update string param */
      uValue.sValue = sLinkStatus;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_G997_XTU_SYSTEM_ENABLING_CONFIG_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_SystemEnablingConfigGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_uint8_t *pXTSE)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_G997_XTUSystemEnabling_t *pXtseData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(pErrorCodeArray,
      DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_CONFIG_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pXtseData, DSL_G997_XTUSystemEnabling_t,
      DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_CONFIG_GET,
      DSL_ST_DSL_ENTITIES);

   if (pXTSE == DSL_NULL ||
         nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pXtseData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_CONFIG_GET))
   {
      for (DSL_int_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_G997_XTU_SYSTEM_ENABLING_CONFIG_GET, (int)&pXtseData[nDev]);

         if (nRet < DSL_SUCCESS ||
            pXtseData[nDev].accessCtl.nReturn < DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_G997_XTU_SYSTEM_ENABLING_CONFIG_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, pXtseData[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_CONFIG_GET);
   }

   /* get data for the given device */
   for (DSL_int_t i = 0; i < DSL_G997_NUM_XTSE_OCTETS; ++i)
   {
      pXTSE[i] = pXtseData[nDevice].data.XTSE[i];
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_G997_XTUSystemEnablingConfigGet API function
*/
static DSL_Error_t DSL_ST_SystemEnablingConfigGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_uint8_t *pXTSE)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_G997_XTUSystemEnablingData_t *pXtseData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(pErrorCodeArray,
      DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_CONFIG_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pXtseData, DSL_G997_XTUSystemEnablingData_t,
      DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_CONFIG_GET,
      DSL_ST_DSL_ENTITIES);

   if (pXTSE == DSL_NULL ||
         nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pXtseData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_CONFIG_GET))
   {
      for (DSL_int_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet =
            DSL_G997_XTUSystemEnablingConfigGet(
               pContext, nDev, &pXtseData[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_G997_XTU_SYSTEM_ENABLING_CONFIG_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, pXtseData[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_CONFIG_GET);
   }

   /* get data for the given device */
   for (DSL_int_t i = 0; i < DSL_G997_NUM_XTSE_OCTETS; ++i)
   {
      pXTSE[i] = pXtseData[nDevice].XTSE[i];
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_StdSupportedUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nOctet = 0, nBit = 0;
   DSL_size_t nOffset = 0, nBufLen = 0;
   DSL_char_t sStandardsSupported[512] = "";
   DSL_char_t *sStandardName = DSL_NULL;
   DSL_uint8_t XTSE[DSL_G997_NUM_XTSE_OCTETS] = { 0 };
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_SystemEnablingConfigGet__vrx518(
         pContext, nDevice, XTSE) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_SystemEnablingConfigGet__vrx618(
         pContext, nDevice, XTSE) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      nBufLen = sizeof(sStandardsSupported);
      for (unsigned int i = 0; i < nStandardsNum; ++i)
      {
         nOctet = standartsTable[i].nOctet;
         nBit = standartsTable[i].nBit;

         if (XTSE[nOctet] & nBit)
         {
            /* select name from the table and exclude leading comma */
            sStandardName = standartsTable[i].sName + ((nOffset) ? 0 : 1);
            nBufLen = (sizeof(sStandardsSupported) > nOffset) ?
               sizeof(sStandardsSupported) - nOffset : 0;
            DSL_ST_strncpy_s(sStandardsSupported + nOffset, nBufLen,
               sStandardName, nBufLen);
            nOffset += DSL_ST_strnlen_s(sStandardName, nBufLen);
         }
      }

      /* update string param */
      uValue.sValue = sStandardsSupported;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

static DSL_void_t DSL_ST_XtseConfigUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint8_t XTSE[DSL_G997_NUM_XTSE_OCTETS] = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_SystemEnablingConfigGet__vrx518(
         pContext, nDevice, XTSE) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_SystemEnablingConfigGet__vrx618(
         pContext, nDevice, XTSE) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update array param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.aValue.uArray.pU8Array = XTSE;
      uValue.aValue.nSize = DSL_G997_NUM_XTSE_OCTETS;
      uValue.aValue.eInputType = U8;
      uValue.aValue.eOutputType = HEX;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_ARRAY, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_G997_XTU_SYSTEM_ENABLING_STATUS_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_SystemEnablingStatusGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_uint8_t *pXTSE)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_G997_XTUSystemEnabling_t *pXtseData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_STATUS_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pXtseData, DSL_G997_XTUSystemEnabling_t,
      DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_STATUS_GET,
      DSL_ST_DSL_ENTITIES);

   if (pXTSE == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pXtseData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_G997_XTU_SYSTEM_ENABLING_STATUS_GET, (int)&pXtseData[nDev]);

         if (nRet < DSL_SUCCESS ||
            pXtseData[nDev].accessCtl.nReturn < DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_G997_XTU_SYSTEM_ENABLING_STATUS_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, pXtseData[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_STATUS_GET);
   }

   /* get data for the given device */
   for (DSL_uint8_t i = 0; i < DSL_G997_NUM_XTSE_OCTETS; ++i)
   {
      pXTSE[i] = pXtseData[nDevice].data.XTSE[i];
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_G997_XTUSystemEnablingStatusGet API function
*/
static DSL_Error_t DSL_ST_SystemEnablingStatusGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_uint8_t *pXTSE)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_G997_XTUSystemEnablingData_t *pXtseData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_STATUS_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pXtseData, DSL_G997_XTUSystemEnablingData_t,
      DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_STATUS_GET,
      DSL_ST_DSL_ENTITIES);

   if (pXTSE == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pXtseData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_G997_XTUSystemEnablingStatusGet(
            pContext, nDev, &pXtseData[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_LINE_STATE_GET ioctl failed "
               "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, lineData[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_XTU_SYSTEM_ENABLING_STATUS_GET);
   }

   for (DSL_uint8_t i = 0; i < DSL_G997_NUM_XTSE_OCTETS_EXTEND; i++)
   {
      pXTSE[i] = pXtseData[nDevice].XTSE[i];
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_StdUsedUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nOctet = 0, nBits = 0;
   DSL_char_t sStandardUsed[20] = "";
   DSL_char_t *sStandardName = DSL_NULL;
   DSL_uint8_t XTSE[DSL_G997_NUM_XTSE_OCTETS] = { 0 };
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_SystemEnablingStatusGet__vrx518(
         pContext, nDevice, XTSE) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_SystemEnablingStatusGet__vrx618(
         pContext, nDevice, XTSE) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      for (unsigned int i = 0; i < nStandardsNum; ++i)
      {
         nOctet = standartsTable[i].nOctet;
         nBits = standartsTable[i].nBit;

         if (XTSE[nOctet] & nBits)
         {
            sStandardName = standartsTable[i].sName + 1;
            DSL_ST_strncpy_s(sStandardUsed, sizeof(sStandardUsed),
               sStandardName, sizeof(sStandardUsed));
            break;
         }
      }

      /* update string param */
      uValue.sValue = sStandardUsed;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

static DSL_void_t DSL_ST_XtseStatusUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint8_t XTSE[DSL_G997_NUM_XTSE_OCTETS] = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_SystemEnablingStatusGet__vrx518(
         pContext, nDevice, XTSE) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_SystemEnablingStatusGet__vrx618(
         pContext, nDevice, XTSE) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update array param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.aValue.uArray.pU8Array = XTSE;
      uValue.aValue.nSize = DSL_G997_NUM_XTSE_OCTETS;
      uValue.aValue.eInputType = U8;
      uValue.aValue.eOutputType = HEX;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_ARRAY, &uValue);
   }
}

static DSL_void_t DSL_ST_LineEncodingUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

   /* update string param */
   uValue.sValue = "DMT"; /* fixed value */
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_STRING, &uValue);
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_BAND_PLAN_SUPPORT_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_BandPlanSupportedGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_boolean_t bSupported[DSL_BANDPLAN_LAST][DSL_PROFILE_LAST])
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_BandPlanSupport_t *pProfilesSupport = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_BAND_PLAN_SUPPORT_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pProfilesSupport, DSL_BandPlanSupport_t,
      DSL_ST_FLAG_BAND_PLAN_SUPPORT_GET, DSL_ST_DSL_ENTITIES);

   if (bSupported == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pProfilesSupport == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_BAND_PLAN_SUPPORT_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_BAND_PLAN_SUPPORT_GET, (int)&pProfilesSupport[nDev]);

         if (nRet < DSL_SUCCESS ||
            pProfilesSupport[nDev].accessCtl.nReturn < DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_BAND_PLAN_SUPPORT_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, pProfilesSupport[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_BAND_PLAN_SUPPORT_GET);
   }

   /* get data for the given device */
   for (unsigned int i = 0; i < DSL_PROFILE_LAST; i++)
   {
      for (unsigned int j = 0; j < DSL_BANDPLAN_LAST; j++)
      {
         bSupported[j][i] = pProfilesSupport[nDevice].data.bSupported[j][i];
      }
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_BandPlanSupportedGet API function
*/
static DSL_Error_t DSL_ST_BandPlanSupportedGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_boolean_t bSupported[DSL_BANDPLAN_LAST][DSL_PROFILE_LAST])
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_BandPlanSupportData_t *pProfilesSupport = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_BAND_PLAN_SUPPORT_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pProfilesSupport, DSL_BandPlanSupportData_t,
      DSL_ST_FLAG_BAND_PLAN_SUPPORT_GET, DSL_ST_DSL_ENTITIES);

   if (bSupported == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pProfilesSupport == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_BAND_PLAN_SUPPORT_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_BandPlanSupportedGet(pContext, &pProfilesSupport[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_BAND_PLAN_SUPPORT_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, pProfilesSupport[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_BAND_PLAN_SUPPORT_GET);
   }

   /* get data for the given device */
   for (unsigned int i = 0; i < DSL_PROFILE_LAST; i++)
   {
      for (unsigned int j = 0; j < DSL_BANDPLAN_LAST; j++)
      {
         bSupported[j][i] = pProfilesSupport[nDevice].bSupported[j][i];
      }
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_AllowedProfilesUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_boolean_t bSupported[DSL_BANDPLAN_LAST][DSL_PROFILE_LAST] = { 0 };
   DSL_size_t nOffset = 0, nBufLen = 0;
   DSL_char_t sAllowedProfiles[40] = "";
   const DSL_char_t *sProfileName = DSL_NULL;
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   nRet = DSL_ST_BandPlanSupportedGet__vrx518(
      pContext, nDevice, bSupported);
#elif defined(DSL_ST_PLATFORM_VRX618)
   nRet = DSL_ST_BandPlanSupportedGet__vrx618(
      pContext, nDevice, bSupported);
#endif /* VRX518/VRX618 */
   if (nRet == DSL_SUCCESS)
   {
      nBufLen = sizeof(sAllowedProfiles);
      for (unsigned int i = 0; i < DSL_PROFILE_LAST; i++)
      {
         for (unsigned int j = 0; j < DSL_BANDPLAN_LAST; j++)
         {
            if (bSupported[j][i])
            {
               /* select name from the table and exclude leading comma */
               sProfileName = profilesTable[i] + ((nOffset) ? 0 : 1);
               nBufLen = (sizeof(sAllowedProfiles) > nOffset) ?
                  sizeof(sAllowedProfiles) - nOffset : 0;
               DSL_ST_strncpy_s(sAllowedProfiles + nOffset, nBufLen,
                  sProfileName, nBufLen);
               nOffset += DSL_ST_strnlen_s(sProfileName, nBufLen);

               break;
            }
         }
      }

      /* update string param */
      uValue.sValue = sAllowedProfiles;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_BAND_PLAN_STATUS_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_BandPlanStatusGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_ST_Profile_t *pProfile)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_BandPlanStatus_t *pProfilesStatus = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_BAND_PLAN_STATUS_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pProfilesStatus, DSL_BandPlanStatus_t,
      DSL_ST_FLAG_BAND_PLAN_STATUS_GET, DSL_ST_DSL_ENTITIES);

   if (pProfile == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pProfilesStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_BAND_PLAN_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_BAND_PLAN_STATUS_GET, (int)&pProfilesStatus[nDev]);

         if (nRet < DSL_SUCCESS ||
            pProfilesStatus[nDev].accessCtl.nReturn < DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_BAND_PLAN_STATUS_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, pProfilesStatus[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_BAND_PLAN_STATUS_GET);
   }

   /* get data for the given device */
   *pProfile = pProfilesStatus[nDevice].data.nProfile;

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_BandPlanStatusGet API function
*/
static DSL_Error_t DSL_ST_BandPlanStatusGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_ST_Profile_t *pProfile)
{
   DSL_Error_t* pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_BandPlanStatusData_t *pProfilesStatus = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_BAND_PLAN_STATUS_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pProfilesStatus, DSL_BandPlanStatusData_t,
      DSL_ST_FLAG_BAND_PLAN_STATUS_GET, DSL_ST_DSL_ENTITIES);

   if (pProfile == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pProfilesStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_BAND_PLAN_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_BandPlanStatusGet(pContext, nDev, &pProfilesStatus[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_BAND_PLAN_STATUS_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, profilesSupport[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_BAND_PLAN_STATUS_GET);
   }

   /* get data for the given device */
   *pProfile = pProfilesStatus[nDevice].nProfile;

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_CurrentProfileUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_ST_Profile_t nProfile;
   DSL_char_t sCurrentProfile[5] = "";
   const DSL_char_t *sProfileName = DSL_NULL;
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   nRet = DSL_ST_BandPlanStatusGet__vrx518(
      pContext, nDevice, &nProfile);
#elif defined(DSL_ST_PLATFORM_VRX618)
   nRet = DSL_ST_BandPlanStatusGet__vrx618(
      pContext, nDevice, &nProfile);
#endif /* VRX518/VRX618 */
   if (nRet == DSL_SUCCESS)
   {
      for (unsigned int i = 0; i < DSL_PROFILE_LAST; i++)
      {
         if (i == nProfile)
         {
            sProfileName = profilesTable[i] + 1;
            DSL_ST_strncpy_s(sCurrentProfile, sizeof(sCurrentProfile),
               sProfileName, sizeof(sCurrentProfile));
            break;
         }
      }

      /* update string param */
      uValue.sValue = sCurrentProfile;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_G997_POWER_MANAGEMENT_STATUS_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_PowerManagementStatusGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_ST_PowerManagement_t *pPMS)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_G997_PowerManagementStatus_t *pPowerStatus = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_POWER_MANAGEMENT_STATUS_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pPowerStatus, DSL_G997_PowerManagementStatus_t,
      DSL_ST_FLAG_G997_POWER_MANAGEMENT_STATUS_GET, DSL_ST_DSL_ENTITIES);

   if (pPMS == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pPowerStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_POWER_MANAGEMENT_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_G997_POWER_MANAGEMENT_STATUS_GET, (int)&pPowerStatus[nDev]);

         if (nRet < DSL_SUCCESS ||
            pPowerStatus[nDev].accessCtl.nReturn < DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_G997_POWER_MANAGEMENT_STATUS_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, pPowerStatus[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_POWER_MANAGEMENT_STATUS_GET);
   }

   /* get data for the given device */
   *pPMS = pPowerStatus[nDevice].data.nPowerManagementStatus;

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_G997_PowerManagementStatusGet API function
*/
static DSL_Error_t DSL_ST_PowerManagementStatusGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_ST_PowerManagement_t *pPMS)
{
   DSL_Error_t* pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_ST_PowerManagement_t *pPowerStatus = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_POWER_MANAGEMENT_STATUS_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pPowerStatus, DSL_ST_PowerManagement_t,
      DSL_ST_FLAG_G997_POWER_MANAGEMENT_STATUS_GET, DSL_ST_DSL_ENTITIES);

   if (pPMS == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pPowerStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_POWER_MANAGEMENT_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_G997_PowerManagementStatusGet(
            pContext, nDev, &pPowerStatus[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_G997_POWER_MANAGEMENT_STATUS_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, pPowerStatus[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_POWER_MANAGEMENT_STATUS_GET);
   }

   /* get data for the given device */
   *pPMS = pPowerStatus[nDevice];

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_PowerMgmtStateUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_ST_PowerManagement_t powerStatus;
   DSL_char_t *powerTable[] = { "L0", "L1", "L2", "L3" };
   DSL_char_t sPowerMgmtState[4] = "";
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   nRet = DSL_ST_PowerManagementStatusGet__vrx518(
      pContext, nDevice, &powerStatus);
#elif defined(DSL_ST_PLATFORM_VRX618)
   nRet = DSL_ST_PowerManagementStatusGet__vrx618(
      pContext, nDevice, &powerStatus);
#endif /* VRX518/VRX618 */
   if (nRet == DSL_SUCCESS)
   {
      DSL_int32_t nPowerTableSize = sizeof(powerTable) / sizeof(DSL_char_t *);
      for (DSL_int32_t i = 0; i < nPowerTableSize; ++i)
      {
         if (i == powerStatus)
         {
            DSL_ST_strncpy_s(sPowerMgmtState, sizeof(sPowerMgmtState),
               powerTable[i], sizeof(sPowerMgmtState));
            break;
         }
      }

      /* update string param */
      uValue.sValue = sPowerMgmtState;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_G997_LINE_INIT_STATUS_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_LineInitStatusGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_G997_LineInit_t *pInitStatus)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_G997_LineInitStatus_t *pInitFailureStatus = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_LINE_INIT_STATUS_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pInitFailureStatus, DSL_G997_LineInitStatus_t,
      DSL_ST_FLAG_G997_LINE_INIT_STATUS_GET, DSL_ST_DSL_ENTITIES);

   if (pInitStatus == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pInitFailureStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_LINE_INIT_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_G997_LINE_INIT_STATUS_GET, (int)&pInitFailureStatus[nDev]);

         if (nRet < DSL_SUCCESS ||
            pInitFailureStatus[nDev].accessCtl.nReturn < DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_G997_LINE_INIT_STATUS_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, pInitFailureStatus[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_LINE_INIT_STATUS_GET);
   }

   /* get data for the given device */
   *pInitStatus = pInitFailureStatus[nDevice].data.nLineInitStatus;

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_G997_LineInitFailureStatusGet API function
*/
static DSL_Error_t DSL_ST_LineInitStatusGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_G997_LineInitStatus_t *pInitStatus)
{
   DSL_Error_t* pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_G997_LineInitFailureStatus_t *pInitFailureStatus = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_LINE_INIT_STATUS_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pInitFailureStatus, DSL_G997_LineInitFailureStatus_t,
      DSL_ST_FLAG_G997_LINE_INIT_STATUS_GET, DSL_ST_DSL_ENTITIES);

   if (pInitStatus == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pInitFailureStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_LINE_INIT_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_G997_LineInitFailureStatusGet(
            pContext, nDev, &pInitFailureStatus[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_G997_LINE_INIT_STATUS_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, profilesSupport[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_LINE_INIT_STATUS_GET);
   }

   /* get data for the given device */
   *pInitStatus = pInitFailureStatus[nDevice].nLineInitStatus;

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_SuccFailCauseUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_Error_t nRet = DSL_SUCCESS;
#if defined(DSL_ST_PLATFORM_VRX518)
   DSL_G997_LineInit_t initStatus;
#elif defined(DSL_ST_PLATFORM_VRX618)
   DSL_G997_LineInitStatus_t initStatus;
#endif /* VRX518/VRX618 */
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   nRet = DSL_ST_LineInitStatusGet__vrx518(
      pContext, nDevice, &initStatus);
#elif defined(DSL_ST_PLATFORM_VRX618)
   nRet = DSL_ST_LineInitStatusGet__vrx618(
      pContext, nDevice, &initStatus);
#endif /* VRX518/VRX618 */
   if (nRet == DSL_SUCCESS)
   {
      /* update integer param */
      uValue.nValue = initStatus;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_G997_LAST_STATE_TRANSMITTED_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_LastStateTransmittedGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_int_t nDevice,
   const DSL_AccessDir_t nDirection,
   DSL_uint32_t *pLST)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_AccessDir_t nDir = DSL_UPSTREAM;
   DSL_G997_LastStateTransmitted_t *pLastState = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_LAST_STATE_TRANSMITTED_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pLastState, DSL_G997_LastStateTransmitted_t,
      DSL_ST_FLAG_G997_LAST_STATE_TRANSMITTED_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);

   if (pLST == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pLastState == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_LAST_STATE_TRANSMITTED_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (nDir = DSL_UPSTREAM; nDir < DSL_ACCESSDIR_LAST; ++nDir)
         {
            DSL_ST_ARRAY2_INDEX_PTR(pLastState, nDev, nDir)->nDirection = nDir;
            nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
               DSL_FIO_G997_LAST_STATE_TRANSMITTED_GET,
               (int)DSL_ST_ARRAY2_INDEX_PTR(pLastState, nDev, nDir));

            if (nRet < DSL_SUCCESS ||
               DSL_ST_ARRAY2_INDEX_PTR(
                  pLastState, nDev, nDir)->accessCtl.nReturn < DSL_SUCCESS)
            {
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_G997_LAST_STATE_TRANSMITTED_GET ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDev, nRet, DSL_ST_ARRAY2_INDEX_PTR(
                     pLastState, nDev, nDir)->accessCtl.nReturn));

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_LAST_STATE_TRANSMITTED_GET);
   }

   /* get data for the given device */
   *pLST = DSL_ST_ARRAY2_INDEX_PTR(
      pLastState, nDevice, nDirection)->data.nLastStateTransmitted;

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_G997_LastStateTransmittedGet API function
*/
static DSL_Error_t DSL_ST_LastStateTransmittedGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_int_t nDevice,
   const DSL_AccessDir_t nDirection,
   DSL_uint32_t *pLST)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_AccessDir_t nDir = DSL_UPSTREAM;
   DSL_uint32_t *pLastState = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_LAST_STATE_TRANSMITTED_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pLastState, DSL_uint32_t,
      DSL_ST_FLAG_G997_LAST_STATE_TRANSMITTED_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);

   if (pLST == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pLastState == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API functions many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_LAST_STATE_TRANSMITTED_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (nDir = DSL_UPSTREAM; nDir < DSL_ACCESSDIR_LAST; ++nDir)
         {
            nRet = DSL_G997_LastStateTransmittedGet(
               pContext, nDev, nDir,
               DSL_ST_ARRAY2_INDEX_PTR(pLastState, nDev, nDir));

            if (nRet < DSL_SUCCESS)
            {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_G997_LAST_STATE_TRANSMITTED_GET ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDev, nRet, pLastState[nDev][nDir].accessCtl.nReturn));
#endif /* if 0 */

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_LAST_STATE_TRANSMITTED_GET);
   }

   /* get data for the given device */
   *pLST = DSL_ST_ARRAY2_INDEX_VAL(pLastState, nDevice, nDirection);

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_LastStateTransmUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel,
   const DSL_AccessDir_t nDirection)
{
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint32_t nLastStateTransmitted;
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   nRet = DSL_ST_LastStateTransmittedGet__vrx518(
      pContext, nDevice, nDirection, &nLastStateTransmitted);
#elif defined(DSL_ST_PLATFORM_VRX618)
   nRet = DSL_ST_LastStateTransmittedGet__vrx618(
      pContext, nDevice, nDirection, &nLastStateTransmitted);
#endif /* VRX518/VRX618 */
   if (nRet == DSL_SUCCESS)
   {
      /* update integer param */
      uValue.nValue = nLastStateTransmitted;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_Us0MaskUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

   /* update string param */
   uValue.sValue = "0xF3F3"; /* all types supported, use fixed value */
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_STRING, &uValue);
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_LINE_FEATURE_STATUS_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_LineFeatureStatusGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_boolean_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint8_t nDev = 0;
   DSL_AccessDir_t nDir = DSL_UPSTREAM;
   DSL_LineFeature_t *pLineFeature = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_LINE_FEATURE_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST
   );
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pLineFeature, DSL_LineFeature_t,
      DSL_ST_FLAG_LINE_FEATURE_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_LINE_FEATURE_STATUS_GET))
   {
      for (nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (nDir = DSL_UPSTREAM; nDir < DSL_ACCESSDIR_LAST; ++nDir)
         {
            DSL_ST_ARRAY2_INDEX_PTR(
               pLineFeature, nDev, nDir)->nDirection = nDir;
            nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
               DSL_FIO_LINE_FEATURE_STATUS_GET,
               (int)DSL_ST_ARRAY2_INDEX_PTR(pLineFeature, nDev, nDir));

            if (nRet < DSL_SUCCESS ||
               DSL_ST_ARRAY2_INDEX_PTR(
                  pLineFeature, nDev, nDir)->accessCtl.nReturn < DSL_SUCCESS)
            {
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_LINE_FEATURE_STATUS_GET(%s) ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDir == DSL_UPSTREAM ? "US" : "DS", nDev, nRet,
                  DSL_ST_ARRAY2_INDEX_PTR(
                     pLineFeature, nDev, nDir)->accessCtl.nReturn));

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_LINE_FEATURE_STATUS_GET);
   }

   /* get data for the given node */
   switch (eNodeIdx)
   {
   case DSL_STATUS_LINE_TRELLIS_US:
      nDir = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(
            pLineFeature, nDevice, nDir)->data.bTrellisEnable;
      break;
   case DSL_STATUS_LINE_TRELLIS_DS:
      nDir = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(
            pLineFeature, nDevice, nDir)->data.bTrellisEnable;
      break;
   case DSL_STATUS_LINE_ACT_SNR_MODE_US:
      nDir = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(
            pLineFeature, nDevice, nDir)->data.bVirtualNoiseSupport;
      break;
   case DSL_STATUS_LINE_ACT_SNR_MODE_DS:
      nDir = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(
            pLineFeature, nDevice, nDir)->data.bVirtualNoiseSupport;
      break;
   default:
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDir);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_FIO_LINE_FEATURE_STATUS_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_LineFeatureStatusGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_boolean_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint32_t nDev = 0;
   DSL_AccessDir_t nDir = DSL_UPSTREAM;
   DSL_LineFeatureData_t *pLineFeature = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_LINE_FEATURE_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST
   );
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pLineFeature, DSL_LineFeatureData_t,
      DSL_ST_FLAG_LINE_FEATURE_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pLineFeature == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_LINE_FEATURE_STATUS_GET))
   {
      for (nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (nDir = DSL_UPSTREAM; nDir < DSL_ACCESSDIR_LAST; ++nDir)
         {
            nRet = DSL_LineFeatureStatusGet(pContext, nDev, nDir,
               DSL_ST_ARRAY2_INDEX_PTR(pLineFeature, nDev, nDir));

            if (nRet < DSL_SUCCESS)
            {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_LINE_FEATURE_STATUS_GET(%s) ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDir == DSL_UPSTREAM ? "US" : "DS",
                  nDev, nRet, pLineFeature[nDev][nDir].accessCtl.nReturn));
#endif /* if 0 */

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_LINE_FEATURE_STATUS_GET);
   }

   /* get data for the given node */
   switch (eNodeIdx)
   {
   case DSL_STATUS_LINE_TRELLIS_US:
      nDir = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(
            pLineFeature, nDevice, nDir)->bTrellisEnable;
      break;
   case DSL_STATUS_LINE_TRELLIS_DS:
      nDir = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(
            pLineFeature, nDevice, nDir)->bTrellisEnable;
      break;
   case DSL_STATUS_LINE_ACT_SNR_MODE_US:
      nDir = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(
            pLineFeature, nDevice, nDir)->bVirtualNoiseSupport;
      break;
   case DSL_STATUS_LINE_ACT_SNR_MODE_DS:
      nDir = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(
            pLineFeature, nDevice, nDir)->bVirtualNoiseSupport;
      break;
   default:
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDir);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_LineFeatureUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_boolean_t bFeatureEnabled = DSL_FALSE;
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineFeatureStatusGet__vrx518(
      pContext, eNodeIdx, nDevice, &bFeatureEnabled) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineFeatureStatusGet__vrx618(
      pContext, eNodeIdx, nDevice, &bFeatureEnabled) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update boolean param */
      uValue.bValue = bFeatureEnabled;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_BOOL, &uValue);
   }
}

static DSL_void_t DSL_ST_LineNrUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

   /* update string param */
   uValue.nValue = nDevice;
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_INT, &uValue);
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_G997_LINE_STATUS_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_G997LineStatusGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint32_t nDev = 0;
   DSL_AccessDir_t nDir = DSL_UPSTREAM;
   DSL_G997_LineStatus_t *pG997LineStatus = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_LINE_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pG997LineStatus, DSL_G997_LineStatus_t,
      DSL_ST_FLAG_G997_LINE_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pG997LineStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_LINE_STATUS_GET))
   {
      for (nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (nDir = DSL_UPSTREAM; nDir < DSL_ACCESSDIR_LAST; ++nDir)
         {
            /*showtime, US */
            DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus,
               nDev, nDir)->nDeltDataType= DSL_DELT_DATA_SHOWTIME;
            DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus,
               nDev, nDir)->nDirection = nDir;
            nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
               DSL_FIO_G997_LINE_STATUS_GET,
               (int)DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDev, nDir));

            if (nRet < DSL_SUCCESS ||
               DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus,
                  nDev, nDir)->accessCtl.nReturn < DSL_SUCCESS)
            {
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_G997_LINE_STATUS_GET(%s) ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDir == DSL_UPSTREAM ? "US" : "DS",
                  nDev, nRet, DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus,
                     nDev, nDir)->accessCtl.nReturn));

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_LINE_STATUS_GET);
   }

   /* get data for the given node */
   switch (eNodeIdx)
   {
   case DSL_STATUS_LINE_MAX_BIT_RATE_US:
      nDir = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->data.ATTNDR;
      break;
   case DSL_STATUS_LINE_MAX_BIT_RATE_DS:
      nDir = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->data.ATTNDR;
      break;
   case DSL_STATUS_LINE_NOISE_MARGIN_US:
      nDir = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->data.SNR;
      break;
   case DSL_STATUS_LINE_NOISE_MARGIN_DS:
      nDir = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->data.SNR;
      break;
   case DSL_STATUS_LINE_POWER_US:
      nDir = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->data.ACTATP;
      break;
   case DSL_STATUS_LINE_POWER_DS:
      nDir = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->data.ACTATP;
      break;
   case DSL_STATUS_LINE_ATTENUATION_US:
      nDir = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->data.LATN;
      break;
   case DSL_STATUS_LINE_ATTENUATION_DS:
      nDir = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->data.LATN;
      break;
   default:
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDir);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_FIO_G997_LINE_STATUS_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_G997LineStatusGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   DSL_uint16_t nDevice,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint32_t nDev = 0;
   DSL_AccessDir_t nDir = DSL_UPSTREAM;
   DSL_G997_LineStatusData_t *pG997LineStatus = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_LINE_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pG997LineStatus, DSL_G997_LineStatusData_t,
      DSL_ST_FLAG_G997_LINE_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pG997LineStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_LINE_STATUS_GET))
   {
      for (nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (nDir = DSL_UPSTREAM; nDir < DSL_ACCESSDIR_LAST; ++nDir)
         {
            nRet = DSL_G997_LineStatusGet(pContext, nDev, nDir,
               DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDev, nDir));

            if (nRet < DSL_SUCCESS)
            {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_G997_LINE_STATUS_GET(US) ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDev, nRet, pG997LineStatus[nDev][nDir].accessCtl.nReturn));
#endif /* if 0 */

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_LINE_STATUS_GET);
   }

   /* get data for the given node */
   switch (eNodeIdx)
   {
   case DSL_STATUS_LINE_MAX_BIT_RATE_US:
      nDir = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->ATTNDR;
      break;
   case DSL_STATUS_LINE_MAX_BIT_RATE_DS:
      nDir = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->ATTNDR;
      break;
   case DSL_STATUS_LINE_NOISE_MARGIN_US:
      nDir = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->SNR;
      break;
   case DSL_STATUS_LINE_NOISE_MARGIN_DS:
      nDir = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->SNR;
      break;
   case DSL_STATUS_LINE_POWER_US:
      nDir = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->ACTATP;
      break;
   case DSL_STATUS_LINE_POWER_DS:
      nDir = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->ACTATP;
      break;
   case DSL_STATUS_LINE_ATTENUATION_US:
      nDir = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->LATN;
      break;
   case DSL_STATUS_LINE_ATTENUATION_DS:
      nDir = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pG997LineStatus, nDevice, nDir)->LATN;
      break;
   default:
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDir);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_MaxBitRateUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nMaxBitRate = 0;
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_G997LineStatusGet__vrx518(
         pContext, eNodeIdx, nDevice, &nMaxBitRate) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_G997LineStatusGet__vrx618(
         pContext, eNodeIdx, nDevice, &nMaxBitRate) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      uValue.nValue = nMaxBitRate;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_NoiseMarginUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nNoiseMargin = 0;
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_G997LineStatusGet__vrx518(
         pContext, eNodeIdx, nDevice, &nNoiseMargin) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_G997LineStatusGet__vrx618(
         pContext, eNodeIdx, nDevice, &nNoiseMargin) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update string param */
      uValue.nValue = nNoiseMargin;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_PowerUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nPower = 0;
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_G997LineStatusGet__vrx518(
         pContext, eNodeIdx, nDevice, &nPower) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_G997LineStatusGet__vrx618(
         pContext, eNodeIdx, nDevice, &nPower) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      uValue.nValue = nPower;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_AttenuationUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nAttenuation = 0;
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_G997LineStatusGet__vrx518(
         pContext, eNodeIdx, nDevice, &nAttenuation) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_G997LineStatusGet__vrx618(
         pContext, eNodeIdx, nDevice, &nAttenuation) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      uValue.nValue = nAttenuation;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_G997_LINE_STATUS_PER_BAND_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_LineStatusPerBandGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_int_t nDevice,
   const DSL_AccessDir_t nDirection,
   DSL_uint16_t *pSNR)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_AccessDir_t nDir = DSL_UPSTREAM;
   DSL_G997_LineStatusPerBand_t *pBandStatus = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_LINE_STATUS_PER_BAND_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pBandStatus, DSL_G997_LineStatusPerBand_t,
      DSL_ST_FLAG_G997_LINE_STATUS_PER_BAND_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);

   if (pSNR == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pBandStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_LINE_STATUS_PER_BAND_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (nDir = DSL_UPSTREAM; nDir < DSL_ACCESSDIR_LAST; ++nDir)
         {
            DSL_ST_ARRAY2_INDEX_PTR(
               pBandStatus, nDev, nDir)->nDirection = nDir;
            nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
               DSL_FIO_G997_LINE_STATUS_PER_BAND_GET,
               (int)DSL_ST_ARRAY2_INDEX_PTR(pBandStatus, nDev, nDir));

            if (nRet < DSL_SUCCESS ||
               DSL_ST_ARRAY2_INDEX_PTR(
                  pBandStatus, nDev, nDir)->accessCtl.nReturn < DSL_SUCCESS)
            {
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_G997_LINE_STATUS_PER_BAND_GET ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDev, nRet, DSL_ST_ARRAY2_INDEX_PTR(
                     pBandStatus, nDev, nDir)->accessCtl.nReturn));

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_LINE_STATUS_PER_BAND_GET);
   }

   /* get data for the given device */
   for (unsigned int i = 0; i < DSL_G997_MAX_NUMBER_OF_BANDS; ++i)
   {
      pSNR[i] = DSL_ST_ARRAY2_INDEX_PTR(
            pBandStatus, nDevice, nDirection)->data.SNR[i];
   }

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_G997_LineStatusPerBandGet API function
*/
static DSL_Error_t DSL_ST_LineStatusPerBandGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_int_t nDevice,
   const DSL_AccessDir_t nDirection,
   DSL_uint16_t *pSNR)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_AccessDir_t nDir = DSL_UPSTREAM;
   DSL_G997_LineStatusPerBandData_t *pBandStatus = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_LINE_STATUS_PER_BAND_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pBandStatus, DSL_G997_LineStatusPerBandData_t,
      DSL_ST_FLAG_G997_LINE_STATUS_PER_BAND_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);

   if (pSNR == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pBandStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_LINE_STATUS_PER_BAND_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (nDir = DSL_UPSTREAM; nDir < DSL_ACCESSDIR_LAST; ++nDir)
         {
            nRet = DSL_G997_LineStatusPerBandGet(
               pContext, nDev, nDir,
               DSL_ST_ARRAY2_INDEX_PTR(pBandStatus, nDev, nDir));

            if (nRet < DSL_SUCCESS)
            {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_G997_LAST_STATE_TRANSMITTED_GET ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDev, nRet, profilesSupport[nDev].accessCtl.nReturn));
#endif /* if 0 */

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_LINE_STATUS_PER_BAND_GET);
   }

   /* get data for the given device */
   for (unsigned int i = 0; i < DSL_G997_MAX_NUMBER_OF_BANDS; ++i)
   {
      pSNR[i] =
         DSL_ST_ARRAY2_INDEX_PTR(pBandStatus, nDevice, nDirection)->SNR[i];
   }

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_SnrMpbUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel,
   const DSL_AccessDir_t nDirection)
{
   DSL_size_t nOffset = 0, nBufSize = 0;
   DSL_char_t sSnrMpbList[256] = "", sBuf[32] = "";
   DSL_char_t *sSnrMpbName = DSL_NULL;
   DSL_uint16_t nSnrArray[DSL_G997_MAX_NUMBER_OF_BANDS] = { 0 };
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineStatusPerBandGet__vrx518(
      pContext, nDevice, nDirection, nSnrArray) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineStatusPerBandGet__vrx618(
      pContext, nDevice, nDirection, nSnrArray) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      nBufSize = sizeof(sSnrMpbList);
      for (unsigned int i = 0; i < DSL_G997_MAX_NUMBER_OF_BANDS; ++i)
      {
         DSL_ST_snprintf_s(sBuf, sizeof(sBuf), ",%d", nSnrArray[i]);
         /* select name from the buf and exclude leading comma */
         sSnrMpbName = sBuf + ((nOffset) ? 0 : 1);
         nBufSize =
            (sizeof(sSnrMpbList) > nOffset) ?
            sizeof(sSnrMpbList) - nOffset : 0;
         DSL_ST_strncpy_s(sSnrMpbList + nOffset, nBufSize,
            sSnrMpbName, nBufSize);
         nOffset += DSL_ST_strnlen_s(sSnrMpbName, nBufSize);
      }

      /* update string param */
      uValue.sValue = sSnrMpbList;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_G997_LINE_INVENTORY_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_LineInventoryGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint32_t nDev = 0;
   DSL_XTUDir_t nDir = DSL_NEAR_END;
   DSL_G997_LineInventory_t *pG997LineInventory = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_G997_LINE_INVENTORY_GET,
      DSL_ST_DSL_ENTITIES, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pG997LineInventory, DSL_G997_LineInventory_t,
      DSL_ST_FLAG_G997_LINE_INVENTORY_GET,
      DSL_ST_DSL_ENTITIES, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pG997LineInventory == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_LINE_INVENTORY_GET))
   {
      for (nDev = 0; nDev < DSL_CPE_DSL_ENTITIES; ++nDev)
      {
         for (nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
         {
            DSL_ST_ARRAY2_INDEX_PTR(
               pG997LineInventory, nDev, nDir)->nDirection = nDir;
            nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
               DSL_FIO_G997_LINE_INVENTORY_GET,
               (int)DSL_ST_ARRAY2_INDEX_PTR(pG997LineInventory, nDev, nDir));

            if (nRet < DSL_SUCCESS ||
               DSL_ST_ARRAY2_INDEX_PTR(pG997LineInventory,
                  nDev, nDir)->accessCtl.nReturn < DSL_SUCCESS)
            {
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_G997_LINE_INVENTORY_GET(%s) ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDir == DSL_NEAR_END ? "NE" : "FE", nDev, nRet,
                  DSL_ST_ARRAY2_INDEX_PTR(
                     pG997LineInventory, nDev, nDir)->accessCtl.nReturn));

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_LINE_INVENTORY_GET);
   }

   /* get data for the given node */
   switch (eNodeIdx)
   {
   case DSL_STATUS_LINE_XTUR_VENDOR:
      nDir = DSL_NEAR_END;
      pData[0] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->data.G994VendorID[2];
      pData[1] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->data.G994VendorID[3];
      pData[2] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->data.G994VendorID[4];
      pData[3] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->data.G994VendorID[5];
      break;
   case DSL_STATUS_LINE_XTUR_COUNTRY:
      nDir = DSL_NEAR_END;
      pData[0] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->data.G994VendorID[0];
      pData[1] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->data.G994VendorID[1];
      break;
   case DSL_STATUS_LINE_XTUC_VENDOR:
      nDir = DSL_FAR_END;
      pData[0] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->data.G994VendorID[2];
      pData[1] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->data.G994VendorID[3];
      pData[2] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->data.G994VendorID[4];
      pData[3] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->data.G994VendorID[5];
      break;
   case DSL_STATUS_LINE_XTUC_COUNTRY:
      nDir = DSL_FAR_END;
      pData[0] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->data.G994VendorID[0];
      pData[1] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->data.G994VendorID[1];
      break;
   default:
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_ST_LineInventoryGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDir);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_FIO_G997_LINE_INVENTORY_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_LineInventoryGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint32_t nDev = 0;
   DSL_ATUDir_t nDir = DSL_NEAR_END;
   DSL_G997_LineInventoryData_t *pG997LineInventory = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_G997_LINE_INVENTORY_GET,
      DSL_ST_DSL_ENTITIES, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pG997LineInventory, DSL_G997_LineInventoryData_t,
      DSL_ST_FLAG_G997_LINE_INVENTORY_GET,
      DSL_ST_DSL_ENTITIES, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pG997LineInventory == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_LINE_INVENTORY_GET))
   {
      for (nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
         {
            nRet = DSL_G997_LineInventoryGet(pContext, nDev, nDir,
               DSL_ST_ARRAY2_INDEX_PTR(pG997LineInventory, nDev, nDir));

            if (nRet < DSL_SUCCESS)
            {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_G997_LINE_INVENTORY_GET(%s) ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDir == DSL_NEAR_END ? "NE" : "FE", nDev, nRet,
                  DSL_ST_ARRAY2_INDEX_PTR(
                     pG997LineInventory, nDev, nDir)->accessCtl.nReturn));
#endif /* if 0 */

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_LINE_INVENTORY_GET);
   }

   /* get data for the given node */
   switch (eNodeIdx)
   {
   case DSL_STATUS_LINE_XTUR_VENDOR:
      nDir = DSL_NEAR_END;
      pData[0] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->G994VendorID[2];
      pData[1] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->G994VendorID[3];
      pData[2] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->G994VendorID[4];
      pData[3] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->G994VendorID[5];
      break;
   case DSL_STATUS_LINE_XTUR_COUNTRY:
      nDir = DSL_NEAR_END;
      pData[0] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->G994VendorID[0];
      pData[1] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->G994VendorID[1];
      break;
   case DSL_STATUS_LINE_XTUC_VENDOR:
      nDir = DSL_FAR_END;
      pData[0] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->G994VendorID[2];
      pData[1] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->G994VendorID[3];
      pData[2] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->G994VendorID[4];
      pData[3] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->G994VendorID[5];
      break;
   case DSL_STATUS_LINE_XTUC_COUNTRY:
      nDir = DSL_FAR_END;
      pData[0] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->G994VendorID[0];
      pData[1] =
         DSL_ST_ARRAY2_INDEX_PTR(
            pG997LineInventory, nDevice, nDir)->G994VendorID[1];
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_ST_LineInventoryGet__vrx618: "
         "unknown node!"
         DSL_CPE_CRLF));
#endif /* if 0 */
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDir);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_XturVendorUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nXturVendor[DSL_ST_MAX_LEN_VENDOR_ID] = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineInventoryGet__vrx518(
         pContext, eNodeIdx, nDevice, nXturVendor) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineInventoryGet__vrx618(
         pContext, eNodeIdx, nDevice, nXturVendor) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update array param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.aValue.uArray.pU32Array = nXturVendor;
      uValue.aValue.nSize = DSL_ST_MAX_LEN_VENDOR_ID;
      uValue.aValue.eInputType = U32;
      uValue.aValue.eOutputType = HEX;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_ARRAY, &uValue);
   }
}

static DSL_void_t DSL_ST_XturCountryUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nXturCountry[DSL_ST_MAX_LEN_COUNTRY_ID] = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineInventoryGet__vrx518(
         pContext, eNodeIdx, nDevice, nXturCountry) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineInventoryGet__vrx618(
         pContext, eNodeIdx, nDevice, nXturCountry) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update array param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.aValue.uArray.pU32Array = nXturCountry;
      uValue.aValue.nSize = DSL_ST_MAX_LEN_COUNTRY_ID;
      uValue.aValue.eInputType = U32;
      uValue.aValue.eOutputType = HEX;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_ARRAY, &uValue);
   }
}

static DSL_void_t DSL_ST_XtucVendorUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nXtucVendor[DSL_ST_MAX_LEN_VENDOR_ID] = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineInventoryGet__vrx518(
         pContext, eNodeIdx, nDevice, nXtucVendor) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineInventoryGet__vrx618(
         pContext, eNodeIdx, nDevice, nXtucVendor) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update array param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.aValue.uArray.pU32Array = nXtucVendor;
      uValue.aValue.nSize = DSL_ST_MAX_LEN_VENDOR_ID;
      uValue.aValue.eInputType = U32;
      uValue.aValue.eOutputType = HEX;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_ARRAY, &uValue);
   }
}

static DSL_void_t DSL_ST_XtucCountryUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nXtucCountry[DSL_ST_MAX_LEN_COUNTRY_ID] = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineInventoryGet__vrx518(
         pContext, eNodeIdx, nDevice, nXtucCountry) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineInventoryGet__vrx618(
         pContext, eNodeIdx, nDevice, nXtucCountry) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update array param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.aValue.uArray.pU32Array = nXtucCountry;
      uValue.aValue.nSize = DSL_ST_MAX_LEN_COUNTRY_ID;
      uValue.aValue.eInputType = U32;
      uValue.aValue.eOutputType = HEX;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_ARRAY, &uValue);
   }
}

static DSL_void_t DSL_ST_XturAnsiStdUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
#if defined(DSL_ST_PLATFORM_VRX518)
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_T1413RevisionStatus_t revisionStatus = { 0 };

   nRet = DSL_CPE_Ioctl(pContext->fd[nDevice],
      DSL_FIO_T1413_XTUR_REVISION_GET, (int)&revisionStatus);
   if (nRet == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = revisionStatus.data.nT1413RevisionNum;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
#elif defined(DSL_ST_PLATFORM_VRX618)
   /* NOT SUPPORTED */
#endif /* VRX518/VRX618 */
}

static DSL_void_t DSL_ST_XturAnsiRevUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
#if defined(DSL_ST_PLATFORM_VRX518)
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_T1413VendorRevisionStatus_t vendorRevisionStatus = { 0 };

   nRet = DSL_CPE_Ioctl(pContext->fd[nDevice],
      DSL_FIO_T1413_XTUR_VENDOR_REVISION_GET, (int)&vendorRevisionStatus);
   if (nRet == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = vendorRevisionStatus.data.nT1413VendorRevisionNum;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
#elif defined(DSL_ST_PLATFORM_VRX618)
   /* NOT SUPPORTED */
#endif /* VRX518/VRX618 */
}

static DSL_void_t DSL_ST_XtucAnsiStdUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
#if defined(DSL_ST_PLATFORM_VRX518)
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_T1413RevisionStatus_t revisionStatus = { 0 };

   nRet = DSL_CPE_Ioctl(pContext->fd[nDevice],
      DSL_FIO_T1413_XTUO_REVISION_GET, (int)&revisionStatus);
   if (nRet == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = revisionStatus.data.nT1413RevisionNum;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
#elif defined(DSL_ST_PLATFORM_VRX618)
   /* NOT SUPPORTED */
#endif /* VRX518/VRX618 */
}

static DSL_void_t DSL_ST_XtucAnsiRevUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
#if defined(DSL_ST_PLATFORM_VRX518)
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_T1413VendorRevisionStatus_t vendorRevisionStatus = { 0 };

   nRet = DSL_CPE_Ioctl(pContext->fd[nDevice],
      DSL_FIO_T1413_XTUO_VENDOR_REVISION_GET, (int)&vendorRevisionStatus);
   if (nRet == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = vendorRevisionStatus.data.nT1413VendorRevisionNum;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
#elif defined(DSL_ST_PLATFORM_VRX618)
   /* NOT SUPPORTED */
#endif /* VRX518/VRX618 */
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_G997_US_POWER_BACK_OFF_STATUS_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_UsPowerBackOffStatusGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_uint16_t *pUPBS)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_G997_UsPowerBackOffStatus_t *pPowerBackOffStatus = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_US_POWER_BACK_OFF_STATUS_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pPowerBackOffStatus, DSL_G997_UsPowerBackOffStatus_t,
      DSL_ST_FLAG_G997_US_POWER_BACK_OFF_STATUS_GET, DSL_ST_DSL_ENTITIES);

   if (pUPBS == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pPowerBackOffStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_US_POWER_BACK_OFF_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_G997_US_POWER_BACK_OFF_STATUS_GET,
            (int)&pPowerBackOffStatus[nDev]);

         if (nRet < DSL_SUCCESS ||
            pPowerBackOffStatus[nDev].accessCtl.nReturn < DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_G997_US_POWER_BACK_OFF_STATUS_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, pPowerBackOffStatus[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_US_POWER_BACK_OFF_STATUS_GET);
   }

   /* get data for the given device */
   switch (eNodeIdx)
   {
#if defined(DSL_ST_PLATFORM_VRX518)
   case DSL_STATUS_LINE_UPBOKLER:
      *pUPBS = pPowerBackOffStatus[nDevice].data.nKl0EstimR;
      break;
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
   case DSL_STATUS_LINE_UPBOKLER_PB:
      for (unsigned int i = 0; i < DSL_G997_MAX_NUMBER_OF_BANDS; ++i)
      {
         pUPBS[i] = pPowerBackOffStatus[nDevice].data.nKl0EstimRPb[i];
      }
      break;
   case DSL_STATUS_LINE_RXTHRSH_DS:
      for (unsigned int i = 0; i < DSL_G997_MAX_NUMBER_OF_BANDS; ++i)
      {
         pUPBS[i] = pPowerBackOffStatus[nDevice].data.nKl0EstimOPb[i];
      }
      break;
   default:
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_ST_UsPowerBackOffStatusGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
      return DSL_ERROR;
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_G997_UsPowerBackOffStatusGet API function
*/
static DSL_Error_t DSL_ST_UsPowerBackOffStatusGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_uint16_t *pUPBS)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_G997_UsPowerBackOffStatusData_t *pPowerBackOffStatus = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_US_POWER_BACK_OFF_STATUS_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pPowerBackOffStatus, DSL_G997_UsPowerBackOffStatusData_t,
      DSL_ST_FLAG_G997_US_POWER_BACK_OFF_STATUS_GET, DSL_ST_DSL_ENTITIES);

   if (pUPBS == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pPowerBackOffStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_US_POWER_BACK_OFF_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_G997_UsPowerBackOffStatusGet(
                  pContext, nDev, &pPowerBackOffStatus[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_G997_US_POWER_BACK_OFF_STATUS_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, pPowerBackOffStatus[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_US_POWER_BACK_OFF_STATUS_GET);
   }

   /* get data for the given device */
   switch (eNodeIdx)
   {
   case DSL_STATUS_LINE_UPBOKLER_PB:
      for (unsigned int i = 0; i < DSL_G997_MAX_NUMBER_OF_BANDS; ++i)
      {
         pUPBS[i] = pPowerBackOffStatus[nDevice].nKlePb[i].nKleRPb;
      }
      break;
   case DSL_STATUS_LINE_RXTHRSH_DS:
      for (unsigned int i = 0; i < DSL_G997_MAX_NUMBER_OF_BANDS; ++i)
      {
         pUPBS[i] = pPowerBackOffStatus[nDevice].nKlePb[i].nKlePb;
      }
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_CPE_G997LineInventoryGet: "
         "unknown node!"
         DSL_CPE_CRLF));
#endif /* if 0 */
      return DSL_ERROR;
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

#if defined(DSL_ST_PLATFORM_VRX518)
static DSL_void_t DSL_ST_UpboklerUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint16_t nUpbokler = 0;

   if (DSL_ST_UsPowerBackOffStatusGet__vrx518(
         pContext, eNodeIdx, nDevice, &nUpbokler) == DSL_SUCCESS)
   {
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nUpbokler;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

static DSL_void_t DSL_ST_UpboklerPbUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_size_t nOffset = 0, nBufSize = 0;
   DSL_char_t sUpboklerPb[26] = "", sBuf[32] = "";
   DSL_char_t *sUpboklerPbName = DSL_NULL;
   DSL_uint16_t nUpboklerPbArray[DSL_G997_MAX_NUMBER_OF_BANDS] = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_UsPowerBackOffStatusGet__vrx518(
         pContext, eNodeIdx, nDevice, nUpboklerPbArray) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_UsPowerBackOffStatusGet__vrx618(
         pContext, eNodeIdx, nDevice, nUpboklerPbArray) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      nBufSize = sizeof(sUpboklerPb);
      for (unsigned int i = 0; i < DSL_G997_MAX_NUMBER_OF_BANDS; ++i)
      {
         DSL_ST_snprintf_s(sBuf, sizeof(sBuf), ",%hu", nUpboklerPbArray[i]);
         sBuf[5] = '\0';
         /* select name from the buf and exclude leading comma */
         sUpboklerPbName = sBuf + ((nOffset) ? 0 : 1);
         nBufSize =
            (sizeof(sUpboklerPb) > nOffset) ?
            sizeof(sUpboklerPb) - nOffset : 0;
         DSL_ST_strncpy_s(sUpboklerPb + nOffset, nBufSize,
            sUpboklerPbName, nBufSize);
         nOffset += DSL_ST_strnlen_s(sUpboklerPbName, nBufSize);
      }

      /* update string param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.sValue = sUpboklerPb;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

static DSL_void_t DSL_ST_RxthrshDsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_size_t nOffset = 0, nBufSize = 0;
   DSL_char_t sRxthrshDs[26] = "", sBuf[32] = "";
   DSL_char_t *sRxthrshDsName = DSL_NULL;
   DSL_uint16_t nRxthrshDsArray[DSL_G997_MAX_NUMBER_OF_BANDS] = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_UsPowerBackOffStatusGet__vrx518(
         pContext, eNodeIdx, nDevice, nRxthrshDsArray) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_UsPowerBackOffStatusGet__vrx618(
         pContext, eNodeIdx, nDevice, nRxthrshDsArray) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      nBufSize = sizeof(sRxthrshDs);
      for (unsigned int i = 0; i < DSL_G997_MAX_NUMBER_OF_BANDS; ++i)
      {
         DSL_ST_snprintf_s(sBuf, sizeof(sBuf), ",%hu", nRxthrshDsArray[i]);
         sBuf[5] = '\0';
         /* select name from the buf and exclude leading comma */
         sRxthrshDsName = sBuf + ((nOffset) ? 0 : 1);
         nBufSize =
            (sizeof(sRxthrshDs) > nOffset) ?
            sizeof(sRxthrshDs) - nOffset : 0;
         DSL_ST_strncpy_s(sRxthrshDs + nOffset, nBufSize,
            sRxthrshDsName, nBufSize);
         nOffset += DSL_ST_strnlen_s(sRxthrshDsName, nBufSize);
      }

      /* update string param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.sValue = sRxthrshDs;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_G997_RATE_ADAPTATION_STATUS_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_RateAdaptationStatusGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_int_t nDevice,
   const DSL_AccessDir_t nDirection,
   DSL_G997_RA_MODE_t *pRaMode)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_AccessDir_t nDir = DSL_UPSTREAM;
   DSL_G997_RateAdaptationStatus_t *pRateAdaptStatus = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_RATE_ADAPTATION_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pRateAdaptStatus, DSL_G997_RateAdaptationStatus_t,
      DSL_ST_FLAG_G997_RATE_ADAPTATION_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);

   if (pRaMode == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pRateAdaptStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_RATE_ADAPTATION_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (nDir = DSL_UPSTREAM; nDir < DSL_ACCESSDIR_LAST; ++nDir)
         {
            DSL_ST_ARRAY2_INDEX_PTR(
               pRateAdaptStatus, nDev, nDir)->nDirection = nDir;
            nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
               DSL_FIO_G997_RATE_ADAPTATION_STATUS_GET,
               (int)DSL_ST_ARRAY2_INDEX_PTR(pRateAdaptStatus, nDev, nDir));

            if (nRet < DSL_SUCCESS ||
               DSL_ST_ARRAY2_INDEX_PTR(pRateAdaptStatus,
                  nDev, nDir)->accessCtl.nReturn < DSL_SUCCESS)
            {
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_G997_RATE_ADAPTATION_STATUS_GET ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDev, nRet,
                  DSL_ST_ARRAY2_INDEX_PTR(
                     pRateAdaptStatus, nDev, nDir)->accessCtl.nReturn));

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_RATE_ADAPTATION_STATUS_GET);
   }

   /* get data for the given device */
   *pRaMode = DSL_ST_ARRAY2_INDEX_PTR(
      pRateAdaptStatus, nDevice, nDirection)->data.RA_MODE;

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_G997_RateAdaptationStatusGet API function
*/
static DSL_Error_t DSL_ST_RateAdaptationStatusGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_int_t nDevice,
   const DSL_AccessDir_t nDirection,
   DSL_G997_RA_MODE_t *pRaMode)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_AccessDir_t nDir = DSL_UPSTREAM;
   DSL_G997_RateAdaptationStatusData_t *pRateAdaptStatus = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_RATE_ADAPTATION_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pRateAdaptStatus, DSL_G997_RateAdaptationStatusData_t,
      DSL_ST_FLAG_G997_RATE_ADAPTATION_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);

   if (pRaMode == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pRateAdaptStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_RATE_ADAPTATION_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (nDir = DSL_UPSTREAM; nDir < DSL_ACCESSDIR_LAST; ++nDir)
         {
            nRet = DSL_G997_RateAdaptationStatusGet(pContext, nDev, nDir,
               DSL_ST_ARRAY2_INDEX_PTR(pRateAdaptStatus, nDev, nDir));

            if (nRet < DSL_SUCCESS)
            {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_G997_RATE_ADAPTATION_STATUS_GET ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDev, nRet, profilesSupport[nDev].accessCtl.nReturn));
#endif /* if 0 */

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_RATE_ADAPTATION_STATUS_GET);
   }

   /* get data for the given device */
   *pRaMode = DSL_ST_ARRAY2_INDEX_PTR(
      pRateAdaptStatus, nDevice, nDirection)->RA_MODE;

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_ActRaModeUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel,
   const DSL_AccessDir_t nDirection)
{
   DSL_G997_RA_MODE_t nRaMode;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_RateAdaptationStatusGet__vrx518(
         pContext, nDevice, nDirection, &nRaMode) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_RateAdaptationStatusGet__vrx618(
         pContext, nDevice, nDirection, &nRaMode) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nRaMode;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_SnrMrocUpdate(
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   /* update integer param */
   DSL_ST_ParamValue_t uValue = { 0 };
   uValue.nValue = 0; /* fixed value */
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_INT, &uValue);
}

/* --- Channel section ---*/

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_G997_CHANNEL_STATUS_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_ChannelStatusGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint32_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_AccessDir_t nDirection = DSL_UPSTREAM;
   DSL_G997_ChannelStatus_t *pChannelStatus = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_CHANNEL_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_ACCESSDIR_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pChannelStatus, DSL_G997_ChannelStatus_t,
      DSL_ST_FLAG_G997_CHANNEL_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_ACCESSDIR_LAST);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pChannelStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration.
      EXCEPTION: The up-to-date DataRates, including reset values on line deactivation,
      are stored in the Control Context and have to be taken from there */
   if (eNodeIdx != DSL_STATUS_LINE_CHANNEL_DATARATE_US &&
       eNodeIdx != DSL_STATUS_LINE_CHANNEL_DATARATE_DS &&
       !DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_CHANNEL_STATUS_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            for (DSL_AccessDir_t nDir = DSL_UPSTREAM; nDir < DSL_ACCESSDIR_LAST; ++nDir)
            {
               DSL_ST_ARRAY3_INDEX_PTR(
                  pChannelStatus, nDev, nCh, nDir)->nChannel = nCh;
               DSL_ST_ARRAY3_INDEX_PTR(
                  pChannelStatus, nDev, nCh, nDir)->nDirection = nDir;

               nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
                  DSL_FIO_G997_CHANNEL_STATUS_GET,
                  (int)DSL_ST_ARRAY3_INDEX_PTR(
                     pChannelStatus, nDev, nCh, nDir));

               if (nRet < DSL_SUCCESS ||
                  DSL_ST_ARRAY3_INDEX_PTR(pChannelStatus,
                     nDev, nCh, nDir)->accessCtl.nReturn < DSL_SUCCESS)
               {
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_G997_CHANNEL_STATUS_GET ioctl "
                     "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                     nDev, nRet, DSL_ST_ARRAY3_INDEX_PTR(
                        pChannelStatus, nDev, nCh, nDir)->accessCtl.nReturn));

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_CHANNEL_STATUS_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATUS_LINE_CHANNEL_DATARATE_US:
      nDirection = DSL_UPSTREAM;
      *pData =
         pContext->nChannelActualDataRate[nDevice][nDirection][nChannel];
      DSL_ST_ARRAY3_INDEX_VAL(
         pErrorCodeArray, nDevice, nChannel, nDirection) = DSL_SUCCESS;
      break;
   case DSL_STATUS_LINE_CHANNEL_DATARATE_DS:
      nDirection = DSL_DOWNSTREAM;
      *pData =
         pContext->nChannelActualDataRate[nDevice][nDirection][nChannel];
      DSL_ST_ARRAY3_INDEX_VAL(
         pErrorCodeArray, nDevice, nChannel, nDirection) = DSL_SUCCESS;
      break;
   case DSL_STATUS_LINE_CHANNEL_ACT_INTERL_DELAY:
      nDirection = DSL_DOWNSTREAM; /* TODO: clarify (no direction specified) */
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pChannelStatus, nDevice,
            nChannel, nDirection)->data.ActualInterleaveDelay;
      break;
   case DSL_STATUS_LINE_CHANNEL_ACTINP:
      nDirection = DSL_DOWNSTREAM; /* TODO: clarify (no direction specified) */
      *pData = DSL_ST_ARRAY3_INDEX_PTR(pChannelStatus,
         nDevice, nChannel, nDirection)->data.ActualImpulseNoiseProtection;
      break;
   case DSL_STATUS_LINE_CHANNEL_ACTNDR_DS:
      nDirection = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pChannelStatus, nDevice,
            nChannel, nDirection)->data.ActualNetDataRate;
      break;
   case DSL_STATUS_LINE_CHANNEL_ACTNDR_US:
      nDirection = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pChannelStatus, nDevice,
            nChannel, nDirection)->data.ActualNetDataRate;
      break;
   case DSL_STATUS_LINE_CHANNEL_ACTINPREIN_DS:
      nDirection = DSL_DOWNSTREAM;
      *pData = DSL_ST_ARRAY3_INDEX_PTR(pChannelStatus,
         nDevice, nChannel, nDirection)->data.ActualImpulseNoiseProtectionRein;
      break;
   case DSL_STATUS_LINE_CHANNEL_ACTINPREIN_US:
      nDirection = DSL_UPSTREAM;
      *pData = DSL_ST_ARRAY3_INDEX_PTR(pChannelStatus,
         nDevice, nChannel, nDirection)->data.ActualImpulseNoiseProtectionRein;
      break;
   case DSL_STATUS_LINE_CHANNEL_INPREPORT:
      nDirection = DSL_DOWNSTREAM;
      *pData = DSL_ST_ARRAY3_INDEX_PTR(pChannelStatus,
         nDevice, nChannel, nDirection)->data.ImpulseNoiseProtectionReportingMode;
      break;
   default:
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_ST_ChannelStatusGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_G997_ChannelStatusGet API function
*/
static DSL_Error_t DSL_ST_ChannelStatusGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint32_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_AccessDir_t nDirection;
   DSL_G997_ChannelStatusData_t *pChannelStatus = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_CHANNEL_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_ACCESSDIR_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pChannelStatus, DSL_G997_ChannelStatusData_t,
      DSL_ST_FLAG_G997_CHANNEL_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_ACCESSDIR_LAST);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pChannelStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_CHANNEL_STATUS_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            for (DSL_AccessDir_t nDir = DSL_UPSTREAM;
               nDir < DSL_ACCESSDIR_LAST; ++nDir)
            {
               nRet = DSL_G997_ChannelStatusGet(pContext, nDev, nCh, nDir,
                  DSL_ST_ARRAY3_INDEX_PTR(pChannelStatus, nDev, nCh, nDir));

               if (nRet < DSL_SUCCESS)
               {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_G997_CHANNEL_STATUS_GET ioctl "
                     "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                     nDev, nRet,
                     DSL_ST_ARRAY2_INDEX_PTR(
                        pChannelStatus, nDev, nDir)->accessCtl.nReturn));
#endif /* if 0 */

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_CHANNEL_STATUS_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATUS_LINE_CHANNEL_DATARATE_US:
      nDirection = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pChannelStatus, nDevice, nChannel, nDirection)->ActualDataRate;
      break;
   case DSL_STATUS_LINE_CHANNEL_DATARATE_DS:
      nDirection = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pChannelStatus, nDevice, nChannel, nDirection)->ActualDataRate;
      break;
   case DSL_STATUS_LINE_CHANNEL_ACT_INTERL_DELAY:
      nDirection = DSL_UPSTREAM; /* TODO: clarify (no direction specified) */
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pChannelStatus, nDevice, nChannel,
            nDirection)->ActualInterleaveDelay;
      break;
   case DSL_STATUS_LINE_CHANNEL_ACTINP:
      nDirection = DSL_UPSTREAM; /* TODO: clarify (no direction specified) */
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pChannelStatus, nDevice, nChannel,
            nDirection)->ActualImpulseNoiseProtection;
      break;
   case DSL_STATUS_LINE_CHANNEL_ACTNDR_DS:
      nDirection = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pChannelStatus, nDevice, nChannel,
            nDirection)->ActualNetDataRate;
      break;
   case DSL_STATUS_LINE_CHANNEL_ACTNDR_US:
      nDirection = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pChannelStatus, nDevice, nChannel,
            nDirection)->ActualNetDataRate;
      break;
   case DSL_STATUS_LINE_CHANNEL_ACTINPREIN_DS:
      nDirection = DSL_DOWNSTREAM;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pChannelStatus, nDevice, nChannel,
            nDirection)->ActualImpulseNoiseProtectionRein;
      break;
   case DSL_STATUS_LINE_CHANNEL_ACTINPREIN_US:
      nDirection = DSL_UPSTREAM;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pChannelStatus, nDevice, nChannel,
            nDirection)->ActualImpulseNoiseProtectionRein;
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_ST_ChannelStatusGet__vrx618: "
         "unknown node!"
         DSL_CPE_CRLF));
#endif /* if 0 */
      return DSL_ERROR;
   }


   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_ChannelActStatusUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nData = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_ChannelStatusGet__vrx518(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_ChannelStatusGet__vrx618(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nData;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_ChannelStatusUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_LineStatus_t eLineState = DSL_ST_LINE_NOT_INITIALIZED;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineStateGet__vrx518(
         pContext, nDevice, &eLineState, DSL_NULL) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineStateGet__vrx618(
         pContext, nDevice, &eLineState, DSL_NULL) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      DSL_ST_ParamValue_t uValue = { 0 };

      switch (eLineState)
      {
      case DSL_ST_LINE_UP:
         uValue.sValue = "Up";
         break;
      case DSL_ST_LINE_ERROR:
         uValue.sValue = "Error";
         break;
      default:
         uValue.sValue = "Down";
         break;
      }

      /* update string param */
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_SYSTEM_INTERFACE_CONFIG_GET
   IOCtl from all available devices and DSL modes.
*/
static DSL_Error_t DSL_ST_SystemInterfaceConfigGet__vrx518(
   DSL_ST_Context_t *pContext,
   const DSL_int_t nDevice,
   const DSL_DslModeSelection_t nDslMode,
   DSL_TcLayerSelection_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint32_t nDev = 0;
   DSL_DslModeSelection_t nDsl = DSL_MODE_ADSL;
   DSL_SystemInterfaceConfig_t *pSiConfig = DSL_NULL;
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_SYSTEM_INTERFACE_CONFIG_GET,
      DSL_ST_DSL_ENTITIES, DSL_MODE_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pSiConfig, DSL_SystemInterfaceConfig_t,
      DSL_ST_FLAG_SYSTEM_INTERFACE_CONFIG_GET,
      DSL_ST_DSL_ENTITIES, DSL_MODE_LAST);

   if (pData == DSL_NULL ||
       nDevice >= DSL_ST_DSL_ENTITIES ||
       (nDslMode == DSL_MODE_NA || nDslMode == DSL_MODE_LAST) ||
      pErrorCodeArray == DSL_NULL || pSiConfig == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_SYSTEM_INTERFACE_CONFIG_GET))
   {
      for (nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (nDsl = DSL_MODE_ADSL; nDsl < DSL_MODE_LAST; ++nDsl)
         {
            DSL_ST_ARRAY2_INDEX_PTR(
               pSiConfig, nDev, nDsl)->nDslMode = nDsl;

            nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
               DSL_FIO_SYSTEM_INTERFACE_CONFIG_GET,
               (int)DSL_ST_ARRAY2_INDEX_PTR(
                  pSiConfig, nDev, nDsl));

            if (nRet < DSL_SUCCESS ||
               DSL_ST_ARRAY2_INDEX_PTR(
                  pSiConfig, nDev, nDsl)->accessCtl.nReturn != DSL_SUCCESS)
            {
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_SYSTEM_INTERFACE_CONFIG_GET ioctl failed "
                  "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
                  nDev, nRet, DSL_ST_ARRAY2_INDEX_PTR(
                     pSiConfig, nDev, nDsl)->accessCtl.nReturn));

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDsl) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDsl) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_SYSTEM_INTERFACE_CONFIG_GET);
   }

   *pData = DSL_ST_ARRAY2_INDEX_PTR(
      pSiConfig, nDevice, nDslMode)->data.nTcLayer;

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDslMode);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

static DSL_void_t DSL_ST_ChannelLinkEncapSupportedUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_Error_t nRet = DSL_ERROR;
   DSL_TcLayerSelection_t data = { 0 };
   #define BUF_SUPPORTED_SIZE 82
   char bufSupported[BUF_SUPPORTED_SIZE];

   memset(&bufSupported, 0, BUF_SUPPORTED_SIZE);

#if defined(DSL_ST_PLATFORM_VRX518)
   /* VRX518 */
   if (DSL_ST_SystemInterfaceConfigGet__vrx518(
      pContext, nDevice, DSL_MODE_ADSL, &data) == DSL_SUCCESS)
   {
#elif defined(DSL_ST_PLATFORM_VRX618)
   /* VRX618 */
   DSL_SystemInterfaceConfigData_t sifConfigData;
   if (DSL_SystemInterfaceConfigGet(
         pContext, nDevice, &sifConfigData) == DSL_SUCCESS)
   {
      data = sifConfigData.nTcLayer;
#endif /* VRX518/VRX618 */
      switch (data)
      {
      case DSL_TC_ATM:
         nRet = DSL_SUCCESS;
         DSL_ST_strncpy_s(bufSupported, BUF_SUPPORTED_SIZE,
            "G.992.3_Annex_K_ATM,", sizeof("G.992.3_Annex_K_ATM,"));
         break;
      case DSL_TC_EFM:
#if defined(DSL_ST_PLATFORM_VRX518)
      case DSL_TC_EFM_FORCED:
#endif /* defined(DSL_ST_PLATFORM_VRX518) */
         nRet = DSL_SUCCESS;
         DSL_ST_strncpy_s(bufSupported, BUF_SUPPORTED_SIZE,
            "G.992.3_Annex_K_PTM,", sizeof("G.992.3_Annex_K_PTM,"));
         break;
      case DSL_TC_AUTO:
         nRet = DSL_SUCCESS;
         DSL_ST_strncpy_s(bufSupported, BUF_SUPPORTED_SIZE,
            "G.994.1 (Auto),", sizeof("G.994.1 (Auto),"));
         break;
      default:
         break;
      }
   }

#if defined(DSL_ST_PLATFORM_VRX518)
   /* VRX518 only - TODO: clarify (VRX618 DSL_SystemInterfaceConfigGet
      does not specify DslMode) */
   if (DSL_ST_SystemInterfaceConfigGet__vrx518(
         pContext, nDevice, DSL_MODE_VDSL, &data) == DSL_SUCCESS)
   {
      DSL_size_t nBufSupportCurrSize = DSL_ST_strnlen_s(
         bufSupported, BUF_SUPPORTED_SIZE);

      switch (data)
      {
      case DSL_TC_ATM:
         nRet = DSL_SUCCESS;
         DSL_ST_strncpy_s(bufSupported + nBufSupportCurrSize,
            BUF_SUPPORTED_SIZE - nBufSupportCurrSize,
            "G.992.2_Annex_K_ATM", sizeof("G.992.2_Annex_K_ATM"));
         break;
      case DSL_TC_EFM:
      case DSL_TC_EFM_FORCED:
         nRet = DSL_SUCCESS;
         DSL_ST_strncpy_s(bufSupported + nBufSupportCurrSize,
            BUF_SUPPORTED_SIZE - nBufSupportCurrSize,
            "G.992.2_Annex_K_PTM", sizeof("G.992.2_Annex_K_PTM"));
         break;
      case DSL_TC_AUTO:
         nRet = DSL_SUCCESS;
         DSL_ST_strncpy_s(bufSupported + nBufSupportCurrSize,
            BUF_SUPPORTED_SIZE - nBufSupportCurrSize,
            "G.994.1 (Auto)", sizeof("G.994.1 (Auto)"));
         break;
      default:
         break;
      }
   }
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

   if (nRet == DSL_SUCCESS)
   {
      /* update string param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.sValue = bufSupported;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_SYSTEM_INTERFACE_STATUS_GET
   ioctl for all devices
*/
static const DSL_char_t* DSL_ST_SystemIfStatusGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_int_t nDevice)
{
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_SystemInterfaceStatus_t
      sysIfData[DSL_ST_MAX_DSL_ENTITIES] = { 0 };
   DSL_uint8_t XTSE[DSL_G997_NUM_XTSE_OCTETS] = { 0 };
   static DSL_char_t *sLinkEncapUsed[DSL_ST_MAX_DSL_ENTITIES] = { DSL_NULL };
   DSL_DslModeSelection_t dslMode = DSL_MODE_NA;

   if (nDevice >= DSL_ST_DSL_ENTITIES)
   {
      return "";
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_SYSTEM_INTERFACE_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_SYSTEM_INTERFACE_STATUS_GET, (int)&sysIfData[nDev]);

         if (nRet < DSL_SUCCESS ||
            sysIfData[nDev].accessCtl.nReturn < DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_SYSTEM_INTERFACE_STATUS_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, sysIfData[nDev].accessCtl.nReturn));
         }
         else
         {
            if (sLinkEncapUsed[nDev] == DSL_NULL)
            {
               sLinkEncapUsed[nDev] =
                  (DSL_char_t*)DSL_ST_Malloc(DSL_ST_MAX_LINK_ENC_STRING_SIZE);
               if (sLinkEncapUsed[nDev] == DSL_NULL)
               {
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_ST_SystemIfStatusGet__vrx518 "
                     "failed to allocate memory!"DSL_CPE_CRLF));
                  return "";
               }
            }
            memset(sLinkEncapUsed[nDev], 0, DSL_ST_MAX_LINK_ENC_STRING_SIZE);
            if (DSL_ST_SystemEnablingStatusGet__vrx518(
               pContext, nDevice, XTSE) == DSL_SUCCESS)
            {
               if (XTSE[7])
               {
                  dslMode = DSL_MODE_VDSL;
               }
               else
               {
                  dslMode = DSL_MODE_ADSL;
               }

               switch (sysIfData[nDev].data.nTcLayer)
               {
               case DSL_TC_ATM:
                  if (dslMode == DSL_MODE_ADSL)
                  {
                     DSL_ST_strncpy_s(sLinkEncapUsed[nDev],
                        DSL_ST_MAX_LINK_ENC_STRING_SIZE,
                        "G.992.3_Annex_K_ATM", sizeof("G.992.3_Annex_K_ATM"));
                  }
                  else
                  {
                     DSL_ST_strncpy_s(sLinkEncapUsed[nDev],
                        DSL_ST_MAX_LINK_ENC_STRING_SIZE,
                        "G.993.2_Annex_K_ATM", sizeof("G.993.2_Annex_K_ATM"));
                  }
                  break;
               case DSL_TC_EFM:
               case DSL_TC_EFM_FORCED:
                  if (dslMode == DSL_MODE_ADSL)
                  {
                     DSL_ST_strncpy_s(sLinkEncapUsed[nDev],
                        DSL_ST_MAX_LINK_ENC_STRING_SIZE,
                        "G.992.3_Annex_K_PTM", sizeof("G.992.3_Annex_K_PTM"));
                  }
                  else
                  {
                     DSL_ST_strncpy_s(sLinkEncapUsed[nDev],
                        DSL_ST_MAX_LINK_ENC_STRING_SIZE,
                        "G.993.2_Annex_K_PTM", sizeof("G.993.2_Annex_K_PTM"));
                  }
                  break;
               case DSL_TC_AUTO:
                  DSL_ST_strncpy_s(sLinkEncapUsed[nDev],
                     DSL_ST_MAX_LINK_ENC_STRING_SIZE,
                     "G.994.1 (Auto)", sizeof("G.994.1 (Auto)"));
                     break;
               default:
                  break;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_SYSTEM_INTERFACE_STATUS_GET);
   }

   return sLinkEncapUsed[nDevice] ? sLinkEncapUsed[nDevice] : "";
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_ChannelStatusGet API function
*/
static const DSL_char_t* DSL_ST_SystemIfStatusGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_Error_t nErrorCodeArray[DSL_ST_MAX_DSL_ENTITIES] = { 0 };
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_G997_XTUSystemEnablingData_t
      xtseData[DSL_ST_MAX_DSL_ENTITIES] = { 0 };
   static DSL_char_t *sLinkEncapUsed[DSL_ST_MAX_DSL_ENTITIES] = { DSL_NULL };
   typedef enum
   {
      /* DSL Mode information not applicable */
      DSL_MODE_NA = -1,
      /* ADSL mode selected. */
      DSL_MODE_ADSL = 0,
      /* VDSL mode selected. */
      DSL_MODE_VDSL,
      /* FAST mode selected. */
      DSL_MODE_FAST
   } DSL_DslModeSelection_t;
   DSL_DslModeSelection_t
      dslMode[DSL_ST_MAX_DSL_ENTITIES] = { DSL_MODE_NA };
   DSL_ChannelStatusData_t
      channelStatus[DSL_ST_MAX_DSL_ENTITIES] = { 0 };
   DSL_boolean_t bStatusAvail = DSL_FALSE;

   if (nDevice >= DSL_ST_DSL_ENTITIES)
   {
      return "";
   }

   /* avoid calling API functions many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_SYSTEM_INTERFACE_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nErrorCodeArray[nDev] = DSL_ERROR;

         /* Get current mode */
         nRet = DSL_G997_XTUSystemEnablingStatusGet(pContext, nDev, &xtseData[nDev]);
         if (nRet == DSL_SUCCESS)
         {
            for (DSL_int_t i = 0; i < DSL_G997_NUM_XTSE_OCTETS_EXTEND; ++i)
            {
               if (xtseData[nDev].XTSE[i] != 0)
               {
                  bStatusAvail = DSL_TRUE;
               }
            }

            if (bStatusAvail)
            {
               if (!xtseData[nDev].XTSE[7] && !xtseData[nDev].XTSE[8])
               {
                  dslMode[nDev] = DSL_MODE_ADSL;
               }
               else if (xtseData[nDev].XTSE[7])
               {
                  dslMode[nDev] = DSL_MODE_VDSL;
               }
               else
               {
                  dslMode[nDev] = DSL_MODE_FAST;
               }

               nRet = DSL_ChannelStatusGet(
                  pContext, nDev, nChannel, DSL_UPSTREAM, &channelStatus[nDev]);
               if (nRet == DSL_SUCCESS)
               {
                  nErrorCodeArray[nDev] = DSL_SUCCESS;
               }
            }
         }

         if (nErrorCodeArray[nDev] == DSL_SUCCESS)
         {
            if (sLinkEncapUsed[nDev] == DSL_NULL)
            {
               sLinkEncapUsed[nDev] =
                  (DSL_char_t*)DSL_ST_Malloc(DSL_ST_MAX_LINK_ENC_STRING_SIZE);
               if (sLinkEncapUsed[nDev] == DSL_NULL)
               {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_ST_SystemIfStatusGet__vrx618 "
                     "failed to allocate memory!"DSL_CPE_CRLF));
#endif /* if 0 */
                  return "";
               }
            }
            memset(sLinkEncapUsed[nDev], 0, DSL_ST_MAX_LINK_ENC_STRING_SIZE);
            switch (channelStatus[nDev].nTcLayerStatus)
            {
            case DSL_TC_STATUS_ATM:
               if (dslMode[nDevice] != DSL_MODE_NA)
               {
                  if (dslMode[nDevice] == DSL_MODE_ADSL)
                  {
                     DSL_StrCpy_s(sLinkEncapUsed[nDev],
                        DSL_ST_MAX_LINK_ENC_STRING_SIZE, "G.992.3_Annex_K_ATM");
                  }
                  else
                  {
                     DSL_StrCpy_s(sLinkEncapUsed[nDev],
                        DSL_ST_MAX_LINK_ENC_STRING_SIZE, "G.993.2_Annex_K_ATM");
                  }
               }
               break;
            case DSL_TC_STATUS_PTM:
               if (dslMode[nDevice] != DSL_MODE_NA)
               {
                  if (dslMode[nDevice] == DSL_MODE_ADSL)
                  {
                     DSL_StrCpy_s(sLinkEncapUsed[nDev],
                        DSL_ST_MAX_LINK_ENC_STRING_SIZE, "G.992.3_Annex_K_PTM");
                  }
                  else
                  {
                     DSL_StrCpy_s(sLinkEncapUsed[nDev],
                        DSL_ST_MAX_LINK_ENC_STRING_SIZE, "G.993.2_Annex_K_PTM");
                  }
               }
               break;
            default:
               break;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_SYSTEM_INTERFACE_STATUS_GET);
   }

   return sLinkEncapUsed[nDevice] ? sLinkEncapUsed[nDevice] : "";
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_ChannelLinkEncapUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   uValue.sValue = DSL_ST_SystemIfStatusGet__vrx518(pContext, nDevice);
#elif defined(DSL_ST_PLATFORM_VRX618)
   uValue.sValue = DSL_ST_SystemIfStatusGet__vrx618(
      pContext, nDevice, nChannel);
#endif /* VRX518/VRX618 */

   /* update string param */
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_STRING, &uValue);
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_G997_FRAMING_PARAMETER_STATUS_GET
   IOCtl from all available devices.
*/
static DSL_Error_t DSL_ST_G997FramingParamStatusGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint32_t nDev = 0;
   DSL_G997_FramingParameterStatus_t *pFpData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_FRAMING_PARAMETER_STATUS_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pFpData, DSL_G997_FramingParameterStatus_t,
      DSL_ST_FLAG_G997_FRAMING_PARAMETER_STATUS_GET,
      DSL_ST_DSL_ENTITIES);

   if (pData == DSL_NULL || nDevice >= DSL_CPE_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pFpData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_FRAMING_PARAMETER_STATUS_GET))
   {
      for (nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         pFpData[nDev].nChannel = 0;
         pFpData[nDev].nDirection = DSL_DOWNSTREAM;

         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_G997_FRAMING_PARAMETER_STATUS_GET,
            (int)&pFpData[nDev]);

         if (nRet < DSL_SUCCESS ||
            pFpData[nDev].accessCtl.nReturn != DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_G997_FRAMING_PARAMETER_STATUS_GET ioctl failed "
               "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, pFpData[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_FRAMING_PARAMETER_STATUS_GET);
   }

   /* get data for the given device */
   switch (eNodeIdx)
   {
   case DSL_STATUS_LINE_CHANNEL_LPATH:
      *pData = pFpData[nDevice].data.nLPATH;
      break;
   case DSL_STATUS_LINE_CHANNEL_INTLVDEPTH:
      *pData = pFpData[nDevice].data.nINTLVDEPTH;
      break;
   case DSL_STATUS_LINE_CHANNEL_INTLVBLOCK:
      *pData = pFpData[nDevice].data.nINTLVBLOCK;
      break;
   case DSL_STATUS_LINE_CHANNEL_NFEC:
      *pData = pFpData[nDevice].data.nNFEC;
      break;
   case DSL_STATUS_LINE_CHANNEL_RFEC:
      *pData = pFpData[nDevice].data.nRFEC;
      break;
   case DSL_STATUS_LINE_CHANNEL_LSYMB:
      *pData = pFpData[nDevice].data.nLSYMB;
      break;
   default:
      return DSL_ERROR;
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_FIO_G997_FRAMING_PARAMETER_STATUS_GET
   IOCtl from all available devices.
*/
static DSL_Error_t DSL_ST_G997FramingParamStatusGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint32_t nDev = 0;
   DSL_G997_FramingParameterStatusData_t *pFpData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_G997_FRAMING_PARAMETER_STATUS_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pFpData, DSL_G997_FramingParameterStatusData_t,
      DSL_ST_FLAG_G997_FRAMING_PARAMETER_STATUS_GET,
      DSL_ST_DSL_ENTITIES);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pFpData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_G997_FRAMING_PARAMETER_STATUS_GET))
   {
      for (nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_G997_FramingParameterStatusGet(pContext,
            nDev,/* nChannel*/ 0, DSL_DOWNSTREAM, &pFpData[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_G997_FRAMING_PARAMETER_STATUS_GET ioctl failed "
               "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, sData[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_G997_FRAMING_PARAMETER_STATUS_GET);
   }

   /* get data for the given device */
   switch (eNodeIdx)
   {
   case DSL_STATUS_LINE_CHANNEL_LPATH:
      *pData = pFpData[nDevice].nLPATH;
      break;
   case DSL_STATUS_LINE_CHANNEL_INTLVDEPTH:
      *pData = pFpData[nDevice].nINTLVDEPTH;
      break;
   case DSL_STATUS_LINE_CHANNEL_INTLVBLOCK:
      *pData = pFpData[nDevice].nINTLVBLOCK;
      break;
   case DSL_STATUS_LINE_CHANNEL_NFEC:
      *pData = pFpData[nDevice].nNFEC;
      break;
   case DSL_STATUS_LINE_CHANNEL_RFEC:
      *pData = pFpData[nDevice].nRFEC;
      break;
   case DSL_STATUS_LINE_CHANNEL_LSYMB:
      *pData = pFpData[nDevice].nLSYMB;
      break;
   default:
      return DSL_ERROR;
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_ChannelFramingUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nData = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_G997FramingParamStatusGet__vrx518(
         pContext, eNodeIdx, nDevice, &nData) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_G997FramingParamStatusGet__vrx618(
         pContext, eNodeIdx, nDevice, &nData) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nData;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX618)
static DSL_void_t DSL_ST_ChannelActINPReportUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ST_ParamValue_t uValue = { 0 };

   /* update boolean param */
   uValue.bValue = DSL_FALSE; /* fixed value */
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_BOOL, &uValue);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_BND_CONFIG_GET ioctl for all devices
*/
static DSL_Error_t DSL_ST_BondingConfigGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_int_t nDevice,
   const DSL_DslModeSelection_t nDslMode,
   DSL_boolean_t *pPafConfig,
   DSL_boolean_t *pImapConfig)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_BND_Config_t *pBondingData = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(pErrorCodeArray,
      DSL_ST_FLAG_BND_CONFIG_GET,
      DSL_ST_DSL_ENTITIES, DSL_MODE_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pBondingData, DSL_BND_Config_t,
      DSL_ST_FLAG_BND_CONFIG_GET,
      DSL_ST_DSL_ENTITIES, DSL_MODE_LAST);

   if (pPafConfig == DSL_NULL || pImapConfig == DSL_NULL ||
         nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pBondingData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_BND_CONFIG_GET))
   {
      for (DSL_int_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_DslModeSelection_t nDsl = DSL_MODE_ADSL;
            nDsl < DSL_MODE_LAST; ++nDsl)
         {
            DSL_ST_ARRAY2_INDEX_PTR(pBondingData, nDev, nDsl)->nDslMode = nDsl;
            nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
               DSL_FIO_BND_CONFIG_GET, (int)DSL_ST_ARRAY2_INDEX_PTR(
                  pBondingData, nDev, nDsl));

            if (nRet < DSL_SUCCESS ||
               DSL_ST_ARRAY2_INDEX_PTR(
                  pBondingData, nDev, nDsl)->accessCtl.nReturn < DSL_SUCCESS)
            {
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_BND_CONFIG_GET ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDev, nRet, DSL_ST_ARRAY2_INDEX_PTR(
                     pBondingData, nDev, nDsl)->accessCtl.nReturn));

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDsl) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDsl) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_BND_CONFIG_GET);
   }

   /* get data for the given device */
   *pPafConfig = DSL_ST_ARRAY2_INDEX_PTR(
      pBondingData, nDevice, nDslMode)->data.bPafEnable;
   *pImapConfig = DSL_ST_ARRAY2_INDEX_PTR(
      pBondingData, nDevice, nDslMode)->data.bImapEnable;

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDslMode);
}

static DSL_char_t* DSL_ST_BndSchemeNameGet(
   DSL_ST_BndSchemeType eBndType,
   DSL_uint32_t nOffset)
{
   DSL_char_t *sSchemeName = DSL_NULL;

   for (DSL_uint_t i = 0; i < nBndSchemesNum; ++i)
   {
      if (bndSchemeTable[i].eType == eBndType)
      {
         /* select name from the table and exclude leading comma */
         sSchemeName = bndSchemeTable[i].sName + ((nOffset) ? 0 : 1);
         break;
      }
   }

   return sSchemeName;
}

static DSL_void_t DSL_ST_BndSchemesSupportedUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nOffset = 0, nBufLen = 0;
   DSL_char_t sSchemesSupported[32] = "";
   DSL_char_t *sSchemeName = DSL_NULL;
   DSL_boolean_t bPafConfigured = DSL_FALSE, bImapConfigured = DSL_FALSE;
   DSL_boolean_t bPafAdded = DSL_FALSE, bImapAdded = DSL_FALSE;
   DSL_ST_ParamValue_t uValue = { 0 };

   nBufLen = sizeof(sSchemesSupported);

   for (DSL_int_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
   {
      for (DSL_DslModeSelection_t nDslMode = DSL_MODE_ADSL;
            nDslMode < DSL_MODE_LAST; ++nDslMode)
      {
         if (DSL_ST_BondingConfigGet__vrx518(
               pContext, nDevice, nDslMode, &bPafConfigured,
               &bImapConfigured) == DSL_SUCCESS)
         {
            if (bPafAdded == DSL_FALSE &&
                  bPafConfigured == DSL_TRUE)
            {
               sSchemeName = DSL_ST_BndSchemeNameGet(
                  DSL_ST_BND_SCHEME_PTM, nOffset);
               if (sSchemeName != DSL_NULL)
               {
                  /* PAF ("Ethernet") bonding supported */
                  nBufLen = (sizeof(sSchemesSupported) > nOffset) ?
                     sizeof(sSchemesSupported) - nOffset : 0;
                  DSL_ST_strncpy_s(sSchemesSupported + nOffset, nBufLen,
                     sSchemeName, nBufLen);
                  nOffset += DSL_ST_strnlen_s(sSchemeName, nBufLen);
                  /* bonding scheme needs to be added to the list only once,
                     if only supported by any device */
                  bPafAdded = DSL_TRUE;
               }
            }

            if (bImapAdded == DSL_FALSE &&
                  bImapConfigured == DSL_TRUE)
            {
               sSchemeName = DSL_ST_BndSchemeNameGet(
                  DSL_ST_BND_SCHEME_ATM, nOffset);
               if (sSchemeName != DSL_NULL)
               {
                  /* IMA+ ("ATM") bonding supported */
                  nBufLen = (sizeof(sSchemesSupported) > nOffset) ?
                     sizeof(sSchemesSupported) - nOffset : 0;
                  DSL_ST_strncpy_s(sSchemesSupported + nOffset, nBufLen,
                     sSchemeName, nBufLen);
                  nOffset += DSL_ST_strnlen_s(sSchemeName, nBufLen);
                  /* bonding scheme needs to be added to the list only once,
                     if only supported by any device */
                  bImapAdded = DSL_TRUE;
               }
            }
         }
      }
   }

   /* update string param */
   uValue.sValue = sSchemesSupported;
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_STRING, &uValue);
}

/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_BND_STATUS_GET ioctl for all devices
*/
static DSL_Error_t DSL_ST_BondingStatusGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_int_t nDevice,
   DSL_BND_Enable_t *pPafEnabled,
   DSL_BND_Enable_t *pImapEnabled)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_BND_StatusGet_t *pBondingData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(pErrorCodeArray,
      DSL_ST_FLAG_BND_STATUS_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pBondingData, DSL_BND_StatusGet_t,
      DSL_ST_FLAG_BND_STATUS_GET,
      DSL_ST_DSL_ENTITIES);

   if (pPafEnabled == DSL_NULL || pImapEnabled == DSL_NULL ||
         nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pBondingData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid sending IOCTL many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_BND_STATUS_GET))
   {
      for (DSL_int_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         memset(&pBondingData[nDev], 0, sizeof(DSL_BND_StatusGet_t));
         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_BND_STATUS_GET, (int)&pBondingData[nDev]);

         if (nRet < DSL_SUCCESS ||
            pBondingData[nDev].accessCtl.nReturn < DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_BND_STATUS_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, pBondingData[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_BND_STATUS_GET);
   }

   /* get data for the given device */
   *pPafEnabled = pBondingData[nDevice].data.nPafEnable;
   *pImapEnabled = pBondingData[nDevice].data.nImapEnable;

   return pErrorCodeArray[nDevice];
}

static DSL_void_t DSL_ST_BndSchemeUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_BND_Enable_t nPafEnabled = DSL_BND_ENABLE_OFF,
      nImapEnabled = DSL_BND_ENABLE_OFF;
   DSL_char_t *sSchemeName = DSL_NULL;
   DSL_char_t sSchemeUsed[20] = "";
   DSL_ST_ParamValue_t uValue = { 0 };

   if (DSL_ST_BondingStatusGet__vrx518(
            pContext, nDevice, &nPafEnabled, &nImapEnabled) == DSL_SUCCESS)
   {
      if (nPafEnabled == DSL_BND_ENABLE_ON)
      {
         sSchemeName = DSL_ST_BndSchemeNameGet(
            DSL_ST_BND_SCHEME_PTM, /*nOffset*/0);
      }
      else if (nImapEnabled == DSL_BND_ENABLE_ON)
      {
         sSchemeName = DSL_ST_BndSchemeNameGet(
            DSL_ST_BND_SCHEME_ATM, /*nOffset*/0);
      }
   }

   if (sSchemeName != DSL_NULL)
   {
      DSL_ST_strncpy_s(sSchemeUsed, sizeof(sSchemeUsed),
         sSchemeName, sizeof(sSchemeUsed));
   }

   /* update string param */
   uValue.sValue = sSchemeUsed;
   DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
      DSL_ST_NODE_TYPE_STRING, &uValue);
}

static DSL_void_t DSL_ST_BndDatarateUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nBndDataRate = 0;
   const DSL_uint16_t nBndGroupIdx = 0;

   if (INCLUDE_DSL_BONDING)
   {
      DSL_CPE_BND_Context_t *pBndCtx = (DSL_CPE_BND_Context_t*)pContext->pBnd;
      if (pBndCtx != DSL_NULL)
      {
         if (eNodeIdx == DSL_STATUS_BND_GROUP_DATARATE_US)
         {
            nBndDataRate = pBndCtx->nActualDataRateUs[nBndGroupIdx];
         }
         else /* DSL_STATUS_BND_GROUP_DATARATE_DS */
         {
            nBndDataRate = pBndCtx->nActualDataRateDs[nBndGroupIdx];
         }
      }

      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nBndDataRate;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
/* --- Fast line status section (VRX618 only) --- */

/*
   This function collects all data provided by
   DSL_FastProfileConfigGet API function
*/
static DSL_Error_t DSL_ST_FastProfileConfigGet(
   DSL_Context_t *pContext,
   const DSL_uint16_t nDevice,
   DSL_uint32_t *pFastProfiles)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_FastProfileConfigData_t *pProfilesSupport = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(pErrorCodeArray,
      DSL_ST_FLAG_FAST_PROFILE_CONFIG_GET, DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pProfilesSupport, DSL_FastProfileConfigData_t,
      DSL_ST_FLAG_FAST_PROFILE_CONFIG_GET, DSL_ST_DSL_ENTITIES);

   if (pFastProfiles == DSL_NULL ||
      pErrorCodeArray == DSL_NULL || pProfilesSupport == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_FAST_PROFILE_CONFIG_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_FastProfileConfigGet(pContext, nDev,
            &pProfilesSupport[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_BAND_PLAN_SUPPORT_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, pProfilesSupport[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_FAST_PROFILE_CONFIG_GET);
   }

   *pFastProfiles = pProfilesSupport[nDevice].nProfiles;

   return pErrorCodeArray[nDevice];
}

static DSL_void_t DSL_ST_FastAllowedProfilesUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nFastProfiles = 0;
   DSL_size_t nOffset = 0, nBufLen = 0;
   DSL_char_t sFastAllowedProfiles[40] = "";
   const DSL_char_t *sFastProfileName = DSL_NULL;
   DSL_ST_ParamValue_t uValue = { 0 };

   if (DSL_ST_FastProfileConfigGet(
         pContext, nDevice, &nFastProfiles) == DSL_SUCCESS)
   {
      nBufLen = sizeof(sFastAllowedProfiles);
      for (unsigned int i = 0; (0x01 << i) < DSL_FAST_PROFILE_LAST; i++)
      {
         if ((i < nFastProfileTableLen) && (nFastProfiles & (0x01 << i)))
         {
            /* select name from the table and exclude leading comma */
            sFastProfileName = fastProfilesTable[i] + ((nOffset) ? 0 : 1);
            nBufLen = (sizeof(sFastAllowedProfiles) > nOffset) ?
               sizeof(sFastAllowedProfiles) - nOffset : 0;
            DSL_ST_strncpy_s(sFastAllowedProfiles + nOffset, nBufLen,
               sFastProfileName, nBufLen);
            nOffset += DSL_ST_strnlen_s(sFastProfileName, nBufLen);
         }
      }

      /* update string param */
      uValue.sValue = sFastAllowedProfiles;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

/*
   This function collects all data provided by
   DSL_FastProfileStatusGet API function
*/
static DSL_Error_t DSL_ST_FastProfileStatusGet(
   DSL_Context_t *pContext,
   const DSL_uint16_t nDevice,
   DSL_uint32_t *pFastProfile)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_FastProfileStatusData_t *pCurrentProfile = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(pErrorCodeArray,
      DSL_ST_FLAG_FAST_PROFILE_STATUS_GET, DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pCurrentProfile, DSL_FastProfileStatusData_t,
      DSL_ST_FLAG_FAST_PROFILE_STATUS_GET, DSL_ST_DSL_ENTITIES);

   if (pFastProfile == DSL_NULL ||
      pErrorCodeArray == DSL_NULL || pCurrentProfile == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_FAST_PROFILE_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_FastProfileStatusGet(pContext, nDev, &pCurrentProfile[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_BAND_PLAN_SUPPORT_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, currentProfile[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_FAST_PROFILE_STATUS_GET);
   }

   *pFastProfile = pCurrentProfile[nDevice].nProfile;

   return pErrorCodeArray[nDevice];
}

static DSL_void_t DSL_ST_FastCurrentProfileUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nFastProfile = 0, nBufLen = 0;
   DSL_char_t sFastCurrentProfile[5] = "";
   const DSL_char_t *sFastProfileName = DSL_NULL;
   DSL_ST_ParamValue_t uValue = { 0 };

   if (DSL_ST_FastProfileStatusGet(
         pContext, nDevice, &nFastProfile) == DSL_SUCCESS)
   {
      nBufLen = sizeof(sFastCurrentProfile);
      for (unsigned int i = 0; (0x01 << i) < DSL_FAST_PROFILE_LAST; i++)
      {
         if ((i < nFastProfileTableLen) && (nFastProfile & (0x01 << i)))
         {
            /* select name from the table and exclude leading comma */
            sFastProfileName = fastProfilesTable[i] + 1;
            DSL_ST_strncpy_s(sFastCurrentProfile, nBufLen,
               sFastProfileName, nBufLen);
            break;
         }
      }

      /* update string param */
      uValue.sValue = sFastCurrentProfile;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_STRING, &uValue);
   }
}

/*
   This function collects all data provided by
   DSL_FastLineStatusGet API function
*/
static DSL_Error_t DSL_ST_FastLineStatusGet(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_uint16_t *pFastLineStatus)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_AccessDir_t nDirection;
   DSL_FastLineStatusData_t *pFlStatus = DSL_NULL;
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_FAST_LINE_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pFlStatus, DSL_FastLineStatusData_t,
      DSL_ST_FLAG_FAST_LINE_STATUS_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);

   if (pFastLineStatus == DSL_NULL ||
      pErrorCodeArray == DSL_NULL || pFlStatus == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_FAST_LINE_STATUS_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_AccessDir_t nDir = DSL_UPSTREAM;
            nDir < DSL_ACCESSDIR_LAST; ++nDir)
         {
            nRet = DSL_FastLineStatusGet(
               pContext, nDev, nDir,
               DSL_ST_ARRAY2_INDEX_PTR(pFlStatus, nDev, nDir));

            if (nRet < DSL_SUCCESS)
            {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_BAND_PLAN_SUPPORT_GET ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDev, nRet, currentProfile[nDev].accessCtl.nReturn));
#endif /* if 0 */

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_FAST_LINE_STATUS_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATUS_FAST_LINE_SNRMRMC_US:
      nDirection = DSL_UPSTREAM;
      *pFastLineStatus =
         DSL_ST_ARRAY2_INDEX_PTR(
            pFlStatus, nDevice, nDirection)->nSnrmRmc;
      break;
   case DSL_STATUS_FAST_LINE_SNRMRMC_DS:
      nDirection = DSL_DOWNSTREAM;
      *pFastLineStatus =
         DSL_ST_ARRAY2_INDEX_PTR(
            pFlStatus, nDevice, nDirection)->nSnrmRmc;
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - Status Parser (DSL_ST_FastLineStatusGet): "
         "unknown node!"
         DSL_CPE_CRLF));
      nErrorCode = DSL_ERROR;
#endif /* if 0 */
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDirection);
}

static DSL_void_t DSL_ST_FastSnrmrmcUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint16_t nSnrmRmc = 0;

   if (DSL_ST_FastLineStatusGet(
         pContext, eNodeIdx, nDevice, &nSnrmRmc) == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nSnrmRmc;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

/*
   This function collects all data provided by
   DSL_FastRMCBitAllocationTableGet API function
*/
#if 0 /* RMC Tones should be provided in dedicated (new) file,
         not in DSL Status file. */
static DSL_Error_t DSL_ST_FastRMCBitAllocationTableGet(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_uint16_t *pToneIdx,
   DSL_uint16_t *pBits)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_AccessDir_t nDirection;
   DSL_FastBatRmcTable *pFastBatRmcTable = DSL_NULL;
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_FAST_RMC_BIT_ALLOCATION_TABLE_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pFastBatRmcTable, DSL_FastBatRmcTable,
      DSL_ST_FLAG_FAST_RMC_BIT_ALLOCATION_TABLE_GET,
      DSL_ST_DSL_ENTITIES, DSL_ACCESSDIR_LAST);

   if (pToneIdx == DSL_NULL || pBits == DSL_NULL ||
      pErrorCodeArray == DSL_NULL || pFastBatRmcTable == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_FAST_RMC_BIT_ALLOCATION_TABLE_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_AccessDir_t nDir = DSL_UPSTREAM;
            nDir < DSL_ACCESSDIR_LAST; ++nDir)
         {
            nRet = DSL_FastRMCBitAllocationTableGet(
               pContext, nDev, nDir,
               DSL_ST_ARRAY2_INDEX_PTR(pFastBatRmcTable, nDev, nDir));

            if (nRet < DSL_SUCCESS)
            {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_BAND_PLAN_SUPPORT_GET ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDev, nRet,
                  DSL_ST_ARRAY2_INDEX_PTR(
                     pFastBatRmcTable, nDev, nDir).accessCtl.nReturn));
#endif /* if 0 */

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nDir) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_FAST_RMC_BIT_ALLOCATION_TABLE_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATUS_FAST_LINE_BITSRMCPS_US:
      nDirection = DSL_UPSTREAM;
      break;
   case DSL_STATUS_FAST_LINE_BITSRMCPS_DS:
      nDirection = DSL_DOWNSTREAM;
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - Status Parser (DSL_ST_FastRMCBitAllocationTableGet): "
         "unknown node!"
         DSL_CPE_CRLF));
      nErrorCode = DSL_ERROR;
#endif /* if 0 */
      return DSL_ERROR;
   }

   /* Copy values to arrays only if data is valid */
   if (DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDirection) ==
      DSL_SUCCESS)
   {
      for (DSL_uint16_t i = 0; i < DSL_GFAST_MAX_RMC_BAT_TONES; ++i)
      {
         pToneIdx[i] = DSL_ST_ARRAY2_INDEX_PTR(pFastBatRmcTable, nDevice,
            nDirection)->tBatRmcEntry[i].ToneIndex;
         pBits[i] = DSL_ST_ARRAY2_INDEX_PTR(pFastBatRmcTable, nDevice,
            nDirection)->tBatRmcEntry[i].Bits;
      }
   }

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nDirection);
}
#endif /* if 0 */

static DSL_void_t DSL_ST_FastBitsrmcpsUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
#if 0 /* RMC Tones should be provided in dedicated (new) file,
         not in DSL Status file. */
   DSL_uint16_t nToneIdx[DSL_GFAST_MAX_RMC_BAT_TONES] = { 0 };
   DSL_uint16_t nBits[DSL_GFAST_MAX_RMC_BAT_TONES] = { 0 };
#define MAX_TONES_BITS_STR_LEN 15

   if (DSL_ST_FastRMCBitAllocationTableGet(
         pContext, eNodeIdx, nDevice, nToneIdx, nBits) == DSL_SUCCESS)
   {
      /* array to store all output strings */
      DSL_char_t aTonesBitsPair
         [DSL_GFAST_MAX_RMC_BAT_TONES][MAX_TONES_BITS_STR_LEN] = { 0 };

      for (DSL_uint16_t i = 0; i < DSL_GFAST_MAX_RMC_BAT_TONES; ++i)
      {
#if 0 /* disabled for the time being (empty array only) due to large amount
         of data - to be clarified which of these values are really needed
         to be stored in the status file */
         DSL_ST_snprintf_s(aTonesBitsPair[i], MAX_TONES_BITS_STR_LEN,
            "(%04d, %02d)", nToneIdx[i], nBits[i]);
         aTonesBitsPair[i][MAX_TONES_BITS_STR_LEN - 1] = '\0';
#else /* storing empty array (workaround) */
         DSL_ST_snprintf_s(aTonesBitsPair[i], MAX_TONES_BITS_STR_LEN, "");
#endif /* if 0 */
      }
      /* update array param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.aValue.uArray.ppStrArray = (DSL_char_t**)aTonesBitsPair;
      uValue.aValue.nSize = DSL_GFAST_MAX_RMC_BAT_TONES;
      uValue.aValue.eOutputType = STR;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_ARRAY, &uValue);
   }

#undef MAX_TONES_BITS_STR_LEN
#endif /* if 0 */
}

/*
   This function collects all data provided by
   DSL_PM_RetransmissionCountersTotalGet API function
*/
static DSL_Error_t DSL_ST_RetransmissionCountersTotalGet(
   DSL_Context_t *pContext,
   const DSL_uint16_t nDevice,
   DSL_uint32_t *pEftrMin)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_PM_RetransmissionCountersData_t *pRetransCounters = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(pErrorCodeArray,
      DSL_ST_FLAG_FAST_RETRANS_COUNTERS_TOTAL_GET, DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pRetransCounters, DSL_PM_RetransmissionCountersData_t,
      DSL_ST_FLAG_FAST_RETRANS_COUNTERS_TOTAL_GET, DSL_ST_DSL_ENTITIES);

   if (pEftrMin == DSL_NULL ||
      pErrorCodeArray == DSL_NULL || pRetransCounters == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_FAST_RETRANS_COUNTERS_TOTAL_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_PM_RetransmissionCountersTotalGet(
            pContext, nDev, DSL_NEAR_END, &pRetransCounters[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_BAND_PLAN_SUPPORT_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, currentProfile[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_FAST_RETRANS_COUNTERS_TOTAL_GET);
   }

   *pEftrMin = pRetransCounters[nDevice].nEftrMin;

   return pErrorCodeArray[nDevice];
}

static DSL_void_t DSL_ST_FastMineftrUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nEftrMin = 0;

   if (DSL_ST_RetransmissionCountersTotalGet(
         pContext, nDevice, &nEftrMin) == DSL_SUCCESS)
   {
      /* update double param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nEftrMin;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_DOUBLE, &uValue);
   }
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */

/* --- Line statistics section --- */

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_PM_CHANNEL_COUNTERS_TOTAL_GET
   IOCtl from all available devices and XTU directions.
*/
static DSL_Error_t DSL_ST_PMCountersTotalGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_ulong_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_XTUDir_t nDirection = DSL_NEAR_END;
   DSL_PM_ChannelCountersTotal_t *pCcData = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray, DSL_ST_FLAG_PM_CHANNEL_COUNTERS_TOTAL_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pCcData, DSL_PM_ChannelCountersTotal_t,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_TOTAL_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_CPE_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pCcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_TOTAL_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_CPE_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            /* omit PM polling for disabled lines */
            if (INCLUDE_DSL_BONDING)
            {
               DSL_CPE_BND_Context_t *pBndCtx =
                  (DSL_CPE_BND_Context_t*)pContext->pBnd;
               if (pBndCtx != DSL_NULL &&
                  pBndCtx->lineBondingConfig[nDev].nPafLineDisabled == 1)
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, DSL_NEAR_END) = DSL_ERROR;
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, DSL_FAR_END) = DSL_ERROR;
                  continue;
               }
            }

            for (DSL_XTUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               DSL_ST_ARRAY3_INDEX_PTR(
                  pCcData, nDev, nCh, nDir)->nDirection = nDir;
               DSL_ST_ARRAY3_INDEX_PTR(
                  pCcData, nDev, nCh, nDir)->nChannel = nCh;

               nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
                  DSL_FIO_PM_CHANNEL_COUNTERS_TOTAL_GET,
                  (int)DSL_ST_ARRAY2_INDEX_PTR(pCcData, nDev, nDir));

               if (nRet < DSL_SUCCESS ||
                  DSL_ST_ARRAY3_INDEX_PTR(
                     pCcData, nDev, nCh, nDir)->accessCtl.nReturn
                  != DSL_SUCCESS)
               {
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_PM_CHANNEL_COUNTERS_TOTAL_GET ioctl failed "
                     "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
                     nDev, nRet, DSL_ST_ARRAY3_INDEX_PTR(pCcData,
                        nDev, nCh, nDir)->accessCtl.nReturn));

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_TOTAL_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_TOTAL_START:
   case DSL_STATS_LINE_CHANNEL_TOTAL_START:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->total.nElapsedTime;
      break;
   case DSL_STATS_LINE_CHANNEL_TOTAL_XTUR_FEC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->data.nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_TOTAL_XTUC_FEC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->data.nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_TOTAL_XTUR_CRC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->data.nCodeViolations;
      break;
   case DSL_STATS_LINE_CHANNEL_TOTAL_XTUC_CRC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->data.nCodeViolations;
      break;
   default:
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_PM_ChannelCountersTotalGet API function
*/
static DSL_Error_t DSL_ST_PMCountersTotalGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_ulong_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_ATUDir_t nDirection = DSL_NEAR_END;
   DSL_PM_ChannelCountersData_t *pCcData = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray, DSL_ST_FLAG_PM_CHANNEL_COUNTERS_TOTAL_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pCcData, DSL_PM_ChannelCountersData_t,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_TOTAL_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pCcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_TOTAL_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            for (DSL_ATUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               nRet = DSL_PM_ChannelCountersTotalGet(pContext,
                  nDev, nCh, nDir,
                  DSL_ST_ARRAY3_INDEX_PTR(pCcData, nDev, nCh, nDir));

               if (nRet < DSL_SUCCESS)
               {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_PM_CHANNEL_COUNTERS_TOTAL_GET ioctl failed "
                     "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
                     nDev, nRet, sData[nDev][nDir].accessCtl.nReturn));
#endif /* if 0 */

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_TOTAL_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_TOTAL_START:
   case DSL_STATS_LINE_CHANNEL_TOTAL_START:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->nElapsedTime;
      break;
   case DSL_STATS_LINE_CHANNEL_TOTAL_XTUR_FEC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(pCcData, nDevice, nChannel, nDirection)->nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_TOTAL_XTUC_FEC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(pCcData, nDevice, nChannel, nDirection)->nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_TOTAL_XTUR_CRC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->nCodeViolations;
      break;
   case DSL_STATS_LINE_CHANNEL_TOTAL_XTUC_CRC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->nCodeViolations;
      break;
   default:
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_TotalStartUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_time_t nElapsedTime = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_PMCountersTotalGet__vrx518(
         pContext, eNodeIdx, nDevice, nChannel,
         (DSL_ulong_t *)&nElapsedTime) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_PMCountersTotalGet__vrx618(
         pContext, eNodeIdx, nDevice, nChannel, &nElapsedTime) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nElapsedTime;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_PM_CHANNEL_COUNTERS_SHOWTIME_GET
   IOCtl from all available devices, history intervals and XTU directions.
*/
static DSL_Error_t DSL_ST_PMCountersShowtimeGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_ulong_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_XTUDir_t nDirection;
   DSL_uint32_t nHistoryInterval;
   DSL_PM_ChannelCounters_t *pCcData = DSL_NULL;
   /* Array Y, Z and W sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0, nArrayW = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY4_GET(pErrorCodeArray,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1,
      DSL_ST_PM_HISTORY_INTERVALS_NUM);
   DSL_ST_DYNAMIC_DATA_ARRAY4_GET(pCcData, DSL_PM_ChannelCounters_t,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1,
      DSL_ST_PM_HISTORY_INTERVALS_NUM);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pCcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_SHOWTIME_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            /* omit PM polling for disabled lines */
            if (INCLUDE_DSL_BONDING)
            {
               DSL_CPE_BND_Context_t *pBndCtx = (DSL_CPE_BND_Context_t *)pContext->pBnd;
               if (pBndCtx != DSL_NULL &&
                  pBndCtx->lineBondingConfig[nDev].nPafLineDisabled == 1)
               {
                  DSL_ST_ARRAY4_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh,
                     DSL_NEAR_END, /*HistoryInterval*/0) = DSL_ERROR;
                  DSL_ST_ARRAY4_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh,
                     DSL_NEAR_END, /*HistoryInterval*/1) = DSL_ERROR;
                  DSL_ST_ARRAY4_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh,
                     DSL_FAR_END,/*HistoryInterval*/0) = DSL_ERROR;
                  DSL_ST_ARRAY4_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh,
                     DSL_FAR_END,/*HistoryInterval*/1) = DSL_ERROR;
                  continue;
               }
            }

            for (DSL_XTUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               for (DSL_uint32_t nHistInt = 0;
                  nHistInt < DSL_ST_PM_HISTORY_INTERVALS_NUM; ++nHistInt)
               {
                  DSL_ST_ARRAY4_INDEX_PTR(
                     pCcData, nDev, nCh, nDir, nHistInt)->nDirection = nDir;
                  DSL_ST_ARRAY4_INDEX_PTR(
                     pCcData, nDev, nCh, nDir, nHistInt)->nChannel = nCh;
                  DSL_ST_ARRAY4_INDEX_PTR(
                     pCcData, nDev, nCh, nDir,
                     nHistInt)->nHistoryInterval = nHistInt;

                  nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
                     DSL_FIO_PM_CHANNEL_COUNTERS_SHOWTIME_GET,
                     (int)DSL_ST_ARRAY4_INDEX_PTR(
                        pCcData, nDev, nCh, nDir, nHistInt));

                  if (nRet < DSL_SUCCESS ||
                     DSL_ST_ARRAY4_INDEX_PTR(
                        pCcData, nDev, nCh,
                        nDir, nHistInt)->accessCtl.nReturn != DSL_SUCCESS)
                  {
                     DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                        "ERROR - DSL_FIO_PM_CHANNEL_COUNTERS_SHOWTIME_GET "
                        "ioctl failed (device<%d>, direction<%s>, "
                        "historyInterval<%d>, nRet=%d, "
                        "accessCtrl=%d)!" DSL_CPE_CRLF,
                        nDev, (nDir == DSL_NEAR_END) ? "near end" : "far end",
                        nHistInt, nRet,
                        DSL_ST_ARRAY4_INDEX_PTR(
                           pCcData, nDev, nCh, nDir,
                           nHistInt)->accessCtl.nReturn));

                     DSL_ST_ARRAY4_INDEX_VAL(
                        pErrorCodeArray, nDev, nCh,
                        nDir, nHistInt) = DSL_ERROR;
                  }
                  else
                  {
                     DSL_ST_ARRAY4_INDEX_VAL(
                        pErrorCodeArray, nDev, nCh,
                        nDir, nHistInt) = DSL_SUCCESS;
                  }
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_SHOWTIME_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_SHOWTIME_START:
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_START:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection,
            nHistoryInterval)->interval.nElapsedTime;
      break;
   case DSL_STATS_LINE_LAST_SHOWTIME_START:
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_START:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection,
            nHistoryInterval)->interval.nElapsedTime;
      break;
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUR_FEC_ERRORS:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection,
            nHistoryInterval)->data.nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUC_FEC_ERRORS:
      nDirection = DSL_FAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection,
            nHistoryInterval)->data.nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUR_FEC_ERRORS:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection,
            nHistoryInterval)->data.nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUC_FEC_ERRORS:
      nDirection = DSL_FAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection,
            nHistoryInterval)->data.nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUR_CRC_ERRORS:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection,
            nHistoryInterval)->data.nCodeViolations;
      break;
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUC_CRC_ERRORS:
      nDirection = DSL_FAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection,
            nHistoryInterval)->data.nCodeViolations;
      break;
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUR_CRC_ERRORS:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection,
            nHistoryInterval)->data.nCodeViolations;
      break;
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUC_CRC_ERRORS:
      nDirection = DSL_FAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection,
            nHistoryInterval)->data.nCodeViolations;
      break;
   default:
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY4_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection, nHistoryInterval);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_PM_ChannelCountersShowtimeGet API function
*/
static DSL_Error_t DSL_ST_PMCountersShowtimeGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_ulong_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_ATUDir_t nDirection;
   DSL_uint32_t nHistoryInterval;
   DSL_PM_ChannelCountersData_t *pCcData = DSL_NULL;
   /* Array Y, Z and W sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0, nArrayW = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY4_GET(pErrorCodeArray,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1,
      DSL_ST_PM_HISTORY_INTERVALS_NUM);
   DSL_ST_DYNAMIC_DATA_ARRAY4_GET(pCcData, DSL_PM_ChannelCountersData_t,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1,
      DSL_ST_PM_HISTORY_INTERVALS_NUM);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pCcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_SHOWTIME_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            for (DSL_ATUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               for (DSL_uint32_t nHistInt = 0;
                  nHistInt < DSL_ST_PM_HISTORY_INTERVALS_NUM; ++nHistInt)
               {
                  nRet = DSL_PM_ChannelCountersShowtimeGet(pContext,
                     nDev, nCh, nDir, nHistInt,
                     DSL_ST_ARRAY4_INDEX_PTR(
                        pCcData, nDev, nCh, nDir, nHistInt));

                  if (nRet < DSL_SUCCESS)
                  {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
                     DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                        "ERROR - DSL_FIO_PM_CHANNEL_COUNTERS_SHOWTIME_GET "
                        "ioctl failed (device<%d>, direction<%s>, "
                        "historyInterval<%d>, nRet=%d, "
                        "accessCtrl=%d)!" DSL_CPE_CRLF,
                        nDev, (nDir == DSL_NEAR_END) ? "near end" : "far end",
                        nHistInt, nRet,
                        DSL_ST_ARRAY4_INDEX_PTR(
                           pCcData, nDev, nCh, nDir,
                           nHistInt)->accessCtl.nReturn));
#endif /* if 0 */

                     DSL_ST_ARRAY4_INDEX_VAL(
                        pErrorCodeArray, nDev,
                        nCh, nDir, nHistInt) = DSL_ERROR;
                  }
                  else
                  {
                     DSL_ST_ARRAY4_INDEX_VAL(
                        pErrorCodeArray, nDev,
                        nCh, nDir, nHistInt) = DSL_SUCCESS;
                  }
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_SHOWTIME_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_SHOWTIME_START:
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_START:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel,
            nDirection, nHistoryInterval)->nElapsedTime;
      break;
   case DSL_STATS_LINE_LAST_SHOWTIME_START:
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_START:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel,
            nDirection, nHistoryInterval)->nElapsedTime;
      break;
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUR_FEC_ERRORS:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection, nHistoryInterval)->nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUC_FEC_ERRORS:
      nDirection = DSL_FAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection, nHistoryInterval)->nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUR_FEC_ERRORS:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection, nHistoryInterval)->nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUC_FEC_ERRORS:
      nDirection = DSL_FAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection, nHistoryInterval)->nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUR_CRC_ERRORS:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel,
            nDirection, nHistoryInterval)->nCodeViolations;
      break;
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUC_CRC_ERRORS:
      nDirection = DSL_FAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel,
            nDirection, nHistoryInterval)->nCodeViolations;
      break;
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUR_CRC_ERRORS:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel,
            nDirection, nHistoryInterval)->nCodeViolations;
      break;
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUC_CRC_ERRORS:
      nDirection = DSL_FAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pCcData, nDevice, nChannel,
            nDirection, nHistoryInterval)->nCodeViolations;
      break;
   default:
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY4_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection, nHistoryInterval);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_ShowtimeStartUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_time_t nShowtimeElapsedTime = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_PMCountersShowtimeGet__vrx518(
         pContext, eNodeIdx, nDevice, nChannel,
         (DSL_ulong_t *)&nShowtimeElapsedTime)
      == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_PMCountersShowtimeGet__vrx618(
         pContext, eNodeIdx, nDevice, nChannel, &nShowtimeElapsedTime)
      == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nShowtimeElapsedTime;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_LastShowtimeStartUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_time_t nLastShowtimeElapsedTime = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_PMCountersShowtimeGet__vrx518(
         pContext, eNodeIdx, nDevice, nChannel,
         (DSL_ulong_t *)&nLastShowtimeElapsedTime)
      == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_PMCountersShowtimeGet__vrx618(
         pContext, eNodeIdx, nDevice, nChannel,
         &nLastShowtimeElapsedTime)
      == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nLastShowtimeElapsedTime;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_PM_LINE_INIT_COUNTERS_1DAY_GET
   IOCtl from all available devices, history intervals and XTU directions.
*/
static DSL_Error_t DSL_ST_PMCounters1DayGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_uint16_t nDevice,
   DSL_time_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_PM_LineInitCounters_t *pInitCounters = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_PM_LINE_INIT_COUNTERS_1DAY_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pInitCounters, DSL_PM_LineInitCounters_t,
      DSL_ST_FLAG_PM_LINE_INIT_COUNTERS_1DAY_GET, DSL_ST_DSL_ENTITIES);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pInitCounters == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_LINE_INIT_COUNTERS_1DAY_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         /* omit PM polling for disabled lines */
         if (INCLUDE_DSL_BONDING)
         {
            DSL_CPE_BND_Context_t *pBndCtx = (DSL_CPE_BND_Context_t*)pContext->pBnd;
            if (pBndCtx != DSL_NULL &&
               pBndCtx->lineBondingConfig[nDev].nPafLineDisabled == 1)
            {
               return DSL_ERROR;
            }
         }

         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_PM_LINE_INIT_COUNTERS_1DAY_GET, (int)pInitCounters);

         if (nRet < DSL_SUCCESS ||
            pInitCounters[nDev].accessCtl.nReturn != DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_PM_LINE_INIT_COUNTERS_1DAY_GET "
               "ioctl failed (device<%d>, nRet=%d, "
               "accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, pInitCounters[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_LINE_INIT_COUNTERS_1DAY_GET);
   }

   *pData = pInitCounters[nDevice].interval.nElapsedTime;

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_PM_LineInitCounters1DayGet API function
*/
static DSL_Error_t DSL_ST_PMCounters1DayGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_uint16_t nDevice,
   DSL_time_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_PM_LineInitCountersData_t *pInitCounters = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_PM_LINE_INIT_COUNTERS_1DAY_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pInitCounters, DSL_PM_LineInitCountersData_t,
      DSL_ST_FLAG_PM_LINE_INIT_COUNTERS_1DAY_GET, DSL_ST_DSL_ENTITIES);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pInitCounters == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_LINE_INIT_COUNTERS_1DAY_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_PM_LineInitCounters1DayGet(pContext,
            nDev, /*nHistoryInterval*/0, &pInitCounters[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_PM_LINE_INIT_COUNTERS_1DAY_GET "
               "ioctl failed (device<%d>, nRet=%d, "
               "accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, pInitCounters[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_LINE_INIT_COUNTERS_1DAY_GET);
   }

   *pData = pInitCounters[nDevice].nElapsedTime;

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_CurrDayStartUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_time_t nCurrDayElapsedTime = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_PMCounters1DayGet__vrx518(
         pContext, nDevice, &nCurrDayElapsedTime) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_PMCounters1DayGet__vrx618(
         pContext, nDevice, &nCurrDayElapsedTime) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nCurrDayElapsedTime;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_PM_CHANNEL_COUNTERS_15MIN_GET
   IOCtl from all available devices and XTU directions.
*/
static DSL_Error_t DSL_ST_PMCounters15MinGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_ulong_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_XTUDir_t nDirection;
   DSL_PM_ChannelCounters_t *pCcData = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_15MIN_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pCcData, DSL_PM_ChannelCounters_t,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_15MIN_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pCcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_15MIN_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            /* omit PM polling for disabled lines */
            if (INCLUDE_DSL_BONDING)
            {
               DSL_CPE_BND_Context_t *pBndCtx =
                  (DSL_CPE_BND_Context_t*)pContext->pBnd;
               if (pBndCtx != DSL_NULL &&
                  pBndCtx->lineBondingConfig[nDev].nPafLineDisabled == 1)
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, DSL_NEAR_END) = DSL_ERROR;
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, DSL_FAR_END) = DSL_ERROR;
                  continue;
               }
            }

            for (DSL_XTUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               DSL_ST_ARRAY3_INDEX_PTR(
                  pCcData, nDev, nCh, nDir)->nHistoryInterval = 0;
               DSL_ST_ARRAY3_INDEX_PTR(
                  pCcData, nDev, nCh, nDir)->nDirection = nDir;
               DSL_ST_ARRAY3_INDEX_PTR(
                  pCcData, nDev, nCh, nDir)->nChannel = nCh;

               nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
                  DSL_FIO_PM_CHANNEL_COUNTERS_15MIN_GET,
                  (int)DSL_ST_ARRAY3_INDEX_PTR(pCcData, nDev, nCh, nDir));

               if (nRet < DSL_SUCCESS ||
                  DSL_ST_ARRAY3_INDEX_PTR(
                     pCcData, nDev, nCh, nDir)->accessCtl.nReturn
                  != DSL_SUCCESS)
               {
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_PM_CHANNEL_COUNTERS_15MIN_GET ioctl failed "
                     "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
                     nDev, nRet, DSL_ST_ARRAY3_INDEX_PTR(
                        pCcData, nDev, nCh, nDir)->accessCtl.nReturn));

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_15MIN_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_QUARTER_HOUR_START:
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_START:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->interval.nElapsedTime;
      break;
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUR_FEC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->data.nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUC_FEC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->data.nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUR_CRC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->data.nCodeViolations;
      break;
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUC_CRC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->data.nCodeViolations;
      break;
   default:
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_ST_PMCounters15MinGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_PM_ChannelCounters15MinGet API function
*/
static DSL_Error_t DSL_ST_PMCounters15MinGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_ulong_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_ATUDir_t nDirection;
   DSL_PM_ChannelCountersData_t *pCcData = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_15MIN_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pCcData, DSL_PM_ChannelCountersData_t,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_15MIN_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pCcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_15MIN_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            for (DSL_ATUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               nRet = DSL_PM_ChannelCounters15MinGet(pContext,
                  nDev, nCh, nDir, /*nHistoryInterval*/0,
                  DSL_ST_ARRAY3_INDEX_PTR(pCcData, nDev, nCh, nDir));

               if (nRet < DSL_SUCCESS)
               {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_PM_CHANNEL_COUNTERS_15MIN_GET ioctl failed "
                     "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
                     nDev, nRet, DSL_ST_ARRAY3_INDEX_PTR(
                        pCcData, nDev, nCh, nDir)->accessCtl.nReturn));
#endif /* if 0 */

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_15MIN_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_QUARTER_HOUR_START:
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_START:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->nElapsedTime;
      break;
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUR_FEC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUC_FEC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUR_CRC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->nCodeViolations;
      break;
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUC_CRC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->nCodeViolations;
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_ST_PMCounters15MinGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
#endif /* if 0 */
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_QuarterHourStartUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_time_t n15MinElapsedTime = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_PMCounters15MinGet__vrx518(
         pContext, eNodeIdx, nDevice, nChannel,
         (DSL_ulong_t *)&n15MinElapsedTime)
      == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_PMCounters15MinGet__vrx618(
         pContext, eNodeIdx, nDevice, nChannel, &n15MinElapsedTime)
      == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = n15MinElapsedTime;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_PM_LINE_SEC_COUNTERS_TOTAL_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_LineSecCountersTotalGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_int_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_PM_LineSecCountersTotal_t *pLscData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_TOTAL_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pLscData, DSL_PM_LineSecCountersTotal_t,
      DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_TOTAL_GET, DSL_ST_DSL_ENTITIES);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pLscData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_TOTAL_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         /* omit PM polling for disabled lines */
         if (INCLUDE_DSL_BONDING)
         {
            DSL_CPE_BND_Context_t *pBndCtx = (DSL_CPE_BND_Context_t*)pContext->pBnd;
            if (pBndCtx != DSL_NULL &&
               pBndCtx->lineBondingConfig[nDev].nPafLineDisabled == 1)
            {
               pErrorCodeArray[nDev] = DSL_ERROR;
               continue;
            }
         }

         pLscData[nDev].nDirection = DSL_NEAR_END;

         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_PM_LINE_SEC_COUNTERS_TOTAL_GET,
            (int)&pLscData[nDev]);

         if (nRet < DSL_SUCCESS ||
            pLscData[nDev].accessCtl.nReturn != DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_PM_LINE_SEC_COUNTERS_TOTAL_GET ioctl failed "
               "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, pLscData[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_TOTAL_GET);
   }

   /* provide data of corresponding IOCtl request */
   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_TOTAL_ERR_SECS:
      *pData = pLscData[nDevice].data.nES;
      break;
   case DSL_STATS_LINE_TOTAL_SEV_ERR_SECS:
      *pData = pLscData[nDevice].data.nSES;
      break;
   default:
      return DSL_ERROR;
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_PM_LineSecCountersTotalGet API function
*/
static DSL_Error_t DSL_ST_LineSecCountersTotalGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_int_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_PM_LineSecCountersData_t *pLscData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_TOTAL_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pLscData, DSL_PM_LineSecCountersData_t,
      DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_TOTAL_GET, DSL_ST_DSL_ENTITIES);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pLscData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_TOTAL_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_PM_LineSecCountersTotalGet(pContext,
            nDev, DSL_NEAR_END, &pLscData[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_PM_LINE_SEC_COUNTERS_TOTAL_GET ioctl failed "
               "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, pLscData[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_TOTAL_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_TOTAL_ERR_SECS:
      *pData = pLscData[nDevice].nES;
      break;
   case DSL_STATS_LINE_TOTAL_SEV_ERR_SECS:
      *pData = pLscData[nDevice].nSES;
      break;
   default:
      return DSL_ERROR;
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_TotalErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_int_t nTotalErrSecs = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineSecCountersTotalGet__vrx518(
         pContext, eNodeIdx, nDevice, &nTotalErrSecs) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineSecCountersTotalGet__vrx618(
         pContext, eNodeIdx, nDevice, &nTotalErrSecs) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nTotalErrSecs;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_TotalSevErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_int_t nTotalSevErrSecs = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineSecCountersTotalGet__vrx518(
         pContext, eNodeIdx, nDevice, &nTotalSevErrSecs) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineSecCountersTotalGet__vrx618(
         pContext, eNodeIdx, nDevice, &nTotalSevErrSecs) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nTotalSevErrSecs;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_PM_LINE_SEC_COUNTERS_SHOWTIME_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_LineSecCountersShowtimeGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_int_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint32_t nHistoryInterval;
   DSL_PM_LineSecCounters_t *pLscData = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_PM_HISTORY_INTERVALS_NUM);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pLscData, DSL_PM_LineSecCounters_t,
      DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_PM_HISTORY_INTERVALS_NUM);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pLscData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_SHOWTIME_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         /* omit PM polling for disabled lines */
         if (INCLUDE_DSL_BONDING)
         {
            DSL_CPE_BND_Context_t *pBndCtx =
               (DSL_CPE_BND_Context_t*)pContext->pBnd;
            if (pBndCtx != DSL_NULL &&
               pBndCtx->lineBondingConfig[nDev].nPafLineDisabled == 1)
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, /*HistoryInterval*/0) = DSL_ERROR;
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, /*HistoryInterval*/1) = DSL_ERROR;
               continue;
            }
         }

         for (DSL_uint32_t nHistInt = 0;
            nHistInt < DSL_ST_PM_HISTORY_INTERVALS_NUM; ++nHistInt)
         {
            DSL_ST_ARRAY2_INDEX_PTR(
               pLscData, nDev, nHistInt)->nDirection = DSL_NEAR_END;
            DSL_ST_ARRAY2_INDEX_PTR(
               pLscData, nDev, nHistInt)->nHistoryInterval = nHistInt;

            nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
               DSL_FIO_PM_LINE_SEC_COUNTERS_SHOWTIME_GET,
               (int)DSL_ST_ARRAY2_INDEX_PTR(pLscData, nDev, nHistInt));

            if (nRet < DSL_SUCCESS ||
               DSL_ST_ARRAY2_INDEX_PTR(
                  pLscData, nDev, nHistInt)->accessCtl.nReturn != DSL_SUCCESS)
            {
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_PM_LINE_SEC_COUNTERS_SHOWTIME_GET "
                  "ioctl failed (device<%d>, historyInterval<%d>, "
                  "nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
                  nDev, nHistInt, nRet,
                  DSL_ST_ARRAY2_INDEX_PTR(
                     pLscData, nDev, nHistInt)->accessCtl.nReturn));

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nHistInt) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nHistInt) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_SHOWTIME_GET);
   }

   /* provide data of corresponding IOCtl request */
   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_SHOWTIME_ERR_SECS:
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(
            pLscData, nDevice, nHistoryInterval)->data.nES;
      break;
   case DSL_STATS_LINE_SHOWTIME_SEV_ERR_SECS:
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(
            pLscData, nDevice, nHistoryInterval)->data.nSES;
      break;
   case DSL_STATS_LINE_LAST_SHOWTIME_ERR_SECS:
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(
            pLscData, nDevice, nHistoryInterval)->data.nES;
      break;
   case DSL_STATS_LINE_LAST_SHOWTIME_SEV_ERR_SECS:
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(
            pLscData, nDevice, nHistoryInterval)->data.nSES;
      break;
   default:
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nHistoryInterval);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_PM_LineSecCountersShowtimeGet API function
*/
static DSL_Error_t DSL_ST_LineSecCountersShowtimeGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_int_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint32_t nHistoryInterval;
   DSL_PM_LineSecCountersData_t *pLscData = DSL_NULL;
   /* Array Y(width) size, needed for memory access
      by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_PM_HISTORY_INTERVALS_NUM);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pLscData, DSL_PM_LineSecCountersData_t,
      DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_PM_HISTORY_INTERVALS_NUM);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pLscData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_SHOWTIME_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint32_t nHistInt = 0;
            nHistInt < DSL_ST_PM_HISTORY_INTERVALS_NUM; ++nHistInt)
         {
            nRet = DSL_PM_LineSecCountersShowtimeGet(pContext,
               nDev, DSL_NEAR_END, nHistInt,
               DSL_ST_ARRAY2_INDEX_PTR(pLscData, nDev, nHistInt));

            if (nRet < DSL_SUCCESS)
            {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_PM_LINE_SEC_COUNTERS_SHOWTIME_GET "
                  "ioctl failed (device<%d>, historyInterval<%d>, "
                  "nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
                  nDev, nHistInt, nRet,
                  DSL_ST_ARRAY2_INDEX_PTR(
                     pLscData, nDev, nHistInt)->accessCtl.nReturn));
#endif /* if 0 */

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nHistInt) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nHistInt) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_SHOWTIME_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_SHOWTIME_ERR_SECS:
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pLscData, nDevice, nHistoryInterval)->nES;
      break;
   case DSL_STATS_LINE_SHOWTIME_SEV_ERR_SECS:
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pLscData, nDevice, nHistoryInterval)->nSES;
      break;
   case DSL_STATS_LINE_LAST_SHOWTIME_ERR_SECS:
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pLscData, nDevice, nHistoryInterval)->nES;
      break;
   case DSL_STATS_LINE_LAST_SHOWTIME_SEV_ERR_SECS:
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY2_INDEX_PTR(pLscData, nDevice, nHistoryInterval)->nSES;
      break;
   default:
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nHistoryInterval);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_ShowtimeErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_int_t nShowtimeErrSecs = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineSecCountersShowtimeGet__vrx518(
         pContext, eNodeIdx, nDevice, &nShowtimeErrSecs) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineSecCountersShowtimeGet__vrx618(
         pContext, eNodeIdx, nDevice, &nShowtimeErrSecs) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nShowtimeErrSecs;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_ShowtimeSevErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_int_t nShowtimeSevErrSecs = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineSecCountersShowtimeGet__vrx518(
         pContext, eNodeIdx, nDevice, &nShowtimeSevErrSecs) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineSecCountersShowtimeGet__vrx618(
         pContext, eNodeIdx, nDevice, &nShowtimeSevErrSecs) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nShowtimeSevErrSecs;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_LastShowtimeErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_int_t nLastShowtimeErrSecs = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineSecCountersShowtimeGet__vrx518(
         pContext, eNodeIdx, nDevice, &nLastShowtimeErrSecs) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineSecCountersShowtimeGet__vrx618(
         pContext, eNodeIdx, nDevice, &nLastShowtimeErrSecs) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nLastShowtimeErrSecs;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_LastShowtimeSevErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_int_t nLastShowtimeSevErrSecs = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineSecCountersShowtimeGet__vrx518(
         pContext, eNodeIdx, nDevice, &nLastShowtimeSevErrSecs) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineSecCountersShowtimeGet__vrx618(
         pContext, eNodeIdx, nDevice, &nLastShowtimeSevErrSecs) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nLastShowtimeSevErrSecs;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_PM_LINE_SEC_COUNTERS_1DAY_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_LineSecCounters1DayGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_int_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_PM_LineSecCounters_t *pLscData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_1DAY_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pLscData, DSL_PM_LineSecCounters_t,
      DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_1DAY_GET, DSL_ST_DSL_ENTITIES);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pLscData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_1DAY_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         /* omit PM polling for disabled lines */
         if (INCLUDE_DSL_BONDING)
         {
            DSL_CPE_BND_Context_t *pBndCtx = (DSL_CPE_BND_Context_t*)pContext->pBnd;
            if (pBndCtx != DSL_NULL &&
               pBndCtx->lineBondingConfig[nDev].nPafLineDisabled == 1)
            {
               pErrorCodeArray[nDev] = DSL_ERROR;
               continue;
            }
         }

         pLscData[nDev].nDirection = DSL_NEAR_END;
         pLscData[nDev].nHistoryInterval = 0;

         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_PM_LINE_SEC_COUNTERS_1DAY_GET,
            (int)&pLscData[nDev]);

         if (nRet < DSL_SUCCESS ||
            pLscData[nDev].accessCtl.nReturn != DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_PM_LINE_SEC_COUNTERS_1DAY_GET ioctl failed "
               "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, pLscData[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_1DAY_GET);
   }

   /* provide data of corresponding IOCtl request */
   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_CURRENT_DAY_ERR_SECS:
      *pData = pLscData[nDevice].data.nES;
      break;
   case DSL_STATS_LINE_CURRENT_DAY_SEV_ERR_SECS:
      *pData = pLscData[nDevice].data.nSES;
      break;
   default:
      return DSL_ERROR;
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_PM_LineSecCounters1DayGet API function
*/
static DSL_Error_t DSL_ST_LineSecCounters1DayGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_int_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_PM_LineSecCountersData_t *pLscData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_1DAY_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pLscData, DSL_PM_LineSecCountersData_t,
      DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_1DAY_GET, DSL_ST_DSL_ENTITIES);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pLscData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_1DAY_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_PM_LineSecCounters1DayGet(pContext,
            nDev, DSL_NEAR_END, /*nHistoryInterval*/0, &pLscData[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_PM_LINE_SEC_COUNTERS_1DAY_GET ioctl failed "
               "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, pLscData[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_1DAY_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_CURRENT_DAY_ERR_SECS:
      *pData = pLscData[nDevice].nES;
      break;
   case DSL_STATS_LINE_CURRENT_DAY_SEV_ERR_SECS:
      *pData = pLscData[nDevice].nSES;
      break;
   default:
      return DSL_ERROR;
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_CurrDayErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_int_t nCurrDayErrSecs = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineSecCounters1DayGet__vrx518(
         pContext, eNodeIdx, nDevice, &nCurrDayErrSecs) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineSecCounters1DayGet__vrx618(
         pContext, eNodeIdx, nDevice, &nCurrDayErrSecs) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nCurrDayErrSecs;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_CurrDaySevErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_int_t nCurrDaySevErrSecs = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineSecCounters1DayGet__vrx518(
      pContext, eNodeIdx, nDevice, &nCurrDaySevErrSecs) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineSecCounters1DayGet__vrx618(
      pContext, eNodeIdx, nDevice, &nCurrDaySevErrSecs) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nCurrDaySevErrSecs;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_PM_LINE_SEC_COUNTERS_15MIN_GET
   ioctl for all devices
*/
static DSL_Error_t DSL_ST_LineSecCounters15MinGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_int_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_PM_LineSecCounters_t *pLscData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_15MIN_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pLscData, DSL_PM_LineSecCounters_t,
      DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_15MIN_GET, DSL_ST_DSL_ENTITIES);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pLscData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_15MIN_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         /* omit PM polling for disabled lines */
         if (INCLUDE_DSL_BONDING)
         {
            DSL_CPE_BND_Context_t *pBndCtx =
               (DSL_CPE_BND_Context_t*)pContext->pBnd;
            if (pBndCtx != DSL_NULL &&
               pBndCtx->lineBondingConfig[nDev].nPafLineDisabled == 1)
            {
               pErrorCodeArray[nDev] = DSL_ERROR;
               continue;
            }
         }

         pLscData[nDev].nDirection = DSL_NEAR_END;
         pLscData[nDev].nHistoryInterval = 0;

         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_PM_LINE_SEC_COUNTERS_15MIN_GET,
            (int)&pLscData[nDev]);

         if (nRet < DSL_SUCCESS ||
            pLscData[nDev].accessCtl.nReturn != DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_PM_LINE_SEC_COUNTERS_15MIN_GET ioctl failed "
               "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, pLscData[nDev].accessCtl.nReturn));

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_15MIN_GET);
   }

   /* provide data of corresponding IOCtl request */
   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_QUARTER_HOUR_ERR_SECS:
      *pData = pLscData[nDevice].data.nES;
      break;
   case DSL_STATS_LINE_QUARTER_HOUR_SEV_ERR_SECS:
      *pData = pLscData[nDevice].data.nSES;
      break;
   default:
      return DSL_ERROR;
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_PM_LineSecCounters15MinGet API function
*/
static DSL_Error_t DSL_ST_LineSecCounters15MinGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_int_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_PM_LineSecCountersData_t *pLscData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_15MIN_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pLscData, DSL_PM_LineSecCountersData_t,
      DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_15MIN_GET, DSL_ST_DSL_ENTITIES);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pLscData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_15MIN_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_PM_LineSecCounters15MinGet(pContext,
            nDev, DSL_NEAR_END, /*nHistoryInterval*/0, &pLscData[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_PM_LINE_SEC_COUNTERS_15MIN_GET ioctl failed "
               "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, pLscData[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_LINE_SEC_COUNTERS_15MIN_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_QUARTER_HOUR_ERR_SECS:
      *pData = pLscData[nDevice].nES;
      break;
   case DSL_STATS_LINE_QUARTER_HOUR_SEV_ERR_SECS:
      *pData = pLscData[nDevice].nSES;
      break;
   default:
      return DSL_ERROR;
   }

   return pErrorCodeArray[nDevice];
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_QuarterHourErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_int_t nQuarterErrSecs = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineSecCounters15MinGet__vrx518(
      pContext, eNodeIdx, nDevice, &nQuarterErrSecs) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineSecCounters15MinGet__vrx618(
      pContext, eNodeIdx, nDevice, &nQuarterErrSecs) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nQuarterErrSecs;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_QuarterHourSevErrSecsUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_int_t nQuarterSevErrSecs = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_LineSecCounters15MinGet__vrx518(
      pContext, eNodeIdx, nDevice, &nQuarterSevErrSecs) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_LineSecCounters15MinGet__vrx618(
      pContext, eNodeIdx, nDevice, &nQuarterSevErrSecs) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nQuarterSevErrSecs;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

/* --- Channel statistics section --- */

static DSL_void_t DSL_ST_ChannelCountersTotalUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ulong_t nData = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_PMCountersTotalGet__vrx518(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_PMCountersTotalGet__vrx618(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nData;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_PM_DATA_PATH_COUNTERS_TOTAL_GET
   IOCtl from all available devices and XTU directions.
*/
static DSL_Error_t DSL_ST_PMChannelDataPathCountersTotalGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_XTUDir_t nDirection;
   DSL_PM_DataPathCountersTotal_t *pDpcData = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_TOTAL_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pDpcData, DSL_PM_DataPathCountersTotal_t,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_TOTAL_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pDpcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_TOTAL_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            /* omit PM polling for disabled lines */
            if (INCLUDE_DSL_BONDING)
            {
               DSL_CPE_BND_Context_t *pBndCtx =
                  (DSL_CPE_BND_Context_t*)pContext->pBnd;
               if (pBndCtx != DSL_NULL &&
                  pBndCtx->lineBondingConfig[nDev].nPafLineDisabled == 1)
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, DSL_NEAR_END) = DSL_ERROR;
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, DSL_FAR_END) = DSL_ERROR;
                  continue;
               }
            }

            for (DSL_XTUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               DSL_ST_ARRAY3_INDEX_PTR(
                  pDpcData, nDev, nCh, nDir)->nDirection = nDir;
               DSL_ST_ARRAY3_INDEX_PTR(
                  pDpcData, nDev, nCh, nDir)->nChannel = nCh;

               nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
                  DSL_FIO_PM_DATA_PATH_COUNTERS_TOTAL_GET,
                  (int)DSL_ST_ARRAY3_INDEX_PTR(pDpcData, nDev, nCh, nDir));

               if (nRet < DSL_SUCCESS ||
                  DSL_ST_ARRAY3_INDEX_PTR(
                     pDpcData, nDev, nCh, nDir)->accessCtl.nReturn
                  != DSL_SUCCESS)
               {
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_PM_DATA_PATH_COUNTERS_TOTAL_GET ioctl failed "
                     "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
                     nDev, nRet, DSL_ST_ARRAY3_INDEX_PTR(
                        pDpcData, nDev, nCh, nDir)->accessCtl.nReturn));

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_TOTAL_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_CHANNEL_TOTAL_XTUR_HEC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pDpcData, nDevice, nChannel, nDirection)->data.nHEC;
      break;
   case DSL_STATS_LINE_CHANNEL_TOTAL_XTUC_HEC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pDpcData, nDevice, nChannel, nDirection)->data.nHEC;
      break;
   default:
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, "
         "DSL_ST_PMChannelDataPathCountersTotalGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_PM_DataPathCountersTotalGet API function
*/
static DSL_Error_t DSL_ST_PMChannelDataPathCountersTotalGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_ATUDir_t nDirection;
   DSL_PM_DataPathCountersData_t *pDpcData = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_TOTAL_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pDpcData, DSL_PM_DataPathCountersData_t,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_TOTAL_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pDpcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_TOTAL_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            for (DSL_ATUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               nRet = DSL_PM_DataPathCountersTotalGet(pContext,
                  nDev, nCh, nDir,
                  DSL_ST_ARRAY3_INDEX_PTR(pDpcData, nDev, nCh, nDir));

               if (nRet < DSL_SUCCESS)
               {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_PM_DATA_PATH_COUNTERS_TOTAL_GET ioctl failed "
                     "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
                     nDev, nRet, DSL_ST_ARRAY3_INDEX_PTR(
                        pDpcData, nDev, nCh, nDir)->accessCtl.nReturn));
#endif /* if 0 */

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_TOTAL_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_CHANNEL_TOTAL_XTUR_HEC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData = DSL_ST_ARRAY3_INDEX_PTR(
         pDpcData, nDevice, nChannel, nDirection)->nHEC;
      break;
   case DSL_STATS_LINE_CHANNEL_TOTAL_XTUC_HEC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData = DSL_ST_ARRAY3_INDEX_PTR(
         pDpcData, nDevice, nChannel, nDirection)->nHEC;
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, "
         "DSL_ST_PMChannelDataPathCountersTotalGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
#endif /* if 0 */
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_ChannelDataPathCountersTotalUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nData = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_PMChannelDataPathCountersTotalGet__vrx518(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_PMChannelDataPathCountersTotalGet__vrx618(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nData;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_ChannelCountersShowtimeUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ulong_t nData = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_PMCountersShowtimeGet__vrx518(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_PMCountersShowtimeGet__vrx618(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nData;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_PM_DATA_PATH_COUNTERS_SHOWTIME_GET
   IOCtl from all available devices, history intervals and XTU directions.
*/
static DSL_Error_t DSL_ST_PMChannelDataPathCountersShowtimeGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_XTUDir_t nDirection;
   DSL_uint32_t nHistoryInterval;
   DSL_PM_DataPathCounters_t *pDpData = DSL_NULL;
   /* Array Y, Z and W sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0, nArrayW = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY4_GET(pErrorCodeArray,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1,
      DSL_ST_PM_HISTORY_INTERVALS_NUM);
   DSL_ST_DYNAMIC_DATA_ARRAY4_GET(pDpData, DSL_PM_DataPathCounters_t,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1,
      DSL_ST_PM_HISTORY_INTERVALS_NUM);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pDpData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_SHOWTIME_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            /* omit PM polling for disabled lines */
            if (INCLUDE_DSL_BONDING)
            {
               DSL_CPE_BND_Context_t *pBndCtx =
                  (DSL_CPE_BND_Context_t *)pContext->pBnd;
               if (pBndCtx != DSL_NULL &&
                  pBndCtx->lineBondingConfig[nDev].nPafLineDisabled == 1)
               {
                  DSL_ST_ARRAY4_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh,
                     DSL_NEAR_END, /*HistoryInterval*/0) = DSL_ERROR;
                  DSL_ST_ARRAY4_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh,
                     DSL_NEAR_END, /*HistoryInterval*/1) = DSL_ERROR;
                  DSL_ST_ARRAY4_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh,
                     DSL_FAR_END,/*HistoryInterval*/0) = DSL_ERROR;
                  DSL_ST_ARRAY4_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh,
                     DSL_FAR_END,/*HistoryInterval*/1) = DSL_ERROR;
                  continue;
               }
            }

            for (DSL_XTUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               for (DSL_uint32_t nHistInt = 0;
                  nHistInt < DSL_ST_PM_HISTORY_INTERVALS_NUM; ++nHistInt)
               {
                  DSL_ST_ARRAY4_INDEX_PTR(
                     pDpData, nDev, nCh, nDir, nHistInt)->nChannel = nCh;
                  DSL_ST_ARRAY4_INDEX_PTR(
                     pDpData, nDev, nCh, nDir, nHistInt)->nDirection = nDir;
                  DSL_ST_ARRAY4_INDEX_PTR(
                     pDpData, nDev, nCh, nDir,
                     nHistInt)->nHistoryInterval = nHistInt;

                  nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
                     DSL_FIO_PM_DATA_PATH_COUNTERS_SHOWTIME_GET,
                     (int)DSL_ST_ARRAY4_INDEX_PTR(
                        pDpData, nDev, nCh, nDir, nHistInt));

                  if (nRet < DSL_SUCCESS ||
                     DSL_ST_ARRAY4_INDEX_PTR(
                        pDpData, nDev, nCh,
                        nDir, nHistInt)->accessCtl.nReturn != DSL_SUCCESS)
                  {
                     DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                        "ERROR - DSL_FIO_PM_DATA_PATH_COUNTERS_SHOWTIME_GET "
                        "ioctl failed (device<%d>, direction<%s>, "
                        "historyInterval<%d>, nRet=%d, "
                        "accessCtrl=%d)!" DSL_CPE_CRLF,
                        nDev, (nDir == DSL_NEAR_END) ? "near end" : "far end",
                        nHistInt, nRet,
                        DSL_ST_ARRAY4_INDEX_PTR(
                           pDpData, nDev, nCh, nDir,
                           nHistInt)->accessCtl.nReturn));

                     DSL_ST_ARRAY4_INDEX_VAL(
                        pErrorCodeArray, nDev, nCh,
                        nDir, nHistInt) = DSL_ERROR;
                  }
                  else
                  {
                     DSL_ST_ARRAY4_INDEX_VAL(
                        pErrorCodeArray, nDev, nCh,
                        nDir, nHistInt) = DSL_SUCCESS;
                  }
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_SHOWTIME_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUR_HEC_ERRORS:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pDpData, nDevice, nChannel, nDirection, nHistoryInterval)->data.nHEC;
      break;
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUC_HEC_ERRORS:
      nDirection = DSL_FAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pDpData, nDevice, nChannel, nDirection, nHistoryInterval)->data.nHEC;
      break;
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUR_HEC_ERRORS:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pDpData, nDevice, nChannel, nDirection, nHistoryInterval)->data.nHEC;
      break;
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUC_HEC_ERRORS:
      nDirection = DSL_FAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pDpData, nDevice, nChannel, nDirection, nHistoryInterval)->data.nHEC;
      break;
   default:
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, "
         "DSL_ST_PMChannelDataPathCountersShowtimeGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY4_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection, nHistoryInterval);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_PM_DataPathCountersShowtimeGet API function
*/
static DSL_Error_t DSL_ST_PMChannelDataPathCountersShowtimeGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_ATUDir_t nDirection;
   DSL_uint32_t nHistoryInterval;
   DSL_PM_DataPathCountersData_t *pDpData = DSL_NULL;
   /* Array Y, Z and W sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0, nArrayW = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY4_GET(pErrorCodeArray,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1,
      DSL_ST_PM_HISTORY_INTERVALS_NUM);
   DSL_ST_DYNAMIC_DATA_ARRAY4_GET(pDpData, DSL_PM_DataPathCountersData_t,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1,
      DSL_ST_PM_HISTORY_INTERVALS_NUM);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pDpData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_SHOWTIME_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            for (DSL_ATUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               for (DSL_uint32_t nHistInt = 0;
                  nHistInt < DSL_ST_PM_HISTORY_INTERVALS_NUM; ++nHistInt)
               {
                  nRet = DSL_PM_DataPathCountersShowtimeGet(pContext,
                     nDev, nCh, nDir, nHistInt,
                     DSL_ST_ARRAY4_INDEX_PTR(
                        pDpData, nDev, nCh, nDir, nHistInt));

                  if (nRet < DSL_SUCCESS)
                  {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
                     DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                        "ERROR - DSL_FIO_PM_DATA_PATH_COUNTERS_SHOWTIME_GET "
                        "ioctl failed (device<%d>, direction<%s>, "
                        "historyInterval<%d>, nRet=%d, "
                        "accessCtrl=%d)!" DSL_CPE_CRLF,
                        nDev, (nDir == DSL_NEAR_END) ? "near end" : "far end",
                        nHistInt, nRet,
                        DSL_ST_ARRAY4_INDEX_PTR(
                           pDpData, nDev, nCh, nDir,
                           nHistInt)->accessCtl.nReturn));
#endif /* if 0 */

                     DSL_ST_ARRAY4_INDEX_VAL(
                        pErrorCodeArray, nDev, nCh,
                        nDir, nHistInt) = DSL_ERROR;
                  }
                  else
                  {
                     DSL_ST_ARRAY4_INDEX_VAL(
                        pErrorCodeArray, nDev, nCh,
                        nDir, nHistInt) = DSL_SUCCESS;
                  }
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_SHOWTIME_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUR_HEC_ERRORS:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pDpData, nDevice, nChannel, nDirection, nHistoryInterval)->nHEC;
      break;
   case DSL_STATS_LINE_CHANNEL_SHOWTIME_XTUC_HEC_ERRORS:
      nDirection = DSL_FAR_END;
      nHistoryInterval = 0;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pDpData, nDevice, nChannel, nDirection, nHistoryInterval)->nHEC;
      break;
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUR_HEC_ERRORS:
      nDirection = DSL_NEAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pDpData, nDevice, nChannel, nDirection, nHistoryInterval)->nHEC;
      break;
   case DSL_STATS_LINE_CHANNEL_LAST_SHOWTIME_XTUC_HEC_ERRORS:
      nDirection = DSL_FAR_END;
      nHistoryInterval = 1;
      *pData =
         DSL_ST_ARRAY4_INDEX_PTR(
            pDpData, nDevice, nChannel, nDirection, nHistoryInterval)->nHEC;
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, "
         "DSL_ST_PMChannelDataPathCountersShowtimeGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
#endif /* if 0 */
      return DSL_ERROR;
   }
   return DSL_ST_ARRAY4_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection, nHistoryInterval);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_ChannelDataPathCountersShowtimeUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nData = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_PMChannelDataPathCountersShowtimeGet__vrx518(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_PMChannelDataPathCountersShowtimeGet__vrx618(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nData;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_PM_CHANNEL_COUNTERS_1DAY_GET
   IOCtl from all available devices and XTU directions.
*/
static DSL_Error_t DSL_ST_PMChannelCounters1DayGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_ulong_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_XTUDir_t nDirection;
   DSL_PM_ChannelCounters_t *pCcData = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_1DAY_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pCcData, DSL_PM_ChannelCounters_t,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_1DAY_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pCcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_1DAY_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            /* omit PM polling for disabled lines */
            if (INCLUDE_DSL_BONDING)
            {
               DSL_CPE_BND_Context_t *pBndCtx =
                  (DSL_CPE_BND_Context_t *)pContext->pBnd;
               if (pBndCtx != DSL_NULL &&
                  pBndCtx->lineBondingConfig[nDev].nPafLineDisabled == 1)
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, DSL_NEAR_END) = DSL_ERROR;
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, DSL_FAR_END) = DSL_ERROR;
                  continue;
               }
            }

            for (DSL_XTUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               DSL_ST_ARRAY3_INDEX_PTR(
                  pCcData, nDev, nCh, nDir)->nChannel = nCh;
               DSL_ST_ARRAY3_INDEX_PTR(
                  pCcData, nDev, nCh, nDir)->nHistoryInterval = 0;
               DSL_ST_ARRAY3_INDEX_PTR(
                  pCcData, nDev, nCh, nDir)->nDirection = nDir;

               nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
                  DSL_FIO_PM_CHANNEL_COUNTERS_1DAY_GET,
                  (int)DSL_ST_ARRAY2_INDEX_PTR(pCcData, nDev, nDir));

               if (nRet < DSL_SUCCESS ||
                  DSL_ST_ARRAY3_INDEX_PTR(
                     pCcData, nDev, nCh, nDir)->accessCtl.nReturn != DSL_SUCCESS)
               {
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_PM_CHANNEL_COUNTERS_1DAY_GET ioctl failed "
                     "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
                     nDev, nRet, DSL_ST_ARRAY3_INDEX_PTR(
                        pCcData, nDev, nCh, nDir)->accessCtl.nReturn));

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_1DAY_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_START:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->interval.nElapsedTime;
      break;
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUR_FEC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->data.nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUC_FEC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->data.nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUR_CRC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->data.nCodeViolations;
      break;
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUC_CRC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->data.nCodeViolations;
      break;
   default:
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_ST_PMChannelCounters1DayGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_PM_ChannelCounters1DayGet API function
*/
static DSL_Error_t DSL_ST_PMChannelCounters1DayGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_ulong_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_ATUDir_t nDirection;
   DSL_PM_ChannelCountersData_t *pCcData = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_1DAY_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pCcData, DSL_PM_ChannelCountersData_t,
      DSL_ST_FLAG_PM_CHANNEL_COUNTERS_1DAY_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pCcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_1DAY_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            for (DSL_ATUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               nRet = DSL_PM_ChannelCounters1DayGet(pContext,
                  nDev, nCh, nDir, /*nHistoryInterval*/0,
                  DSL_ST_ARRAY3_INDEX_PTR(pCcData, nDev, nCh, nDir));

               if (nRet < DSL_SUCCESS)
               {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_PM_CHANNEL_COUNTERS_1DAY_GET ioctl failed "
                     "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
                     nDev, nRet, sData[nDev][nDir].accessCtl.nReturn));
#endif /* if 0 */

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_CHANNEL_COUNTERS_1DAY_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_START:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->nElapsedTime;
      break;
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUR_FEC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUC_FEC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->nFEC;
      break;
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUR_CRC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->nCodeViolations;
      break;
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUC_CRC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pCcData, nDevice, nChannel, nDirection)->nCodeViolations;
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_ST_PMChannelCounters1DayGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
#endif /* if 0 */
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_ChannelCounters1DayUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ulong_t nData = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_PMChannelCounters1DayGet__vrx518(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_PMChannelCounters1DayGet__vrx618(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nData;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_PM_DATA_PATH_COUNTERS_1DAY_GET
   IOCtl from all available devices and XTU directions.
*/
static DSL_Error_t DSL_ST_PMChannelDataPathCounters1DayGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_XTUDir_t nDirection;
   DSL_PM_DataPathCounters_t *pDpcData = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_1DAY_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pDpcData, DSL_PM_DataPathCounters_t,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_1DAY_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pDpcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_1DAY_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            /* omit PM polling for disabled lines */
            if (INCLUDE_DSL_BONDING)
            {
               DSL_CPE_BND_Context_t *pBndCtx =
                  (DSL_CPE_BND_Context_t *)pContext->pBnd;
               if (pBndCtx != DSL_NULL &&
                  pBndCtx->lineBondingConfig[nDev].nPafLineDisabled == 1)
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, DSL_NEAR_END) = DSL_ERROR;
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, DSL_FAR_END) = DSL_ERROR;
                  continue;
               }
            }

            for (DSL_XTUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               DSL_ST_ARRAY3_INDEX_PTR(
                  pDpcData, nDev, nCh, nDir)->nChannel = nCh;
               DSL_ST_ARRAY3_INDEX_PTR(
                  pDpcData, nDev, nCh, nDir)->nHistoryInterval = 0;
               DSL_ST_ARRAY3_INDEX_PTR(
                  pDpcData, nDev, nCh, nDir)->nDirection = nDir;

               nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
                  DSL_FIO_PM_DATA_PATH_COUNTERS_1DAY_GET,
                  (int)DSL_ST_ARRAY3_INDEX_PTR(pDpcData, nDev, nCh, nDir));

               if (nRet < DSL_SUCCESS ||
                  DSL_ST_ARRAY3_INDEX_PTR(
                     pDpcData, nDev, nCh, nDir)->accessCtl.nReturn != DSL_SUCCESS)
               {
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_PM_DATA_PATH_COUNTERS_1DAY_GET ioctl failed "
                     "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
                     nDev, nRet, DSL_ST_ARRAY3_INDEX_PTR(
                        pDpcData, nDev, nCh, nDir)->accessCtl.nReturn));

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_1DAY_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUR_HEC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pDpcData, nDevice, nChannel, nDirection)->data.nHEC;
      break;
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUC_HEC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pDpcData, nDevice, nChannel, nDirection)->data.nHEC;
      break;
   default:
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_ST_PMChannelCounters1DayGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_PM_DataPathCounters1DayGet API function
*/
static DSL_Error_t DSL_ST_PMChannelDataPathCounters1DayGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_ATUDir_t nDirection;
   DSL_PM_DataPathCountersData_t *pDpcData = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_1DAY_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pDpcData, DSL_PM_DataPathCountersData_t,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_1DAY_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pDpcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_1DAY_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            for (DSL_ATUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               nRet = DSL_PM_DataPathCounters1DayGet(pContext,
                  nDev, nCh, nDir, /*nHistoryInterval*/0,
                  DSL_ST_ARRAY3_INDEX_PTR(pDpcData, nDev, nCh, nDir));

               if (nRet < DSL_SUCCESS)
               {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_PM_DATA_PATH_COUNTERS_1DAY_GET ioctl failed "
                     "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
                     nDev, nRet, DSL_ST_ARRAY3_INDEX_PTR(
                        pDpcData, nDev, nCh, nDir)->accessCtl.nReturn));
#endif /* if 0 */

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_1DAY_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUR_HEC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData = DSL_ST_ARRAY3_INDEX_PTR(
         pDpcData, nDevice, nChannel, nDirection)->nHEC;
      break;
   case DSL_STATS_LINE_CHANNEL_CURRENT_DAY_XTUC_HEC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData = DSL_ST_ARRAY3_INDEX_PTR(
         pDpcData, nDevice, nChannel, nDirection)->nHEC;
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, DSL_ST_PMChannelCounters1DayGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
#endif /* if 0 */
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_ChannelDataPathCounters1DayUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nData = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_PMChannelDataPathCounters1DayGet__vrx518(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_PMChannelDataPathCounters1DayGet__vrx618(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nData;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_ChannelCounters15MinUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_ulong_t nData = { 0 };

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_PMCounters15MinGet__vrx518(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_PMCounters15MinGet__vrx618(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nData;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_PM_DATA_PATH_COUNTERS_15MIN_GET
   IOCtl from all available devices and XTU directions.
*/
static DSL_Error_t DSL_ST_PMChannelDataPathCounters15MinGet__vrx518(
   DSL_CPE_Control_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_XTUDir_t nDirection;
   DSL_PM_DataPathCounters_t *pDpcData = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_15MIN_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pDpcData, DSL_PM_DataPathCounters_t,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_15MIN_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pDpcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_15MIN_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            /* omit PM polling for disabled lines */
            if (INCLUDE_DSL_BONDING)
            {
               DSL_CPE_BND_Context_t *pBndCtx =
                  (DSL_CPE_BND_Context_t *)pContext->pBnd;
               if (pBndCtx != DSL_NULL &&
                  pBndCtx->lineBondingConfig[nDev].nPafLineDisabled == 1)
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, DSL_NEAR_END) = DSL_ERROR;
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, DSL_FAR_END) = DSL_ERROR;
                  continue;
               }
            }

            for (DSL_XTUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               DSL_ST_ARRAY3_INDEX_PTR(
                  pDpcData, nDev, nCh, nDir)->nChannel = nCh;
               DSL_ST_ARRAY3_INDEX_PTR(
                  pDpcData, nDev, nCh, nDir)->nHistoryInterval = 0;
               DSL_ST_ARRAY3_INDEX_PTR(
                  pDpcData, nDev, nCh, nDir)->nDirection = nDir;

               nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
                  DSL_FIO_PM_DATA_PATH_COUNTERS_15MIN_GET,
                  (int)DSL_ST_ARRAY3_INDEX_PTR(pDpcData, nDev, nCh, nDir));

               if (nRet < DSL_SUCCESS ||
                  DSL_ST_ARRAY3_INDEX_PTR(
                     pDpcData, nDev, nCh, nDir)->accessCtl.nReturn
                  != DSL_SUCCESS)
               {
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_PM_DATA_PATH_COUNTERS_15MIN_GET "
                     "ioctl failed (device<%d>, nRet=%d, accessCtrl=%d)!"
                     DSL_CPE_CRLF, nDev, nRet,
                     DSL_ST_ARRAY3_INDEX_PTR(
                        pDpcData, nDev, nCh, nDir)->accessCtl.nReturn));

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_15MIN_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUR_HEC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pDpcData, nDevice, nChannel, nDirection)->data.nHEC;
      break;
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUC_HEC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData =
         DSL_ST_ARRAY3_INDEX_PTR(
            pDpcData, nDevice, nChannel, nDirection)->data.nHEC;
      break;
   default:
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, "
         "DSL_ST_PMChannelDataPathCounters15MinGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#if defined(DSL_ST_PLATFORM_VRX618)
/*
   [VRX618]
   This function collects all data provided by
   DSL_PM_DataPathCounters15MinGet API function
*/
static DSL_Error_t DSL_ST_PMChannelDataPathCounters15MinGet__vrx618(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   const DSL_uint8_t nChannel,
   DSL_uint32_t *pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_ATUDir_t nDirection;
   DSL_PM_DataPathCountersData_t *pDpcData = DSL_NULL;
   /* Array Y(width) and Z(depth) sizes, needed for memory
      access by index (set and used in the macros) */
   DSL_uint8_t nArrayY = 0, nArrayZ = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY3_GET(
      pErrorCodeArray,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_15MIN_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);
   DSL_ST_DYNAMIC_DATA_ARRAY3_GET(
      pDpcData, DSL_PM_DataPathCountersData_t,
      DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_15MIN_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_CHANNELS_PER_LINE, DSL_FAR_END + 1);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pDpcData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_15MIN_GET))
   {
      for (DSL_uint32_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint8_t nCh = 0; nCh < DSL_ST_CHANNELS_PER_LINE; ++nCh)
         {
            for (DSL_ATUDir_t nDir = DSL_NEAR_END; nDir <= DSL_FAR_END; ++nDir)
            {
               nRet = DSL_PM_DataPathCounters15MinGet(pContext,
                  nDev, nCh, nDir, /*nHistoryInterval*/0,
                  DSL_ST_ARRAY3_INDEX_PTR(pDpcData, nDev, nCh, nDir));

               if (nRet < DSL_SUCCESS)
               {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
                  DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                     "ERROR - DSL_FIO_PM_DATA_PATH_COUNTERS_15MIN_GET "
                     "ioctl failed (device<%d>, nRet=%d, accessCtrl=%d)!"
                     DSL_CPE_CRLF, nDev, nRet,
                     DSL_ST_ARRAY3_INDEX_PTR(
                        pDpcData, nDev, nCh, nDir)->accessCtl.nReturn));
#endif /* if 0 */

                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_ERROR;
               }
               else
               {
                  DSL_ST_ARRAY3_INDEX_VAL(
                     pErrorCodeArray, nDev, nCh, nDir) = DSL_SUCCESS;
               }
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_PM_DATA_PATH_COUNTERS_15MIN_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUR_HEC_ERRORS:
      nDirection = DSL_NEAR_END;
      *pData = DSL_ST_ARRAY3_INDEX_PTR(
         pDpcData, nDevice, nChannel, nDirection)->nHEC;
      break;
   case DSL_STATS_LINE_CHANNEL_QUARTER_HOUR_XTUC_HEC_ERRORS:
      nDirection = DSL_FAR_END;
      *pData = DSL_ST_ARRAY3_INDEX_PTR(
         pDpcData, nDevice, nChannel, nDirection)->nHEC;
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - StatusParser, "
         "DSL_ST_PMChannelDataPathCounters15MinGet__vrx518: "
         "unknown node!"
         DSL_CPE_CRLF));
#endif /* if 0 */
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY3_INDEX_VAL(
      pErrorCodeArray, nDevice, nChannel, nDirection);
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) */

static DSL_void_t DSL_ST_ChannelDataPathCounters15MinUpdate(
   DSL_ST_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint32_t nData = 0;

#if defined(DSL_ST_PLATFORM_VRX518)
   if (DSL_ST_PMChannelDataPathCounters15MinGet__vrx518(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#elif defined(DSL_ST_PLATFORM_VRX618)
   if (DSL_ST_PMChannelDataPathCounters15MinGet__vrx618(
         pContext, eNodeIdx, nDevice, nChannel, &nData) == DSL_SUCCESS)
#endif /* VRX518/VRX618 */
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nData;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

#if defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION)
/*
   [VRX518]
   This function collects all data provided by
   DSL_FIO_FILTER_DETECTION_BASIC_DATA_GET
   IOCtl from all available devices.
*/
static DSL_Error_t DSL_ST_FilterDetectionBasicDataGet__vrx518(
   const DSL_ST_Context_t* pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_int16_t* pData)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint32_t nDev = 0;
   DSL_FilterDetectionBasic_t *pFdData = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(
      pErrorCodeArray, DSL_ST_FLAG_FILTER_DETECTION_BASIC_DATA_GET,
      DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pFdData, DSL_FilterDetectionBasic_t,
      DSL_ST_FLAG_FILTER_DETECTION_BASIC_DATA_GET, DSL_ST_DSL_ENTITIES);

   if (pData == DSL_NULL || nDevice >= DSL_ST_DSL_ENTITIES ||
      pErrorCodeArray == DSL_NULL || pFdData == DSL_NULL)
   {
      return DSL_ERROR;
   }

   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_FILTER_DETECTION_BASIC_DATA_GET))
   {
      for (nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_CPE_Ioctl(pContext->fd[nDev],
            DSL_FIO_FILTER_DETECTION_BASIC_DATA_GET,
            (int)&pFdData[nDev]);

         pErrorCodeArray[nDev] = DSL_SUCCESS;

         if (nRet < DSL_SUCCESS ||
            pFdData[nDev].accessCtl.nReturn != DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_FILTER_DETECTION_BASIC_DATA_GET ioctl failed "
               "(device<%d>, nRet=%d, accessCtrl=%d)!" DSL_CPE_CRLF,
               nDev, nRet, pFdData[nDev].accessCtl.nReturn));

            if (pFdData[nDev].accessCtl.nReturn ==
                  DSL_ERR_ONLY_AVAILABLE_IN_SHOWTIME ||
               pFdData[nDev].accessCtl.nReturn ==
                  DSL_ERR_NOT_SUPPORTED_IN_CURRENT_VDSL_MODE ||
               pFdData[nDev].accessCtl.nReturn ==
                  DSL_ERR_NOT_SUPPORTED_BY_FIRMWARE)
            {
               pFdData[nDev].data.nInitResult = DSL_MFD_INIT_RESULT_UNDONE;
               pFdData[nDev].data.nMetric3 = DSL_MFD_METRIC3_UNDONE;
            }
            else
            {
               pErrorCodeArray[nDev] = DSL_ERROR;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_FILTER_DETECTION_BASIC_DATA_GET);
   }

   /* provide data of corresponding IOCtl request */
   switch (eNodeIdx)
   {
   case DSL_STATUS_LINE_MFD_BASIC_DATA_FILTER_DETECTION:
      *pData = pFdData[nDevice].data.nInitResult;
      break;
   case DSL_STATUS_LINE_MFD_BASIC_DATA_METRIC3:
      *pData = pFdData[nDevice].data.nMetric3;
      break;
   default:
      return DSL_ERROR;
   }

   return pErrorCodeArray[nDevice];
}

static DSL_void_t DSL_ST_MfdBasicDataStatusUpdate(
   DSL_ST_Context_t* pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_int16_t nData = 0;

   if (DSL_ST_FilterDetectionBasicDataGet__vrx518(
         pContext, eNodeIdx, nDevice, &nData) == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nData;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}
#endif /* defined(DSL_ST_PLATFORM_VRX518) && defined(INCLUDE_DSL_FILTER_DETECTION) */

#if defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1)
/* --- Fast line stats section (VRX618 only) --- */

/*
   This function collects all data provided by
   DSL_FastOlrStatisticsTotalGet API function
*/
static DSL_Error_t DSL_ST_FastOlrStatisticsTotalGet(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_uint16_t *pOlrStatistics)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_FastOlrStatisticsTotalData_t *pOlrStats = DSL_NULL;
   DSL_ST_DYNAMIC_ERROR_ARRAY1_GET(pErrorCodeArray,
      DSL_ST_FLAG_FAST_OLR_STATISTICS_TOTAL_GET, DSL_ST_DSL_ENTITIES);
   DSL_ST_DYNAMIC_DATA_ARRAY1_GET(
      pOlrStats, DSL_FastOlrStatisticsTotalData_t,
      DSL_ST_FLAG_FAST_OLR_STATISTICS_TOTAL_GET, DSL_ST_DSL_ENTITIES);

   if (pOlrStatistics == DSL_NULL ||
      pErrorCodeArray == DSL_NULL || pOlrStats == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_FAST_OLR_STATISTICS_TOTAL_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         nRet = DSL_FastOlrStatisticsTotalGet(
            pContext, nDev, DSL_NEAR_END, &pOlrStats[nDev]);

         if (nRet < DSL_SUCCESS)
         {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_BAND_PLAN_SUPPORT_GET ioctl "
               "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
               nDev, nRet, profilesSupport[nDev].accessCtl.nReturn));
#endif /* if 0 */

            pErrorCodeArray[nDev] = DSL_ERROR;
         }
         else
         {
            pErrorCodeArray[nDev] = DSL_SUCCESS;
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_FAST_OLR_STATISTICS_TOTAL_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_FAST_LINE_TOTAL_SUCCESS_BSW:
      *pOlrStatistics = pOlrStats[nDevice].BitswapExecuted;
      break;
   case DSL_STATS_FAST_LINE_TOTAL_SUCCESS_SRA:
      *pOlrStatistics = pOlrStats[nDevice].SraExecuted;
      break;
   case DSL_STATS_FAST_LINE_TOTAL_SUCCESS_FRA:
      *pOlrStatistics = pOlrStats[nDevice].FraNoiExecuted +
         pOlrStats[nDevice].FraDoiExecuted;
      break;
   case DSL_STATS_FAST_LINE_TOTAL_SUCCESS_RPA:
      *pOlrStatistics = pOlrStats[nDevice].RpaExecuted;
      break;
   case DSL_STATS_FAST_LINE_TOTAL_SUCCESS_TIGA:
      *pOlrStatistics = pOlrStats[nDevice].TigaExecuted;
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - Status Parser (DSL_ST_FastOlrStatisticsTotalGet): "
         "unknown node!"
         DSL_CPE_CRLF));
      nErrorCode = DSL_ERROR;
#endif /* if 0 */
      return DSL_ERROR;
   }

   return pErrorCodeArray[nDevice];
}

static DSL_void_t DSL_ST_FastTotalSuccessBswUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint16_t nSuccessBsw = 0;

   if (DSL_ST_FastOlrStatisticsTotalGet(
         pContext, eNodeIdx, nDevice, &nSuccessBsw) == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nSuccessBsw;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_FastTotalSuccessSraUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint16_t nSuccessSra = 0;

   if (DSL_ST_FastOlrStatisticsTotalGet(
      pContext, eNodeIdx, nDevice, &nSuccessSra) == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nSuccessSra;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_FastTotalSuccessFraUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint16_t nSuccessFra = 0;

   if (DSL_ST_FastOlrStatisticsTotalGet(
      pContext, eNodeIdx, nDevice, &nSuccessFra) == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nSuccessFra;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_FastTotalSuccessRpaUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint16_t nSuccessRpa = 0;

   if (DSL_ST_FastOlrStatisticsTotalGet(
         pContext, eNodeIdx, nDevice, &nSuccessRpa) == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nSuccessRpa;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_FastTotalSuccessTigaUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint16_t nSuccessTiga = 0;

   if (DSL_ST_FastOlrStatisticsTotalGet(
         pContext, eNodeIdx, nDevice, &nSuccessTiga) == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nSuccessTiga;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

/*
   This function collects all data provided by
   DSL_PM_FastOlrCountersShowtimeGet API function
*/
static DSL_Error_t DSL_ST_FastOlrCountersShowtimeGet(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_uint16_t nDevice,
   DSL_uint16_t *pOlrCounters)
{
   DSL_Error_t *pErrorCodeArray = DSL_NULL;
   DSL_Error_t nRet = DSL_SUCCESS;
   DSL_uint32_t nHistoryInterval;
   DSL_PM_FastOlrCountersData_t *pFastOlrCounters = DSL_NULL;
   DSL_uint8_t nArrayY = 0;
   DSL_ST_DYNAMIC_ERROR_ARRAY2_GET(
      pErrorCodeArray, DSL_ST_FLAG_FAST_OLR_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_PM_HISTORY_INTERVALS_NUM);
   DSL_ST_DYNAMIC_DATA_ARRAY2_GET(
      pFastOlrCounters, DSL_PM_FastOlrCountersData_t,
      DSL_ST_FLAG_FAST_OLR_COUNTERS_SHOWTIME_GET,
      DSL_ST_DSL_ENTITIES, DSL_ST_PM_HISTORY_INTERVALS_NUM);

   if (pOlrCounters == DSL_NULL ||
      pErrorCodeArray == DSL_NULL || pFastOlrCounters == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* avoid calling API function many times in one status update iteration */
   if (!DSL_ST_IsCallFlagSet(DSL_ST_FLAG_FAST_OLR_COUNTERS_SHOWTIME_GET))
   {
      for (DSL_uint8_t nDev = 0; nDev < DSL_ST_DSL_ENTITIES; ++nDev)
      {
         for (DSL_uint32_t nHistInt = 0;
            nHistInt < DSL_ST_PM_HISTORY_INTERVALS_NUM; ++nHistInt)
         {
            nRet = DSL_PM_FastOlrCountersShowtimeGet(
               pContext, nDev, DSL_NEAR_END, nHistInt,
               DSL_ST_ARRAY2_INDEX_PTR(pFastOlrCounters, nDev, nHistInt));

            if (nRet < DSL_SUCCESS)
            {
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_BAND_PLAN_SUPPORT_GET ioctl "
                  "failed (device<%d>, nRet=%d, accessCtrl=%d)!"DSL_CPE_CRLF,
                  nDev, nRet, profilesSupport[nDev].accessCtl.nReturn));
#endif /* if 0 */

               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nHistInt) = DSL_ERROR;
            }
            else
            {
               DSL_ST_ARRAY2_INDEX_VAL(
                  pErrorCodeArray, nDev, nHistInt) = DSL_SUCCESS;
            }
         }
      }

      DSL_ST_CallFlagSet(DSL_ST_FLAG_FAST_OLR_COUNTERS_SHOWTIME_GET);
   }

   switch (eNodeIdx)
   {
   case DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_BSW:
      nHistoryInterval = 0;
      *pOlrCounters =
         DSL_ST_ARRAY2_INDEX_PTR(
            pFastOlrCounters, nDevice, nHistoryInterval)->nSuccessBSW;
      break;
   case DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_SRA:
      nHistoryInterval = 0;
      *pOlrCounters =
         DSL_ST_ARRAY2_INDEX_PTR(
            pFastOlrCounters, nDevice, nHistoryInterval)->nSuccessSRA;
      break;
   case DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_FRA:
      nHistoryInterval = 0;
      *pOlrCounters =
         DSL_ST_ARRAY2_INDEX_PTR(
            pFastOlrCounters, nDevice, nHistoryInterval)->nSuccessFRA;
      break;
   case DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_RPA:
      nHistoryInterval = 0;
      *pOlrCounters =
         DSL_ST_ARRAY2_INDEX_PTR(
            pFastOlrCounters, nDevice, nHistoryInterval)->nSuccessRPA;
      break;
   case DSL_STATS_FAST_LINE_SHOWTIME_SUCCESS_TIGA:
      nHistoryInterval = 0;
      *pOlrCounters =
         DSL_ST_ARRAY2_INDEX_PTR(
            pFastOlrCounters, nDevice, nHistoryInterval)->nSuccessTIGA;
      break;
   case DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_BSW:
      nHistoryInterval = 1;
      *pOlrCounters =
         DSL_ST_ARRAY2_INDEX_PTR(
            pFastOlrCounters, nDevice, nHistoryInterval)->nSuccessBSW;
      break;
   case DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_SRA:
      nHistoryInterval = 1;
      *pOlrCounters =
         DSL_ST_ARRAY2_INDEX_PTR(
            pFastOlrCounters, nDevice, nHistoryInterval)->nSuccessSRA;
      break;
   case DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_FRA:
      nHistoryInterval = 1;
      *pOlrCounters =
         DSL_ST_ARRAY2_INDEX_PTR(
            pFastOlrCounters, nDevice, nHistoryInterval)->nSuccessFRA;
      break;
   case DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_RPA:
      nHistoryInterval = 1;
      *pOlrCounters =
         DSL_ST_ARRAY2_INDEX_PTR(
            pFastOlrCounters, nDevice, nHistoryInterval)->nSuccessRPA;
      break;
   case DSL_STATS_FAST_LINE_LAST_SHOWTIME_SUCCESS_TIGA:
      nHistoryInterval = 1;
      *pOlrCounters =
         DSL_ST_ARRAY2_INDEX_PTR(
            pFastOlrCounters, nDevice, nHistoryInterval)->nSuccessTIGA;
      break;
   default:
#if 0 /* TODO: unify printing for VRX518 and VRX618 */
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - Status Parser (DSL_ST_FastOlrCountersShowtimeGet): "
         "unknown node!"
         DSL_CPE_CRLF));
      nErrorCode = DSL_ERROR;
#endif /* if 0 */
      return DSL_ERROR;
   }

   return DSL_ST_ARRAY2_INDEX_VAL(pErrorCodeArray, nDevice, nHistoryInterval);
}

static DSL_void_t DSL_ST_FastShowtimeSuccessBswUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint16_t nSuccessBsw = 0;

   if (DSL_ST_FastOlrCountersShowtimeGet(
         pContext, eNodeIdx, nDevice, &nSuccessBsw) == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nSuccessBsw;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_FastShowtimeSuccessSraUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint16_t nSuccessSra = 0;

   if (DSL_ST_FastOlrCountersShowtimeGet(
         pContext, eNodeIdx, nDevice, &nSuccessSra) == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nSuccessSra;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_FastShowtimeSuccessFraUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint16_t nSuccessFra = 0;

   if (DSL_ST_FastOlrCountersShowtimeGet(
         pContext, eNodeIdx, nDevice, &nSuccessFra) == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nSuccessFra;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_FastShowtimeSuccessRpaUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint16_t nSuccessRpa = 0;

   if (DSL_ST_FastOlrCountersShowtimeGet(
         pContext, eNodeIdx, nDevice, &nSuccessRpa) == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nSuccessRpa;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}

static DSL_void_t DSL_ST_FastShowtimeSuccessTigaUpdate(
   DSL_Context_t *pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   DSL_uint16_t nSuccessTiga = 0;

   if (DSL_ST_FastOlrCountersShowtimeGet(
         pContext, eNodeIdx, nDevice, &nSuccessTiga) == DSL_SUCCESS)
   {
      /* update integer param */
      DSL_ST_ParamValue_t uValue = { 0 };
      uValue.nValue = nSuccessTiga;
      DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
         DSL_ST_NODE_TYPE_INT, &uValue);
   }
}
#endif /* defined(DSL_ST_PLATFORM_VRX618) && (INCLUDE_DSL_API_GFAST_SUPPORT == 1) */

#if defined(DSL_ST_PLATFORM_VRX518)
#if defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1)
static DSL_void_t DSL_ST_ConfigurationStatusUpdate(
   DSL_CPE_Control_Context_t* pContext,
   const DSL_ST_StatusNodeIdx_t eNodeIdx,
   const DSL_int_t nDevice,
   const DSL_uint8_t nChannel)
{
   if (pContext->pConfigurationStatus)
   {
      DSL_CPE_ConfigStatus_t *pCurrCfgStList = pContext->pConfigurationStatus,
         *pListItem = DSL_NULL, *pNext = DSL_NULL;
      DSL_uint32_t nListSize = 0, i = 0;
      DSL_char_t **ppCfgStatusArray = DSL_NULL;
      DSL_ST_ParamValue_t uValue = { 0 };

      /* count number of list items */
      pListItem = pCurrCfgStList;
      while (pListItem != DSL_NULL)
      {
         nListSize++;
         pListItem = pListItem->pNext;
      }

      /* allocate memory for local array */
      ppCfgStatusArray = (DSL_char_t**)DSL_ST_Malloc(
         nListSize * sizeof(DSL_char_t*));
      for (i = 0; i < nListSize; ++i)
      {
         ppCfgStatusArray[i] = (DSL_char_t*)DSL_ST_Malloc(MAX_ARR_STR_LEN);
      }

      /* store the current configuration status in a local array
         and reset (cleanup) the configuration status list */
      pListItem = pCurrCfgStList;
      i = 0;
      while (pListItem != DSL_NULL && i < nListSize)
      {
         if (ppCfgStatusArray != DSL_NULL && ppCfgStatusArray[i] != DSL_NULL)
         {
            memset(ppCfgStatusArray[i], 0, MAX_ARR_STR_LEN);
            DSL_ST_strncpy_s(ppCfgStatusArray[i], MAX_ARR_STR_LEN,
               pListItem->pStatus, DSL_ST_strnlen_s(
                  pListItem->pStatus, MAX_ARR_STR_LEN - 1));
         }

         DSL_ST_Free(pListItem->pStatus);
         pNext = pListItem->pNext;
         DSL_ST_Free(pListItem);

         pListItem = pNext;
         i++;
      }

      pContext->pConfigurationStatus = DSL_NULL;

      if (ppCfgStatusArray != DSL_NULL)
      {
         /* update array param */
         uValue.aValue.uArray.ppStrArray = ppCfgStatusArray;
         uValue.aValue.nSize = nListSize;
         uValue.aValue.eOutputType = STR;
         DSL_ST_StatusParamUpdate(eNodeIdx, nDevice, nChannel,
            DSL_ST_NODE_TYPE_ARRAY, &uValue);

         /* free memory */
         for (i = 0; i < nListSize; ++i)
         {
            if (ppCfgStatusArray[i] != DSL_NULL)
            {
               DSL_ST_Free(ppCfgStatusArray[i]);
               ppCfgStatusArray[i] = DSL_NULL;
            }
         }
         DSL_ST_Free(ppCfgStatusArray);
         ppCfgStatusArray = DSL_NULL;
      }
   }
}
#endif /* defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1) */
#endif /* defined(DSL_ST_PLATFORM_VRX518) */

#endif /* defined(INCLUDE_DSL_STATUS_PARSER) && (INCLUDE_DSL_STATUS_PARSER == 1) */
#endif /* defined(DSL_VRX_DEVICE_VRX518) || defined(DSL_GFAST_DEVICE_VRX618) */
