/******************************************************************************

         Copyright (c) 2018 - 2020 Intel Corporation

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

*******************************************************************************/

#if defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1)

#include "json.h"
#include "dsl_cpe_configuration_parser.h"
#include "dsl_mgmt_interface.h"

#include "drv_dsl_cpe_api_ioctl.h"
#if defined(INCLUDE_DSL_CPE_API_VRX)
/* MEI CPE driver specific header (e.g. IOCtls) */
#include "drv_mei_cpe_interface.h"
#endif /* defined(INCLUDE_DSL_CPE_API_VRX) */

#undef DSL_CCA_DBG_BLOCK
#define DSL_CCA_DBG_BLOCK DSL_CCA_DBG_APP

#define CONFIG_ROOT_NAME "Root"
#define CONFIG_SECTION_PATH_SEPARATOR "."

/* DSL sections */
#define CONFIG_DSL_CSP_SECTION_PATH \
   CONFIG_ROOT_NAME CONFIG_SECTION_PATH_SEPARATOR "dsl"

#define CONFIG_DEBUGGING_SECTION_PATH \
   CONFIG_DSL_CSP_SECTION_PATH CONFIG_SECTION_PATH_SEPARATOR "debugging"

#define CONFIG_STARTUPINIT_SECTION_PATH \
   CONFIG_DSL_CSP_SECTION_PATH CONFIG_SECTION_PATH_SEPARATOR "startup_init"

#define CONFIG_BITSWAP_SECTION_PATH \
   CONFIG_DSL_CSP_SECTION_PATH CONFIG_SECTION_PATH_SEPARATOR "bitswap"

#define CONFIG_RETRANSMISSION_SECTION_PATH \
   CONFIG_DSL_CSP_SECTION_PATH CONFIG_SECTION_PATH_SEPARATOR "retransmission"

#define CONFIG_SRA_SECTION_PATH \
   CONFIG_DSL_CSP_SECTION_PATH CONFIG_SECTION_PATH_SEPARATOR "sra"

#define CONFIG_VIRTUALNOISE_SECTION_PATH \
   CONFIG_DSL_CSP_SECTION_PATH CONFIG_SECTION_PATH_SEPARATOR "virtual_noise"

#define CONFIG_REBOOTCRITERIA_SECTION_PATH \
   CONFIG_DSL_CSP_SECTION_PATH CONFIG_SECTION_PATH_SEPARATOR "reboot_criteria"

#define CONFIG_XTSE_SECTION_PATH \
   CONFIG_DSL_CSP_SECTION_PATH CONFIG_SECTION_PATH_SEPARATOR "xtse"

#define CONFIG_BONDING_SECTION_PATH \
   CONFIG_DSL_CSP_SECTION_PATH CONFIG_SECTION_PATH_SEPARATOR "bonding"

#define CONFIG_TCLAYER_SECTION_PATH \
   CONFIG_DSL_CSP_SECTION_PATH CONFIG_SECTION_PATH_SEPARATOR "tc_layer"

#define CONFIG_COMMON_SECTION_PATH \
   CONFIG_DSL_CSP_SECTION_PATH CONFIG_SECTION_PATH_SEPARATOR "common"

/* DSL Common subsections */
#define CONFIG_LOWLEVELHSTONES_SECTION_PATH \
   CONFIG_COMMON_SECTION_PATH CONFIG_SECTION_PATH_SEPARATOR "low_level_hs_tones"

#define CONFIGURATION_VALUE_UNDEFINED 0x7FFFFFFF

#define PARSE_SECTION_INT(Section, ParameterName, ConfigField) \
   do { \
      if (bFound == DSL_FALSE && \
          strstr(pSectionPath, \
                 Section CONFIG_SECTION_PATH_SEPARATOR ParameterName) \
         != NULL) \
      { \
         ConfigField = nIntVal; \
         bFound = DSL_TRUE; \
      } \
   } \
   while(0)

#define PARSE_SECTION_STRING(Section, ParameterName, ConfigField) \
   do { \
      if (bFound == DSL_FALSE && \
          strstr(pSectionPath, \
                 Section CONFIG_SECTION_PATH_SEPARATOR ParameterName) \
         != NULL) \
      { \
         cpe_control_strncpy_s( \
            ConfigField, sizeof(ConfigField), nStringVal, sizeof(nStringVal)); \
         bFound = DSL_TRUE; \
      } \
   } \
   while(0)

#define PARSE_SECTION_HEX(Section, ParameterName, ConfigField) \
   do { \
      if (bFound == DSL_FALSE && \
          strstr(pSectionPath, \
                 Section CONFIG_SECTION_PATH_SEPARATOR ParameterName) \
         != NULL) \
      { \
         ConfigField = (DSL_uint32_t)(strtol(nStringVal, NULL, 16)); \
         bFound = DSL_TRUE; \
      } \
   } \
   while(0)

/* Macro used to check if configuration parameter is in valid range */
#define CONFIG_PARAM_RANGE_VALIDATION(Param, ParamId, nMinVal, nMaxVal) \
   do { \
      DSL_int32_t val = Param; \
      if (val == CONFIGURATION_VALUE_UNDEFINED) \
      { \
            break; \
      } \
      if ((val > nMaxVal) || (val < nMinVal)) \
      { \
         nRangeCheck = DSL_ERR_PARAM_RANGE; \
         \
         DSL_CPE_ConfigEntryAppliedValueType_u applyVal; \
         memset(&applyVal, 0, sizeof(applyVal)); \
         applyVal.iVal = Param; \
         \
         DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList, \
            pConfiguration->type, \
            ParamId, \
            applyVal, \
            nRangeCheck); \
         \
         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, \
            (DSL_CPE_PREFIX"ERROR - Configuration param %s " \
            "validation failed! (min = %d, max = %d, current = %d)!" \
            DSL_CPE_CRLF, #Param, nMinVal, nMaxVal, val)); \
      } \
   } \
   while(0)

/* Macro used to check if parameter in DSL_CPE_Configuration_t (configParam)
is undefined, if so use currentParam (from DSL_xxxGet function or any other source) */
#define CONFIG_PARAM_APPLY(currentParam, configParam) \
   do { \
      currentParam = (configParam == CONFIGURATION_VALUE_UNDEFINED) ? \
         currentParam : configParam; \
   } \
   while(0)

#define CONFIG_FREE_LIST \
   do { \
      while (pCurrent != DSL_NULL) { \
         pNext = pCurrent->pNext; \
         free(pCurrent); \
         pCurrent = pNext; \
      } \
   } while(0)

#define CONFIG_CHANGE_STATUS_READY_FLAG(flag) \
   do { \
      DSL_CPE_LockGet(&g_ConfigStatusLock); \
      g_bIsConfigStatusReady = flag; \
      DSL_CPE_LockSet(&g_ConfigStatusLock); \
   } while(0)

#define CONFIG_CHANGE_ONGOING_FLAG(flag) \
   do { \
      DSL_CPE_LockGet(&g_ConfigOngoingLock); \
      g_bIsConfigOngoing = flag; \
      DSL_CPE_LockSet(&g_ConfigOngoingLock); \
   } while(0)

#define CONFIG_SECTION_PATH_LENGTH 256
#define CONFIG_PARAMETER_STRING_VALUE_LENGTH 64
#define CONFIG_STATUS_LENGTH 320

/**
   String representation of configuration types.
   Keep it in the same order as DSL_ConfigurationType_e enum!
*/
static const DSL_char_t *g_sConfigurationType[] = {
   "Unset",
   "Config file",
   "Backup config",
   "Default config"
};

/**
   String representation of json types.
   Keep it in the same order as json_type enum!
*/
static const DSL_char_t *g_sJsonType[] = {
   "null",
   "boolean",
   "double",
   "int",
   "object",
   "array",
   "string"
};

/* Configuration file path */
static const DSL_char_t *g_pJsonConfigPath = "/tmp/dsl/dsl.conf";
static DSL_Configuration_t g_sConfiguration = { 0 };
static const DSL_Configuration_t g_sDefaultConfiguration =
{
   /* type */
   DSL_CPE_CONFIGURATION_TYPE_DEFAULT,

   /* data */
   {
      /* DSL_CFG_Debugging_t */
      {
          /* link start */
          1,
          /* debug and test interface */
          1
      },

      /* DSL_CFG_StartupInit_t */
      {
         /* next mode */
         0,
         /* max device number */
         1,
         /* lines per device */
         1,
         /* channels per line */
         1
      },

      /* DSL_CFG_Bitswap_t */
      {
         /* ADSL US */
         1,
         /* ADSL DS */
         1,
         /* VDSL US */
         1,
         /* VDSL DS */
         1
      },

      /* DSL_CFG_Retransmission_t */
      {
         /* ADSL US */
         0,
         /* ADSL DS */
         0,
         /* VDSL US */
         1,
         /* VDSL DS */
         1
      },

      /* DSL_CFG_Sra_t */
      {
         /* ADSL US */
         0,
         /* ADSL DS */
         0,
         /* VDSL US */
         1,
         /* VDSL DS */
         1
      },

      /* DSL_CFG_VirtualNoise_t */
      {
         /* US */
         1,
         /* DS */
         1
      },

      /* DSL_CFG_RebootCriteria_t */
      {
         /* US */
         0x4F,
         /* DS */
         0xF
      },

      /* DSL_CFG_SystemInterface_t */
      {
         /* ADSL TC Layer */
         0,
         /* VDSL TC Layer */
         0
      },

      /* DSL_CFG_Bonding_t */
      {
         /* ADSL PTM */
         0,
         /* ADSL ATM */
         0,
         /* VDSL PTM */
         0,
         /* VDSL ATM */
         0
      },

      /* DSL_CFG_Common_t */
      {
         /* OperatorSelect */
         0,

         /* LdAfeShutdown */
         1,

         /* VectoringEnable */
         0,

         /* VdslProfileVal */
         0x1FF,

         /* ActSeq */
         1,

         /* ActMode */
         1,

         /* Remember */
         0,

         /* FWMsgPollingOnly */
         0,

         /* DSL_CFG_LowLevelHsTones_t */
         {
            /* ADSL */
            0,
            /* VDSL */
            0
         }
      },

      /* xtse */
      { 0x4, 0x0, 0x4, 0x0, 0xC, 0x1, 0x0, 0x7 }
   }
};

static DSL_boolean_t g_bIsConfigStatusReady = DSL_FALSE;
static DSL_boolean_t g_bIsConfigOngoing = DSL_FALSE;
static DSL_CPE_Lock_t g_ConfigStatusLock;
static DSL_CPE_Lock_t g_ConfigOngoingLock;

/**
   Indexes of mandatory and optional configuration entries
*/
typedef enum
{
   CONFIG_ROOT = 0,
   CONFIG_DSL = 1,

   CONFIG_DSL_DEBUGGING,
   CONFIG_DSL_DEBUGGING_DEBUG_LEVEL,
   CONFIG_DSL_DEBUGGING_DEBUG_LEVELS_APP,
   CONFIG_DSL_DEBUGGING_DEBUG_LEVELS_DRV,
   CONFIG_DSL_DEBUGGING_ENABLE_PRINT,
   CONFIG_DSL_DEBUGGING_DEBUG_AND_TEST_INTERFACES,

   CONFIG_DSL_DEBUGGING_AUTOBOOT_CFG,
   CONFIG_DSL_DEBUGGING_AUTOBOOT_CFG_ADSL,
   CONFIG_DSL_DEBUGGING_AUTOBOOT_CFG_VDSL,

   CONFIG_DSL_DEBUGGING_LINK_START,

   CONFIG_DSL_STARTUPINIT,
   CONFIG_DSL_STARTUPINIT_NEXT_MODE,
   CONFIG_DSL_STARTUPINIT_MAX_DEVICE_NUMBER,
   CONFIG_DSL_STARTUPINIT_LINES_PER_DEVICE,
   CONFIG_DSL_STARTUPINIT_CHANNELS_PER_LINE,

   CONFIG_DSL_BITSWAP,
   CONFIG_DSL_BITSWAP_VDSL_US,
   CONFIG_DSL_BITSWAP_VDSL_DS,
   CONFIG_DSL_BITSWAP_ADSL_US,
   CONFIG_DSL_BITSWAP_ADSL_DS,

   CONFIG_DSL_RETRANSMISSION,
   CONFIG_DSL_RETRANSMISSION_VDSL_US,
   CONFIG_DSL_RETRANSMISSION_VDSL_DS,
   CONFIG_DSL_RETRANSMISSION_ADSL_US,
   CONFIG_DSL_RETRANSMISSION_ADSL_DS,

   CONFIG_DSL_SRA,
   CONFIG_DSL_SRA_VDSL_US,
   CONFIG_DSL_SRA_VDSL_DS,
   CONFIG_DSL_SRA_ADSL_US,
   CONFIG_DSL_SRA_ADSL_DS,

   CONFIG_DSL_VIRTUALNOISE,
   CONFIG_DSL_VIRTUALNOISE_US,
   CONFIG_DSL_VIRTUALNOISE_DS,

   CONFIG_DSL_BONDING,
   CONFIG_DSL_BONDING_ADSL_PTM,
   CONFIG_DSL_BONDING_ADSL_ATM,
   CONFIG_DSL_BONDING_VDSL_PTM,
   CONFIG_DSL_BONDING_VDSL_ATM,

   CONFIG_DSL_TCLAYER,
   CONFIG_DSL_TCLAYER_ADSL,
   CONFIG_DSL_TCLAYER_VDSL,

   CONFIG_DSL_COMMON,
   CONFIG_DSL_COMMON_OPERATOR_SELECT,
   CONFIG_DSL_COMMON_LD_AFE_SHUTDOWN,
   CONFIG_DSL_COMMON_VECTORING_ENABLE,
   CONFIG_DSL_COMMON_ACTIVATION_SEQUENCE,
   CONFIG_DSL_COMMON_ACTIVATION_MODE,
   CONFIG_DSL_COMMON_REMEMBER,
   CONFIG_DSL_COMMON_FW_MSG_POLLING_ONLY,
   CONFIG_DSL_COMMON_VDSL_PROFILE,

   CONFIG_DSL_COMMON_LOWLEVELHSTONES,
   CONFIG_DSL_COMMON_LOWLEVELHSTONES_ADSL,
   CONFIG_DSL_COMMON_LOWLEVELHSTONES_VDSL,

   CONFIG_DSL_REBOOTCRITERIA,
   CONFIG_DSL_REBOOTCRITERIA_ADSL,
   CONFIG_DSL_REBOOTCRITERIA_VDSL,

   CONFIG_DSL_XTSE,
   CONFIG_DSL_XTSE_FIRST_ELEMENT
} DSL_CPE_ConfigEntryIndex_e;

/**
   Configuration parameter entry
*/
typedef struct
{
   DSL_CPE_ConfigEntryIndex_e eIndex;
   DSL_char_t *pParameterPath;
   enum json_type eParameterType;
   DSL_boolean_t bMandatory;
} DSL_CPE_ConfigEntryPattern_t;

/**
   Recognized configuration parameter entry
*/
typedef struct DSL_CPE_ConfigEntryRecognized
{
   DSL_CPE_ConfigEntryIndex_e eIndex;
   enum json_type eParameterType;
   struct DSL_CPE_ConfigEntryRecognized *pNext;
} DSL_CPE_ConfigEntryRecognized_t;

/**
   Unrecognized configuration parameter entry
*/
typedef struct DSL_CPE_ConfigEntryUnrecognized
{
   DSL_char_t path[CONFIG_SECTION_PATH_LENGTH];
   struct DSL_CPE_ConfigEntryUnrecognized *pNext;
} DSL_CPE_ConfigEntryUnrecognized_t;

typedef union
{
   DSL_char_t strVal[CONFIG_PARAMETER_STRING_VALUE_LENGTH];
   DSL_int32_t iVal;
   DSL_boolean_t bVal;
} DSL_CPE_ConfigEntryAppliedValueType_u;

/**
   Applied (or rejected) configuration parameter entry
*/
typedef struct DSL_CPE_ConfigEntryApplied
{
   DSL_CPE_ConfigurationType_e eConfigType;
   DSL_CPE_ConfigEntryIndex_e eIndex;
   DSL_CPE_ConfigEntryAppliedValueType_u val;
   DSL_int32_t nApplyRetCode;
   struct DSL_CPE_ConfigEntryApplied *pNext;
} DSL_CPE_ConfigEntryApplied_t;

/**
   Autoboot stop points settings placeholder
   in context of reconfiguration
*/
typedef struct DSL_CPE_AutobootLockContext
{
   DSL_boolean_t bWaitBeforeLinkActivation[DSL_CPE_MAX_DSL_ENTITIES];
   DSL_boolean_t bWaitBeforeConfigWrite[DSL_CPE_MAX_DSL_ENTITIES];
   DSL_boolean_t bWaitBeforeRestart[DSL_CPE_MAX_DSL_ENTITIES];
#ifdef INCLUDE_DSL_CPE_CMV_SCRIPTS_SUPPORT
   DSL_boolean_t bAutoContinueWaitBeforeLinkActivation[DSL_CPE_MAX_DSL_ENTITIES];
   DSL_boolean_t bAutoContinueWaitBeforeConfigWrite[DSL_CPE_MAX_DSL_ENTITIES];
   DSL_boolean_t bAutoContinueWaitBeforeRestart[DSL_CPE_MAX_DSL_ENTITIES];
#endif /* INCLUDE_DSL_CPE_CMV_SCRIPTS_SUPPORT*/
} DSL_CPE_AutobootLockContext_t;

/**
   Mandatory and optional configuration parameter patterns.
   Used to decide of parameter category/match.
   Optional params used to suppress unwanted warnings.
*/
static const DSL_CPE_ConfigEntryPattern_t g_sPatterns[] =
{
   /* Optional
      (used only in a debug context so defined directly here -
      no param names' definitions for these nodes) */
   { CONFIG_DSL_DEBUGGING_DEBUG_LEVEL,
      CONFIG_DEBUGGING_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR "debug_level",
      json_type_int,
      DSL_FALSE
   },
   { CONFIG_DSL_DEBUGGING_DEBUG_LEVELS_APP,
      CONFIG_DEBUGGING_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR "debug_levels_app",
      json_type_string,
      DSL_FALSE
   },
   { CONFIG_DSL_DEBUGGING_DEBUG_LEVELS_DRV,
      CONFIG_DEBUGGING_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR "debug_levels_drv",
      json_type_string,
      DSL_FALSE
   },
   { CONFIG_DSL_DEBUGGING_ENABLE_PRINT,
      CONFIG_DEBUGGING_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR "enable_print",
      json_type_int,
      DSL_FALSE
   },
   { CONFIG_DSL_DEBUGGING_AUTOBOOT_CFG_ADSL,
      CONFIG_DEBUGGING_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR "autoboot_cfg.adsl",
      json_type_string,
      DSL_FALSE
   },
   { CONFIG_DSL_DEBUGGING_AUTOBOOT_CFG_VDSL,
      CONFIG_DEBUGGING_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR "autoboot_cfg.vdsl",
      json_type_string,
      DSL_FALSE
   },

   { CONFIG_DSL_DEBUGGING_LINK_START,
      CONFIG_DEBUGGING_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_LINK_START,
      json_type_int,
      DSL_FALSE
   },

   /* Mandatory */
   { CONFIG_DSL_DEBUGGING_DEBUG_AND_TEST_INTERFACES,
      CONFIG_DEBUGGING_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_DEBUG_AND_TEST_INTERFACES,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_STARTUPINIT_NEXT_MODE,
      CONFIG_STARTUPINIT_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_NEXT_MODE,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_STARTUPINIT_MAX_DEVICE_NUMBER,
      CONFIG_STARTUPINIT_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_MAX_DEVICE_NUMBER,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_STARTUPINIT_LINES_PER_DEVICE,
      CONFIG_STARTUPINIT_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_LINES_PER_DEVICE,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_STARTUPINIT_CHANNELS_PER_LINE,
      CONFIG_STARTUPINIT_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_CHANNELS_PER_LINE,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_BITSWAP_VDSL_US,
      CONFIG_BITSWAP_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_BITSWAP_VDSL_US,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_BITSWAP_VDSL_DS,
      CONFIG_BITSWAP_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_BITSWAP_VDSL_DS,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_BITSWAP_ADSL_US,
      CONFIG_BITSWAP_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_BITSWAP_ADSL_US,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_BITSWAP_ADSL_DS,
      CONFIG_BITSWAP_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_BITSWAP_ADSL_DS,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_RETRANSMISSION_VDSL_US,
      CONFIG_RETRANSMISSION_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_RETX_VDSL_US,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_RETRANSMISSION_VDSL_DS,
      CONFIG_RETRANSMISSION_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_RETX_VDSL_DS,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_RETRANSMISSION_ADSL_US,
      CONFIG_RETRANSMISSION_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_RETX_ADSL_US,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_RETRANSMISSION_ADSL_DS,
      CONFIG_RETRANSMISSION_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_RETX_ADSL_DS,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_SRA_VDSL_US,
      CONFIG_SRA_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_SRA_VDSL_US,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_SRA_VDSL_DS,
      CONFIG_SRA_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_SRA_VDSL_DS,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_SRA_ADSL_US,
      CONFIG_SRA_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_SRA_ADSL_US,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_SRA_ADSL_DS,
      CONFIG_SRA_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_SRA_ADSL_DS,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_VIRTUALNOISE_US,
      CONFIG_VIRTUALNOISE_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_VN_US,
      json_type_int,
   },
   { CONFIG_DSL_VIRTUALNOISE_DS,
      CONFIG_VIRTUALNOISE_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_VN_DS,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_BONDING_ADSL_PTM,
      CONFIG_BONDING_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_BONDING_ADSL_PTM,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_BONDING_ADSL_ATM,
      CONFIG_BONDING_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_BONDING_ADSL_ATM,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_BONDING_VDSL_PTM,
      CONFIG_BONDING_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_BONDING_VDSL_PTM,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_BONDING_VDSL_ATM,
      CONFIG_BONDING_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_BONDING_VDSL_ATM,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_TCLAYER_ADSL,
      CONFIG_TCLAYER_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_TC_ADSL,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_TCLAYER_VDSL,
      CONFIG_TCLAYER_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_TC_VDSL,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_COMMON_OPERATOR_SELECT,
      CONFIG_COMMON_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_OPERATOR_SELECT,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_COMMON_LD_AFE_SHUTDOWN,
      CONFIG_COMMON_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_LD_AFE_SHUTDOWN,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_COMMON_VECTORING_ENABLE,
      CONFIG_COMMON_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_VECTORING_ENABLE,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_COMMON_ACTIVATION_SEQUENCE,
      CONFIG_COMMON_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_ACTIVATION_SEQUENCE,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_COMMON_ACTIVATION_MODE,
      CONFIG_COMMON_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_ACTIVATION_MODE,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_COMMON_REMEMBER,
      CONFIG_COMMON_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_REMEMBER,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_COMMON_FW_MSG_POLLING_ONLY,
      CONFIG_COMMON_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_FW_MSG_POLLING_ONLY,
      json_type_int,
      DSL_TRUE
   },
   { CONFIG_DSL_COMMON_VDSL_PROFILE,
      CONFIG_COMMON_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_VDSL_PROFILE,
      json_type_string,
      DSL_TRUE
   },
   { CONFIG_DSL_COMMON_LOWLEVELHSTONES_ADSL,
      CONFIG_LOWLEVELHSTONES_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_LOW_LEVEL_HS_TONES_ADSL,
      json_type_string,
      DSL_TRUE
   },
   { CONFIG_DSL_COMMON_LOWLEVELHSTONES_VDSL,
      CONFIG_LOWLEVELHSTONES_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_LOW_LEVEL_HS_TONES_VDSL,
      json_type_string,
      DSL_TRUE
   },
   { CONFIG_DSL_REBOOTCRITERIA_ADSL,
      CONFIG_REBOOTCRITERIA_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_REBOOT_ADSL,
      json_type_string,
      DSL_TRUE
   },
   { CONFIG_DSL_REBOOTCRITERIA_VDSL,
      CONFIG_REBOOTCRITERIA_SECTION_PATH \
      CONFIG_SECTION_PATH_SEPARATOR DSL_CSP_CFG_REBOOT_VDSL,
      json_type_string,
      DSL_TRUE
   },
   { CONFIG_DSL_XTSE,
      CONFIG_XTSE_SECTION_PATH,
      json_type_array,
      DSL_TRUE
   },
   { CONFIG_DSL_XTSE_FIRST_ELEMENT,
      CONFIG_XTSE_SECTION_PATH "[0]",
      json_type_string,
      DSL_TRUE
   }
};

static const DSL_size_t nPatternsNum =
   sizeof(g_sPatterns) / sizeof(g_sPatterns[0]);
static DSL_size_t nRecognizedEntriesNum = 0;
static DSL_size_t nUnrecognizedEntriesNum = 0;
static const DSL_size_t nUnrecognizedEntriesLimit = 10;
static DSL_size_t nAppliedEntriesNum = 0;
static DSL_size_t nFinalStatusEntriesNum = 0;

/**
   Pointers to current lists of entries
*/
DSL_CPE_ConfigEntryRecognized_t *g_pRecognizedEntriesList = DSL_NULL;
DSL_CPE_ConfigEntryUnrecognized_t *g_pUnrecognizedEntriesList = DSL_NULL;
DSL_CPE_ConfigEntryApplied_t *g_pAppliedEntriesList = DSL_NULL;
DSL_CPE_ConfigStatus_t *g_pFinalStatusEntriesList = DSL_NULL;

/**********************************************/
/* start local function declarations          */
/**********************************************/

static DSL_Error_t DSL_CPE_JsonParseConfigFile(
   const DSL_char_t * pPath,
   DSL_Configuration_t *pData
);

static DSL_void_t DSL_CPE_JsonReadObj(
   json_object * pObj,
   DSL_char_t * pSectionPath,
   DSL_Configuration_t *pData
);

static DSL_void_t DSL_CPE_JsonParse(
   json_object * pObj,
   DSL_char_t * pSectionPath,
   DSL_Configuration_t *pData
);

static DSL_void_t DSL_CPE_JsonParseArray(
   json_object * pObj,
   DSL_char_t * pKey,
   DSL_char_t * pSectionPath,
   DSL_Configuration_t *pData
);

static DSL_Error_t DSL_CPE_ConfigBackupCreate(
   const DSL_CPE_Control_Context_t *pCtrlCtx,
   DSL_Configuration_t *pBackupConfiguration
);

static DSL_Error_t DSL_CPE_ConfigRead(
   DSL_CPE_ConfigStatus_t **ppConfigurationStatus
);

static DSL_Error_t DSL_CPE_ConfigValidateAndApply(
   const DSL_CPE_Control_Context_t *pCtrlCtx,
   const DSL_Configuration_t *pConfiguration
);

static DSL_Error_t DSL_CPE_AutobootLock(
   const DSL_CPE_Control_Context_t *pCtrlCtx,
   DSL_CPE_AutobootLockContext_t *pLockCxt
);

static DSL_Error_t DSL_CPE_AutobootUnlock(
   const DSL_CPE_Control_Context_t *pCtrlCtx,
   const DSL_CPE_AutobootLockContext_t *pLockCxt
);

static DSL_void_t DSL_CPE_AutobootRestart(
   const DSL_CPE_Control_Context_t* pCtrlCtx
);

static DSL_boolean_t DSL_CPE_AutobootScriptsExistCheck(
   DSL_void_t
);

/**
   Validate and apply configuration functions
*/
static DSL_Error_t DSL_CPE_LowLevelCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration
);

static DSL_Error_t DSL_CPE_LineFeatureCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration
);

static DSL_Error_t DSL_CPE_RebootCriteriaCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration
);

static DSL_Error_t DSL_CPE_VdslProfileCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration
);

static DSL_Error_t DSL_CPE_G997_RateAdaptationCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration
);

static DSL_Error_t DSL_CPE_SysIfCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration
);

static DSL_Error_t DSL_CPE_BondingCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration
);

static DSL_Error_t DSL_CPE_XtseCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration
);

static DSL_Error_t DSL_CPE_VectoringEnableCfgValidateAndApply(
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration
);

static DSL_Error_t DSL_CPE_FwMessagePollingCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration
);

static DSL_Error_t DSL_CPE_OperatorSelectCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration
);

/**
   Backup configuration functions
*/
static DSL_Error_t DSL_CPE_LowLevelCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
);

static DSL_Error_t DSL_CPE_LineFeatureCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
);

static DSL_Error_t DSL_CPE_RebootCriteriaCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
);

static DSL_Error_t DSL_CPE_VdslProfileCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
);

static DSL_Error_t DSL_CPE_G997_RateAdaptationCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
);

static DSL_Error_t DSL_CPE_SysIfCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
);

static DSL_Error_t DSL_CPE_XtseCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
);

static DSL_Error_t DSL_CPE_VectoringEnableCfgBackup(
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
);

static DSL_Error_t DSL_CPE_FwMessagePollingCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
);

static DSL_Error_t DSL_CPE_OperatorSelectCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
);

/**
   Status related functions
*/
static DSL_void_t DSL_CPE_ConfigEntryRecognizedListDelete(
   DSL_CPE_ConfigEntryRecognized_t **ppHead
);

static DSL_void_t DSL_CPE_ConfigEntryUnrecognizedListDelete(
   DSL_CPE_ConfigEntryUnrecognized_t **ppHead
);

static DSL_void_t DSL_CPE_ConfigEntryAppliedListDelete(
   DSL_CPE_ConfigEntryApplied_t **ppHead
);

static DSL_void_t DSL_CPE_ConfigStatusDelete(
   DSL_CPE_ConfigStatus_t **ppHead
);

static DSL_Error_t DSL_CPE_ConfigStatusEntryAdd(
   DSL_CPE_ConfigStatus_t **ppHead,
   const DSL_char_t *pStatus
);

static DSL_void_t DSL_CPE_ConfigEntryRecognizedMap(
   const DSL_CPE_ConfigEntryRecognized_t *pHead,
   DSL_CPE_ConfigStatus_t **ppFinalStatus,
   DSL_boolean_t *pbIsConfigFallbackNeeded
);

static DSL_void_t DSL_CPE_ConfigEntryUnrecognizedMap(
   const DSL_CPE_ConfigEntryUnrecognized_t *pHead,
   DSL_CPE_ConfigStatus_t **ppFinalStatus
);

static DSL_void_t DSL_CPE_ConfigEntryAppliedMap(
   const DSL_CPE_ConfigEntryApplied_t *pHead,
   DSL_CPE_ConfigStatus_t **ppFinalStatus
);

static DSL_Error_t DSL_CPE_ConfigStatusCollect(
   DSL_CPE_ConfigStatus_t **ppConfigurationStatus,
   DSL_CPE_ConfigEntryRecognized_t **ppRecognizedList,
   DSL_CPE_ConfigEntryUnrecognized_t **ppUnrecognizedList,
   DSL_CPE_ConfigEntryApplied_t **ppAppliedList
);

static DSL_Error_t DSL_CPE_ConfigEntryUnrecognizedAdd(
   DSL_CPE_ConfigEntryUnrecognized_t **ppHead,
   const DSL_char_t *pParameterPath
);

static DSL_Error_t DSL_CPE_ConfigEntryRecognizedAdd(
   DSL_CPE_ConfigEntryRecognized_t **ppHead,
   const DSL_char_t *pParameterPath,
   const json_type eParameterType
);

static DSL_Error_t DSL_CPE_ConfigEntryAppliedAdd(
   DSL_CPE_ConfigEntryApplied_t **ppHead,
   const DSL_CPE_ConfigurationType_e eConfigType,
   const DSL_CPE_ConfigEntryIndex_e eIndex,
   const DSL_CPE_ConfigEntryAppliedValueType_u val,
   const DSL_uint32_t nApplyRetCode
);

static DSL_void_t DSL_CPE_ConfigInputValidate(
   const DSL_char_t *pParameterPath,
   const json_type eParameterType
);

static DSL_void_t DSL_CPE_ConfigStatusRelease(
   const DSL_Configuration_t *pConfiguration,
   DSL_Error_t nConfigRetCode
);

/**********************************************/
/* start interface function definitions       */
/**********************************************/

/*
   For a detailed description of the function, its arguments and return value
   please refer to the description in the header file 'dsl_cpe_configuration_parser.h'
*/
DSL_Error_t DSL_CPE_ConfigInit()
{
   static DSL_boolean_t bInitDone = DSL_FALSE;
   DSL_Error_t nRet = DSL_ERROR;

   if (bInitDone == DSL_FALSE)
   {
      if (DSL_CPE_LockCreate(&g_ConfigStatusLock) != DSL_SUCCESS)
      {
         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - Configuration status lock "
            "creation failed!" DSL_CPE_CRLF));
      }

      if (DSL_CPE_LockCreate(&g_ConfigOngoingLock) != DSL_SUCCESS)
      {
         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - Configuration ongoing process lock "
            "creation failed!" DSL_CPE_CRLF));
      }

      if (DSL_CPE_ConfigRead(&g_pFinalStatusEntriesList) == DSL_ERROR)
      {
         cpe_control_memcpy_s(
            &g_sConfiguration, sizeof(DSL_Configuration_t),
            &g_sDefaultConfiguration, sizeof(DSL_Configuration_t));

         DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
            "WARNING - Configuration initialized "
            "with default values!" DSL_CPE_CRLF));

         nRet = DSL_WRN_CONFIG_PARAM_IGNORED;
      }
      else
      {
         nRet = DSL_SUCCESS;
      }

      bInitDone = DSL_TRUE;
   }

   return nRet;
}

/*
   For a detailed description of the function, its arguments and return value
   please refer to the description in the header file 'dsl_cpe_configuration_parser.h'
*/
DSL_Error_t DSL_CPE_ConfigGet(const DSL_Configuration_t **pConfiguration)
{
   *pConfiguration = &g_sConfiguration;

   return DSL_SUCCESS;
}

/*
   For a detailed description of the function, its arguments and return value
   please refer to the description in the header file 'dsl_cpe_configuration_parser.h'
*/
DSL_Error_t DSL_CPE_ConfigUpdate(
   DSL_CPE_Control_Context_t *pCtrlCtx)
{
   DSL_Error_t nRet = DSL_SUCCESS;
   static DSL_boolean_t bReconfig = DSL_FALSE;
   DSL_Configuration_t sBackupConfiguration;
   DSL_boolean_t bIsBackupCreated = DSL_FALSE;
   DSL_boolean_t bAutobootRestart = DSL_TRUE;
   const DSL_Configuration_t *pConfiguration = &g_sConfiguration;
   DSL_CPE_AutobootLockContext_t sAutobootLockContext = { 0 };

   /* on init
      ConfigRead function is already called in ConfigInit function -
      no need to call it again */
   if (bReconfig == DSL_TRUE)
   {
      nRet = DSL_CPE_ConfigRead(&g_pFinalStatusEntriesList);

      if (DSL_CPE_AutobootLock(pCtrlCtx, &sAutobootLockContext) == DSL_ERROR)
      {
         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - Autoboot lock failed!" DSL_CPE_CRLF));
      }

      /* not in startup so
         stores current configuration as backup before trying to apply a new one */
      if (DSL_CPE_ConfigBackupCreate(pCtrlCtx,
                                     &sBackupConfiguration) == DSL_SUCCESS)
      {
         bIsBackupCreated = DSL_TRUE;
      }
   }

   /* do not proceed when ConfigRead failed with undefined values */
   if (nRet == DSL_SUCCESS)
   {
      nRet = DSL_CPE_ConfigValidateAndApply(pCtrlCtx, pConfiguration);
   }

   /* applies backuped configuration only if new configuration is invalid:
      parsing or applying failed */
   if (nRet < DSL_SUCCESS)
   {
      /* if the new configuration was rejected, the autoboot restart
         shall be not performed */
      bAutobootRestart = DSL_FALSE;

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - Configuration Parser: " \
         "Applying configuration failed!" DSL_CPE_CRLF));

      if (bIsBackupCreated == DSL_TRUE)
      {
         pConfiguration = &sBackupConfiguration;

         nRet = DSL_CPE_ConfigValidateAndApply(pCtrlCtx, pConfiguration);

         if (nRet < DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - Configuration Parser: " \
               "Applying backuped configuration failed!" DSL_CPE_CRLF));
         }
      }

      /* applies hardcoded default configuration
         only if even backuped configuration is invalid:
         gathering or applying failed */
      if (nRet < DSL_SUCCESS)
      {
         pConfiguration = &g_sDefaultConfiguration;

         nRet = DSL_CPE_ConfigValidateAndApply(pCtrlCtx, pConfiguration);

         if (nRet < DSL_SUCCESS)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - Configuration Parser: " \
               "Applying default configuration failed!" DSL_CPE_CRLF));
         }
      }
   }

   if (bReconfig == DSL_TRUE)
   {
      if (DSL_CPE_AutobootUnlock(pCtrlCtx, &sAutobootLockContext) == DSL_ERROR)
      {
         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - Autoboot unlock failed!" DSL_CPE_CRLF));
      }

      /* Trigger link reconfiguration if required  */
      if (pConfiguration->data.sDebuggingConfig.nLinkStart == 1
            && bAutobootRestart == DSL_TRUE)
      {
         DSL_CPE_AutobootRestart(pCtrlCtx);
      }
   }

   (DSL_void_t) DSL_CPE_ConfigStatusCollect(
      &g_pFinalStatusEntriesList,
      DSL_NULL,
      DSL_NULL,
      &g_pAppliedEntriesList);

   DSL_CPE_ConfigStatusRelease(pConfiguration, nRet);

   bReconfig = DSL_TRUE;

   return nRet;
}

/*
   For a detailed description of the function, please refer to the
   description in the header file 'dsl_cpe_configuration_parser.h'
*/

DSL_Error_t DSL_CPE_ConfigStatusTransfer(
   DSL_CPE_ConfigStatus_t **ppConfigurationStatus)
{
   DSL_Error_t nErrCode = DSL_ERROR;

   /* configuration status is polled periodically
      so no need to waste time here
      if right now new status is beeing prepared */
   if (DSL_CPE_LockTimedGet(&g_ConfigStatusLock, 0, NULL))
   {
      if (g_bIsConfigStatusReady == DSL_TRUE)
      {
         g_bIsConfigStatusReady = DSL_FALSE;

         if (g_pFinalStatusEntriesList != DSL_NULL)
         {
            /* transfer ownership of configuration status list */
            *ppConfigurationStatus = g_pFinalStatusEntriesList;

            g_pFinalStatusEntriesList = DSL_NULL;
            nFinalStatusEntriesNum = 0;

            nErrCode = DSL_SUCCESS;
         }
      }

      DSL_CPE_LockSet(&g_ConfigStatusLock);
   }

   return nErrCode;
}

/*
   For a detailed description of the function, please refer to the
   description in the header file 'dsl_cpe_configuration_parser.h'
*/
DSL_boolean_t DSL_CPE_ConfigProcessIsOngoingCheck(DSL_void_t)
{
   DSL_boolean_t bOngoing = DSL_TRUE;

   if (DSL_CPE_LockTimedGet(&g_ConfigOngoingLock, 0, NULL) == 0)
   {
      bOngoing = g_bIsConfigOngoing;

      DSL_CPE_LockSet(&g_ConfigOngoingLock);
   }

   return bOngoing;
}


/*********************************************/
/* start local function definitions          */
/*********************************************/

static DSL_Error_t DSL_CPE_JsonParseConfigFile(
   const DSL_char_t * pPath,
   DSL_Configuration_t *pData)
{
   DSL_CPE_File_t *pFile = DSL_NULL;
   DSL_int_t nFileLength = 0;
   DSL_char_t * pBuffer = DSL_NULL;
   DSL_char_t currentSectionPath[CONFIG_SECTION_PATH_LENGTH] = { CONFIG_ROOT_NAME };

   json_object * pRootObj = DSL_NULL;

   pFile = DSL_CPE_FOpen(pPath, "r");
   if (pFile == DSL_NULL)
   {
      return DSL_ERROR;
   }

   /* Get length of file as JSON has strict format
   and we have to read whole file at once */
   fseek(pFile, 0, SEEK_END);
   nFileLength = ftell(pFile);
   fseek(pFile, 0, SEEK_SET);

   /* Alloc buffer for JSON file content */
   pBuffer = (DSL_char_t *)DSL_CPE_Malloc(nFileLength * sizeof(DSL_char_t));
   if (pBuffer == DSL_NULL)
   {
      DSL_CPE_FClose(pFile);
      return DSL_ERROR;
   }

   /* Read file */
   DSL_CPE_FRead(pBuffer, sizeof(DSL_char_t), nFileLength, pFile);
   DSL_CPE_FClose(pFile);

   /* Create JSON Object from string */
   pRootObj = json_tokener_parse(pBuffer);
   DSL_CPE_Free(pBuffer);

   if (pRootObj == DSL_NULL)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
         "Configuration Parser: invalid JSON file syntax" DSL_CPE_CRLF));
      return DSL_ERROR;
   }

   pData->type = DSL_CPE_CONFIGURATION_TYPE_FILE;
   /* by default (especially for the release images where debugging section
      in the config file is not applicable) applying new configuration to
      the line automatically is required */
   pData->data.sDebuggingConfig.nLinkStart = 1;

   /* Start parsing */
   DSL_CPE_JsonReadObj(pRootObj, currentSectionPath, pData);

   return DSL_SUCCESS;
}

static DSL_void_t DSL_CPE_JsonReadObj(
   json_object * pObj,
   DSL_char_t *pSectionPath,
   DSL_Configuration_t *pData)
{
   enum json_type nType = json_type_null;
   DSL_char_t currentSectionPath[CONFIG_SECTION_PATH_LENGTH];
   json_object *pTmpObj = DSL_NULL;

   json_object_object_foreach(pObj, key, val)
   {
      pTmpObj = pObj;
      DSL_CPE_snprintf(currentSectionPath,
         sizeof(currentSectionPath), "%s.%s", pSectionPath, key);

      nType = json_object_get_type(val);

      switch (nType)
      {
      case json_type_array:
         DSL_CPE_JsonParseArray(pTmpObj, key, currentSectionPath, pData);
         break;
      case json_type_object:
         json_object_object_get_ex(pTmpObj, key, &pTmpObj);

         if (pTmpObj != DSL_NULL)
         {
            DSL_CPE_JsonReadObj(pTmpObj, currentSectionPath, pData);
         }
         break;
      case json_type_null:
      case json_type_boolean:
      case json_type_double:
      case json_type_int:
      case json_type_string:
         DSL_CPE_JsonParse(val, currentSectionPath, pData);
         break;
      }
   }
}

static DSL_void_t DSL_CPE_JsonParse(
   json_object * pObj,
   DSL_char_t * pSectionPath,
   DSL_Configuration_t *pData)
{
   enum json_type nType = json_type_null;
   DSL_int_t nIntVal = 0;
   DSL_char_t nStringVal[CONFIG_PARAMETER_STRING_VALUE_LENGTH] = { 0 };
   DSL_boolean_t bFound = DSL_FALSE;

   DSL_CFG_Debugging_t *pDebuggingConfig = &pData->data.sDebuggingConfig;
   DSL_CFG_StartupInit_t *pStartupInitConfig = &pData->data.sStartupInitConfig;
   DSL_CFG_Bitswap_t *pBitswapConfig = &pData->data.sBitswapConfig;
   DSL_CFG_Common_t *pCommonConfig = &pData->data.sCommonConfig;
   DSL_CFG_Retransmission_t *pRetransmissionConfig =
      &pData->data.sRetransmissionConfig;
   DSL_CFG_Sra_t *pSraConfig = &pData->data.sSraConfig;
   DSL_CFG_VirtualNoise_t *pVirtualNoiseConfig =
      &pData->data.sVirtualNoiseConfig;
   DSL_CFG_RebootCriteria_t *pRebootCriteriaConfig =
      &pData->data.sRebootCriteriaConfig;
   DSL_CFG_SystemInterface_t *pSystemIfConfig =
      &pData->data.sSystemIfConfig;
   DSL_CFG_Bonding_t *pBondingConfig =
      &pData->data.sBondingConfig;

   /* We are only interested in Root.DSL section */
   if (strstr(pSectionPath, CONFIG_DSL_CSP_SECTION_PATH) == DSL_NULL)
   {
      return;
   }

   nType = json_object_get_type(pObj);

   DSL_CPE_ConfigInputValidate(pSectionPath, nType);

   switch (nType)
   {
      case json_type_boolean:
      case json_type_int:
         nIntVal = (DSL_int_t)json_object_get_int(pObj);

         DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
            "Configuration Parser: %s: %d" DSL_CPE_CRLF,
            pSectionPath, nIntVal));

         /* Debugging */
         PARSE_SECTION_INT(CONFIG_DEBUGGING_SECTION_PATH,
                           "link_start",
                           pDebuggingConfig->nLinkStart);

         PARSE_SECTION_INT(CONFIG_DEBUGGING_SECTION_PATH,
                           DSL_CSP_CFG_DEBUG_AND_TEST_INTERFACES,
                           pDebuggingConfig->nDebugAndTestInterfaces);

         /* StartupInit */
         PARSE_SECTION_INT(CONFIG_STARTUPINIT_SECTION_PATH,
                           DSL_CSP_CFG_NEXT_MODE,
                           pStartupInitConfig->nNextMode);

         PARSE_SECTION_INT(CONFIG_STARTUPINIT_SECTION_PATH,
                           DSL_CSP_CFG_MAX_DEVICE_NUMBER,
                           pStartupInitConfig->nMaxDeviceNumber);

         PARSE_SECTION_INT(CONFIG_STARTUPINIT_SECTION_PATH,
                           DSL_CSP_CFG_LINES_PER_DEVICE,
                           pStartupInitConfig->nLinesPerDevice);

         PARSE_SECTION_INT(CONFIG_STARTUPINIT_SECTION_PATH,
                           DSL_CSP_CFG_CHANNELS_PER_LINE,
                           pStartupInitConfig->nChannelsPerLine);

         /* Bitswap */
         PARSE_SECTION_INT(CONFIG_BITSWAP_SECTION_PATH,
                           DSL_CSP_CFG_BITSWAP_VDSL_US,
                           pBitswapConfig->Us_Vdsl);

         PARSE_SECTION_INT(CONFIG_BITSWAP_SECTION_PATH,
                           DSL_CSP_CFG_BITSWAP_VDSL_DS,
                           pBitswapConfig->Ds_Vdsl);

         PARSE_SECTION_INT(CONFIG_BITSWAP_SECTION_PATH,
                           DSL_CSP_CFG_BITSWAP_ADSL_US,
                           pBitswapConfig->Us_Adsl);

         PARSE_SECTION_INT(CONFIG_BITSWAP_SECTION_PATH,
                           DSL_CSP_CFG_BITSWAP_ADSL_DS,
                           pBitswapConfig->Ds_Adsl);

         /* Retransmission */
         PARSE_SECTION_INT(CONFIG_RETRANSMISSION_SECTION_PATH,
                           DSL_CSP_CFG_RETX_VDSL_US,
                           pRetransmissionConfig->Us_Vdsl);

         PARSE_SECTION_INT(CONFIG_RETRANSMISSION_SECTION_PATH,
                           DSL_CSP_CFG_RETX_VDSL_DS,
                           pRetransmissionConfig->Ds_Vdsl);

         PARSE_SECTION_INT(CONFIG_RETRANSMISSION_SECTION_PATH,
                           DSL_CSP_CFG_RETX_ADSL_US,
                           pRetransmissionConfig->Us_Adsl);

         PARSE_SECTION_INT(CONFIG_RETRANSMISSION_SECTION_PATH,
                           DSL_CSP_CFG_RETX_ADSL_DS,
                           pRetransmissionConfig->Ds_Adsl);

         /* SRA */
         PARSE_SECTION_INT(CONFIG_SRA_SECTION_PATH,
                           DSL_CSP_CFG_SRA_VDSL_US,
                           pSraConfig->Us_Vdsl);

         PARSE_SECTION_INT(CONFIG_SRA_SECTION_PATH,
                           DSL_CSP_CFG_SRA_VDSL_DS,
                           pSraConfig->Ds_Vdsl);

         PARSE_SECTION_INT(CONFIG_SRA_SECTION_PATH,
                           DSL_CSP_CFG_SRA_ADSL_US,
                           pSraConfig->Us_Adsl);

         PARSE_SECTION_INT(CONFIG_SRA_SECTION_PATH,
                           DSL_CSP_CFG_SRA_ADSL_DS,
                           pSraConfig->Ds_Adsl);

         /* Virtualnoise */
         PARSE_SECTION_INT(CONFIG_VIRTUALNOISE_SECTION_PATH,
                           DSL_CSP_CFG_VN_US,
                           pVirtualNoiseConfig->Us);

         PARSE_SECTION_INT(CONFIG_VIRTUALNOISE_SECTION_PATH,
                           DSL_CSP_CFG_VN_DS,
                           pVirtualNoiseConfig->Ds);

         /* TcLayer */
         PARSE_SECTION_INT(CONFIG_TCLAYER_SECTION_PATH,
                           DSL_CSP_CFG_TC_ADSL,
                           pSystemIfConfig->nTcLayer_Adsl);

         PARSE_SECTION_INT(CONFIG_TCLAYER_SECTION_PATH,
                           DSL_CSP_CFG_TC_VDSL,
                           pSystemIfConfig->nTcLayer_Vdsl);

         /* Bonding */
         if (INCLUDE_DSL_BONDING)
         {
            PARSE_SECTION_INT(CONFIG_BONDING_SECTION_PATH,
                              DSL_CSP_CFG_BONDING_ADSL_PTM,
                              pBondingConfig->nBonding_AdslPtm);

            PARSE_SECTION_INT(CONFIG_BONDING_SECTION_PATH,
                              DSL_CSP_CFG_BONDING_ADSL_ATM,
                              pBondingConfig->nBonding_AdslAtm);

            PARSE_SECTION_INT(CONFIG_BONDING_SECTION_PATH,
                              DSL_CSP_CFG_BONDING_VDSL_PTM,
                              pBondingConfig->nBonding_VdslPtm);

            PARSE_SECTION_INT(CONFIG_BONDING_SECTION_PATH,
                              DSL_CSP_CFG_BONDING_VDSL_ATM,
                              pBondingConfig->nBonding_VdslAtm);
         }

         /* Common */
         PARSE_SECTION_INT(CONFIG_COMMON_SECTION_PATH,
                           DSL_CSP_CFG_OPERATOR_SELECT,
                           pCommonConfig->nOperatorSelect);

         PARSE_SECTION_INT(CONFIG_COMMON_SECTION_PATH,
                           DSL_CSP_CFG_LD_AFE_SHUTDOWN,
                           pCommonConfig->LdAfeShutdown);

         PARSE_SECTION_INT(CONFIG_COMMON_SECTION_PATH,
                           DSL_CSP_CFG_VECTORING_ENABLE,
                           pCommonConfig->VectoringEnable);

         PARSE_SECTION_INT(CONFIG_COMMON_SECTION_PATH,
                           DSL_CSP_CFG_ACTIVATION_SEQUENCE,
                           pCommonConfig->ActSeq);

         PARSE_SECTION_INT(CONFIG_COMMON_SECTION_PATH,
                           DSL_CSP_CFG_ACTIVATION_MODE,
                           pCommonConfig->ActMode);

         PARSE_SECTION_INT(CONFIG_COMMON_SECTION_PATH,
                           DSL_CSP_CFG_REMEMBER,
                           pCommonConfig->Remember);

         PARSE_SECTION_INT(CONFIG_COMMON_SECTION_PATH,
                           DSL_CSP_CFG_FW_MSG_POLLING_ONLY,
                           pCommonConfig->FWMsgPollingOnly);

         if (bFound == DSL_FALSE)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
               "Configuration Parser: Unknown parameter %s" DSL_CPE_CRLF,
               pSectionPath));
         }
         break;
      case json_type_string:
         DSL_CPE_snprintf(nStringVal, sizeof(nStringVal), "%s",
            json_object_get_string(pObj));
         DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
            "Configuration Parser: %s: %s" DSL_CPE_CRLF,
            pSectionPath, nStringVal));

         /* Reboot criteria */
         PARSE_SECTION_HEX(CONFIG_REBOOTCRITERIA_SECTION_PATH,
                           DSL_CSP_CFG_REBOOT_ADSL,
                           pRebootCriteriaConfig->Adsl);

         PARSE_SECTION_HEX(CONFIG_REBOOTCRITERIA_SECTION_PATH,
                           DSL_CSP_CFG_REBOOT_VDSL,
                           pRebootCriteriaConfig->Vdsl);

         /* Common */
         PARSE_SECTION_HEX(CONFIG_COMMON_SECTION_PATH,
                           DSL_CSP_CFG_VDSL_PROFILE,
                           pCommonConfig->VdslProfileVal);

         PARSE_SECTION_HEX(CONFIG_LOWLEVELHSTONES_SECTION_PATH,
                           DSL_CSP_CFG_LOW_LEVEL_HS_TONES_ADSL,
                           pCommonConfig->sLowLevelHsTonesConfig.Adsl);

         PARSE_SECTION_HEX(CONFIG_LOWLEVELHSTONES_SECTION_PATH,
                           DSL_CSP_CFG_LOW_LEVEL_HS_TONES_VDSL,
                           pCommonConfig->sLowLevelHsTonesConfig.Vdsl);

         if (bFound == DSL_FALSE)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
               "Configuration Parser: Unknown parameter %s" DSL_CPE_CRLF,
               pSectionPath));
         }
         break;
      default:
         break;
   }
}

static DSL_void_t DSL_CPE_JsonParseArray(
   json_object * pObj,
   DSL_char_t * pKey,
   DSL_char_t * pSectionPath,
   DSL_Configuration_t *pData)
{
   enum json_type nType = json_type_null;
   json_object * pArrayObj = pObj;
   json_object * pValue = DSL_NULL;
   DSL_char_t currentSectionPath[CONFIG_SECTION_PATH_LENGTH];
   DSL_int_t nArrayLength = 0;
   DSL_char_t nStringVal[CONFIG_PARAMETER_STRING_VALUE_LENGTH] = { 0 };
   unsigned char *pG997XtuVal = pData->data.G997XtuVal;
   DSL_boolean_t bFound = DSL_FALSE;

   if (pKey != DSL_NULL)
   {
      json_object_object_get_ex(pObj, pKey, &pArrayObj);
   }

   nArrayLength = json_object_array_length(pArrayObj);

   DSL_CPE_ConfigInputValidate(pSectionPath, json_object_get_type(pArrayObj));

   for (DSL_int_t i = 0; i < nArrayLength; ++i)
   {
      DSL_CPE_snprintf(currentSectionPath,
         sizeof(currentSectionPath), "%s[%d]", pSectionPath, i);

      pValue = json_object_array_get_idx(pArrayObj, i);
      nType = json_object_get_type(pValue);

      bFound = DSL_FALSE;

      /* check array type just for the first element */
      if (i == 0)
      {
         DSL_CPE_ConfigInputValidate(currentSectionPath, nType);
      }

      switch (nType)
      {
      case json_type_array:
         DSL_CPE_JsonParseArray(pValue, DSL_NULL, currentSectionPath, pData);
         break;
      case json_type_object:
         DSL_CPE_JsonReadObj(pValue, currentSectionPath, pData);
         break;
      case json_type_string:
         DSL_CPE_snprintf(nStringVal, sizeof(nStringVal), "%s",
            json_object_get_string(pValue));

         /* XTSE */
         if (strstr(pSectionPath, CONFIG_XTSE_SECTION_PATH) != DSL_NULL)
         {
            if (i >= DSL_G997_NUM_XTSE_OCTETS)
            {
               DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
                  "Configuration Array Parser: XTSE, index out of range (%d)"
                  DSL_CPE_CRLF, i));
               break;
            }

            PARSE_SECTION_HEX(CONFIG_DSL_CSP_SECTION_PATH, "xtse",
               pG997XtuVal[i]);
         }
         break;
      case json_type_null:
      case json_type_boolean:
      case json_type_double:
      case json_type_int:
      default:
         break;
      }
   }
}

/**
   Create backup of current working configuration
*/
static DSL_Error_t DSL_CPE_ConfigBackupCreate(
   const DSL_CPE_Control_Context_t *pCtrlCtx,
   DSL_Configuration_t *pBackupConfiguration)
{
   DSL_Error_t nRet = DSL_SUCCESS, nErrCode = DSL_SUCCESS;
   DSL_Configuration_t sBackupConfiguration =
      { DSL_CPE_CONFIGURATION_TYPE_BACKUP, { { CONFIGURATION_VALUE_UNDEFINED } } };

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_ConfigBackupCreate" DSL_CPE_CRLF));

   if (pCtrlCtx == DSL_NULL)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - Invalid context pointer!" DSL_CPE_CRLF));
      return DSL_ERROR;
   }

   /* sets XTSE to invalid values */
   memset(sBackupConfiguration.data.G997XtuVal, 0, DSL_G997_NUM_XTSE_OCTETS);

   cpe_control_memcpy_s(
      pBackupConfiguration, sizeof(DSL_Configuration_t),
      &sBackupConfiguration, sizeof(DSL_Configuration_t));

   /* in bonding case
      first device configuration
      will be overwritten by second one */
   for (int nDevice = 0; nDevice < DSL_CPE_DSL_ENTITIES; ++nDevice)
   {
      nRet = DSL_CPE_LowLevelCfgBackup(pCtrlCtx, nDevice,
                                       pBackupConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      nRet = DSL_CPE_LineFeatureCfgBackup(pCtrlCtx, nDevice,
                                          pBackupConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      nRet = DSL_CPE_RebootCriteriaCfgBackup(pCtrlCtx, nDevice,
                                             pBackupConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      nRet = DSL_CPE_VdslProfileCfgBackup(pCtrlCtx, nDevice,
                                          pBackupConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      nRet = DSL_CPE_G997_RateAdaptationCfgBackup(pCtrlCtx, nDevice,
                                                  pBackupConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      nRet = DSL_CPE_SysIfCfgBackup(pCtrlCtx, nDevice,
                                    pBackupConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      nRet = DSL_CPE_XtseCfgBackup(pCtrlCtx, nDevice,
                                   pBackupConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

#if defined(INCLUDE_DSL_CPE_API_VRX)
      nRet = DSL_CPE_VectoringEnableCfgBackup(nDevice, pBackupConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }
#endif

      nRet = DSL_CPE_FwMessagePollingCfgBackup(pCtrlCtx, nDevice,
                                               pBackupConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      nRet = DSL_CPE_OperatorSelectCfgBackup(pCtrlCtx, nDevice,
                                             pBackupConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_ConfigBackupCreate, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/**
   Read configuration from the config file
*/
static DSL_Error_t DSL_CPE_ConfigRead(
   DSL_CPE_ConfigStatus_t **ppConfigurationStatus)
{
   DSL_Error_t nRet, nErrCode = DSL_SUCCESS;
   DSL_Configuration_t sUndefinedConfiguration =
      { DSL_CPE_CONFIGURATION_TYPE_UNSET, { { CONFIGURATION_VALUE_UNDEFINED } } };

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_ConfigRead" DSL_CPE_CRLF));

   /* in case status parser not take ownership
      delete old data before creating a new one */
   DSL_CPE_ConfigStatusDelete(ppConfigurationStatus);

   /* sets XTSE to invalid values */
   memset(sUndefinedConfiguration.data.G997XtuVal,
      0, DSL_G997_NUM_XTSE_OCTETS);

   cpe_control_memcpy_s(
      &g_sConfiguration, sizeof(DSL_Configuration_t),
      &sUndefinedConfiguration, sizeof(DSL_Configuration_t));

   if ((nRet = DSL_CPE_JsonParseConfigFile(g_pJsonConfigPath,
         &g_sConfiguration)) == DSL_ERROR)
   {
      nErrCode = nRet;

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - Parsing configuration file failed!" DSL_CPE_CRLF));
   }

   if ((nRet = DSL_CPE_ConfigStatusCollect(&g_pFinalStatusEntriesList,
         &g_pRecognizedEntriesList, &g_pUnrecognizedEntriesList, DSL_NULL)) ==
       DSL_ERROR)
   {
      nErrCode = nRet;

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - Validating configuration file failed!" DSL_CPE_CRLF));
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_ConfigRead, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

static DSL_boolean_t DSL_CPE_AutobootScriptsExistCheck(
   DSL_void_t)
{
   DSL_boolean_t bExist = DSL_FALSE;

#ifdef INCLUDE_DSL_CPE_CMV_SCRIPTS_SUPPORT
   if ((g_sAdslScript != DSL_NULL) && (strlen(g_sAdslScript) > 0))
   {
      bExist = DSL_TRUE;
   }

#if defined(INCLUDE_DSL_CPE_API_VRX)
   if (bExist == DSL_FALSE &&
       (g_sVdslScript != DSL_NULL) && (strlen(g_sVdslScript) > 0))
   {
      bExist = DSL_TRUE;
   }
#endif /* defined(INCLUDE_DSL_CPE_API_VRX) */

#endif /* INCLUDE_DSL_CPE_CMV_SCRIPTS_SUPPORT */

   return bExist;
}

/**
   Set Autoboot stop points
   to avoid unwated side effects during reconfiguration.
*/
static DSL_Error_t DSL_CPE_AutobootLock(
   const DSL_CPE_Control_Context_t *pCtrlCtx,
   DSL_CPE_AutobootLockContext_t *pLockCtx)
{
   DSL_Error_t nRet, nErrCode = DSL_SUCCESS;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_AutobootLock" DSL_CPE_CRLF));

   CONFIG_CHANGE_ONGOING_FLAG(DSL_TRUE);

   for (DSL_int32_t nDevice = 0; nDevice < DSL_CPE_DSL_ENTITIES; ++nDevice)
   {
      DSL_AutobootConfig_t autobootConfig = { 0 };

      /* preserve system's current settings */
#ifdef INCLUDE_DSL_CPE_CMV_SCRIPTS_SUPPORT
      pLockCtx->bAutoContinueWaitBeforeConfigWrite[nDevice] =
         g_bAutoContinueWaitBeforeConfigWrite[nDevice];
      pLockCtx->bAutoContinueWaitBeforeLinkActivation[nDevice] =
         g_bAutoContinueWaitBeforeLinkActivation[nDevice];
      pLockCtx->bAutoContinueWaitBeforeRestart[nDevice] =
         g_bAutoContinueWaitBeforeRestart[nDevice];
#endif /* INCLUDE_DSL_CPE_CMV_SCRIPTS_SUPPORT */
      pLockCtx->bWaitBeforeConfigWrite[nDevice] =
         g_bWaitBeforeConfigWrite[nDevice];
      pLockCtx->bWaitBeforeLinkActivation[nDevice] =
         g_bWaitBeforeLinkActivation[nDevice];
      pLockCtx->bWaitBeforeRestart[nDevice] =
         g_bWaitBeforeRestart[nDevice];

      /* pause Autoboot */
#ifdef INCLUDE_DSL_CPE_CMV_SCRIPTS_SUPPORT
      g_bAutoContinueWaitBeforeConfigWrite[nDevice] = DSL_FALSE;
      g_bAutoContinueWaitBeforeLinkActivation[nDevice] = DSL_FALSE;
      g_bAutoContinueWaitBeforeRestart[nDevice] = DSL_FALSE;
#endif /* INCLUDE_DSL_CPE_CMV_SCRIPTS_SUPPORT */
      g_bWaitBeforeConfigWrite[nDevice] = DSL_TRUE;
      g_bWaitBeforeLinkActivation[nDevice] = DSL_TRUE;
      g_bWaitBeforeRestart[nDevice] = DSL_TRUE;

      autobootConfig.data.nStateMachineOptions.bWaitBeforeConfigWrite =
         g_bWaitBeforeConfigWrite[nDevice];
      autobootConfig.data.nStateMachineOptions.bWaitBeforeLinkActivation =
         g_bWaitBeforeLinkActivation[nDevice];
      autobootConfig.data.nStateMachineOptions.bWaitBeforeRestart =
         g_bWaitBeforeRestart[nDevice];

      nRet = DSL_CPE_Ioctl(pCtrlCtx->fd[nDevice],
               DSL_FIO_AUTOBOOT_CONFIG_SET,
               (int) &autobootConfig);

      /* store error code in case of failure */
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;

         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - DSL_FIO_AUTOBOOT_CONFIG_SET ioctl failed, "
            "error=%d dev=%d!" DSL_CPE_CRLF,
            nRet, nDevice));
      }

      /* on failure print additional debug info */
      if (autobootConfig.accessCtl.nReturn)
      {
         DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
            "WARNING - DSL_FIO_AUTOBOOT_CONFIG_SET "
            "access control retCode=%d dev=%d!" DSL_CPE_CRLF,
            autobootConfig.accessCtl.nReturn, nDevice));
      }
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_AutobootLock, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/**
   Unset Autoboot stop points
   to allow normal operation after reconfiguration.
*/
static DSL_Error_t DSL_CPE_AutobootUnlock(
   const DSL_CPE_Control_Context_t *pCtrlCtx,
   const DSL_CPE_AutobootLockContext_t *pLockCtx)
{
   DSL_Error_t nRet, nErrCode = DSL_SUCCESS;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_AutobootUnlock" DSL_CPE_CRLF));

   for (DSL_int32_t nDevice = 0; nDevice < DSL_CPE_DSL_ENTITIES; ++nDevice)
   {
      DSL_AutobootConfig_t autobootConfig = { 0 };
      DSL_AutobootStatus_t autobootStatus = { 0 };

      /* restore system's previous settings */
#ifdef INCLUDE_DSL_CPE_CMV_SCRIPTS_SUPPORT
      g_bAutoContinueWaitBeforeConfigWrite[nDevice] =
         pLockCtx->bAutoContinueWaitBeforeConfigWrite[nDevice];
      g_bAutoContinueWaitBeforeLinkActivation[nDevice] =
         pLockCtx->bAutoContinueWaitBeforeLinkActivation[nDevice];
      g_bAutoContinueWaitBeforeRestart[nDevice] =
         pLockCtx->bAutoContinueWaitBeforeRestart[nDevice];
#endif /* INCLUDE_DSL_CPE_CMV_SCRIPTS_SUPPORT */
      g_bWaitBeforeConfigWrite[nDevice] =
         pLockCtx->bWaitBeforeConfigWrite[nDevice];
      g_bWaitBeforeLinkActivation[nDevice] =
         pLockCtx->bWaitBeforeLinkActivation[nDevice];
      g_bWaitBeforeRestart[nDevice] =
         pLockCtx->bWaitBeforeRestart[nDevice];

      /* unpause Autoboot */
      autobootConfig.data.nStateMachineOptions.bWaitBeforeConfigWrite =
         g_bWaitBeforeConfigWrite[nDevice];
      autobootConfig.data.nStateMachineOptions.bWaitBeforeLinkActivation =
         g_bWaitBeforeLinkActivation[nDevice];
      autobootConfig.data.nStateMachineOptions.bWaitBeforeRestart =
         g_bWaitBeforeRestart[nDevice];

      nRet = DSL_CPE_Ioctl(pCtrlCtx->fd[nDevice],
               DSL_FIO_AUTOBOOT_CONFIG_SET,
               (int) &autobootConfig);

      /* store error code in case of failure */
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;

         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - DSL_FIO_AUTOBOOT_CONFIG_SET ioctl failed, "
            "error=%d dev=%d!" DSL_CPE_CRLF,
            nRet, nDevice));
      }

      /* on failure print additional debug info */
      if (autobootConfig.accessCtl.nReturn)
      {
         DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
            "WARNING - DSL_FIO_AUTOBOOT_CONFIG_SET "
            "access control retCode=%d dev=%d!" DSL_CPE_CRLF,
            autobootConfig.accessCtl.nReturn, nDevice));
      }

      nRet = DSL_CPE_Ioctl(pCtrlCtx->fd[nDevice],
               DSL_FIO_AUTOBOOT_STATUS_GET,
               (int) &autobootStatus);

      /* store error code in case of failure */
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;

         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - DSL_FIO_AUTOBOOT_STATUS_GET ioctl failed, "
            "error=%d dev=%d!" DSL_CPE_CRLF,
            nRet, nDevice));
      }
      else
      {
         if (autobootStatus.data.nStatus == DSL_AUTOBOOT_STATUS_CONFIG_WRITE_WAIT ||
             autobootStatus.data.nStatus == DSL_AUTOBOOT_STATUS_LINK_ACTIVATE_WAIT ||
             autobootStatus.data.nStatus == DSL_AUTOBOOT_STATUS_RESTART_WAIT)
         {
            DSL_AutobootControl_t autobootControl = { 0 };

            DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
               "Autoboot status=%d" DSL_CPE_CRLF,
               autobootStatus.data.nStatus));

            if (DSL_CPE_AutobootScriptsExistCheck() == DSL_TRUE)
            {
               autobootControl.data.nCommand = DSL_AUTOBOOT_CTRL_RESTART;
            }
            else
            {
               autobootControl.data.nCommand = DSL_AUTOBOOT_CTRL_CONTINUE;
            }

            nRet = DSL_CPE_Ioctl(pCtrlCtx->fd[nDevice],
                     DSL_FIO_AUTOBOOT_CONTROL_SET,
                     (int) &autobootControl.data.nCommand);

            /* store error code in case of failure */
            if (nRet != DSL_SUCCESS)
            {
               nErrCode = nRet;

               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                  "ERROR - DSL_FIO_AUTOBOOT_CONTROL_SET ioctl failed, "
                  "error=%d dev=%d!" DSL_CPE_CRLF,
                  nRet, nDevice));
            }

            /* on failure print additional debug info */
            if (autobootControl.accessCtl.nReturn)
            {
               DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
                  "WARNING - DSL_FIO_AUTOBOOT_CONTROL_SET "
                  "access control retCode=%d dev=%d!" DSL_CPE_CRLF,
                  autobootControl.accessCtl.nReturn, nDevice));
            }
         }
      }

      /* on failure print additional debug info */
      if (autobootStatus.accessCtl.nReturn)
      {
         DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
            "WARNING - DSL_FIO_AUTOBOOT_STATUS_GET "
            "access control retCode=%d dev=%d!" DSL_CPE_CRLF,
            autobootStatus.accessCtl.nReturn, nDevice));
      }
   }

   CONFIG_CHANGE_ONGOING_FLAG(DSL_FALSE);

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_AutobootUnlock, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/**
   Execute autoboot restart (apply new configuration to the line(s))
*/
static DSL_void_t DSL_CPE_AutobootRestart(
   const DSL_CPE_Control_Context_t* pCtrlCtx)
{
   DSL_int_t nRet = 0, nDevice = 0;
   DSL_AutobootControl_t pAcs;

   for (nDevice = 0; nDevice < DSL_CPE_DSL_ENTITIES; ++nDevice)
   {
      memset(&pAcs, 0x0, sizeof(DSL_AutobootControl_t));
      /* Restat Autoboot handling*/
      pAcs.data.nCommand = DSL_AUTOBOOT_CTRL_RESTART;

      nRet = DSL_CPE_Ioctl(pCtrlCtx->fd[nDevice],
         DSL_FIO_AUTOBOOT_CONTROL_SET, (DSL_int_t)&pAcs);
      if (nRet < 0)
      {
         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - Configuration Parser: DSL_FIO_AUTOBOOT_CONTROL_SET ioctl "
            "failed, operation=RESTART, error=%d dev=%d!" DSL_CPE_CRLF,
            nRet, nDevice));
      }
   }
}

/**
   Execute config update
*/
static DSL_Error_t DSL_CPE_ConfigValidateAndApply(
   const DSL_CPE_Control_Context_t *pCtrlCtx,
   const DSL_Configuration_t *pConfiguration)
{
   DSL_Error_t nRet = DSL_SUCCESS, nErrCode = DSL_SUCCESS;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_ConfigValidateAndApply" DSL_CPE_CRLF));

   if (pCtrlCtx == DSL_NULL)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - Invalid context pointer!" DSL_CPE_CRLF));
      return DSL_ERROR;
   }

   if (pConfiguration == DSL_NULL)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - Invalid configuration pointer!" DSL_CPE_CRLF));
      return DSL_ERROR;
   }

   for (int nDevice = 0; nDevice < DSL_CPE_DSL_ENTITIES; ++nDevice)
   {
      nRet = DSL_CPE_LowLevelCfgValidateAndApply(pCtrlCtx, nDevice,
                                                 pConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      nRet = DSL_CPE_LineFeatureCfgValidateAndApply(pCtrlCtx, nDevice,
                                                    pConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      nRet = DSL_CPE_RebootCriteriaCfgValidateAndApply(pCtrlCtx, nDevice,
                                                       pConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      nRet = DSL_CPE_VdslProfileCfgValidateAndApply(pCtrlCtx, nDevice,
                                                    pConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      nRet = DSL_CPE_G997_RateAdaptationCfgValidateAndApply(pCtrlCtx, nDevice,
                                                            pConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      nRet = DSL_CPE_SysIfCfgValidateAndApply(pCtrlCtx, nDevice,
                                              pConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      /* NOTE: a bonding configuration must be always applied after the system
         interface configuration (SysIf) in order to make use of the related
         API internal configuration consistency checks in the most effective
         way */
      if (INCLUDE_DSL_BONDING)
      {
         nRet = DSL_CPE_BondingCfgValidateAndApply(pCtrlCtx, nDevice,
                                              pConfiguration);
         if (nRet != DSL_SUCCESS)
         {
            nErrCode = nRet;
         }
      }

      nRet = DSL_CPE_XtseCfgValidateAndApply(pCtrlCtx, nDevice,
                                             pConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

#if defined(INCLUDE_DSL_CPE_API_VRX)
      nRet = DSL_CPE_VectoringEnableCfgValidateAndApply(nDevice, pConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }
#endif

      nRet = DSL_CPE_FwMessagePollingCfgValidateAndApply(pCtrlCtx, nDevice,
                                                         pConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }

      nRet = DSL_CPE_OperatorSelectCfgValidateAndApply(pCtrlCtx, nDevice,
                                                       pConfiguration);
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;
      }
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_ConfigValidateAndApply, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function validates and applies device LowLevel configuration
   taken from the config file

   \param pControlContext     Pointer to DSL CPE Control context structure, [I]
   \param nDevNum             Number of device for configuration, [I]
   \param pConfiguration      Pointer to DSL configuration structure, [I]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_LowLevelCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration)
{
   DSL_Error_t nErrCode = DSL_SUCCESS;
   DSL_Error_t nRangeCheck = DSL_SUCCESS;
   DSL_LowLevelConfiguration_t sLowLevelCfg = { 0 };
   DSL_CFG_LowLevelHsTones_t sCFGLowLevelHsTones;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_LowLevelCfgValidateAndApply, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   sCFGLowLevelHsTones =
      pConfiguration->data.sCommonConfig.sLowLevelHsTonesConfig;

   CONFIG_PARAM_RANGE_VALIDATION(
      sCFGLowLevelHsTones.Adsl,
      CONFIG_DSL_COMMON_LOWLEVELHSTONES_ADSL,
      DSL_DEV_HS_TONE_GROUP_CLEANED,
      DSL_DEV_HS_TONE_GROUP_ADSL2_A43C);
   CONFIG_PARAM_RANGE_VALIDATION(
      sCFGLowLevelHsTones.Vdsl,
      CONFIG_DSL_COMMON_LOWLEVELHSTONES_VDSL,
      DSL_DEV_HS_TONE_GROUP_CLEANED,
      DSL_DEV_HS_TONE_GROUP_ADSL2_A43C);

   if (nRangeCheck != DSL_SUCCESS)
      return nRangeCheck;

   if (sCFGLowLevelHsTones.Adsl == DSL_DEV_HS_TONE_GROUP_CLEANED &&
       sCFGLowLevelHsTones.Vdsl == DSL_DEV_HS_TONE_GROUP_CLEANED)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
         "API default handshake tones will be used." DSL_CPE_CRLF));

      return nErrCode;
   }

   nErrCode = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_LOW_LEVEL_CONFIGURATION_GET,
                  (int) &sLowLevelCfg);

   if (nErrCode == DSL_SUCCESS)
   {
      if (sCFGLowLevelHsTones.Adsl > DSL_DEV_HS_TONE_GROUP_CLEANED ||
         sCFGLowLevelHsTones.Vdsl > DSL_DEV_HS_TONE_GROUP_CLEANED)
      {
         CONFIG_PARAM_APPLY(
            sLowLevelCfg.data.nHsToneGroupMode,
            DSL_DEV_HS_TONE_GROUP_MODE_MANUAL);
         CONFIG_PARAM_APPLY(
            sLowLevelCfg.data.nHsToneGroup_AV,
            DSL_DEV_HS_TONE_GROUP_CLEANED);
      }
      else
      {
         CONFIG_PARAM_APPLY(
            sLowLevelCfg.data.nHsToneGroupMode,
            DSL_DEV_HS_TONE_GROUP_MODE_AUTO);
      }

      if (sCFGLowLevelHsTones.Adsl > DSL_DEV_HS_TONE_GROUP_CLEANED)
      {
         CONFIG_PARAM_APPLY(
            sLowLevelCfg.data.nHsToneGroup_A,
            sCFGLowLevelHsTones.Adsl);
      }
      if (sCFGLowLevelHsTones.Vdsl > DSL_DEV_HS_TONE_GROUP_CLEANED)
      {
         CONFIG_PARAM_APPLY(
            sLowLevelCfg.data.nHsToneGroup_V,
            sCFGLowLevelHsTones.Vdsl);
      }

      nErrCode = DSL_CPE_Ioctl(
                     pControlContext->fd[nDevNum],
                     DSL_FIO_LOW_LEVEL_CONFIGURATION_SET,
                     (int) &sLowLevelCfg);

      if (nErrCode != DSL_SUCCESS)
      {
         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - DSL_FIO_LOW_LEVEL_CONFIGURATION_SET ioctl failed, "
            "error=%d!" DSL_CPE_CRLF,
            nErrCode));
      }
   }
   else
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_LOW_LEVEL_CONFIGURATION_GET ioctl failed, "
         "error=%d!" DSL_CPE_CRLF,
         nErrCode));
   }

   /* on failure print additional debug info */
   if (sLowLevelCfg.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - DSL_FIO_LOW_LEVEL_CONFIGURATION "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sLowLevelCfg.accessCtl.nReturn));
   }

   /* Collect configuration status information */
   if (nErrCode != DSL_SUCCESS)
   {
      DSL_CPE_ConfigEntryAppliedValueType_u applyVal;

      memset(&applyVal, 0, sizeof(applyVal));
      applyVal.iVal = pConfiguration->data.sCommonConfig.sLowLevelHsTonesConfig.Adsl;

      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_COMMON_LOWLEVELHSTONES_ADSL,
         applyVal,
         sLowLevelCfg.accessCtl.nReturn);

      memset(&applyVal, 0, sizeof(applyVal));
      applyVal.iVal = pConfiguration->data.sCommonConfig.sLowLevelHsTonesConfig.Vdsl;

      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_COMMON_LOWLEVELHSTONES_VDSL,
         applyVal,
         sLowLevelCfg.accessCtl.nReturn);
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_LowLevelCfgValidateAndApply, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function validates and applies LineFeature configuration
   taken from the config file

   \param pControlContext     Pointer to DSL CPE Control context structure, [I]
   \param nDevNum             Number of device for configuration, [I]
   \param pConfiguration      Pointer to DSL configuration structure, [I]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_LineFeatureCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration)
{
   DSL_Error_t nRet = DSL_SUCCESS, nErrCode = DSL_SUCCESS;
   DSL_Error_t nRangeCheck = DSL_SUCCESS;
   DSL_LineFeature_t sLineFeature = { 0 };
   DSL_CFG_Bitswap_t sCFGBitswap;
   DSL_CFG_Retransmission_t sCFGRetransmission;
   DSL_CFG_VirtualNoise_t sCFGVirtualNoise;
   DSL_DslModeSelection_t dslMode = DSL_MODE_NA;
   DSL_AccessDir_t accessDir = DSL_ACCESSDIR_NA;
   /* Configuration of retransmission setting:
         0: Disable retransmission
         1: Enable retransmission
         2: Use API internal default configuration */
   const DSL_uint8_t CONFIG_MIN_RETX_VAL = 0;
   const DSL_uint8_t CONFIG_MAX_RETX_VAL = 2;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_LineFeatureCfgValidateAndApply, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   sCFGBitswap = pConfiguration->data.sBitswapConfig;
   sCFGRetransmission = pConfiguration->data.sRetransmissionConfig;
   sCFGVirtualNoise = pConfiguration->data.sVirtualNoiseConfig;

   CONFIG_PARAM_RANGE_VALIDATION(
      sCFGRetransmission.Us_Adsl,
      CONFIG_DSL_RETRANSMISSION_ADSL_US,
      CONFIG_MIN_RETX_VAL,
      CONFIG_MAX_RETX_VAL);
   CONFIG_PARAM_RANGE_VALIDATION(
      sCFGRetransmission.Ds_Adsl,
      CONFIG_DSL_RETRANSMISSION_ADSL_DS,
      CONFIG_MIN_RETX_VAL,
      CONFIG_MAX_RETX_VAL);
   CONFIG_PARAM_RANGE_VALIDATION(
      sCFGRetransmission.Us_Vdsl,
      CONFIG_DSL_RETRANSMISSION_VDSL_US,
      CONFIG_MIN_RETX_VAL,
      CONFIG_MAX_RETX_VAL);
   CONFIG_PARAM_RANGE_VALIDATION(
      sCFGRetransmission.Ds_Vdsl,
      CONFIG_DSL_RETRANSMISSION_VDSL_DS,
      CONFIG_MIN_RETX_VAL,
      CONFIG_MAX_RETX_VAL);

   if (nRangeCheck != DSL_SUCCESS)
      return nRangeCheck;

   /* Use API internal default configuration */
   if (sCFGRetransmission.Us_Adsl == CONFIG_MAX_RETX_VAL)
      sCFGRetransmission.Us_Adsl = 0;

   if (sCFGRetransmission.Ds_Adsl == CONFIG_MAX_RETX_VAL)
      sCFGRetransmission.Ds_Adsl = 0;

   if (sCFGRetransmission.Us_Vdsl == CONFIG_MAX_RETX_VAL)
      sCFGRetransmission.Us_Vdsl = 1;

   if (sCFGRetransmission.Ds_Vdsl == CONFIG_MAX_RETX_VAL)
      sCFGRetransmission.Ds_Vdsl = 1;

   for (dslMode = DSL_MODE_ADSL; dslMode < DSL_MODE_LAST; ++dslMode)
   {
      for (accessDir = DSL_UPSTREAM;
           accessDir < DSL_ACCESSDIR_LAST;
           ++accessDir)
      {
         memset(&sLineFeature, 0x0, sizeof(DSL_LineFeature_t));
         sLineFeature.nDslMode = dslMode;
         sLineFeature.nDirection = accessDir;

         nRet = DSL_CPE_Ioctl(
                     pControlContext->fd[nDevNum],
                     DSL_FIO_LINE_FEATURE_CONFIG_GET,
                     (int) &sLineFeature);

         if (nRet == DSL_SUCCESS)
         {
            if (dslMode == DSL_MODE_ADSL)
            {
               if (accessDir == DSL_UPSTREAM)
               {
                  CONFIG_PARAM_APPLY(
                     sLineFeature.data.bBitswapEnable,
                     (DSL_int32_t)(sCFGBitswap.Us_Adsl));
                  CONFIG_PARAM_APPLY(
                     sLineFeature.data.bReTxEnable,
                     sCFGRetransmission.Us_Adsl);
                  CONFIG_PARAM_APPLY(
                     sLineFeature.data.bVirtualNoiseSupport,
                     (DSL_int32_t)(sCFGVirtualNoise.Us));
               }
               else
               {
                  CONFIG_PARAM_APPLY(
                     sLineFeature.data.bBitswapEnable,
                     (DSL_int32_t)(sCFGBitswap.Ds_Adsl));
                  CONFIG_PARAM_APPLY(
                     sLineFeature.data.bReTxEnable,
                     sCFGRetransmission.Ds_Adsl);
                  CONFIG_PARAM_APPLY(
                     sLineFeature.data.bVirtualNoiseSupport,
                     (DSL_int32_t)(sCFGVirtualNoise.Ds));
               }
            }
#if defined(INCLUDE_DSL_CPE_API_VRX)
            else
            {
               if (accessDir == DSL_UPSTREAM)
               {
                  CONFIG_PARAM_APPLY(
                     sLineFeature.data.bBitswapEnable,
                     (DSL_int32_t)(sCFGBitswap.Us_Vdsl));
                  CONFIG_PARAM_APPLY(
                     sLineFeature.data.bReTxEnable,
                     sCFGRetransmission.Us_Vdsl);
                  CONFIG_PARAM_APPLY(
                     sLineFeature.data.bVirtualNoiseSupport,
                     (DSL_int32_t)(sCFGVirtualNoise.Us));
               }
               else
               {
                  CONFIG_PARAM_APPLY(
                     sLineFeature.data.bBitswapEnable,
                     (DSL_int32_t)(sCFGBitswap.Ds_Vdsl));
                  CONFIG_PARAM_APPLY(
                     sLineFeature.data.bReTxEnable,
                     sCFGRetransmission.Ds_Vdsl);
                  CONFIG_PARAM_APPLY(
                     sLineFeature.data.bVirtualNoiseSupport,
                     (DSL_int32_t)(sCFGVirtualNoise.Ds));
               }
            }
#endif /* INCLUDE_DSL_CPE_API_VRX */

            nRet = DSL_CPE_Ioctl(
                        pControlContext->fd[nDevNum],
                        DSL_FIO_LINE_FEATURE_CONFIG_SET,
                        (int) &sLineFeature);

            if (nRet != DSL_SUCCESS)
            {
               nErrCode = nRet;

               DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
                 "ERROR - DSL_FIO_LINE_FEATURE_CONFIG_SET ioctl failed, "
                  "error=%d!" DSL_CPE_CRLF,
                  nRet));
            }
         }
         else
         {
            nErrCode = nRet;

            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_LINE_FEATURE_CONFIG_GET ioctl failed, "
               "error=%d!" DSL_CPE_CRLF,
               nRet));
         }

         /* on failure print additional debug info */
         if (sLineFeature.accessCtl.nReturn)
         {
            nRet = sLineFeature.accessCtl.nReturn;

            DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
               "WARNING - DSL_FIO_LINE_FEATURE_CONFIG "
               "access control retCode=%d!" DSL_CPE_CRLF,
               sLineFeature.accessCtl.nReturn));
         }

         /* Collect configuration status information */
         if (nRet != DSL_SUCCESS)
         {
            DSL_CPE_ConfigEntryAppliedValueType_u applyVal;

            if (dslMode == DSL_MODE_ADSL &&
                accessDir == DSL_UPSTREAM)
            {
               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.bVal = pConfiguration->data.sBitswapConfig.Us_Adsl;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_BITSWAP_ADSL_US,
                  applyVal,
                  nRet);

               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.iVal = pConfiguration->data.sRetransmissionConfig.Us_Adsl;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_RETRANSMISSION_ADSL_US,
                  applyVal,
                  nRet);

               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.bVal = pConfiguration->data.sVirtualNoiseConfig.Us;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_VIRTUALNOISE_US,
                  applyVal,
                  nRet);
            }
            else if (dslMode == DSL_MODE_ADSL &&
                     accessDir == DSL_DOWNSTREAM)
            {
               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.bVal = pConfiguration->data.sBitswapConfig.Ds_Adsl;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_BITSWAP_ADSL_DS,
                  applyVal,
                  nRet);

               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.iVal = pConfiguration->data.sRetransmissionConfig.Ds_Adsl;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_RETRANSMISSION_ADSL_DS,
                  applyVal,
                  nRet);

               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.bVal = pConfiguration->data.sVirtualNoiseConfig.Ds;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_VIRTUALNOISE_DS,
                  applyVal,
                  nRet);
            }
            else if (dslMode == DSL_MODE_VDSL &&
                     accessDir == DSL_UPSTREAM)
            {
               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.bVal = pConfiguration->data.sBitswapConfig.Us_Vdsl;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_BITSWAP_VDSL_US,
                  applyVal,
                  nRet);

               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.iVal = pConfiguration->data.sRetransmissionConfig.Us_Vdsl;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_RETRANSMISSION_VDSL_US,
                  applyVal,
                  nRet);

               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.bVal = pConfiguration->data.sVirtualNoiseConfig.Us;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_VIRTUALNOISE_US,
                  applyVal,
                  nRet);
            }
            else if (dslMode == DSL_MODE_VDSL &&
                     accessDir == DSL_DOWNSTREAM)
            {
               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.bVal = pConfiguration->data.sBitswapConfig.Ds_Vdsl;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_BITSWAP_VDSL_DS,
                  applyVal,
                  nRet);

               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.iVal = pConfiguration->data.sRetransmissionConfig.Ds_Vdsl;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_RETRANSMISSION_VDSL_DS,
                  applyVal,
                  nRet);

               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.bVal = pConfiguration->data.sVirtualNoiseConfig.Ds;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_VIRTUALNOISE_DS,
                  applyVal,
                  nRet);
            }
         }
      }
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_LineFeatureCfgValidateAndApply, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function validates and applies Reboot configuration
   taken from the config file

   \param pControlContext     Pointer to DSL CPE Control context structure, [I]
   \param nDevNum             Number of device for configuration, [I]
   \param pConfiguration      Pointer to DSL configuration structure, [I]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_RebootCriteriaCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration)
{
   DSL_Error_t nRet = DSL_SUCCESS, nErrCode = DSL_SUCCESS;
   DSL_Error_t nRangeCheck = DSL_SUCCESS;
   DSL_RebootCriteriaConfig_t sRebootCriteriaConfig;
   DSL_CFG_RebootCriteria_t sCFGRebootCriteria = { 0 };

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_RebootCfgValidateAndApply, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   sCFGRebootCriteria = pConfiguration->data.sRebootCriteriaConfig;

   CONFIG_PARAM_RANGE_VALIDATION(
      sCFGRebootCriteria.Adsl,
      CONFIG_DSL_REBOOTCRITERIA_ADSL,
      DSL_REBOOT_CRITERIA_CLEANED,
      DSL_REBOOT_CRITERIA_LCD_BC1);
   CONFIG_PARAM_RANGE_VALIDATION(
      sCFGRebootCriteria.Vdsl,
      CONFIG_DSL_REBOOTCRITERIA_VDSL,
      DSL_REBOOT_CRITERIA_CLEANED,
      DSL_REBOOT_CRITERIA_LCD_BC1);

   if (nRangeCheck != DSL_SUCCESS)
      return nRangeCheck;

   memset(&sRebootCriteriaConfig, 0x0, sizeof(DSL_RebootCriteriaConfig_t));
   sRebootCriteriaConfig.nDslMode = DSL_MODE_ADSL;

   CONFIG_PARAM_APPLY(
      sRebootCriteriaConfig.data.nRebootCriteria,
      sCFGRebootCriteria.Adsl);

   nRet = DSL_CPE_Ioctl(
               pControlContext->fd[nDevNum],
               DSL_FIO_REBOOT_CRITERIA_CONFIG_SET,
               (int) &sRebootCriteriaConfig);

   /* store error code in case of failure */
   if (nRet != DSL_SUCCESS)
   {
      nErrCode = nRet;

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_REBOOT_CRITERIA_CONFIG_SET ioctl failed, "
         "error=%d!" DSL_CPE_CRLF,
         nRet));
   }

   /* on failure print additional debug info */
   if (sRebootCriteriaConfig.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - DSL_FIO_REBOOT_CRITERIA_CONFIG "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sRebootCriteriaConfig.accessCtl.nReturn));
   }

   /* Collect configuration status information */
   if (nRet != DSL_SUCCESS)
   {
      DSL_CPE_ConfigEntryAppliedValueType_u applyVal;

      memset(&applyVal, 0, sizeof(applyVal));
      applyVal.iVal = pConfiguration->data.sRebootCriteriaConfig.Adsl;

      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_REBOOTCRITERIA_ADSL,
         applyVal,
         sRebootCriteriaConfig.accessCtl.nReturn);
   }

#if defined(INCLUDE_DSL_CPE_API_VRX)
   memset(&sRebootCriteriaConfig, 0x0, sizeof(DSL_RebootCriteriaConfig_t));
   sRebootCriteriaConfig.nDslMode = DSL_MODE_VDSL;

   CONFIG_PARAM_APPLY(
      sRebootCriteriaConfig.data.nRebootCriteria,
      sCFGRebootCriteria.Vdsl);

   nRet = DSL_CPE_Ioctl(
               pControlContext->fd[nDevNum],
               DSL_FIO_REBOOT_CRITERIA_CONFIG_SET,
               (int) &sRebootCriteriaConfig);

   /* store error code in case of failure */
   if (nRet != DSL_SUCCESS)
   {
      nErrCode = nRet;

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_REBOOT_CRITERIA_CONFIG_SET ioctl failed, "
         "error=%d!" DSL_CPE_CRLF,
         nRet));
   }

   /* on failure print additional debug info */
   if (sRebootCriteriaConfig.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - DSL_FIO_REBOOT_CRITERIA_CONFIG "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sRebootCriteriaConfig.accessCtl.nReturn));
   }

   /* Collect configuration status information */
   if (nRet != DSL_SUCCESS)
   {
      DSL_CPE_ConfigEntryAppliedValueType_u applyVal;

      memset(&applyVal, 0, sizeof(applyVal));
      applyVal.iVal = pConfiguration->data.sRebootCriteriaConfig.Vdsl;

      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_REBOOTCRITERIA_VDSL,
         applyVal,
         sRebootCriteriaConfig.accessCtl.nReturn);
   }
#endif /* INCLUDE_DSL_CPE_API_VRX */

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_RebootCfgValidateAndApply, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function validates and applies VDSL profile configuration
   taken from the config file

   \param pControlContext     Pointer to DSL CPE Control context structure, [I]
   \param nDevNum             Number of device for configuration, [I]
   \param pConfiguration      Pointer to DSL configuration structure, [I]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_VdslProfileCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration)
{
   DSL_Error_t nErrCode = DSL_SUCCESS;
   DSL_Error_t nRangeCheck = DSL_SUCCESS;
   DSL_VdslProfileConfig_t sVdslProfile;
   DSL_uint32_t nCFGVdslProfileVal = 0;
   const DSL_uint32_t nMaxMask = 0x1FF;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_VdslProfileCfgValidateAndApply, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   nCFGVdslProfileVal = pConfiguration->data.sCommonConfig.VdslProfileVal;

   /* Use API internal default configuration */
   if (nCFGVdslProfileVal == 0)
      nCFGVdslProfileVal = nMaxMask;

   CONFIG_PARAM_RANGE_VALIDATION(
      nCFGVdslProfileVal,
      CONFIG_DSL_COMMON_VDSL_PROFILE,
      DSL_BF_PROFILE_8A,
      nMaxMask);

   if (nRangeCheck != DSL_SUCCESS)
      return nRangeCheck;

   memset(&sVdslProfile, 0x0, sizeof(DSL_VdslProfileConfig_t));

   CONFIG_PARAM_APPLY(
      sVdslProfile.data.nVdslProfile,
      nCFGVdslProfileVal);

   nErrCode = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_VDSL_PROFILE_CONFIG_SET,
                  (int) &sVdslProfile);

   /* store error code in case of failure */
   if (nErrCode != DSL_SUCCESS)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_VDSL_PROFILE_CONFIG_SET ioctl failed, "
         "error=%d!" DSL_CPE_CRLF,
         nErrCode));
   }

   /* on failure print additional debug info */
   if (sVdslProfile.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "wARNING - DSL_FIO_VDSL_PROFILE_CONFIG "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sVdslProfile.accessCtl.nReturn));
   }

   /* Collect configuration status information */
   if (nErrCode != DSL_SUCCESS)
   {
      DSL_CPE_ConfigEntryAppliedValueType_u applyVal;

      memset(&applyVal, 0, sizeof(applyVal));
      applyVal.iVal = pConfiguration->data.sCommonConfig.VdslProfileVal;

      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_COMMON_VDSL_PROFILE,
         applyVal,
         sVdslProfile.accessCtl.nReturn);
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_VdslProfileCfgValidateAndApply, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function validates and applies seamless rate adaptation configuration
   taken from the config file

   \param pControlContext     Pointer to DSL CPE Control context structure, [I]
   \param nDevNum             Number of device for configuration, [I]
   \param pConfiguration      Pointer to DSL configuration structure, [I]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_G997_RateAdaptationCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration)
{
   DSL_Error_t nRet = DSL_SUCCESS, nErrCode = DSL_SUCCESS;
   DSL_Error_t nRangeCheck = DSL_SUCCESS;
   DSL_G997_RateAdaptationConfig_t sg997RA;
   DSL_CFG_Sra_t sCFGSra;
   DSL_DslModeSelection_t dslMode = DSL_MODE_NA;
   DSL_AccessDir_t accessDir = DSL_ACCESSDIR_NA;
   const DSL_uint8_t g997RAShift = 2;
   /* Configuration of seamless rate adaptation (SRA):
         0: Disable SRA
         1: Enable SRA
         2: Use API internal default configuration
            (disabled for ADSL, enabled for VDSL) */
   const DSL_uint8_t CONFIG_MIN_SRA_VAL = 0;
   const DSL_uint8_t CONFIG_MAX_SRA_VAL = 2;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_G997_RateAdaptationCfgValidateAndApply, device<%u>"
      DSL_CPE_CRLF,
      nDevNum));

   sCFGSra = pConfiguration->data.sSraConfig;

   /* system holds shifted values
      so align backuped values before validation */
   if (pConfiguration->type == DSL_CPE_CONFIGURATION_TYPE_BACKUP)
   {
      sCFGSra.Us_Adsl -= g997RAShift;
      sCFGSra.Ds_Adsl -= g997RAShift;
      sCFGSra.Us_Vdsl -= g997RAShift;
      sCFGSra.Ds_Vdsl -= g997RAShift;
   }

   CONFIG_PARAM_RANGE_VALIDATION(
      sCFGSra.Us_Adsl,
      CONFIG_DSL_SRA_ADSL_US,
      CONFIG_MIN_SRA_VAL,
      CONFIG_MAX_SRA_VAL);
   CONFIG_PARAM_RANGE_VALIDATION(
      sCFGSra.Ds_Adsl,
      CONFIG_DSL_SRA_ADSL_DS,
      CONFIG_MIN_SRA_VAL,
      CONFIG_MAX_SRA_VAL);
   CONFIG_PARAM_RANGE_VALIDATION(
      sCFGSra.Us_Vdsl,
      CONFIG_DSL_SRA_VDSL_US,
      CONFIG_MIN_SRA_VAL,
      CONFIG_MAX_SRA_VAL);
   CONFIG_PARAM_RANGE_VALIDATION(
      sCFGSra.Ds_Vdsl,
      CONFIG_DSL_SRA_VDSL_DS,
      CONFIG_MIN_SRA_VAL,
      CONFIG_MAX_SRA_VAL);

   if (nRangeCheck != DSL_SUCCESS)
      return nRangeCheck;

   /* Use API internal default configuration */
   if (sCFGSra.Us_Adsl == CONFIG_MAX_SRA_VAL)
      sCFGSra.Us_Adsl = 0;

   if (sCFGSra.Ds_Adsl == CONFIG_MAX_SRA_VAL)
      sCFGSra.Ds_Adsl = 0;

   if (sCFGSra.Us_Vdsl == CONFIG_MAX_SRA_VAL)
      sCFGSra.Us_Vdsl = 1;

   if (sCFGSra.Ds_Vdsl == CONFIG_MAX_SRA_VAL)
      sCFGSra.Ds_Vdsl = 1;

   for (dslMode = DSL_MODE_ADSL; dslMode < DSL_MODE_LAST; ++dslMode)
   {
      for (accessDir = DSL_UPSTREAM;
           accessDir < DSL_ACCESSDIR_LAST;
           ++accessDir)
      {
         memset(&sg997RA, 0x0, sizeof(DSL_G997_RateAdaptationConfig_t));

         sg997RA.nDslMode = dslMode;
         sg997RA.nDirection = accessDir;

         if (dslMode == DSL_MODE_ADSL)
         {
            if (accessDir == DSL_UPSTREAM)
            {
               CONFIG_PARAM_APPLY(
                  sg997RA.data.RA_MODE,
                  (sCFGSra.Us_Adsl + g997RAShift));
            }
            else
            {
               CONFIG_PARAM_APPLY(
                  sg997RA.data.RA_MODE,
                  (sCFGSra.Ds_Adsl + g997RAShift));
            }
         }
#if defined(INCLUDE_DSL_CPE_API_VRX)
         else
         {
            if (accessDir == DSL_UPSTREAM)
            {
               CONFIG_PARAM_APPLY(
                  sg997RA.data.RA_MODE,
                  (sCFGSra.Us_Vdsl + g997RAShift));
            }
            else
            {
               CONFIG_PARAM_APPLY(
                  sg997RA.data.RA_MODE,
                  (sCFGSra.Ds_Vdsl + g997RAShift));
            }
         }
#endif /* INCLUDE_DSL_CPE_API_VRX */

         nRet = DSL_CPE_Ioctl(
                     pControlContext->fd[nDevNum],
                     DSL_FIO_G997_RATE_ADAPTATION_CONFIG_SET,
                     (int) &sg997RA);

         /* store error code in case of failure */
         if (nRet != DSL_SUCCESS)
         {
            nErrCode = nRet;

            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_VDSL_PROFILE_CONFIG_SET ioctl failed, "
               "error=%d!" DSL_CPE_CRLF,
               nRet));
         }

         /* on failure print additional debug info */
         if (sg997RA.accessCtl.nReturn)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
               "WARNING - DSL_FIO_VDSL_PROFILE_CONFIG "
               "access control retCode=%d!" DSL_CPE_CRLF,
               sg997RA.accessCtl.nReturn));
         }

         /* Collect configuration status information */
         if (nRet != DSL_SUCCESS)
         {
            DSL_CPE_ConfigEntryAppliedValueType_u applyVal;

            if (dslMode == DSL_MODE_ADSL &&
                accessDir == DSL_UPSTREAM)
            {
               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.bVal = pConfiguration->data.sSraConfig.Us_Adsl;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_SRA_ADSL_US,
                  applyVal,
                  sg997RA.accessCtl.nReturn);
            }
            else if (dslMode == DSL_MODE_ADSL &&
                     accessDir == DSL_DOWNSTREAM)
            {
               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.bVal = pConfiguration->data.sSraConfig.Ds_Adsl;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_SRA_ADSL_DS,
                  applyVal,
                  sg997RA.accessCtl.nReturn);
            }
#if defined(INCLUDE_DSL_CPE_API_VRX)
            else if (dslMode == DSL_MODE_VDSL &&
                     accessDir == DSL_UPSTREAM)
            {
               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.bVal = pConfiguration->data.sSraConfig.Us_Vdsl;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_SRA_VDSL_US,
                  applyVal,
                  sg997RA.accessCtl.nReturn);
            }
            else if (dslMode == DSL_MODE_VDSL &&
                     accessDir == DSL_DOWNSTREAM)
            {
               memset(&applyVal, 0, sizeof(applyVal));
               applyVal.bVal = pConfiguration->data.sSraConfig.Ds_Vdsl;

               DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
                  pConfiguration->type,
                  CONFIG_DSL_SRA_VDSL_DS,
                  applyVal,
                  sg997RA.accessCtl.nReturn);
            }
#endif /* INCLUDE_DSL_CPE_API_VRX */
         }
      }
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_G997_RateAdaptationCfgValidateAndApply, retCode=%d"
      DSL_CPE_CRLF, nErrCode));

   return nErrCode;
}

/*
   This function applies SystemInterface configuration taken from the
   config file

   \param pControlContext     Pointer to DSL CPE Control context structure, [I]
   \param nDevNum             Number of device for configuration, [I]
   \param pConfiguration      Pointer to DSL configuration structure, [I]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_SysIfCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration)
{
   DSL_Error_t nRet = DSL_SUCCESS, nErrCode = DSL_SUCCESS;
   DSL_Error_t nRangeCheck = DSL_SUCCESS;
   DSL_SystemInterfaceConfig_t sSystemIfConfig = { 0 };
   DSL_CFG_SystemInterface_t sCfgSystemIfConfig;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_SysIfCfgValidateAndApply, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   sCfgSystemIfConfig = pConfiguration->data.sSystemIfConfig;

   CONFIG_PARAM_RANGE_VALIDATION(
      sCfgSystemIfConfig.nTcLayer_Adsl,
      CONFIG_DSL_TCLAYER_ADSL,
      DSL_TC_UNKNOWN,
      DSL_TC_EFM_FORCED);
   CONFIG_PARAM_RANGE_VALIDATION(
      sCfgSystemIfConfig.nTcLayer_Vdsl,
      CONFIG_DSL_TCLAYER_VDSL,
      DSL_TC_UNKNOWN,
      DSL_TC_EFM_FORCED);

   if (nRangeCheck != DSL_SUCCESS)
      return nRangeCheck;

   memset(&sSystemIfConfig, 0x0, sizeof(DSL_SystemInterfaceConfig_t));
   sSystemIfConfig.nDslMode = DSL_MODE_ADSL;

   nRet = DSL_CPE_Ioctl(
               pControlContext->fd[nDevNum],
               DSL_FIO_SYSTEM_INTERFACE_CONFIG_GET,
               (int) &sSystemIfConfig);

   if (nRet == DSL_SUCCESS)
   {
      /* if TcLayer_Adsl is "0" the API internal default
         configuration value DSL_TC_ATM shall be used */
      if (sCfgSystemIfConfig.nTcLayer_Adsl == 0)
      {
         sSystemIfConfig.data.nTcLayer = DSL_TC_ATM;
      }
      else
      {
         CONFIG_PARAM_APPLY(
            sSystemIfConfig.data.nTcLayer,
            sCfgSystemIfConfig.nTcLayer_Adsl);
      }

      nRet = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_SYSTEM_INTERFACE_CONFIG_SET,
                  (int) &sSystemIfConfig);

      /* store error code in case of failure */
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;

         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - DSL_FIO_OPERATOR_CONFIG_SET ioctl failed, "
            "error=%d!" DSL_CPE_CRLF,
            nRet));
      }
   }
   else
   {
      nErrCode = nRet;

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_SYSTEM_INTERFACE_CONFIG_GET ioctl failed, "
         "error=%d!" DSL_CPE_CRLF,
         nRet));
   }

   /* on failure print additional debug info */
   if (sSystemIfConfig.accessCtl.nReturn)
   {
      nRet = sSystemIfConfig.accessCtl.nReturn;

      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "wARNING - DSL_FIO_SYSTEM_INTERFACE_CONFIG "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sSystemIfConfig.accessCtl.nReturn));
   }

   /* Collect configuration status information */
   if (nRet != DSL_SUCCESS)
   {
      DSL_CPE_ConfigEntryAppliedValueType_u applyVal;

      memset(&applyVal, 0, sizeof(applyVal));
      applyVal.iVal = pConfiguration->data.sSystemIfConfig.nTcLayer_Adsl;

      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_TCLAYER_ADSL,
         applyVal,
         nRet);
   }

#if defined(INCLUDE_DSL_CPE_API_VRX)
   memset(&sSystemIfConfig, 0x0, sizeof(DSL_SystemInterfaceConfig_t));
   sSystemIfConfig.nDslMode = DSL_MODE_VDSL;

   nRet = DSL_CPE_Ioctl(
               pControlContext->fd[nDevNum],
               DSL_FIO_SYSTEM_INTERFACE_CONFIG_GET,
               (int) &sSystemIfConfig);

   if (nRet == DSL_SUCCESS)
   {
      /* if TcLayer_Vdsl is "0" the API internal default
         configuration value DSL_TC_EFM shall be used */
      if (sCfgSystemIfConfig.nTcLayer_Vdsl == 0)
      {
         sSystemIfConfig.data.nTcLayer = DSL_TC_EFM;
      }
      else
      {
         CONFIG_PARAM_APPLY(
            sSystemIfConfig.data.nTcLayer,
            sCfgSystemIfConfig.nTcLayer_Vdsl);
      }

      nRet = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_SYSTEM_INTERFACE_CONFIG_SET,
                  (int) &sSystemIfConfig);

      /* store error code in case of failure */
      if (nRet != DSL_SUCCESS)
      {
         nErrCode = nRet;

         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - DSL_FIO_OPERATOR_CONFIG_SET ioctl failed, "
            "error=%d!" DSL_CPE_CRLF,
            nRet));
      }
   }
   else
   {
      nErrCode = nRet;

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_SYSTEM_INTERFACE_CONFIG_GET ioctl failed, "
         "error=%d!" DSL_CPE_CRLF,
         nRet));
   }

   /* on failure print additional debug info */
   if (sSystemIfConfig.accessCtl.nReturn)
   {
      nRet = sSystemIfConfig.accessCtl.nReturn;

      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "wARNING - DSL_FIO_SYSTEM_INTERFACE_CONFIG "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sSystemIfConfig.accessCtl.nReturn));
   }

   /* Collect configuration status information */
   if (nRet != DSL_SUCCESS)
   {
      DSL_CPE_ConfigEntryAppliedValueType_u applyVal;

      memset(&applyVal, 0, sizeof(applyVal));
      applyVal.iVal = pConfiguration->data.sSystemIfConfig.nTcLayer_Vdsl;

      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_TCLAYER_VDSL,
         applyVal,
         nRet);
   }
#endif

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_SysIfCfgValidateAndApply, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function applies Bonding configuration taken from the
   config file

   \param pControlContext     Pointer to DSL CPE Control context structure, [I]
   \param nDevNum             Number of device for configuration, [I]
   \param pConfiguration      Pointer to DSL configuration structure, [I]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_BondingCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration)
{
   DSL_Error_t nRet = DSL_SUCCESS, nRetDslMode[DSL_MODE_LAST] =  { DSL_SUCCESS },
      nErrCode = DSL_ERROR;
   DSL_Error_t nRangeCheck = DSL_SUCCESS;
   DSL_BND_Config_t sBondingConfig = { 0 };
   DSL_CFG_Bonding_t sCfgBondingConfig;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_BondingCfgValidateAndApply, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   sCfgBondingConfig = pConfiguration->data.sBondingConfig;

   CONFIG_PARAM_RANGE_VALIDATION(
      sCfgBondingConfig.nBonding_AdslPtm,
      CONFIG_DSL_BONDING_ADSL_PTM,
      DSL_BND_ENABLE_OFF,
      DSL_BND_ENABLE_ON);
   CONFIG_PARAM_RANGE_VALIDATION(
      sCfgBondingConfig.nBonding_AdslAtm,
      CONFIG_DSL_BONDING_ADSL_ATM,
      DSL_BND_ENABLE_OFF,
      DSL_BND_ENABLE_ON);
   CONFIG_PARAM_RANGE_VALIDATION(
      sCfgBondingConfig.nBonding_VdslPtm,
      CONFIG_DSL_BONDING_VDSL_PTM,
      DSL_BND_ENABLE_OFF,
      DSL_BND_ENABLE_ON);
   CONFIG_PARAM_RANGE_VALIDATION(
      sCfgBondingConfig.nBonding_VdslAtm,
      CONFIG_DSL_BONDING_VDSL_ATM,
      DSL_BND_ENABLE_OFF,
      DSL_BND_ENABLE_ON);

   if (nRangeCheck != DSL_SUCCESS)
   {
      return nRangeCheck;
   }

   memset(&sBondingConfig, 0x0, sizeof(DSL_BND_Config_t));
   sBondingConfig.nDslMode = DSL_MODE_ADSL;

#ifdef INCLUDE_DSL_CONFIG_GET
   nRet = DSL_CPE_Ioctl(
               pControlContext->fd[nDevNum],
               DSL_FIO_BND_CONFIG_GET,
               (int) &sBondingConfig);
   if (nRet == DSL_SUCCESS)
   {
#endif/* INCLUDE_DSL_CONFIG_GET */
      CONFIG_PARAM_APPLY(
         sBondingConfig.data.bPafEnable,
         sCfgBondingConfig.nBonding_AdslPtm);
      CONFIG_PARAM_APPLY(
         sBondingConfig.data.bImapEnable,
         sCfgBondingConfig.nBonding_AdslAtm);

      nRet = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_BND_CONFIG_SET,
                  (int) &sBondingConfig);

      /* store error code in case of failure */
      if (nRet != DSL_SUCCESS)
      {
         /* on failure print additional debug info */
         if (sBondingConfig.accessCtl.nReturn)
         {
            nRet = sBondingConfig.accessCtl.nReturn;

            DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
               "WARNING - DSL_FIO_BND_CONFIG_SET (ADSL) "
               "access control retCode=%d!" DSL_CPE_CRLF,
               sBondingConfig.accessCtl.nReturn));
         }
         nRetDslMode[sBondingConfig.nDslMode] = nRet;

         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - DSL_FIO_BND_CONFIG_SET (ADSL) ioctl failed, "
            "error=%d!" DSL_CPE_CRLF,
            nRet));
      }
#ifdef INCLUDE_DSL_CONFIG_GET
   }
   else
   {
      /* on failure print additional debug info */
      if (sBondingConfig.accessCtl.nReturn < DSL_SUCCESS)
      {
         nRet = sBondingConfig.accessCtl.nReturn;

         DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
            "WARNING - DSL_FIO_BND_CONFIG_GET (ADSL) "
            "access control retCode=%d!" DSL_CPE_CRLF,
            sBondingConfig.accessCtl.nReturn));
      }
      nRetDslMode[sBondingConfig.nDslMode] = nRet;

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_BND_CONFIG_GET (ADSL) ioctl failed, "
         "error=%d!" DSL_CPE_CRLF,
         nRet));
   }
#endif /* INCLUDE_DSL_CONFIG_GET */

   /* Collect configuration status information */
   if (nRet != DSL_SUCCESS)
   {
      DSL_CPE_ConfigEntryAppliedValueType_u applyVal;
      memset(&applyVal, 0, sizeof(applyVal));

      applyVal.iVal = sCfgBondingConfig.nBonding_AdslPtm;
      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_BONDING_ADSL_PTM,
         applyVal,
         nRet);

      applyVal.iVal = sCfgBondingConfig.nBonding_AdslAtm;
      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_BONDING_ADSL_ATM,
         applyVal,
         nRet);
   }

#if defined(INCLUDE_DSL_CPE_API_VRX)
   memset(&sBondingConfig, 0x0, sizeof(DSL_BND_Config_t));
   sBondingConfig.nDslMode = DSL_MODE_VDSL;

#ifdef INCLUDE_DSL_CONFIG_GET
   nRet = DSL_CPE_Ioctl(
               pControlContext->fd[nDevNum],
               DSL_FIO_BND_CONFIG_GET,
               (int) &sBondingConfig);
   if (nRet == DSL_SUCCESS)
   {
#endif /* INCLUDE_DSL_CONFIG_GET */
      CONFIG_PARAM_APPLY(
         sBondingConfig.data.bPafEnable,
         sCfgBondingConfig.nBonding_VdslPtm);
      CONFIG_PARAM_APPLY(
         sBondingConfig.data.bImapEnable,
         sCfgBondingConfig.nBonding_VdslAtm);

      nRet = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_BND_CONFIG_SET,
                  (int) &sBondingConfig);

      /* store error code in case of failure */
      if (nRet != DSL_SUCCESS)
      {
         /* on failure print additional debug info */
         if (sBondingConfig.accessCtl.nReturn)
         {
            nRet = sBondingConfig.accessCtl.nReturn;

            DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
               "WARNING - DSL_FIO_BND_CONFIG_SET (VDSL) "
               "access control retCode=%d!" DSL_CPE_CRLF,
               sBondingConfig.accessCtl.nReturn));
         }
         nRetDslMode[sBondingConfig.nDslMode] = nRet;

         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - DSL_FIO_BND_CONFIG_SET (VDSL) ioctl failed, "
            "error=%d!" DSL_CPE_CRLF,
            nRet));
      }
#ifdef INCLUDE_DSL_CONFIG_GET
   }
   else
   {
      /* on failure print additional debug info */
      if (sBondingConfig.accessCtl.nReturn)
      {
         nRet = sBondingConfig.accessCtl.nReturn;

         DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
            "WARNING - DSL_FIO_BND_CONFIG_GET (VDSL) "
            "access control retCode=%d!" DSL_CPE_CRLF,
            sBondingConfig.accessCtl.nReturn));
      }
      nRetDslMode[sBondingConfig.nDslMode] = nRet;

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_BND_CONFIG_GET (VDSL) ioctl failed, "
         "error=%d!" DSL_CPE_CRLF,
         nRet));
   }
#endif /* INCLUDE_DSL_CONFIG_GET */

   /* Collect configuration status information */
   if (nRet != DSL_SUCCESS)
   {
      DSL_CPE_ConfigEntryAppliedValueType_u applyVal;
      memset(&applyVal, 0, sizeof(applyVal));

      applyVal.iVal = sCfgBondingConfig.nBonding_VdslPtm;
      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_BONDING_VDSL_PTM,
         applyVal,
         nRet);

      applyVal.iVal = sCfgBondingConfig.nBonding_VdslAtm;
      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_BONDING_VDSL_ATM,
         applyVal,
         nRet);
   }
#endif

   for (DSL_DslModeSelection_t dslMode = DSL_MODE_ADSL;
           dslMode < DSL_MODE_LAST; ++dslMode)
   {
      /* if at least one configuration succeeded, return SUCCESS */
      if(nRetDslMode[dslMode] == DSL_SUCCESS)
      {
         nErrCode = DSL_SUCCESS;
         break;
      }
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_BondingCfgValidateAndApply, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function applies XTSE configuration taken from the config file

   \param pControlContext     Pointer to DSL CPE Control context structure, [I]
   \param nDevNum             Number of device for configuration, [I]
   \param pConfiguration      Pointer to DSL configuration structure, [I]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_XtseCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration)
{
   DSL_Error_t nErrCode = DSL_SUCCESS;
   DSL_G997_XTUSystemEnabling_t sXtse = { 0 };
   const DSL_uint8_t *pG997XtuVal = DSL_NULL;
   DSL_int_t i;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_XtseCfgValidateAndApply, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   pG997XtuVal = pConfiguration->data.G997XtuVal;

   nErrCode = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_G997_XTU_SYSTEM_ENABLING_CONFIG_GET,
                  (int) &sXtse);

   if (nErrCode == DSL_SUCCESS)
   {
      for (i = 0; i < DSL_G997_NUM_XTSE_OCTETS; ++i)
      {
         sXtse.data.XTSE[i] = pG997XtuVal[i];
      }

      nErrCode = DSL_CPE_Ioctl(
                     pControlContext->fd[nDevNum],
                     DSL_FIO_G997_XTU_SYSTEM_ENABLING_CONFIG_SET,
                     (int) &sXtse);

      /* store error code in case of failure */
      if (nErrCode != DSL_SUCCESS)
      {
         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
            "ERROR - DSL_FIO_G997_XTU_SYSTEM_ENABLING_CONFIG_SET ioctl failed, "
            "error=%d!" DSL_CPE_CRLF,
            nErrCode));
      }
   }
   else
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_G997_XTU_SYSTEM_ENABLING_CONFIG_GET ioctl failed, "
         "error=%d!" DSL_CPE_CRLF,
         nErrCode));
   }

   /* on failure print additional debug info */
   if (sXtse.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - DSL_FIO_G997_XTU_SYSTEM_ENABLING_CONFIG "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sXtse.accessCtl.nReturn));
   }

   /* Collect configuration status information */
   if (nErrCode != DSL_SUCCESS)
   {
      DSL_CPE_ConfigEntryAppliedValueType_u applyVal;
      DSL_int_t nCopied = 0;
      DSL_int_t nOffset = 0;

      memset(&applyVal, 0, sizeof(applyVal));

      for (i = 0; i < DSL_G997_NUM_XTSE_OCTETS && nCopied >= 0; ++i)
      {
         nCopied = cpe_control_snprintf_s(applyVal.strVal + nOffset,
            CONFIG_PARAMETER_STRING_VALUE_LENGTH - nOffset,
            "0x%02x ",
            pConfiguration->data.G997XtuVal[i]);

         nOffset += nCopied;
      }

      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_XTSE,
         applyVal,
         sXtse.accessCtl.nReturn == 0 ? nErrCode : sXtse.accessCtl.nReturn);
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_XtseCfgValidateAndApply, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

#if defined(INCLUDE_DSL_CPE_API_VRX)
/*
   This function applies Vectoring configuration taken from the config file

   \note Vectoring is only supported for VDSL

   \param nDevNum             Device number, [I]
   \param pConfiguration      Pointer to DSL configuration structure, [I]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_VectoringEnableCfgValidateAndApply(
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration)
{
   DSL_Error_t nErrCode = DSL_SUCCESS;
   DSL_Error_t nRangeCheck = DSL_SUCCESS;
   unsigned int nVectoringEnable = 0;
   DSL_int_t nMeiFd;
   DSL_char_t meiDevName[32] = {0};
   IOCTL_MEI_dsmConfig_t sDsmConfig;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_VectoringEnableCfgValidateAndApply, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   nVectoringEnable = pConfiguration->data.sCommonConfig.VectoringEnable;

   CONFIG_PARAM_RANGE_VALIDATION(
      nVectoringEnable,
      CONFIG_DSL_COMMON_VECTORING_ENABLE,
      e_MEI_VECTOR_CTRL_OFF,
      e_MEI_VECTOR_CTRL_AUTO);

   if (nRangeCheck != DSL_SUCCESS)
      return nRangeCheck;

   memset(&sDsmConfig, 0, sizeof(IOCTL_MEI_dsmConfig_t));
   sDsmConfig.eVectorControl = nVectoringEnable;

   cpe_control_snprintf_s(meiDevName, sizeof(meiDevName),
      "/dev/mei_cpe/%u", nDevNum);
   nMeiFd = DSL_CPE_Open(meiDevName);
   if (nMeiFd <= 0)
   {
      DSL_CPE_Close(nMeiFd);

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - MEI Driver <%s> does not exist!" DSL_CPE_CRLF,
         meiDevName));
      return DSL_ERROR;
   }

   nErrCode = DSL_CPE_Ioctl(nMeiFd,
                  FIO_MEI_DSM_CONFIG_SET,
                  (int) &sDsmConfig);

   if (nErrCode != DSL_SUCCESS)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - FIO_MEI_DSM_CONFIG_SET ioctl failed, error=%d!" DSL_CPE_CRLF,
         nErrCode));
   }

   /* on failure print additional debug info */
   if (sDsmConfig.ictl.retCode)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - FIO_MEI_DSM_CONFIG "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sDsmConfig.ictl.retCode));
   }

   DSL_CPE_Close(nMeiFd);

   /* Collect configuration status information */
   if (nErrCode != DSL_SUCCESS)
   {
      DSL_CPE_ConfigEntryAppliedValueType_u applyVal;

      memset(&applyVal, 0, sizeof(applyVal));
      applyVal.iVal = pConfiguration->data.sCommonConfig.VectoringEnable;

      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_COMMON_VECTORING_ENABLE,
         applyVal,
         sDsmConfig.ictl.retCode);
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_VectoringEnableCfgValidateAndApply, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}
#endif /* defined(INCLUDE_DSL_CPE_API_VRX) */

/*
   This function applies FW message polling mode (for API) configuration
   taken from the config file

   \param pControlContext     Pointer to DSL CPE Control context structure, [I]
   \param nDevNum             Number of device for configuration, [I]
   \param pConfiguration      Pointer to DSL configuration structure, [I]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_FwMessagePollingCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration)
{
   DSL_Error_t nErrCode = DSL_SUCCESS;
   DSL_boolean_t bFWMsgPollingOnly;
   DSL_InstanceControl_t sInstanceControl;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_FwMessagePollingCfgValidateAndApply, device<%u>"
      DSL_CPE_CRLF,
      nDevNum));

   bFWMsgPollingOnly = pConfiguration->data.sCommonConfig.FWMsgPollingOnly;

   memset(&sInstanceControl, 0x0, sizeof(DSL_InstanceControl_t));
   sInstanceControl.data.bEventActivation = DSL_TRUE;
   sInstanceControl.data.bFwEventActivation = bFWMsgPollingOnly == DSL_TRUE ?
           DSL_FALSE : DSL_TRUE;

   nErrCode = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_INSTANCE_CONTROL_SET,
                  (int) &sInstanceControl);

   /* store error code in case of failure */
   if (nErrCode != DSL_SUCCESS)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_INSTANCE_CONTROL_SET ioctl failed, "
         "error=%d!" DSL_CPE_CRLF,
         nErrCode));
   }

   /* on failure print additional debug info */
   if (sInstanceControl.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "wARNING - DSL_FIO_INSTANCE_CONTROL_SET "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sInstanceControl.accessCtl.nReturn));
   }

   /* Collect configuration status information */
   if (nErrCode != DSL_SUCCESS)
   {
      DSL_CPE_ConfigEntryAppliedValueType_u applyVal;

      memset(&applyVal, 0, sizeof(applyVal));
      applyVal.bVal = pConfiguration->data.sCommonConfig.FWMsgPollingOnly;

      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_COMMON_FW_MSG_POLLING_ONLY,
         applyVal,
         sInstanceControl.accessCtl.nReturn);
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_FwMessagePollingCfgValidateAndApply, retCode=%d"
      DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function applies OperatorSelect value taken from the config file

   \note Vectoring is only supported for VDSL

   \param pControlContext     Pointer to DSL CPE Control context structure, [I]
   \param nDevNum             Number of device for configuration, [I]
   \param pConfiguration      Pointer to DSL configuration structure, [I]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_OperatorSelectCfgValidateAndApply(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   const DSL_Configuration_t *pConfiguration)
{
   DSL_Error_t nErrCode = DSL_SUCCESS;
   DSL_Error_t nRangeCheck = DSL_SUCCESS;
   DSL_uint16_t nOperatorSelect;
   DSL_OperatorConfig_t sOperatorConfig;
   /* FW message values defined with MCAT is defined for 0..19
      but FW will block reserved values from within full-scale of 8-bit */
   const DSL_uint8_t CONFIG_MIN_OPERATOR_SELECT_VAL = 0;
   const DSL_uint8_t CONFIG_MAX_OPERATOR_SELECT_VAL = 255;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_OperatorSelectCfgValidateAndApply, device<%u>"
      DSL_CPE_CRLF,
      nDevNum));

   nOperatorSelect =
      (DSL_uint16_t)pConfiguration->data.sCommonConfig.nOperatorSelect;

   CONFIG_PARAM_RANGE_VALIDATION(
      nOperatorSelect,
      CONFIG_DSL_COMMON_OPERATOR_SELECT,
      CONFIG_MIN_OPERATOR_SELECT_VAL,
      CONFIG_MAX_OPERATOR_SELECT_VAL);

   if (nRangeCheck != DSL_SUCCESS)
      return nRangeCheck;

   memset(&sOperatorConfig, 0, sizeof(DSL_OperatorConfig_t));
   sOperatorConfig.data.nDslOperator = nOperatorSelect;

   nErrCode = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_OPERATOR_CONFIG_SET,
                  (int) &sOperatorConfig);

   /* store error code in case of failure */
   if (nErrCode != DSL_SUCCESS)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_OPERATOR_CONFIG_SET ioctl failed, "
         "error=%d!" DSL_CPE_CRLF,
         nErrCode));
   }

   /* on failure print additional debug info */
   if (sOperatorConfig.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - DSL_FIO_OPERATOR_CONFIG "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sOperatorConfig.accessCtl.nReturn));
   }

   /* Collect configuration status information */
   if (nErrCode != DSL_SUCCESS)
   {
      DSL_CPE_ConfigEntryAppliedValueType_u applyVal;

      memset(&applyVal, 0, sizeof(applyVal));
      applyVal.bVal = pConfiguration->data.sCommonConfig.nOperatorSelect;

      DSL_CPE_ConfigEntryAppliedAdd(&g_pAppliedEntriesList,
         pConfiguration->type,
         CONFIG_DSL_COMMON_OPERATOR_SELECT,
         applyVal,
         sOperatorConfig.accessCtl.nReturn);
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_OperatorSelectCfgValidateAndApply, retCode=%d"
      DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function retrieves current device LowLevel configuration
   and stores it as backup configuration

   \param pControlContext        Pointer to DSL CPE Control context structure, [I]
   \param nDevNum                Number of device for configuration, [I]
   \param pBackupConfiguration   Pointer to DSL configuration structure, [O]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_LowLevelCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
)
{
   DSL_Error_t nErrCode = DSL_SUCCESS;
   DSL_LowLevelConfiguration_t sLowLevelCfg = { 0 };
   DSL_CFG_LowLevelHsTones_t *pCFGLowLevelHsTones = DSL_NULL;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_LowLevelCfgBackup, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   pCFGLowLevelHsTones =
      &(pBackupConfiguration->data.sCommonConfig.sLowLevelHsTonesConfig);

   nErrCode = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_LOW_LEVEL_CONFIGURATION_GET,
                  (int) &sLowLevelCfg);

   if (nErrCode == DSL_SUCCESS)
   {
      pCFGLowLevelHsTones->Adsl = sLowLevelCfg.data.nHsToneGroup_A;
      pCFGLowLevelHsTones->Vdsl = sLowLevelCfg.data.nHsToneGroup_V;
   }
   else
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_LOW_LEVEL_CONFIGURATION_GET ioctl failed, "
         "error=%d, dev=%d!" DSL_CPE_CRLF,
         nErrCode, nDevNum));
   }

   /* on failure print additional debug info */
   if (sLowLevelCfg.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - DSL_FIO_LOW_LEVEL_CONFIGURATION_GET "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sLowLevelCfg.accessCtl.nReturn));
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_LowLevelCfgBackup, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function retrieves current device LineFeature configuration
   and stores it as backup configuration

   \param pControlContext        Pointer to DSL CPE Control context structure, [I]
   \param nDevNum                Number of device for configuration, [I]
   \param pBackupConfiguration   Pointer to DSL configuration structure, [O]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_LineFeatureCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
)
{
   DSL_Error_t nRet = DSL_SUCCESS, nErrCode = DSL_SUCCESS;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_LineFeatureCfgBackup, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   DSL_LineFeature_t sLineFeature;
   DSL_CFG_Bitswap_t *pCFGBitswap = DSL_NULL;
   DSL_CFG_Retransmission_t *pCFGRetransmission = DSL_NULL;
   DSL_CFG_VirtualNoise_t *pCFGVirtualNoise = DSL_NULL;
   DSL_DslModeSelection_t dslMode = DSL_MODE_NA;
   DSL_AccessDir_t accessDir = DSL_ACCESSDIR_NA;

   pCFGBitswap = &(pBackupConfiguration->data.sBitswapConfig);
   pCFGRetransmission = &(pBackupConfiguration->data.sRetransmissionConfig);
   pCFGVirtualNoise = &(pBackupConfiguration->data.sVirtualNoiseConfig);

   for (dslMode = DSL_MODE_ADSL; dslMode < DSL_MODE_LAST; ++dslMode)
   {
      for (accessDir = DSL_UPSTREAM;
           accessDir < DSL_ACCESSDIR_LAST;
           ++accessDir)
      {
         memset(&sLineFeature, 0x0, sizeof(DSL_LineFeature_t));
         sLineFeature.nDslMode = dslMode;
         sLineFeature.nDirection = accessDir;

         nRet = DSL_CPE_Ioctl(
                     pControlContext->fd[nDevNum],
                     DSL_FIO_LINE_FEATURE_CONFIG_GET,
                     (int) &sLineFeature);

         if (nRet == DSL_SUCCESS)
         {
            if (dslMode == DSL_MODE_ADSL)
            {
               if (accessDir == DSL_UPSTREAM)
               {
                  pCFGBitswap->Us_Adsl = sLineFeature.data.bBitswapEnable;
                  pCFGRetransmission->Us_Adsl = sLineFeature.data.bReTxEnable;
                  pCFGVirtualNoise->Us = sLineFeature.data.bVirtualNoiseSupport;
               }
               else
               {
                  pCFGBitswap->Ds_Adsl = sLineFeature.data.bBitswapEnable;
                  pCFGRetransmission->Ds_Adsl = sLineFeature.data.bReTxEnable;
                  pCFGVirtualNoise->Ds = sLineFeature.data.bVirtualNoiseSupport;
               }
            }
#if defined(INCLUDE_DSL_CPE_API_VRX)
            else
            {
               if (accessDir == DSL_UPSTREAM)
               {
                  pCFGBitswap->Us_Vdsl = sLineFeature.data.bBitswapEnable;
                  pCFGRetransmission->Us_Vdsl = sLineFeature.data.bReTxEnable;
                  pCFGVirtualNoise->Us = sLineFeature.data.bVirtualNoiseSupport;
               }
               else
               {
                  pCFGBitswap->Ds_Vdsl = sLineFeature.data.bBitswapEnable;
                  pCFGRetransmission->Ds_Vdsl = sLineFeature.data.bReTxEnable;
                  pCFGVirtualNoise->Ds = sLineFeature.data.bVirtualNoiseSupport;
               }
            }
#endif /* INCLUDE_DSL_CPE_API_VRX */
         }
         else
         {
            nErrCode = nRet;

            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_LINE_FEATURE_CONFIG_GET ioctl failed, "
               "error=%d dev=%d mode=%s dir=%s!" DSL_CPE_CRLF,
               nRet, nDevNum,
               (dslMode == DSL_MODE_ADSL ? "ADSL" : "VDSL"),
               (accessDir == DSL_UPSTREAM ? "US" : "DS")));
         }

         /* on failure print additional debug info */
         if (sLineFeature.accessCtl.nReturn)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
               "WARNING - DSL_FIO_LINE_FEATURE_CONFIG_GET "
               "access control retCode=%d!" DSL_CPE_CRLF,
               sLineFeature.accessCtl.nReturn));
         }
      }
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_LineFeatureCfgBackup, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function retrieves current device reboot criteria configuration
   and stores it as backup configuration

   \param pControlContext        Pointer to DSL CPE Control context structure, [I]
   \param nDevNum                Number of device for configuration, [I]
   \param pBackupConfiguration   Pointer to DSL configuration structure, [O]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_RebootCriteriaCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
)
{
   DSL_Error_t nRet = DSL_SUCCESS, nErrCode = DSL_SUCCESS;
   DSL_RebootCriteriaConfig_t sRebootCriteriaConfig;
   DSL_CFG_RebootCriteria_t *pCFGRebootCriteria = DSL_NULL;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_RebootCriteriaCfgBackup, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   pCFGRebootCriteria = &(pBackupConfiguration->data.sRebootCriteriaConfig);

   memset(&sRebootCriteriaConfig, 0x0, sizeof(DSL_RebootCriteriaConfig_t));
   sRebootCriteriaConfig.nDslMode = DSL_MODE_ADSL;

   nRet = DSL_CPE_Ioctl(
               pControlContext->fd[nDevNum],
               DSL_FIO_REBOOT_CRITERIA_CONFIG_GET,
               (int) &sRebootCriteriaConfig);

   if (nRet == DSL_SUCCESS)
   {
      pCFGRebootCriteria->Adsl = sRebootCriteriaConfig.data.nRebootCriteria;
   }
   /* store error code in case of failure */
   else
   {
      nErrCode = nRet;

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_REBOOT_CRITERIA_CONFIG_GET ioctl failed, "
         "error=%d dev=%d mode=ADSL!" DSL_CPE_CRLF,
         nRet, nDevNum));
   }

   /* on failure print additional debug info */
   if (sRebootCriteriaConfig.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - DSL_FIO_REBOOT_CRITERIA_CONFIG_GET "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sRebootCriteriaConfig.accessCtl.nReturn));
   }

#if defined(INCLUDE_DSL_CPE_API_VRX)
   memset(&sRebootCriteriaConfig, 0x0, sizeof(DSL_RebootCriteriaConfig_t));
   sRebootCriteriaConfig.nDslMode = DSL_MODE_VDSL;

   nRet = DSL_CPE_Ioctl(
               pControlContext->fd[nDevNum],
               DSL_FIO_REBOOT_CRITERIA_CONFIG_GET,
               (int) &sRebootCriteriaConfig);

   if (nRet == DSL_SUCCESS)
   {
      pCFGRebootCriteria->Vdsl = sRebootCriteriaConfig.data.nRebootCriteria;
   }
   /* store error code in case of failure */
   else
   {
      nErrCode = nRet;

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_REBOOT_CRITERIA_CONFIG_GET ioctl failed, "
         "error=%d dev=%d mode=VDSL!" DSL_CPE_CRLF,
         nRet, nDevNum));
   }

   /* on failure print additional debug info */
   if (sRebootCriteriaConfig.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - DSL_FIO_REBOOT_CRITERIA_CONFIG "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sRebootCriteriaConfig.accessCtl.nReturn));
   }
#endif /* INCLUDE_DSL_CPE_API_VRX */

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_RebootCriteriaCfgBackup, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function retrieves current device vdsl profile configuration
   and stores it as backup configuration

   \param pControlContext        Pointer to DSL CPE Control context structure, [I]
   \param nDevNum                Number of device for configuration, [I]
   \param pBackupConfiguration   Pointer to DSL configuration structure, [O]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_VdslProfileCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
)
{
   DSL_Error_t nErrCode = DSL_SUCCESS;
   DSL_VdslProfileConfig_t sVdslProfile = { 0 };
   DSL_uint32_t *pCFGVdslProfileVal = DSL_NULL;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_VdslProfileCfgBackup, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   pCFGVdslProfileVal =
      &(pBackupConfiguration->data.sCommonConfig.VdslProfileVal);

   nErrCode = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_VDSL_PROFILE_CONFIG_GET,
                  (int) &sVdslProfile);

   if (nErrCode == DSL_SUCCESS)
   {
      *pCFGVdslProfileVal = sVdslProfile.data.nVdslProfile;
   }
   else
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_VDSL_PROFILE_CONFIG_GET ioctl failed, "
         "error=%d dev=%d!" DSL_CPE_CRLF,
         nErrCode, nDevNum));
   }

   /* on failure print additional debug info */
   if (sVdslProfile.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "wARNING - DSL_FIO_VDSL_PROFILE_CONFIG_GET "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sVdslProfile.accessCtl.nReturn));
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_VdslProfileCfgBackup, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function retrieves current device G997 rate adaptation configuration
   and stores it as backup configuration

   \param pControlContext        Pointer to DSL CPE Control context structure, [I]
   \param nDevNum                Number of device for configuration, [I]
   \param pBackupConfiguration   Pointer to DSL configuration structure, [O]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_G997_RateAdaptationCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
)
{
   DSL_Error_t nRet = DSL_SUCCESS, nErrCode = DSL_SUCCESS;
   DSL_G997_RateAdaptationConfig_t sg997RA;
   DSL_CFG_Sra_t *pCFGSra = DSL_NULL;
   DSL_DslModeSelection_t dslMode = DSL_MODE_NA;
   DSL_AccessDir_t accessDir = DSL_ACCESSDIR_NA;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_G997_RateAdaptationCfgBackup, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   pCFGSra = &(pBackupConfiguration->data.sSraConfig);

   for (dslMode = DSL_MODE_ADSL; dslMode < DSL_MODE_LAST; ++dslMode)
   {
      for (accessDir = DSL_UPSTREAM;
           accessDir < DSL_ACCESSDIR_LAST;
           ++accessDir)
      {
         memset(&sg997RA, 0x0, sizeof(DSL_G997_RateAdaptationConfig_t));
         sg997RA.nDslMode = dslMode;
         sg997RA.nDirection = accessDir;

         nRet = DSL_CPE_Ioctl(
                     pControlContext->fd[nDevNum],
                     DSL_FIO_G997_RATE_ADAPTATION_CONFIG_GET,
                     (int) &sg997RA);

         if (nRet == DSL_SUCCESS)
         {
            if (dslMode == DSL_MODE_ADSL)
            {
               if (accessDir == DSL_UPSTREAM)
               {
                  pCFGSra->Us_Adsl = sg997RA.data.RA_MODE;
               }
               else
               {
                  pCFGSra->Ds_Adsl = sg997RA.data.RA_MODE;
               }
            }
#if defined(INCLUDE_DSL_CPE_API_VRX)
            else
            {
               if (accessDir == DSL_UPSTREAM)
               {
                  pCFGSra->Us_Vdsl = sg997RA.data.RA_MODE;
               }
               else
               {
                  pCFGSra->Ds_Vdsl = sg997RA.data.RA_MODE;
               }
            }
#endif /* INCLUDE_DSL_CPE_API_VRX */
         }
         /* store error code in case of failure */
         else
         {
            nErrCode = nRet;

            DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
               "ERROR - DSL_FIO_VDSL_PROFILE_CONFIG_GET ioctl failed, "
               "error=%d dev=%d mode=%s dir=%s!" DSL_CPE_CRLF,
               nRet, nDevNum,
               (dslMode == DSL_MODE_ADSL ? "ADSL" : "VDSL"),
               (accessDir == DSL_UPSTREAM ? "US" : "DS")));
         }

         /* on failure print additional debug info */
         if (sg997RA.accessCtl.nReturn)
         {
            DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
               "WARNING - DSL_FIO_VDSL_PROFILE_CONFIG_GET "
               "access control retCode=%d!" DSL_CPE_CRLF,
               sg997RA.accessCtl.nReturn));
         }
      }
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_G997_RateAdaptationCfgBackup, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function retrieves current device system interface configuration
   and stores it as backup configuration

   \param pControlContext        Pointer to DSL CPE Control context structure, [I]
   \param nDevNum                Number of device for configuration, [I]
   \param pBackupConfiguration   Pointer to DSL configuration structure, [O]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_SysIfCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
)
{
   DSL_Error_t nRet = DSL_SUCCESS, nErrCode = DSL_SUCCESS;
   DSL_SystemInterfaceConfig_t sSystemIfConfig;
   DSL_CFG_SystemInterface_t *pCfgSystemIfConfig = DSL_NULL;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_SysIfCfgBackup, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   pCfgSystemIfConfig = &(pBackupConfiguration->data.sSystemIfConfig);

   memset(&sSystemIfConfig, 0x0, sizeof(DSL_SystemInterfaceConfig_t));
   sSystemIfConfig.nDslMode = DSL_MODE_ADSL;

   nRet = DSL_CPE_Ioctl(
               pControlContext->fd[nDevNum],
               DSL_FIO_SYSTEM_INTERFACE_CONFIG_GET,
               (int) &sSystemIfConfig);

   if (nRet == DSL_SUCCESS)
   {
      pCfgSystemIfConfig->nTcLayer_Adsl = sSystemIfConfig.data.nTcLayer;
   }
   else
   {
      nErrCode = nRet;

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_SYSTEM_INTERFACE_CONFIG_GET ioctl failed, "
         "error=%d dev=%d!" DSL_CPE_CRLF,
         nRet, nDevNum));
   }

   /* on failure print additional debug info */
   if (sSystemIfConfig.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "wARNING - DSL_FIO_SYSTEM_INTERFACE_CONFIG_GET "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sSystemIfConfig.accessCtl.nReturn));
   }

#if defined(INCLUDE_DSL_CPE_API_VRX)
   memset(&sSystemIfConfig, 0x0, sizeof(DSL_SystemInterfaceConfig_t));
   sSystemIfConfig.nDslMode = DSL_MODE_VDSL;

   nRet = DSL_CPE_Ioctl(
               pControlContext->fd[nDevNum],
               DSL_FIO_SYSTEM_INTERFACE_CONFIG_GET,
               (int) &sSystemIfConfig);

   if (nRet == DSL_SUCCESS)
   {
      pCfgSystemIfConfig->nTcLayer_Vdsl = sSystemIfConfig.data.nTcLayer;
   }
   else
   {
      nErrCode = nRet;

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_SYSTEM_INTERFACE_CONFIG_GET ioctl failed, "
         "error=%d!" DSL_CPE_CRLF,
         nRet));
   }

   /* on failure print additional debug info */
   if (sSystemIfConfig.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "wARNING - DSL_FIO_SYSTEM_INTERFACE_CONFIG_GET "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sSystemIfConfig.accessCtl.nReturn));
   }
#endif

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_SysIfCfgBackup, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function retrieves current device XTSE configuration
   and stores it as backup configuration

   \param pControlContext        Pointer to DSL CPE Control context structure, [I]
   \param nDevNum                Number of device for configuration, [I]
   \param pBackupConfiguration   Pointer to DSL configuration structure, [O]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_XtseCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration)
{
   DSL_Error_t nErrCode = DSL_SUCCESS;
   DSL_G997_XTUSystemEnabling_t sXtse = { 0 };
   DSL_uint8_t *pG997XtuVal = DSL_NULL;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_XtseCfgBackup, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   pG997XtuVal = pBackupConfiguration->data.G997XtuVal;

   nErrCode = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_G997_XTU_SYSTEM_ENABLING_CONFIG_GET,
                  (int) &sXtse);

   if (nErrCode == DSL_SUCCESS)
   {
      for (DSL_int_t i = 0; i < DSL_G997_NUM_XTSE_OCTETS; ++i)
      {
         pG997XtuVal[i] = sXtse.data.XTSE[i];
      }
   }
   else
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_G997_XTU_SYSTEM_ENABLING_CONFIG_GET ioctl failed, "
         "error=%d dev=%d!" DSL_CPE_CRLF,
         nErrCode, nDevNum));
   }

   /* on failure print additional debug info */
   if (sXtse.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "wARNING - DSL_FIO_G997_XTU_SYSTEM_ENABLING_CONFIG_GET "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sXtse.accessCtl.nReturn));
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_XtseCfgBackup, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function retrieves current device vectoring configuration
   and stores it as backup configuration

   \param pControlContext        Pointer to DSL CPE Control context structure, [I]
   \param nDevNum                Number of device for configuration, [I]
   \param pBackupConfiguration   Pointer to DSL configuration structure, [O]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_VectoringEnableCfgBackup(
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration)
{
   DSL_Error_t nErrCode = DSL_SUCCESS;
   DSL_uint32_t *pVectoringEnable = DSL_NULL;
   DSL_int_t nMeiFd;
   DSL_char_t meiDevName[32] = {0};
   IOCTL_MEI_dsmConfig_t sDsmConfig = { 0 };

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_VectoringEnableCfgBackup, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   cpe_control_snprintf_s(meiDevName, sizeof(meiDevName), "/dev/mei_cpe/%u",
                    nDevNum);
   nMeiFd = DSL_CPE_Open(meiDevName);
   if (nMeiFd <= 0)
   {
      DSL_CPE_Close(nMeiFd);

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - MEI Driver <%s> does not exist!" DSL_CPE_CRLF,
         meiDevName));
      return DSL_ERROR;
   }

   pVectoringEnable =
      &(pBackupConfiguration->data.sCommonConfig.VectoringEnable);

   nErrCode = DSL_CPE_Ioctl(nMeiFd,
                  FIO_MEI_DSM_CONFIG_GET,
                  (int) &sDsmConfig);

   if (nErrCode == DSL_SUCCESS)
   {
      *pVectoringEnable = sDsmConfig.eVectorControl;
   }
   else
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - FIO_MEI_DSM_CONFIG_GET ioctl failed, error=%d dev=%d!"
         DSL_CPE_CRLF,
         nErrCode, nDevNum));
   }

   /* on failure print additional debug info */
   if (sDsmConfig.ictl.retCode)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - FIO_MEI_DSM_CONFIG_GET "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sDsmConfig.ictl.retCode));
   }

   DSL_CPE_Close(nMeiFd);

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_VectoringEnableCfgBackup, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

/*
   This function retrieves current device fw message polling configuration
   and stores it as backup configuration

   \param pControlContext        Pointer to DSL CPE Control context structure, [I]
   \param nDevNum                Number of device for configuration, [I]
   \param pBackupConfiguration   Pointer to DSL configuration structure, [O]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/
static DSL_Error_t DSL_CPE_FwMessagePollingCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
)
{
   DSL_Error_t nErrCode = DSL_SUCCESS;
   DSL_boolean_t *pFWMsgPollingOnly = DSL_NULL;
   DSL_InstanceStatus_t sInstanceStatus = { 0 };

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_FwMessagePollingCfgBackup, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   pFWMsgPollingOnly =
      &(pBackupConfiguration->data.sCommonConfig.FWMsgPollingOnly);

   nErrCode = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_INSTANCE_STATUS_GET,
                  (int) &sInstanceStatus);

   if (nErrCode == DSL_SUCCESS)
   {
      *pFWMsgPollingOnly = sInstanceStatus.data.bFwEventActivation;
   }
   else
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_INSTANCE_STATUS_GET ioctl failed, "
         "error=%d dev=%d!" DSL_CPE_CRLF,
         nErrCode, nDevNum));
   }

   /* on failure print additional debug info */
   if (sInstanceStatus.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "wARNING - DSL_FIO_INSTANCE_STATUS_GET "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sInstanceStatus.accessCtl.nReturn));
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_FwMessagePollingCfgBackup, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}
/*
   This function retrieves current device operator select configuration
   and stores it as backup configuration

   \param pControlContext        Pointer to DSL CPE Control context structure, [I]
   \param nDevNum                Number of device for configuration, [I]
   \param pBackupConfiguration   Pointer to DSL configuration structure, [O]

   \return  Return values are defined within the \ref DSL_Error_t definition
   - DSL_SUCCESS in case of success
   - DSL_ERROR if operation failed
*/

static DSL_Error_t DSL_CPE_OperatorSelectCfgBackup(
   const DSL_CPE_Control_Context_t *pControlContext,
   const DSL_uint32_t nDevNum,
   DSL_Configuration_t *pBackupConfiguration
)
{
   DSL_Error_t nErrCode = DSL_SUCCESS;
   DSL_uint32_t *pOperatorSelect = DSL_NULL;
   DSL_OperatorConfig_t sOperatorConfig = { 0 };

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "IN - DSL_CPE_OperatorSelectCfgBackup, device<%u>" DSL_CPE_CRLF,
      nDevNum));

   pOperatorSelect =
      &(pBackupConfiguration->data.sCommonConfig.nOperatorSelect);

   nErrCode = DSL_CPE_Ioctl(
                  pControlContext->fd[nDevNum],
                  DSL_FIO_OPERATOR_CONFIG_GET,
                  (int) &sOperatorConfig);

   if (nErrCode == DSL_SUCCESS)
   {
      *pOperatorSelect = sOperatorConfig.data.nDslOperator;
   }
   else
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
         "ERROR - DSL_FIO_OPERATOR_CONFIG_GET ioctl failed, "
         "error=%d dev=%d!" DSL_CPE_CRLF,
         nErrCode, nDevNum));
   }

   /* on failure print additional debug info */
   if (sOperatorConfig.accessCtl.nReturn)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN, (DSL_CPE_PREFIX
         "WARNING - DSL_FIO_OPERATOR_CONFIG_GET "
         "access control retCode=%d!" DSL_CPE_CRLF,
         sOperatorConfig.accessCtl.nReturn));
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
      "OUT - DSL_CPE_OperatorSelectCfgBackup, retCode=%d" DSL_CPE_CRLF,
      nErrCode));

   return nErrCode;
}

static DSL_void_t DSL_CPE_ConfigEntryRecognizedListDelete(
   DSL_CPE_ConfigEntryRecognized_t **ppHead)
{
   DSL_CPE_ConfigEntryRecognized_t *pCurrent = *ppHead;
   DSL_CPE_ConfigEntryRecognized_t *pNext = DSL_NULL;

   CONFIG_FREE_LIST;

   *ppHead = DSL_NULL;
   nRecognizedEntriesNum = 0;

   return;
}

static DSL_void_t DSL_CPE_ConfigEntryUnrecognizedListDelete(
   DSL_CPE_ConfigEntryUnrecognized_t **ppHead)
{
   DSL_CPE_ConfigEntryUnrecognized_t *pCurrent = *ppHead;
   DSL_CPE_ConfigEntryUnrecognized_t *pNext = DSL_NULL;

   CONFIG_FREE_LIST;

   *ppHead = DSL_NULL;
   nUnrecognizedEntriesNum = 0;

   return;
}

static DSL_void_t DSL_CPE_ConfigEntryAppliedListDelete(
   DSL_CPE_ConfigEntryApplied_t **ppHead)
{
   DSL_CPE_ConfigEntryApplied_t *pCurrent = *ppHead;
   DSL_CPE_ConfigEntryApplied_t *pNext = DSL_NULL;

   CONFIG_FREE_LIST;

   *ppHead = DSL_NULL;
   nAppliedEntriesNum = 0;

   return;
}

static DSL_void_t DSL_CPE_ConfigStatusDelete(
   DSL_CPE_ConfigStatus_t **ppHead)
{
   DSL_CPE_ConfigStatus_t *pCurrent = *ppHead;
   DSL_CPE_ConfigStatus_t *pNext = DSL_NULL;

   CONFIG_CHANGE_STATUS_READY_FLAG(DSL_FALSE);

   while (pCurrent != DSL_NULL)
   {
      /* remember to free memory for status text! */
      free(pCurrent->pStatus);
      pCurrent->pStatus = DSL_NULL;

      pNext = pCurrent->pNext;
      free(pCurrent);

      pCurrent = pNext;
   }

   *ppHead = DSL_NULL;
   nFinalStatusEntriesNum = 0;

   return;
}

static DSL_Error_t DSL_CPE_ConfigStatusEntryAdd(
   DSL_CPE_ConfigStatus_t **ppHead,
   const DSL_char_t *pStatus)
{
   DSL_Error_t nRet = DSL_SUCCESS;
   size_t nStatusLen = 0;

   DSL_CPE_ConfigStatus_t *pNew = DSL_NULL;
   DSL_CPE_ConfigStatus_t *pEnd = *ppHead;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"IN - DSL_CPE_ConfigStatusEntryAdd" DSL_CPE_CRLF));

   pNew = malloc(sizeof(DSL_CPE_ConfigStatus_t));
   if (pNew)
   {
      cpe_control_memset_s(pNew, sizeof(DSL_CPE_ConfigStatus_t),
         0, sizeof(DSL_CPE_ConfigStatus_t));
   }
   else
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR,
         (DSL_CPE_PREFIX"Memory allocation for entry failed!" DSL_CPE_CRLF));

      return DSL_ERROR;
   }

   nStatusLen = cpe_control_strnlen_s(pStatus, CONFIG_SECTION_PATH_LENGTH);
   pNew->pStatus = malloc(nStatusLen + 1);

   if (pNew->pStatus != DSL_NULL)
   {
      cpe_control_memset_s(pNew->pStatus, nStatusLen + 1, 0, nStatusLen);
      cpe_control_strncpy_s(pNew->pStatus, nStatusLen + 1,
         pStatus, nStatusLen);
   }
   else
   {
      free(pNew);

      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR,
         (DSL_CPE_PREFIX"Memory allocation for status failed!" DSL_CPE_CRLF));

      return DSL_ERROR;
   }

   if (*ppHead == DSL_NULL)
   {
      *ppHead = pNew;
   }
   else
   {
      while (pEnd->pNext != DSL_NULL)
         pEnd = pEnd->pNext;

      pEnd->pNext = pNew;
   }

   ++nFinalStatusEntriesNum;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"OUT - DSL_CPE_ConfigStatusEntryAdd<%d>, "
       "nRet=<%d>" DSL_CPE_CRLF,
       nFinalStatusEntriesNum, nRet));

   return nRet;
}

/**
   Maps recognized parameters to final status list
   based on its appearance and type match.
*/
static DSL_void_t DSL_CPE_ConfigEntryRecognizedMap(
   const DSL_CPE_ConfigEntryRecognized_t *pHead,
   DSL_CPE_ConfigStatus_t **ppFinalStatus,
   DSL_boolean_t *pbIsConfigFallbackNeeded)
{
   const DSL_CPE_ConfigEntryRecognized_t *pCurrent = DSL_NULL;
   DSL_boolean_t bMatch = DSL_FALSE;
   DSL_char_t status[CONFIG_STATUS_LENGTH] = { 0 };

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"IN - DSL_CPE_ConfigEntryRecognizedMap<%d>" DSL_CPE_CRLF,
      nRecognizedEntriesNum));

   for (DSL_size_t i = 0; i < nPatternsNum; ++i)
   {
      pCurrent = pHead;

      while (pCurrent != DSL_NULL)
      {
         bMatch = DSL_FALSE;

         if (pCurrent->eIndex == g_sPatterns[i].eIndex)
         {
            bMatch = DSL_TRUE;
            break;
         }

         pCurrent = pCurrent->pNext;
      }

      if (bMatch == DSL_TRUE)
      {
         /* Found configuration parameter type mismatch */
         if (g_sPatterns[i].eParameterType != pCurrent->eParameterType)
         {
            /* Fallback is not needed when optional parameter has wrong type */
            if (g_sPatterns[i].bMandatory == DSL_TRUE)
            {
               *pbIsConfigFallbackNeeded = DSL_TRUE;
            }

            cpe_control_memset_s(status, CONFIG_STATUS_LENGTH,
               0, CONFIG_STATUS_LENGTH);

            cpe_control_snprintf_s(status, CONFIG_STATUS_LENGTH,
               "%s: Error - Incorrect parameter type: '%s' is <%s> "
               "but should be <%s>",
               g_sConfigurationType[DSL_CPE_CONFIGURATION_TYPE_FILE],
               g_sPatterns[i].pParameterPath,
               g_sJsonType[pCurrent->eParameterType],
               g_sJsonType[g_sPatterns[i].eParameterType]);

            DSL_CPE_ConfigStatusEntryAdd(
               ppFinalStatus,
               status);
         }
      }
      /* Not found matching mandatory configuration parameter */
      else if (g_sPatterns[i].bMandatory == DSL_TRUE)
      {
         *pbIsConfigFallbackNeeded = DSL_TRUE;

         cpe_control_memset_s(status, CONFIG_STATUS_LENGTH,
            0, CONFIG_STATUS_LENGTH);

         cpe_control_snprintf_s(status, CONFIG_STATUS_LENGTH,
            "%s: Error - Missing parameter: '%s'",
            g_sConfigurationType[DSL_CPE_CONFIGURATION_TYPE_FILE],
            g_sPatterns[i].pParameterPath);

         DSL_CPE_ConfigStatusEntryAdd(
            ppFinalStatus,
            status);
      }
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"OUT - DSL_CPE_ConfigEntryRecognizedMap" DSL_CPE_CRLF));

   return;
}

/**
   Maps unrecognized parameters to final status list.
*/
static DSL_void_t DSL_CPE_ConfigEntryUnrecognizedMap(
   const DSL_CPE_ConfigEntryUnrecognized_t *pHead,
   DSL_CPE_ConfigStatus_t **ppFinalStatus)
{
   const DSL_CPE_ConfigEntryUnrecognized_t *pCurrent = pHead;
   DSL_char_t status[CONFIG_STATUS_LENGTH] = { 0 };

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"IN - DSL_CPE_ConfigEntryUnrecognizedMap<%d>" DSL_CPE_CRLF,
      nUnrecognizedEntriesNum));

   while (pCurrent != DSL_NULL)
   {
      cpe_control_memset_s(status, CONFIG_STATUS_LENGTH,
         0, CONFIG_STATUS_LENGTH);

      cpe_control_snprintf_s(status, CONFIG_STATUS_LENGTH,
         "%s: Warning - Unrecognized parameter: '%s'",
         g_sConfigurationType[DSL_CPE_CONFIGURATION_TYPE_FILE],
         pCurrent->path);

      DSL_CPE_ConfigStatusEntryAdd(
         ppFinalStatus,
         status);

      pCurrent = pCurrent->pNext;
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"OUT - DSL_CPE_ConfigEntryUnrecognizedMap" DSL_CPE_CRLF));

   return;
}

/**
   Maps applied (with warnings) or rejected parameters to final status list.
*/
static DSL_void_t DSL_CPE_ConfigEntryAppliedMap(
   const DSL_CPE_ConfigEntryApplied_t *pHead,
   DSL_CPE_ConfigStatus_t **ppFinalStatus)
{
   const DSL_CPE_ConfigEntryApplied_t *pCurrent = pHead;
   DSL_boolean_t bMatch = DSL_FALSE;
   DSL_size_t i = 0;
   DSL_char_t status[CONFIG_STATUS_LENGTH] = { 0 };
   const DSL_char_t sError[] = "Error";
   const DSL_char_t sWarning[] = "Warning";
   const DSL_char_t *pApplyStatus = DSL_NULL;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"IN - DSL_CPE_ConfigEntryAppliedMap<%d>" DSL_CPE_CRLF,
      nAppliedEntriesNum));

   while (pCurrent != DSL_NULL)
   {
      bMatch = DSL_FALSE;

      for (i = 0; i < nPatternsNum; ++i)
      {
         if (pCurrent->eIndex == g_sPatterns[i].eIndex)
         {
            bMatch = DSL_TRUE;
            break;
         }
      }

      if (bMatch == DSL_TRUE)
      {
         if (pCurrent->nApplyRetCode > 0)
         {
            pApplyStatus = sWarning;
         }
         else if (pCurrent->nApplyRetCode < 0)
         {
            pApplyStatus = sError;
         }

         cpe_control_memset_s(status, CONFIG_STATUS_LENGTH,
            0, CONFIG_STATUS_LENGTH);

         if (g_sPatterns[i].eParameterType == json_type_int)
         {
            cpe_control_snprintf_s(status, CONFIG_STATUS_LENGTH,
               "%s: %s #%d when applying '%s' = %d",
               g_sConfigurationType[pCurrent->eConfigType],
               pApplyStatus,
               pCurrent->nApplyRetCode,
               g_sPatterns[i].pParameterPath,
               pCurrent->val.iVal);
         }
         else if (g_sPatterns[i].eParameterType == json_type_string)
         {
            cpe_control_snprintf_s(status, CONFIG_STATUS_LENGTH,
               "%s: %s #%d when applying '%s' = '%s'",
               g_sConfigurationType[pCurrent->eConfigType],
               pApplyStatus,
               pCurrent->nApplyRetCode,
               g_sPatterns[i].pParameterPath,
               pCurrent->val.strVal);
         }
         else if (g_sPatterns[i].eParameterType == json_type_array)
         {
            cpe_control_snprintf_s(status, CONFIG_STATUS_LENGTH,
               "%s: %s #%d when applying '%s' = [%s]",
               g_sConfigurationType[pCurrent->eConfigType],
               pApplyStatus,
               pCurrent->nApplyRetCode,
               g_sPatterns[i].pParameterPath,
               pCurrent->val.strVal);
         }

         DSL_CPE_ConfigStatusEntryAdd(
            ppFinalStatus,
            status);
      }
      /* should not occur! */
      else
      {
         DSL_CCA_DEBUG(DSL_CCA_DBG_ERR,
            (DSL_CPE_PREFIX
            "Unknown configuration parameter index <%d>!" DSL_CPE_CRLF,
            pCurrent->eIndex));
      }

      pCurrent = pCurrent->pNext;
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"OUT - DSL_CPE_ConfigEntryAppliedMap" DSL_CPE_CRLF));

   return;
}

/**
   Central function calling map functions
   and freeing intermediate entries lists.
*/
static DSL_Error_t DSL_CPE_ConfigStatusCollect(
   DSL_CPE_ConfigStatus_t **ppConfigurationStatus,
   DSL_CPE_ConfigEntryRecognized_t **ppRecognizedList,
   DSL_CPE_ConfigEntryUnrecognized_t **ppUnrecognizedList,
   DSL_CPE_ConfigEntryApplied_t **ppAppliedList)
{
   DSL_Error_t nErrCode = DSL_SUCCESS;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"IN - DSL_CPE_ConfigStatusCollect" DSL_CPE_CRLF));

   if (ppUnrecognizedList != DSL_NULL)
   {
      if (*ppUnrecognizedList != DSL_NULL)
      {
         DSL_CPE_ConfigEntryUnrecognizedMap(
            *ppUnrecognizedList,
            ppConfigurationStatus);

         DSL_CPE_ConfigEntryUnrecognizedListDelete(ppUnrecognizedList);
      }
   }

   if (ppRecognizedList != DSL_NULL)
   {
      if (*ppRecognizedList != DSL_NULL)
      {
         DSL_boolean_t bIsFallbackNeeded = DSL_FALSE;

         DSL_CPE_ConfigEntryRecognizedMap(
            *ppRecognizedList,
            ppConfigurationStatus,
            &bIsFallbackNeeded);

         if (bIsFallbackNeeded == DSL_TRUE)
         {
            nErrCode = DSL_ERROR;
         }

         DSL_CPE_ConfigEntryRecognizedListDelete(ppRecognizedList);
      }
   }

   if (ppAppliedList != DSL_NULL)
   {
      if (*ppAppliedList != DSL_NULL)
      {
         DSL_CPE_ConfigEntryAppliedMap(
            *ppAppliedList,
            ppConfigurationStatus);

         DSL_CPE_ConfigEntryAppliedListDelete(ppAppliedList);
      }
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"OUT - DSL_CPE_ConfigStatusCollect, "
       "nErrCode=<%d>" DSL_CPE_CRLF,
       nErrCode));

   return nErrCode;
}

static DSL_Error_t DSL_CPE_ConfigEntryUnrecognizedAdd(
   DSL_CPE_ConfigEntryUnrecognized_t **ppHead,
   const DSL_char_t *pParameterPath)
{
   DSL_Error_t nRet = DSL_SUCCESS;

   DSL_CPE_ConfigEntryUnrecognized_t *pNew = DSL_NULL;
   DSL_CPE_ConfigEntryUnrecognized_t *pEnd = *ppHead;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"IN - DSL_CPE_ConfigEntryUnrecognizedAdd" DSL_CPE_CRLF));

   if (nUnrecognizedEntriesNum >= nUnrecognizedEntriesLimit)
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_WRN,
         (DSL_CPE_PREFIX"Too many (max=%d) "
          "unrecognized parameters!" DSL_CPE_CRLF,
          nUnrecognizedEntriesLimit));

      return DSL_ERROR;
   }

   pNew = malloc(sizeof(DSL_CPE_ConfigEntryUnrecognized_t));

   if (pNew)
   {
      cpe_control_memset_s(pNew, sizeof(DSL_CPE_ConfigEntryUnrecognized_t),
         0, sizeof(DSL_CPE_ConfigEntryUnrecognized_t));
   }
   else
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR,
         (DSL_CPE_PREFIX"Memory allocation failed!" DSL_CPE_CRLF));

      return DSL_ERROR;
   }

   cpe_control_strncpy_s(pNew->path, CONFIG_SECTION_PATH_LENGTH,
      pParameterPath, CONFIG_SECTION_PATH_LENGTH);

   pNew->pNext = DSL_NULL;

   if (*ppHead == DSL_NULL)
   {
      *ppHead = pNew;
   }
   else
   {
      while (pEnd->pNext != DSL_NULL)
         pEnd = pEnd->pNext;

      pEnd->pNext = pNew;
   }

   ++nUnrecognizedEntriesNum;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"OUT - DSL_CPE_ConfigEntryUnrecognizedAdd<%d>, "
       "nRet=<%d>." DSL_CPE_CRLF,
       nUnrecognizedEntriesNum, nRet));

   return nRet;
}

static DSL_Error_t DSL_CPE_ConfigEntryRecognizedAdd(
   DSL_CPE_ConfigEntryRecognized_t **ppHead,
   const DSL_char_t *pParameterPath,
   const json_type eParameterType)
{
   DSL_Error_t nRet = DSL_SUCCESS;

   DSL_CPE_ConfigEntryRecognized_t *pNew = DSL_NULL;
   DSL_CPE_ConfigEntryRecognized_t *pEnd = *ppHead;

   DSL_size_t i = 0;
   DSL_boolean_t bMatch = DSL_FALSE;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"IN - DSL_CPE_ConfigEntryRecognizedAdd" DSL_CPE_CRLF));

   pNew = malloc(sizeof(DSL_CPE_ConfigEntryRecognized_t));
   if (pNew)
   {
      cpe_control_memset_s(pNew, sizeof(DSL_CPE_ConfigEntryRecognized_t),
         0, sizeof(DSL_CPE_ConfigEntryRecognized_t));
   }
   else
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR,
         (DSL_CPE_PREFIX"Memory allocation failed!" DSL_CPE_CRLF));

      return DSL_ERROR;
   }

   /* Matches input path to patterns */
   for (i = 0; i < nPatternsNum; ++i)
   {
      if (strstr(g_sPatterns[i].pParameterPath, pParameterPath) != DSL_NULL)
      {
         bMatch = DSL_TRUE;
         break;
      }
   }

   /* store recognized pattern */
   if (bMatch == DSL_TRUE)
   {
      pNew->eIndex = g_sPatterns[i].eIndex;
      pNew->eParameterType = eParameterType;
      pNew->pNext = DSL_NULL;

      if (*ppHead == DSL_NULL)
      {
         *ppHead = pNew;
      }
      else
      {
         while (pEnd->pNext != DSL_NULL)
            pEnd = pEnd->pNext;

         pEnd->pNext = pNew;
      }

      ++nRecognizedEntriesNum;
   }
   /* inform caller about unrecognized pattern */
   else
   {
      nRet = DSL_ERROR;
   }

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"OUT - DSL_CPE_ConfigEntryRecognizedAdd<%d>, "
       "nRet=<%d>." DSL_CPE_CRLF,
       nRecognizedEntriesNum, nRet));

   return nRet;
}

static DSL_Error_t DSL_CPE_ConfigEntryAppliedAdd(
   DSL_CPE_ConfigEntryApplied_t **ppHead,
   const DSL_CPE_ConfigurationType_e eConfigType,
   const DSL_CPE_ConfigEntryIndex_e eIndex,
   const DSL_CPE_ConfigEntryAppliedValueType_u val,
   const DSL_uint32_t nApplyRetCode)
{
   DSL_Error_t nRet = DSL_SUCCESS;

   DSL_CPE_ConfigEntryApplied_t *pNew = DSL_NULL;
   DSL_CPE_ConfigEntryApplied_t *pEnd = *ppHead;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"IN - DSL_CPE_ConfigEntryAppliedAdd" DSL_CPE_CRLF));

   pNew = malloc(sizeof(DSL_CPE_ConfigEntryApplied_t));
   if (pNew)
   {
      cpe_control_memset_s(pNew, sizeof(DSL_CPE_ConfigEntryApplied_t),
         0, sizeof(DSL_CPE_ConfigEntryApplied_t));
   }
   else
   {
      DSL_CCA_DEBUG(DSL_CCA_DBG_ERR,
         (DSL_CPE_PREFIX"Memory allocation failed!" DSL_CPE_CRLF));

      return DSL_ERROR;
   }

   pNew->eConfigType = eConfigType;
   pNew->eIndex = eIndex;
   pNew->val = val;
   pNew->nApplyRetCode = nApplyRetCode;
   pNew->pNext = DSL_NULL;

   if (*ppHead == DSL_NULL)
   {
      *ppHead = pNew;
   }
   else
   {
      while (pEnd->pNext != DSL_NULL)
         pEnd = pEnd->pNext;

      pEnd->pNext = pNew;
   }

   ++nAppliedEntriesNum;

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"OUT - DSL_CPE_ConfigEntryAppliedAdd<%d>, "
       "nRet=<%d>." DSL_CPE_CRLF,
       nAppliedEntriesNum, nRet));

   return nRet;
}

/**
   Central function to classify configuration parameter
   (parsed from file).
*/
static DSL_void_t DSL_CPE_ConfigInputValidate(
   const DSL_char_t *pParameterPath,
   const json_type eParameterType)
{
   DSL_Error_t nRet = DSL_SUCCESS;

   /* At firs: try to recognize param */
   nRet = DSL_CPE_ConfigEntryRecognizedAdd(
      &g_pRecognizedEntriesList,
      pParameterPath,
      eParameterType);

   if (nRet == DSL_ERROR)
   {
      /* At second: handle it as unrecognized */
      (DSL_void_t) DSL_CPE_ConfigEntryUnrecognizedAdd(
         &g_pUnrecognizedEntriesList,
         pParameterPath);
   }

   return;
}

/**
   Sum up configuration process status
   and set ready flag.
*/
static DSL_void_t DSL_CPE_ConfigStatusRelease(
   const DSL_Configuration_t *pConfiguration,
   DSL_Error_t nConfigRetCode)
{
   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"IN - DSL_CPE_ConfigStatusRelease" DSL_CPE_CRLF));

   if (pConfiguration != DSL_NULL)
   {
      /* final configuration status statement */
      DSL_char_t status[CONFIG_STATUS_LENGTH] = { 0 };

      cpe_control_snprintf_s(status, CONFIG_STATUS_LENGTH,
         "%s: Configuration %s",
         g_sConfigurationType[pConfiguration->type],
         (nConfigRetCode == DSL_SUCCESS ? "succeed." : "failed!"));

      DSL_CPE_ConfigStatusEntryAdd(
         &g_pFinalStatusEntriesList,
         status);
   }

   CONFIG_CHANGE_STATUS_READY_FLAG(DSL_TRUE);

   DSL_CCA_DEBUG(DSL_CCA_DBG_MSG,
      (DSL_CPE_PREFIX"OUT - DSL_CPE_ConfigStatusRelease" DSL_CPE_CRLF));

   return;
}

#endif /* defined(INCLUDE_DSL_JSON_PARSING) && (INCLUDE_DSL_JSON_PARSING == 1) */
